
# -*- coding: utf-8 -*-
"""
DO NOT EDIT THIS FILE!
It is automatically generated from opcfoundation.org schemas.
"""

from opcua import ua


def create_standard_address_space_Part5(server):
  
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=51")
    node.BrowseName = ua.QualifiedName.from_string("FromState")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=32")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for a reference to the state before a transition.")
    attrs.DisplayName = ua.LocalizedText("FromState")
    attrs.InverseName = ua.LocalizedText("ToTransition")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=51")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=32")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=52")
    node.BrowseName = ua.QualifiedName.from_string("ToState")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=32")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for a reference to the state after a transition.")
    attrs.DisplayName = ua.LocalizedText("ToState")
    attrs.InverseName = ua.LocalizedText("FromTransition")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=52")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=32")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=53")
    node.BrowseName = ua.QualifiedName.from_string("HasCause")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=32")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for a reference to a method that can cause a transition to occur.")
    attrs.DisplayName = ua.LocalizedText("HasCause")
    attrs.InverseName = ua.LocalizedText("MayBeCausedBy")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=53")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=32")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=54")
    node.BrowseName = ua.QualifiedName.from_string("HasEffect")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=32")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for a reference to an event that may be raised when a transition occurs.")
    attrs.DisplayName = ua.LocalizedText("HasEffect")
    attrs.InverseName = ua.LocalizedText("MayBeEffectedBy")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=54")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=32")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=117")
    node.BrowseName = ua.QualifiedName.from_string("HasSubStateMachine")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=32")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for a reference to a substate for a state.")
    attrs.DisplayName = ua.LocalizedText("HasSubStateMachine")
    attrs.InverseName = ua.LocalizedText("SubStateMachineOf")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=117")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=32")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=58")
    node.BrowseName = ua.QualifiedName.from_string("BaseObjectType")
    node.NodeClass = ua.NodeClass.ObjectType
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("The base type for all object nodes.")
    attrs.DisplayName = ua.LocalizedText("BaseObjectType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=61")
    node.BrowseName = ua.QualifiedName.from_string("FolderType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for objects that organize other nodes.")
    attrs.DisplayName = ua.LocalizedText("FolderType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=61")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=62")
    node.BrowseName = ua.QualifiedName.from_string("BaseVariableType")
    node.NodeClass = ua.NodeClass.VariableType
    attrs = ua.VariableTypeAttributes()
    attrs.Description = ua.LocalizedText("The abstract base type for all variable nodes.")
    attrs.DisplayName = ua.LocalizedText("BaseVariableType")
    attrs.IsAbstract = True
    attrs.Description = ua.LocalizedText("The abstract base type for all variable nodes.")
    attrs.DisplayName = ua.LocalizedText("BaseVariableType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=63")
    node.BrowseName = ua.QualifiedName.from_string("BaseDataVariableType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=62")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for variable that represents a process value.")
    attrs.DisplayName = ua.LocalizedText("BaseDataVariableType")
    attrs.Description = ua.LocalizedText("The type for variable that represents a process value.")
    attrs.DisplayName = ua.LocalizedText("BaseDataVariableType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=63")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=62")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=68")
    node.BrowseName = ua.QualifiedName.from_string("PropertyType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=62")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for variable that represents a property of another node.")
    attrs.DisplayName = ua.LocalizedText("PropertyType")
    attrs.Description = ua.LocalizedText("The type for variable that represents a property of another node.")
    attrs.DisplayName = ua.LocalizedText("PropertyType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=68")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=62")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=69")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeDescriptionType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for variable that represents the description of a data type encoding.")
    attrs.DisplayName = ua.LocalizedText("DataTypeDescriptionType")
    attrs.Description = ua.LocalizedText("The type for variable that represents the description of a data type encoding.")
    attrs.DisplayName = ua.LocalizedText("DataTypeDescriptionType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=69")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=104")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=69")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=105")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=69")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=104")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeVersion")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=69")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The version number for the data type description.")
    attrs.DisplayName = ua.LocalizedText("DataTypeVersion")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=105")
    node.BrowseName = ua.QualifiedName.from_string("DictionaryFragment")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=69")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A fragment of a data type dictionary that defines the data type.")
    attrs.DisplayName = ua.LocalizedText("DictionaryFragment")
    attrs.DataType = ua.NodeId(ua.ObjectIds.ByteString)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=105")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=105")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=105")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=72")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeDictionaryType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for variable that represents the collection of data type decriptions.")
    attrs.DisplayName = ua.LocalizedText("DataTypeDictionaryType")
    attrs.Description = ua.LocalizedText("The type for variable that represents the collection of data type decriptions.")
    attrs.DisplayName = ua.LocalizedText("DataTypeDictionaryType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.ByteString)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=72")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=106")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=72")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=107")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=72")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15001")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=72")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=106")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeVersion")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=72")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The version number for the data type dictionary.")
    attrs.DisplayName = ua.LocalizedText("DataTypeVersion")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=106")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=106")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=106")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=72")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=107")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=72")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A URI that uniquely identifies the dictionary.")
    attrs.DisplayName = ua.LocalizedText("NamespaceUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=107")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=107")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=107")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=72")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15001")
    node.BrowseName = ua.QualifiedName.from_string("Deprecated")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=72")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Indicates that all of the definitions for the dictionary are available through a DataTypeDefinition Attribute.")
    attrs.DisplayName = ua.LocalizedText("Deprecated")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15001")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15001")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15001")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=72")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=75")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeSystemType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("DataTypeSystemType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=75")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=76")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeEncodingType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("DataTypeEncodingType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=76")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=77")
    node.BrowseName = ua.QualifiedName.from_string("ModellingRuleType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for an object that describes how an instance declaration is used when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("ModellingRuleType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=77")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=111")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=77")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=111")
    node.BrowseName = ua.QualifiedName.from_string("NamingRule")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=77")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Specified the significances of the BrowseName when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("NamingRule")
    attrs.DataType = ua.NodeId.from_string("i=120")
    attrs.Value = ua.Variant(1, ua.VariantType.Int32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=111")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=111")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=111")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=77")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=78")
    node.BrowseName = ua.QualifiedName.from_string("Mandatory")
    node.NodeClass = ua.NodeClass.Object
    node.TypeDefinition = ua.NodeId.from_string("i=77")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Specifies that an instance with the attributes and references of the instance declaration must appear when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("Mandatory")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=78")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=112")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=78")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=77")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=112")
    node.BrowseName = ua.QualifiedName.from_string("NamingRule")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=78")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Specified the significances of the BrowseName when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("NamingRule")
    attrs.DataType = ua.NodeId.from_string("i=120")
    attrs.Value = ua.Variant(1, ua.VariantType.Int32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=112")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=112")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=80")
    node.BrowseName = ua.QualifiedName.from_string("Optional")
    node.NodeClass = ua.NodeClass.Object
    node.TypeDefinition = ua.NodeId.from_string("i=77")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Specifies that an instance with the attributes and references of the instance declaration may appear when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("Optional")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=80")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=113")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=80")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=77")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=113")
    node.BrowseName = ua.QualifiedName.from_string("NamingRule")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=80")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Specified the significances of the BrowseName when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("NamingRule")
    attrs.DataType = ua.NodeId.from_string("i=120")
    attrs.Value = ua.Variant(2, ua.VariantType.Int32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=113")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=113")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=83")
    node.BrowseName = ua.QualifiedName.from_string("ExposesItsArray")
    node.NodeClass = ua.NodeClass.Object
    node.TypeDefinition = ua.NodeId.from_string("i=77")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Specifies that an instance appears for each element of the containing array variable.")
    attrs.DisplayName = ua.LocalizedText("ExposesItsArray")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=83")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=114")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=83")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=77")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=114")
    node.BrowseName = ua.QualifiedName.from_string("NamingRule")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=83")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Specified the significances of the BrowseName when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("NamingRule")
    attrs.DataType = ua.NodeId.from_string("i=120")
    attrs.Value = ua.Variant(3, ua.VariantType.Int32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=114")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=114")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=83")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=79")
    node.BrowseName = ua.QualifiedName.from_string("MandatoryShared")
    node.NodeClass = ua.NodeClass.Object
    node.TypeDefinition = ua.NodeId.from_string("i=77")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Specifies that a reference to a shared instance must appear in when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("MandatoryShared")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=79")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=116")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=79")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=77")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=116")
    node.BrowseName = ua.QualifiedName.from_string("NamingRule")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=79")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Specified the significances of the BrowseName when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("NamingRule")
    attrs.DataType = ua.NodeId.from_string("i=120")
    attrs.Value = ua.Variant(1, ua.VariantType.Int32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=116")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=116")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=79")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11508")
    node.BrowseName = ua.QualifiedName.from_string("OptionalPlaceholder")
    node.NodeClass = ua.NodeClass.Object
    node.TypeDefinition = ua.NodeId.from_string("i=77")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Specifies that zero or more instances with the attributes and references of the instance declaration may appear when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("OptionalPlaceholder")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11508")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11509")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11508")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=77")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11509")
    node.BrowseName = ua.QualifiedName.from_string("NamingRule")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11508")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Specified the significances of the BrowseName when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("NamingRule")
    attrs.DataType = ua.NodeId.from_string("i=120")
    attrs.Value = ua.Variant(2, ua.VariantType.Int32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11509")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11509")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11508")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11510")
    node.BrowseName = ua.QualifiedName.from_string("MandatoryPlaceholder")
    node.NodeClass = ua.NodeClass.Object
    node.TypeDefinition = ua.NodeId.from_string("i=77")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Specifies that one or more instances with the attributes and references of the instance declaration must appear when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("MandatoryPlaceholder")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11510")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11511")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11510")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=77")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11511")
    node.BrowseName = ua.QualifiedName.from_string("NamingRule")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11510")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Specified the significances of the BrowseName when a type is instantiated.")
    attrs.DisplayName = ua.LocalizedText("NamingRule")
    attrs.DataType = ua.NodeId.from_string("i=120")
    attrs.Value = ua.Variant(1, ua.VariantType.Int32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11511")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11511")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11510")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=84")
    node.BrowseName = ua.QualifiedName.from_string("Root")
    node.NodeClass = ua.NodeClass.Object
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The root of the server address space.")
    attrs.DisplayName = ua.LocalizedText("Root")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=84")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=85")
    node.BrowseName = ua.QualifiedName.from_string("Objects")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=84")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The browse entry point when looking for objects in the server address space.")
    attrs.DisplayName = ua.LocalizedText("Objects")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=85")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=84")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=85")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=86")
    node.BrowseName = ua.QualifiedName.from_string("Types")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=84")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The browse entry point when looking for types in the server address space.")
    attrs.DisplayName = ua.LocalizedText("Types")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=86")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=84")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=86")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=87")
    node.BrowseName = ua.QualifiedName.from_string("Views")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=84")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The browse entry point when looking for views in the server address space.")
    attrs.DisplayName = ua.LocalizedText("Views")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=87")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=84")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=87")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=88")
    node.BrowseName = ua.QualifiedName.from_string("ObjectTypes")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=86")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The browse entry point when looking for object types in the server address space.")
    attrs.DisplayName = ua.LocalizedText("ObjectTypes")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=88")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=86")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=88")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=88")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=89")
    node.BrowseName = ua.QualifiedName.from_string("VariableTypes")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=86")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The browse entry point when looking for variable types in the server address space.")
    attrs.DisplayName = ua.LocalizedText("VariableTypes")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=89")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=86")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=89")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=62")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=89")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=90")
    node.BrowseName = ua.QualifiedName.from_string("DataTypes")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=86")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The browse entry point when looking for data types in the server address space.")
    attrs.DisplayName = ua.LocalizedText("DataTypes")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=90")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=86")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=90")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=90")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=91")
    node.BrowseName = ua.QualifiedName.from_string("ReferenceTypes")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=86")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The browse entry point when looking for reference types in the server address space.")
    attrs.DisplayName = ua.LocalizedText("ReferenceTypes")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=91")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=86")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=91")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=31")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=91")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=92")
    node.BrowseName = ua.QualifiedName.from_string("XML Schema")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=90")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=75")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("A type system which uses XML schema to describe the encoding of data types.")
    attrs.DisplayName = ua.LocalizedText("XML Schema")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=92")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=90")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=92")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=75")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=93")
    node.BrowseName = ua.QualifiedName.from_string("OPC Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=90")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=75")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("A type system which uses OPC binary schema to describe the encoding of data types.")
    attrs.DisplayName = ua.LocalizedText("OPC Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=93")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=90")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=93")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=75")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15957")
    node.BrowseName = ua.QualifiedName.from_string("0:http://opcfoundation.org/UA/")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=11715")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=11616")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("http://opcfoundation.org/UA/")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15958")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15959")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15960")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15961")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15962")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15963")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15964")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16134")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16135")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16136")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=15957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11715")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15958")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15957")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The URI of the namespace.")
    attrs.DisplayName = ua.LocalizedText("NamespaceUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('http://opcfoundation.org/UA/', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15958")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15958")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15957")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15959")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceVersion")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15957")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The human readable string representing version of the namespace.")
    attrs.DisplayName = ua.LocalizedText("NamespaceVersion")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('1.04', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15959")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15959")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15957")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15960")
    node.BrowseName = ua.QualifiedName.from_string("NamespacePublicationDate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15957")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The publication date for the namespace.")
    attrs.DisplayName = ua.LocalizedText("NamespacePublicationDate")
    attrs.DataType = ua.NodeId(ua.ObjectIds.DateTime)
    attrs.Value = ua.Variant('2017-11-22', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15960")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15960")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15957")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15961")
    node.BrowseName = ua.QualifiedName.from_string("IsNamespaceSubset")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15957")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("If TRUE then the server only supports a subset of the namespace.")
    attrs.DisplayName = ua.LocalizedText("IsNamespaceSubset")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.Value = ua.Variant(False, ua.VariantType.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15961")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15961")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15957")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15962")
    node.BrowseName = ua.QualifiedName.from_string("StaticNodeIdTypes")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15957")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of IdTypes for nodes which are the same in every server that exposes them.")
    attrs.DisplayName = ua.LocalizedText("StaticNodeIdTypes")
    attrs.DataType = ua.NodeId.from_string("i=256")
    attrs.Value = ua.Variant([0], ua.VariantType.Int32)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15962")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15962")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15957")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15963")
    node.BrowseName = ua.QualifiedName.from_string("StaticNumericNodeIdRange")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15957")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of ranges for numeric node ids which are the same in every server that exposes them.")
    attrs.DisplayName = ua.LocalizedText("StaticNumericNodeIdRange")
    attrs.DataType = ua.NodeId.from_string("i=291")
    attrs.Value = ua.Variant(['1:65535'], ua.VariantType.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15963")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15963")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15957")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15964")
    node.BrowseName = ua.QualifiedName.from_string("StaticStringNodeIdPattern")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15957")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A regular expression which matches string node ids are the same in every server that exposes them.")
    attrs.DisplayName = ua.LocalizedText("StaticStringNodeIdPattern")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('\n      ', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15964")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15964")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15957")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16134")
    node.BrowseName = ua.QualifiedName.from_string("DefaultRolePermissions")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15957")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DefaultRolePermissions")
    attrs.DataType = ua.NodeId.from_string("i=96")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16134")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16134")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15957")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16135")
    node.BrowseName = ua.QualifiedName.from_string("DefaultUserRolePermissions")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15957")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DefaultUserRolePermissions")
    attrs.DataType = ua.NodeId.from_string("i=96")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16135")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16135")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15957")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16136")
    node.BrowseName = ua.QualifiedName.from_string("DefaultAccessRestrictions")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15957")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DefaultAccessRestrictions")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16136")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16136")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15957")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2004")
    node.BrowseName = ua.QualifiedName.from_string("ServerType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("Specifies the current status and capabilities of the server.")
    attrs.DisplayName = ua.LocalizedText("ServerType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2005")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2006")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15003")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2007")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2008")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2742")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12882")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17612")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2009")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2010")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2011")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2012")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11527")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11489")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12871")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12746")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12883")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2005")
    node.BrowseName = ua.QualifiedName.from_string("ServerArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("The list of server URIs used by the server.")
    attrs.DisplayName = ua.LocalizedText("ServerArray")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2005")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2005")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2005")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2006")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("The list of namespace URIs used by the server.")
    attrs.DisplayName = ua.LocalizedText("NamespaceArray")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2006")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2006")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2006")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15003")
    node.BrowseName = ua.QualifiedName.from_string("UrisVersion")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("Defines the version of the ServerArray and the NamespaceArray.")
    attrs.DisplayName = ua.LocalizedText("UrisVersion")
    attrs.DataType = ua.NodeId.from_string("i=20998")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15003")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15003")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15003")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2007")
    node.BrowseName = ua.QualifiedName.from_string("ServerStatus")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2138")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("The current status of the server.")
    attrs.DisplayName = ua.LocalizedText("ServerStatus")
    attrs.DataType = ua.NodeId.from_string("i=862")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2007")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3074")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2007")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3075")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2007")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3076")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2007")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3077")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2007")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3084")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2007")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3085")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2007")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2138")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2007")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2007")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3074")
    node.BrowseName = ua.QualifiedName.from_string("StartTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2007")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StartTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3074")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3074")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3074")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2007")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3075")
    node.BrowseName = ua.QualifiedName.from_string("CurrentTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2007")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3075")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3075")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3075")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2007")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3076")
    node.BrowseName = ua.QualifiedName.from_string("State")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2007")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("State")
    attrs.DataType = ua.NodeId.from_string("i=852")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3076")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3076")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3076")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2007")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3077")
    node.BrowseName = ua.QualifiedName.from_string("BuildInfo")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2007")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=3051")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BuildInfo")
    attrs.DataType = ua.NodeId.from_string("i=338")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3078")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3079")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3080")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3081")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3082")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3083")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3051")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2007")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3078")
    node.BrowseName = ua.QualifiedName.from_string("ProductUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3077")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("ProductUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3078")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3078")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3078")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3077")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3079")
    node.BrowseName = ua.QualifiedName.from_string("ManufacturerName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3077")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("ManufacturerName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3079")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3079")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3079")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3077")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3080")
    node.BrowseName = ua.QualifiedName.from_string("ProductName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3077")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("ProductName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3080")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3080")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3080")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3077")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3081")
    node.BrowseName = ua.QualifiedName.from_string("SoftwareVersion")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3077")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("SoftwareVersion")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3081")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3081")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3081")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3077")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3082")
    node.BrowseName = ua.QualifiedName.from_string("BuildNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3077")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("BuildNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3082")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3082")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3082")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3077")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3083")
    node.BrowseName = ua.QualifiedName.from_string("BuildDate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3077")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("BuildDate")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3083")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3083")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3083")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3077")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3084")
    node.BrowseName = ua.QualifiedName.from_string("SecondsTillShutdown")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2007")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecondsTillShutdown")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3084")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3084")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3084")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2007")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3085")
    node.BrowseName = ua.QualifiedName.from_string("ShutdownReason")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2007")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ShutdownReason")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3085")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3085")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3085")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2007")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2008")
    node.BrowseName = ua.QualifiedName.from_string("ServiceLevel")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("A value indicating the level of service the server can provide. 255 indicates the best.")
    attrs.DisplayName = ua.LocalizedText("ServiceLevel")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Byte)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2008")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2008")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2008")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2742")
    node.BrowseName = ua.QualifiedName.from_string("Auditing")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("A flag indicating whether the server is currently generating audit events.")
    attrs.DisplayName = ua.LocalizedText("Auditing")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2742")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2742")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2742")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12882")
    node.BrowseName = ua.QualifiedName.from_string("EstimatedReturnTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("Indicates the time at which the Server is expected to be available in the state RUNNING.")
    attrs.DisplayName = ua.LocalizedText("EstimatedReturnTime")
    attrs.DataType = ua.NodeId(ua.ObjectIds.DateTime)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12882")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12882")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12882")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17612")
    node.BrowseName = ua.QualifiedName.from_string("LocalTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("Indicates the time zone the Server is is  running in.")
    attrs.DisplayName = ua.LocalizedText("LocalTime")
    attrs.DataType = ua.NodeId.from_string("i=8912")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=17612")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=17612")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=17612")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2009")
    node.BrowseName = ua.QualifiedName.from_string("ServerCapabilities")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2013")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Describes capabilities supported by the server.")
    attrs.DisplayName = ua.LocalizedText("ServerCapabilities")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2009")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3086")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2009")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3087")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2009")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3088")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2009")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3089")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2009")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3090")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2009")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3091")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2009")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3092")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2009")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3093")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2009")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3094")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2009")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2009")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2009")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3086")
    node.BrowseName = ua.QualifiedName.from_string("ServerProfileArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2009")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of profiles supported by the server.")
    attrs.DisplayName = ua.LocalizedText("ServerProfileArray")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3086")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3086")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3086")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2009")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3087")
    node.BrowseName = ua.QualifiedName.from_string("LocaleIdArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2009")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of locales supported by the server.")
    attrs.DisplayName = ua.LocalizedText("LocaleIdArray")
    attrs.DataType = ua.NodeId.from_string("i=295")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3087")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3087")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3087")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2009")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3088")
    node.BrowseName = ua.QualifiedName.from_string("MinSupportedSampleRate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2009")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The minimum sampling interval supported by the server.")
    attrs.DisplayName = ua.LocalizedText("MinSupportedSampleRate")
    attrs.DataType = ua.NodeId.from_string("i=290")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3088")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3088")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3088")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2009")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3089")
    node.BrowseName = ua.QualifiedName.from_string("MaxBrowseContinuationPoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2009")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of continuation points for Browse operations per session.")
    attrs.DisplayName = ua.LocalizedText("MaxBrowseContinuationPoints")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3089")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3089")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3089")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2009")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3090")
    node.BrowseName = ua.QualifiedName.from_string("MaxQueryContinuationPoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2009")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of continuation points for Query operations per session.")
    attrs.DisplayName = ua.LocalizedText("MaxQueryContinuationPoints")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3090")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3090")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3090")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2009")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3091")
    node.BrowseName = ua.QualifiedName.from_string("MaxHistoryContinuationPoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2009")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of continuation points for ReadHistory operations per session.")
    attrs.DisplayName = ua.LocalizedText("MaxHistoryContinuationPoints")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3091")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3091")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3091")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2009")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3092")
    node.BrowseName = ua.QualifiedName.from_string("SoftwareCertificates")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2009")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The software certificates owned by the server.")
    attrs.DisplayName = ua.LocalizedText("SoftwareCertificates")
    attrs.DataType = ua.NodeId.from_string("i=344")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3092")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3092")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3092")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2009")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3093")
    node.BrowseName = ua.QualifiedName.from_string("ModellingRules")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2009")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("A folder for the modelling rules supported by the server.")
    attrs.DisplayName = ua.LocalizedText("ModellingRules")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3093")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3093")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3093")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2009")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3094")
    node.BrowseName = ua.QualifiedName.from_string("AggregateFunctions")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2009")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("A folder for the real time aggregates supported by the server.")
    attrs.DisplayName = ua.LocalizedText("AggregateFunctions")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3094")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3094")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3094")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2009")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2010")
    node.BrowseName = ua.QualifiedName.from_string("ServerDiagnostics")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2020")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Reports diagnostics about the server.")
    attrs.DisplayName = ua.LocalizedText("ServerDiagnostics")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2010")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2010")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3110")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2010")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3111")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2010")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3114")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2010")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2020")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2010")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2010")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3095")
    node.BrowseName = ua.QualifiedName.from_string("ServerDiagnosticsSummary")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2010")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2150")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A summary of server level diagnostics.")
    attrs.DisplayName = ua.LocalizedText("ServerDiagnosticsSummary")
    attrs.DataType = ua.NodeId.from_string("i=859")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3096")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3097")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3098")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3099")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3100")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3101")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3102")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3104")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3105")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3106")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3107")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3108")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2010")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3096")
    node.BrowseName = ua.QualifiedName.from_string("ServerViewCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerViewCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3096")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3096")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3096")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3097")
    node.BrowseName = ua.QualifiedName.from_string("CurrentSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3097")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3097")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3097")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3098")
    node.BrowseName = ua.QualifiedName.from_string("CumulatedSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CumulatedSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3099")
    node.BrowseName = ua.QualifiedName.from_string("SecurityRejectedSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityRejectedSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3099")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3099")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3099")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3100")
    node.BrowseName = ua.QualifiedName.from_string("RejectedSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RejectedSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3100")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3100")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3100")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3101")
    node.BrowseName = ua.QualifiedName.from_string("SessionTimeoutCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionTimeoutCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3101")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3101")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3101")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3102")
    node.BrowseName = ua.QualifiedName.from_string("SessionAbortCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionAbortCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3102")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3102")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3102")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3104")
    node.BrowseName = ua.QualifiedName.from_string("PublishingIntervalCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishingIntervalCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3105")
    node.BrowseName = ua.QualifiedName.from_string("CurrentSubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentSubscriptionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3105")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3105")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3105")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3106")
    node.BrowseName = ua.QualifiedName.from_string("CumulatedSubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CumulatedSubscriptionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3106")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3106")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3106")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3107")
    node.BrowseName = ua.QualifiedName.from_string("SecurityRejectedRequestsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityRejectedRequestsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3107")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3107")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3107")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3108")
    node.BrowseName = ua.QualifiedName.from_string("RejectedRequestsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RejectedRequestsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3108")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3108")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3108")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3110")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2010")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2171")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of diagnostics for each active subscription.")
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=874")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3110")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2171")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3110")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3110")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2010")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3111")
    node.BrowseName = ua.QualifiedName.from_string("SessionsDiagnosticsSummary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2010")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2026")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("A summary of session level diagnostics.")
    attrs.DisplayName = ua.LocalizedText("SessionsDiagnosticsSummary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3111")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3112")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3111")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3113")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3111")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2026")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3111")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3111")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2010")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3112")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3111")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2196")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of diagnostics for each active session.")
    attrs.DisplayName = ua.LocalizedText("SessionDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=865")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3112")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2196")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3112")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3112")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3111")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3113")
    node.BrowseName = ua.QualifiedName.from_string("SessionSecurityDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3111")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2243")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of security related diagnostics for each active session.")
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=868")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3113")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2243")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3113")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3113")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3111")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3114")
    node.BrowseName = ua.QualifiedName.from_string("EnabledFlag")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2010")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("If TRUE the diagnostics collection is enabled.")
    attrs.DisplayName = ua.LocalizedText("EnabledFlag")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    attrs.AccessLevel = 3
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3114")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3114")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3114")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2010")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2011")
    node.BrowseName = ua.QualifiedName.from_string("VendorServerInfo")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2033")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Server information provided by the vendor.")
    attrs.DisplayName = ua.LocalizedText("VendorServerInfo")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2011")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2033")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2011")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2011")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2012")
    node.BrowseName = ua.QualifiedName.from_string("ServerRedundancy")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2034")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Describes the redundancy capabilities of the server.")
    attrs.DisplayName = ua.LocalizedText("ServerRedundancy")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2012")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3115")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2012")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2034")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2012")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2012")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3115")
    node.BrowseName = ua.QualifiedName.from_string("RedundancySupport")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2012")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Indicates what style of redundancy is supported by the server.")
    attrs.DisplayName = ua.LocalizedText("RedundancySupport")
    attrs.DataType = ua.NodeId.from_string("i=851")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3115")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3115")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3115")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2012")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11527")
    node.BrowseName = ua.QualifiedName.from_string("Namespaces")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=11645")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Describes the namespaces supported by the server.")
    attrs.DisplayName = ua.LocalizedText("Namespaces")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11527")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11645")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11527")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11527")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11489")
    node.BrowseName = ua.QualifiedName.from_string("GetMonitoredItems")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("GetMonitoredItems")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11489")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11490")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11489")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11491")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11489")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11489")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11490")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11489")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'SubscriptionId'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11490")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11490")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11490")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11489")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11491")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11489")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'ServerHandles'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = 1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'ClientHandles'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = 1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11491")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11491")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11491")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11489")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12871")
    node.BrowseName = ua.QualifiedName.from_string("ResendData")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("ResendData")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12871")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12872")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12871")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12871")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12872")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12871")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'SubscriptionId'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12872")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12872")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12872")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12871")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12746")
    node.BrowseName = ua.QualifiedName.from_string("SetSubscriptionDurable")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("SetSubscriptionDurable")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12747")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12748")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12747")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12746")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'SubscriptionId'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'LifetimeInHours'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12747")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12747")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12747")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12746")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12748")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12746")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RevisedLifetimeInHours'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12748")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12748")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12748")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12746")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12883")
    node.BrowseName = ua.QualifiedName.from_string("RequestServerStateChange")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=2004")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RequestServerStateChange")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12883")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12884")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12883")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12883")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12884")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12883")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'State'
    extobj.DataType = ua.NodeId.from_string("i=852")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'EstimatedReturnTime'
    extobj.DataType = ua.NodeId.from_string("i=13")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'SecondsTillShutdown'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Reason'
    extobj.DataType = ua.NodeId.from_string("i=21")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Restart'
    extobj.DataType = ua.NodeId.from_string("i=1")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12884")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12884")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12884")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12883")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2013")
    node.BrowseName = ua.QualifiedName.from_string("ServerCapabilitiesType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes the capabilities supported by the server.")
    attrs.DisplayName = ua.LocalizedText("ServerCapabilitiesType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2014")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2016")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2017")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2732")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2733")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2734")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3049")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11549")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11550")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12910")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11551")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2019")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2754")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11562")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16295")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2013")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2014")
    node.BrowseName = ua.QualifiedName.from_string("ServerProfileArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of profiles supported by the server.")
    attrs.DisplayName = ua.LocalizedText("ServerProfileArray")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2014")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2014")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2014")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2016")
    node.BrowseName = ua.QualifiedName.from_string("LocaleIdArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of locales supported by the server.")
    attrs.DisplayName = ua.LocalizedText("LocaleIdArray")
    attrs.DataType = ua.NodeId.from_string("i=295")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2016")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2016")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2016")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2017")
    node.BrowseName = ua.QualifiedName.from_string("MinSupportedSampleRate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The minimum sampling interval supported by the server.")
    attrs.DisplayName = ua.LocalizedText("MinSupportedSampleRate")
    attrs.DataType = ua.NodeId.from_string("i=290")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2017")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2017")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2017")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2732")
    node.BrowseName = ua.QualifiedName.from_string("MaxBrowseContinuationPoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of continuation points for Browse operations per session.")
    attrs.DisplayName = ua.LocalizedText("MaxBrowseContinuationPoints")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2732")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2732")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2732")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2733")
    node.BrowseName = ua.QualifiedName.from_string("MaxQueryContinuationPoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of continuation points for Query operations per session.")
    attrs.DisplayName = ua.LocalizedText("MaxQueryContinuationPoints")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2733")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2733")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2733")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2734")
    node.BrowseName = ua.QualifiedName.from_string("MaxHistoryContinuationPoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of continuation points for ReadHistory operations per session.")
    attrs.DisplayName = ua.LocalizedText("MaxHistoryContinuationPoints")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2734")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2734")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2734")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3049")
    node.BrowseName = ua.QualifiedName.from_string("SoftwareCertificates")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The software certificates owned by the server.")
    attrs.DisplayName = ua.LocalizedText("SoftwareCertificates")
    attrs.DataType = ua.NodeId.from_string("i=344")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3049")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3049")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3049")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11549")
    node.BrowseName = ua.QualifiedName.from_string("MaxArrayLength")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum length for an array value supported by the server.")
    attrs.DisplayName = ua.LocalizedText("MaxArrayLength")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11549")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11549")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11549")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11550")
    node.BrowseName = ua.QualifiedName.from_string("MaxStringLength")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum length for a string value supported by the server.")
    attrs.DisplayName = ua.LocalizedText("MaxStringLength")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11550")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11550")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11550")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12910")
    node.BrowseName = ua.QualifiedName.from_string("MaxByteStringLength")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum length for a byte string value supported by the server.")
    attrs.DisplayName = ua.LocalizedText("MaxByteStringLength")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12910")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12910")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12910")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11551")
    node.BrowseName = ua.QualifiedName.from_string("OperationLimits")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=11564")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Defines the limits supported by the server for different operations.")
    attrs.DisplayName = ua.LocalizedText("OperationLimits")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11551")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11551")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11551")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2019")
    node.BrowseName = ua.QualifiedName.from_string("ModellingRules")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("A folder for the modelling rules supported by the server.")
    attrs.DisplayName = ua.LocalizedText("ModellingRules")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2019")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2019")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2019")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2754")
    node.BrowseName = ua.QualifiedName.from_string("AggregateFunctions")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("A folder for the real time aggregates supported by the server.")
    attrs.DisplayName = ua.LocalizedText("AggregateFunctions")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2754")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2754")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2754")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11562")
    node.BrowseName = ua.QualifiedName.from_string("<VendorCapability>")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2137")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("<VendorCapability>")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11562")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2137")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11562")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11508")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11562")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16295")
    node.BrowseName = ua.QualifiedName.from_string("Roles")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2013")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=15607")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Describes the roles supported by the server.")
    attrs.DisplayName = ua.LocalizedText("Roles")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16295")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16296")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16295")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16299")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16295")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15607")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16295")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16295")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16296")
    node.BrowseName = ua.QualifiedName.from_string("AddRole")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=16295")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddRole")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16296")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16297")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16296")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16298")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16296")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16296")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16295")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16297")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16296")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RoleName'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'NamespaceUri'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16297")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16297")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16297")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16296")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16298")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16296")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RoleNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16298")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16298")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16298")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16296")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16299")
    node.BrowseName = ua.QualifiedName.from_string("RemoveRole")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=16295")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveRole")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16299")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16300")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16299")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16299")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16295")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16300")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16299")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RoleNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16300")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16300")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16300")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16299")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2020")
    node.BrowseName = ua.QualifiedName.from_string("ServerDiagnosticsType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("The diagnostics information for a server.")
    attrs.DisplayName = ua.LocalizedText("ServerDiagnosticsType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2020")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2020")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2022")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2020")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2023")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2020")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2744")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2020")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2025")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2020")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2021")
    node.BrowseName = ua.QualifiedName.from_string("ServerDiagnosticsSummary")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2020")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2150")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A summary of server level diagnostics.")
    attrs.DisplayName = ua.LocalizedText("ServerDiagnosticsSummary")
    attrs.DataType = ua.NodeId.from_string("i=859")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3116")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3117")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3118")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3119")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3120")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3121")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3122")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3124")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3125")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3126")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3127")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3128")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2021")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2020")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3116")
    node.BrowseName = ua.QualifiedName.from_string("ServerViewCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2021")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerViewCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3116")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3116")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3116")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3117")
    node.BrowseName = ua.QualifiedName.from_string("CurrentSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2021")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3117")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3117")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3117")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3118")
    node.BrowseName = ua.QualifiedName.from_string("CumulatedSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2021")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CumulatedSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3118")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3118")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3118")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3119")
    node.BrowseName = ua.QualifiedName.from_string("SecurityRejectedSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2021")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityRejectedSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3119")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3119")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3119")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3120")
    node.BrowseName = ua.QualifiedName.from_string("RejectedSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2021")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RejectedSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3120")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3120")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3120")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3121")
    node.BrowseName = ua.QualifiedName.from_string("SessionTimeoutCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2021")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionTimeoutCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3121")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3121")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3121")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3122")
    node.BrowseName = ua.QualifiedName.from_string("SessionAbortCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2021")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionAbortCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3122")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3122")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3122")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3124")
    node.BrowseName = ua.QualifiedName.from_string("PublishingIntervalCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2021")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishingIntervalCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3124")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3124")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3124")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3125")
    node.BrowseName = ua.QualifiedName.from_string("CurrentSubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2021")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentSubscriptionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3125")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3125")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3125")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3126")
    node.BrowseName = ua.QualifiedName.from_string("CumulatedSubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2021")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CumulatedSubscriptionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3126")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3126")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3126")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3127")
    node.BrowseName = ua.QualifiedName.from_string("SecurityRejectedRequestsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2021")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityRejectedRequestsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3127")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3127")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3127")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3128")
    node.BrowseName = ua.QualifiedName.from_string("RejectedRequestsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2021")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RejectedRequestsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3128")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3128")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3128")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2021")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2022")
    node.BrowseName = ua.QualifiedName.from_string("SamplingIntervalDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2020")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2164")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of diagnostics for each sampling interval supported by the server.")
    attrs.DisplayName = ua.LocalizedText("SamplingIntervalDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=856")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2022")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2164")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2022")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2022")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2020")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2023")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2020")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2171")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of diagnostics for each active subscription.")
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=874")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2023")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2171")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2023")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2023")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2020")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2744")
    node.BrowseName = ua.QualifiedName.from_string("SessionsDiagnosticsSummary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2020")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2026")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("A summary of session level diagnostics.")
    attrs.DisplayName = ua.LocalizedText("SessionsDiagnosticsSummary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2744")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3129")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2744")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3130")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2744")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2026")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2744")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2744")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2020")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3129")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2744")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2196")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of diagnostics for each active session.")
    attrs.DisplayName = ua.LocalizedText("SessionDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=865")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3129")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2196")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3129")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3129")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2744")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3130")
    node.BrowseName = ua.QualifiedName.from_string("SessionSecurityDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2744")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2243")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of security related diagnostics for each active session.")
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=868")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3130")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2243")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3130")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3130")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2744")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2025")
    node.BrowseName = ua.QualifiedName.from_string("EnabledFlag")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2020")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("If TRUE the diagnostics collection is enabled.")
    attrs.DisplayName = ua.LocalizedText("EnabledFlag")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    attrs.AccessLevel = 3
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2025")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2025")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2025")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2020")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2026")
    node.BrowseName = ua.QualifiedName.from_string("SessionsDiagnosticsSummaryType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("Provides a summary of session level diagnostics.")
    attrs.DisplayName = ua.LocalizedText("SessionsDiagnosticsSummaryType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2026")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2027")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2026")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2028")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2026")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12097")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2026")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2027")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2026")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2196")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of diagnostics for each active session.")
    attrs.DisplayName = ua.LocalizedText("SessionDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=865")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2027")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2196")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2027")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2027")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2026")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2028")
    node.BrowseName = ua.QualifiedName.from_string("SessionSecurityDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2026")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2243")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of security related diagnostics for each active session.")
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=868")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2028")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2243")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2028")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2028")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2026")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12097")
    node.BrowseName = ua.QualifiedName.from_string("<ClientName>")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2026")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2029")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("<ClientName>")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12097")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12097")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12142")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12097")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12152")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12097")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2029")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12097")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11508")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12097")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2026")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12098")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnostics")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12097")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2197")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Diagnostics information for an active session.")
    attrs.DisplayName = ua.LocalizedText("SessionDiagnostics")
    attrs.DataType = ua.NodeId.from_string("i=865")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12099")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12100")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12101")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12102")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12103")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12104")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12105")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12106")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12107")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12108")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12109")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12110")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12111")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12112")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12113")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12114")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12115")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12116")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12117")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12118")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12119")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12120")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12121")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12122")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12123")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12124")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12125")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12126")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12127")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12128")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12129")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12130")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12131")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12132")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12133")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12134")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12135")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12136")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12137")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12138")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12139")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12140")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12141")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12097")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12099")
    node.BrowseName = ua.QualifiedName.from_string("SessionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12099")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12099")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12099")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12100")
    node.BrowseName = ua.QualifiedName.from_string("SessionName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12100")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12100")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12100")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12101")
    node.BrowseName = ua.QualifiedName.from_string("ClientDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientDescription")
    attrs.DataType = ua.NodeId.from_string("i=308")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12101")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12101")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12101")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12102")
    node.BrowseName = ua.QualifiedName.from_string("ServerUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12102")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12102")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12102")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12103")
    node.BrowseName = ua.QualifiedName.from_string("EndpointUrl")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointUrl")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12103")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12103")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12103")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12104")
    node.BrowseName = ua.QualifiedName.from_string("LocaleIds")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("LocaleIds")
    attrs.DataType = ua.NodeId.from_string("i=295")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12105")
    node.BrowseName = ua.QualifiedName.from_string("ActualSessionTimeout")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ActualSessionTimeout")
    attrs.DataType = ua.NodeId.from_string("i=290")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12105")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12105")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12105")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12106")
    node.BrowseName = ua.QualifiedName.from_string("MaxResponseMessageSize")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MaxResponseMessageSize")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12106")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12106")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12106")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12107")
    node.BrowseName = ua.QualifiedName.from_string("ClientConnectionTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientConnectionTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12107")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12107")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12107")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12108")
    node.BrowseName = ua.QualifiedName.from_string("ClientLastContactTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientLastContactTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12108")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12108")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12108")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12109")
    node.BrowseName = ua.QualifiedName.from_string("CurrentSubscriptionsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentSubscriptionsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12109")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12109")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12109")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12110")
    node.BrowseName = ua.QualifiedName.from_string("CurrentMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentMonitoredItemsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12110")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12110")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12110")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12111")
    node.BrowseName = ua.QualifiedName.from_string("CurrentPublishRequestsInQueue")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentPublishRequestsInQueue")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12111")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12111")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12111")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12112")
    node.BrowseName = ua.QualifiedName.from_string("TotalRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TotalRequestCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12112")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12112")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12112")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12113")
    node.BrowseName = ua.QualifiedName.from_string("UnauthorizedRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UnauthorizedRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12113")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12113")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12113")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12114")
    node.BrowseName = ua.QualifiedName.from_string("ReadCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ReadCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12114")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12114")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12114")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12115")
    node.BrowseName = ua.QualifiedName.from_string("HistoryReadCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryReadCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12115")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12115")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12115")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12116")
    node.BrowseName = ua.QualifiedName.from_string("WriteCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("WriteCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12116")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12116")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12116")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12117")
    node.BrowseName = ua.QualifiedName.from_string("HistoryUpdateCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryUpdateCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12117")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12117")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12117")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12118")
    node.BrowseName = ua.QualifiedName.from_string("CallCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CallCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12118")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12118")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12118")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12119")
    node.BrowseName = ua.QualifiedName.from_string("CreateMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateMonitoredItemsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12119")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12119")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12119")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12120")
    node.BrowseName = ua.QualifiedName.from_string("ModifyMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ModifyMonitoredItemsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12120")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12120")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12120")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12121")
    node.BrowseName = ua.QualifiedName.from_string("SetMonitoringModeCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SetMonitoringModeCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12121")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12121")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12121")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12122")
    node.BrowseName = ua.QualifiedName.from_string("SetTriggeringCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SetTriggeringCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12122")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12122")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12122")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12123")
    node.BrowseName = ua.QualifiedName.from_string("DeleteMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteMonitoredItemsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12123")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12123")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12123")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12124")
    node.BrowseName = ua.QualifiedName.from_string("CreateSubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateSubscriptionCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12124")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12124")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12124")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12125")
    node.BrowseName = ua.QualifiedName.from_string("ModifySubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ModifySubscriptionCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12125")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12125")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12125")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12126")
    node.BrowseName = ua.QualifiedName.from_string("SetPublishingModeCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SetPublishingModeCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12126")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12126")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12126")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12127")
    node.BrowseName = ua.QualifiedName.from_string("PublishCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12127")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12127")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12127")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12128")
    node.BrowseName = ua.QualifiedName.from_string("RepublishCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RepublishCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12128")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12128")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12128")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12129")
    node.BrowseName = ua.QualifiedName.from_string("TransferSubscriptionsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransferSubscriptionsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12129")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12129")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12129")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12130")
    node.BrowseName = ua.QualifiedName.from_string("DeleteSubscriptionsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteSubscriptionsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12130")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12130")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12130")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12131")
    node.BrowseName = ua.QualifiedName.from_string("AddNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AddNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12131")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12131")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12131")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12132")
    node.BrowseName = ua.QualifiedName.from_string("AddReferencesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AddReferencesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12132")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12132")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12132")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12133")
    node.BrowseName = ua.QualifiedName.from_string("DeleteNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12133")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12133")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12133")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12134")
    node.BrowseName = ua.QualifiedName.from_string("DeleteReferencesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteReferencesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12134")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12134")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12134")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12135")
    node.BrowseName = ua.QualifiedName.from_string("BrowseCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrowseCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12135")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12135")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12135")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12136")
    node.BrowseName = ua.QualifiedName.from_string("BrowseNextCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrowseNextCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12136")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12136")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12136")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12137")
    node.BrowseName = ua.QualifiedName.from_string("TranslateBrowsePathsToNodeIdsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TranslateBrowsePathsToNodeIdsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12137")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12137")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12137")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12138")
    node.BrowseName = ua.QualifiedName.from_string("QueryFirstCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("QueryFirstCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12139")
    node.BrowseName = ua.QualifiedName.from_string("QueryNextCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("QueryNextCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12139")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12139")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12139")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12140")
    node.BrowseName = ua.QualifiedName.from_string("RegisterNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RegisterNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12140")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12140")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12140")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12141")
    node.BrowseName = ua.QualifiedName.from_string("UnregisterNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12098")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UnregisterNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12141")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12141")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12141")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12098")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12142")
    node.BrowseName = ua.QualifiedName.from_string("SessionSecurityDiagnostics")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12097")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2244")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Security related diagnostics information for an active session.")
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnostics")
    attrs.DataType = ua.NodeId.from_string("i=868")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12143")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12144")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12145")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12146")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12147")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12148")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12149")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12150")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12151")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2244")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12097")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12143")
    node.BrowseName = ua.QualifiedName.from_string("SessionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12143")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12143")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12143")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12144")
    node.BrowseName = ua.QualifiedName.from_string("ClientUserIdOfSession")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientUserIdOfSession")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12144")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12144")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12144")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12145")
    node.BrowseName = ua.QualifiedName.from_string("ClientUserIdHistory")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientUserIdHistory")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12145")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12145")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12145")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12146")
    node.BrowseName = ua.QualifiedName.from_string("AuthenticationMechanism")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AuthenticationMechanism")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12146")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12146")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12146")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12147")
    node.BrowseName = ua.QualifiedName.from_string("Encoding")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Encoding")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12147")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12147")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12147")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12148")
    node.BrowseName = ua.QualifiedName.from_string("TransportProtocol")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransportProtocol")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12148")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12148")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12148")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12149")
    node.BrowseName = ua.QualifiedName.from_string("SecurityMode")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityMode")
    attrs.DataType = ua.NodeId.from_string("i=302")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12149")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12149")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12149")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12150")
    node.BrowseName = ua.QualifiedName.from_string("SecurityPolicyUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityPolicyUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12151")
    node.BrowseName = ua.QualifiedName.from_string("ClientCertificate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientCertificate")
    attrs.DataType = ua.NodeId(ua.ObjectIds.ByteString)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12151")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12151")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12151")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12152")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12097")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2171")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of diagnostics for each subscription owned by the session.")
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=874")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12152")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2171")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12152")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12152")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12097")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2029")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnosticsObjectType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("A container for session level diagnostics information.")
    attrs.DisplayName = ua.LocalizedText("SessionDiagnosticsObjectType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2029")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2029")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2031")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2029")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2032")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2029")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2030")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnostics")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2029")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2197")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Diagnostics information for an active session.")
    attrs.DisplayName = ua.LocalizedText("SessionDiagnostics")
    attrs.DataType = ua.NodeId.from_string("i=865")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3131")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3132")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3133")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3134")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3135")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3136")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3137")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3138")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3139")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3140")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3141")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3142")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3143")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8898")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11891")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3151")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3152")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3153")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3154")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3155")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3156")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3157")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3158")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3159")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3160")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3161")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3162")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3163")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3164")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3165")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3166")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3167")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3168")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3169")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3170")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3171")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3172")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3173")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3174")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3175")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3176")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3177")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3178")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2029")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3131")
    node.BrowseName = ua.QualifiedName.from_string("SessionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3131")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3131")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3131")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3132")
    node.BrowseName = ua.QualifiedName.from_string("SessionName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3132")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3132")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3132")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3133")
    node.BrowseName = ua.QualifiedName.from_string("ClientDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientDescription")
    attrs.DataType = ua.NodeId.from_string("i=308")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3133")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3133")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3133")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3134")
    node.BrowseName = ua.QualifiedName.from_string("ServerUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3134")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3134")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3134")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3135")
    node.BrowseName = ua.QualifiedName.from_string("EndpointUrl")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointUrl")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3135")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3135")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3135")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3136")
    node.BrowseName = ua.QualifiedName.from_string("LocaleIds")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("LocaleIds")
    attrs.DataType = ua.NodeId.from_string("i=295")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3136")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3136")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3136")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3137")
    node.BrowseName = ua.QualifiedName.from_string("ActualSessionTimeout")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ActualSessionTimeout")
    attrs.DataType = ua.NodeId.from_string("i=290")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3137")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3137")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3137")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3138")
    node.BrowseName = ua.QualifiedName.from_string("MaxResponseMessageSize")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MaxResponseMessageSize")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3139")
    node.BrowseName = ua.QualifiedName.from_string("ClientConnectionTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientConnectionTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3139")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3139")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3139")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3140")
    node.BrowseName = ua.QualifiedName.from_string("ClientLastContactTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientLastContactTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3140")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3140")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3140")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3141")
    node.BrowseName = ua.QualifiedName.from_string("CurrentSubscriptionsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentSubscriptionsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3141")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3141")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3141")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3142")
    node.BrowseName = ua.QualifiedName.from_string("CurrentMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentMonitoredItemsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3143")
    node.BrowseName = ua.QualifiedName.from_string("CurrentPublishRequestsInQueue")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentPublishRequestsInQueue")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3143")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3143")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3143")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8898")
    node.BrowseName = ua.QualifiedName.from_string("TotalRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TotalRequestCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8898")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8898")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8898")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11891")
    node.BrowseName = ua.QualifiedName.from_string("UnauthorizedRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UnauthorizedRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11891")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11891")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11891")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3151")
    node.BrowseName = ua.QualifiedName.from_string("ReadCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ReadCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3151")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3151")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3151")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3152")
    node.BrowseName = ua.QualifiedName.from_string("HistoryReadCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryReadCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3152")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3152")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3152")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3153")
    node.BrowseName = ua.QualifiedName.from_string("WriteCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("WriteCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3153")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3153")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3153")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3154")
    node.BrowseName = ua.QualifiedName.from_string("HistoryUpdateCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryUpdateCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3154")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3154")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3154")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3155")
    node.BrowseName = ua.QualifiedName.from_string("CallCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CallCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3155")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3155")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3155")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3156")
    node.BrowseName = ua.QualifiedName.from_string("CreateMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateMonitoredItemsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3156")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3156")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3156")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3157")
    node.BrowseName = ua.QualifiedName.from_string("ModifyMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ModifyMonitoredItemsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3157")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3157")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3157")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3158")
    node.BrowseName = ua.QualifiedName.from_string("SetMonitoringModeCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SetMonitoringModeCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3158")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3158")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3158")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3159")
    node.BrowseName = ua.QualifiedName.from_string("SetTriggeringCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SetTriggeringCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3159")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3159")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3159")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3160")
    node.BrowseName = ua.QualifiedName.from_string("DeleteMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteMonitoredItemsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3160")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3160")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3160")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3161")
    node.BrowseName = ua.QualifiedName.from_string("CreateSubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateSubscriptionCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3161")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3161")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3161")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3162")
    node.BrowseName = ua.QualifiedName.from_string("ModifySubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ModifySubscriptionCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3163")
    node.BrowseName = ua.QualifiedName.from_string("SetPublishingModeCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SetPublishingModeCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3163")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3163")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3163")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3164")
    node.BrowseName = ua.QualifiedName.from_string("PublishCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3164")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3164")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3164")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3165")
    node.BrowseName = ua.QualifiedName.from_string("RepublishCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RepublishCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3166")
    node.BrowseName = ua.QualifiedName.from_string("TransferSubscriptionsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransferSubscriptionsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3166")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3166")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3166")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3167")
    node.BrowseName = ua.QualifiedName.from_string("DeleteSubscriptionsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteSubscriptionsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3167")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3167")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3167")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3168")
    node.BrowseName = ua.QualifiedName.from_string("AddNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AddNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3168")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3168")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3168")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3169")
    node.BrowseName = ua.QualifiedName.from_string("AddReferencesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AddReferencesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3169")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3169")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3169")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3170")
    node.BrowseName = ua.QualifiedName.from_string("DeleteNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3170")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3170")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3170")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3171")
    node.BrowseName = ua.QualifiedName.from_string("DeleteReferencesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteReferencesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3171")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3171")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3171")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3172")
    node.BrowseName = ua.QualifiedName.from_string("BrowseCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrowseCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3173")
    node.BrowseName = ua.QualifiedName.from_string("BrowseNextCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrowseNextCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3173")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3173")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3173")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3174")
    node.BrowseName = ua.QualifiedName.from_string("TranslateBrowsePathsToNodeIdsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TranslateBrowsePathsToNodeIdsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3174")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3174")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3174")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3175")
    node.BrowseName = ua.QualifiedName.from_string("QueryFirstCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("QueryFirstCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3176")
    node.BrowseName = ua.QualifiedName.from_string("QueryNextCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("QueryNextCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3176")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3176")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3176")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3177")
    node.BrowseName = ua.QualifiedName.from_string("RegisterNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RegisterNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3177")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3177")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3177")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3178")
    node.BrowseName = ua.QualifiedName.from_string("UnregisterNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2030")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UnregisterNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3178")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3178")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3178")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2030")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2031")
    node.BrowseName = ua.QualifiedName.from_string("SessionSecurityDiagnostics")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2029")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2244")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Security related diagnostics information for an active session.")
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnostics")
    attrs.DataType = ua.NodeId.from_string("i=868")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3179")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3180")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3181")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3182")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3183")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3184")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3185")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3186")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3187")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2244")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2029")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3179")
    node.BrowseName = ua.QualifiedName.from_string("SessionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2031")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3179")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3179")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3179")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2031")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3180")
    node.BrowseName = ua.QualifiedName.from_string("ClientUserIdOfSession")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2031")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientUserIdOfSession")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3180")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3180")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3180")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2031")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3181")
    node.BrowseName = ua.QualifiedName.from_string("ClientUserIdHistory")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2031")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientUserIdHistory")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3181")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3181")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3181")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2031")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3182")
    node.BrowseName = ua.QualifiedName.from_string("AuthenticationMechanism")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2031")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AuthenticationMechanism")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3182")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3182")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3182")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2031")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3183")
    node.BrowseName = ua.QualifiedName.from_string("Encoding")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2031")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Encoding")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2031")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3184")
    node.BrowseName = ua.QualifiedName.from_string("TransportProtocol")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2031")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransportProtocol")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3184")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3184")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3184")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2031")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3185")
    node.BrowseName = ua.QualifiedName.from_string("SecurityMode")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2031")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityMode")
    attrs.DataType = ua.NodeId.from_string("i=302")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3185")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3185")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3185")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2031")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3186")
    node.BrowseName = ua.QualifiedName.from_string("SecurityPolicyUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2031")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityPolicyUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3186")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3186")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3186")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2031")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3187")
    node.BrowseName = ua.QualifiedName.from_string("ClientCertificate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2031")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientCertificate")
    attrs.DataType = ua.NodeId(ua.ObjectIds.ByteString)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3187")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3187")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3187")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2031")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2032")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2029")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2171")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of diagnostics for each subscription owned by the session.")
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=874")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2032")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2171")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2032")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2032")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2029")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2033")
    node.BrowseName = ua.QualifiedName.from_string("VendorServerInfoType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("A base type for vendor specific server information.")
    attrs.DisplayName = ua.LocalizedText("VendorServerInfoType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2033")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2034")
    node.BrowseName = ua.QualifiedName.from_string("ServerRedundancyType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("A base type for an object that describe how a server supports redundancy.")
    attrs.DisplayName = ua.LocalizedText("ServerRedundancyType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2034")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2035")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2034")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2035")
    node.BrowseName = ua.QualifiedName.from_string("RedundancySupport")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2034")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Indicates what style of redundancy is supported by the server.")
    attrs.DisplayName = ua.LocalizedText("RedundancySupport")
    attrs.DataType = ua.NodeId.from_string("i=851")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2035")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2035")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2035")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2034")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2036")
    node.BrowseName = ua.QualifiedName.from_string("TransparentRedundancyType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2034")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("Identifies the capabilties of server that supports transparent redundancy.")
    attrs.DisplayName = ua.LocalizedText("TransparentRedundancyType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2037")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2038")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2034")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2037")
    node.BrowseName = ua.QualifiedName.from_string("CurrentServerId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The ID of the server that is currently in use.")
    attrs.DisplayName = ua.LocalizedText("CurrentServerId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2037")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2037")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2037")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2038")
    node.BrowseName = ua.QualifiedName.from_string("RedundantServerArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of servers in the same redundant set.")
    attrs.DisplayName = ua.LocalizedText("RedundantServerArray")
    attrs.DataType = ua.NodeId.from_string("i=853")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2038")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2038")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2038")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2039")
    node.BrowseName = ua.QualifiedName.from_string("NonTransparentRedundancyType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2034")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("Identifies the capabilties of server that supports non-transparent redundancy.")
    attrs.DisplayName = ua.LocalizedText("NonTransparentRedundancyType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2039")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2040")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2039")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2034")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2040")
    node.BrowseName = ua.QualifiedName.from_string("ServerUriArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2039")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of servers in the same redundant set.")
    attrs.DisplayName = ua.LocalizedText("ServerUriArray")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2040")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2040")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2040")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2039")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11945")
    node.BrowseName = ua.QualifiedName.from_string("NonTransparentNetworkRedundancyType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2039")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("NonTransparentNetworkRedundancyType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11945")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11948")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11945")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2039")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11948")
    node.BrowseName = ua.QualifiedName.from_string("ServerNetworkGroups")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11945")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerNetworkGroups")
    attrs.DataType = ua.NodeId.from_string("i=11944")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11948")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11948")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11948")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11945")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11564")
    node.BrowseName = ua.QualifiedName.from_string("OperationLimitsType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=61")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("Identifies the operation limits imposed by the server.")
    attrs.DisplayName = ua.LocalizedText("OperationLimitsType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11565")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12161")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12162")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11567")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12163")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12164")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11569")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11570")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11571")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11572")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11573")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11574")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11565")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerRead")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11564")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single Read request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerRead")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11565")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11565")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11565")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12161")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerHistoryReadData")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11564")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single data HistoryRead request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerHistoryReadData")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12161")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12161")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12161")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12162")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerHistoryReadEvents")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11564")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single event HistoryRead request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerHistoryReadEvents")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11567")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerWrite")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11564")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single Write request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerWrite")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11567")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11567")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11567")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12163")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerHistoryUpdateData")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11564")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single data HistoryUpdate request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerHistoryUpdateData")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12163")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12163")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12163")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12164")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerHistoryUpdateEvents")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11564")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single event HistoryUpdate request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerHistoryUpdateEvents")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12164")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12164")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12164")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11569")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerMethodCall")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11564")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single Call request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerMethodCall")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11569")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11569")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11569")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11570")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerBrowse")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11564")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single Browse request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerBrowse")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11570")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11570")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11570")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11571")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerRegisterNodes")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11564")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single RegisterNodes request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerRegisterNodes")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11571")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11571")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11571")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11572")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerTranslateBrowsePathsToNodeIds")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11564")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single TranslateBrowsePathsToNodeIds request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerTranslateBrowsePathsToNodeIds")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11572")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11572")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11572")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11573")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerNodeManagement")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11564")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single AddNodes, AddReferences, DeleteNodes or DeleteReferences request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerNodeManagement")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11573")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11573")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11573")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11574")
    node.BrowseName = ua.QualifiedName.from_string("MaxMonitoredItemsPerCall")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11564")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single MonitoredItem related request.")
    attrs.DisplayName = ua.LocalizedText("MaxMonitoredItemsPerCall")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11574")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11574")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11574")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11575")
    node.BrowseName = ua.QualifiedName.from_string("FileType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("An object that represents a file that can be accessed via the server.")
    attrs.DisplayName = ua.LocalizedText("FileType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11575")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11576")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11575")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12686")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11575")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12687")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11575")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11579")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11575")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13341")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11575")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11580")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11575")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11583")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11575")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11585")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11575")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11588")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11575")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11590")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11575")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11593")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11575")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11576")
    node.BrowseName = ua.QualifiedName.from_string("Size")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11575")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The size of the file in bytes.")
    attrs.DisplayName = ua.LocalizedText("Size")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt64)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11576")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11576")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11576")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12686")
    node.BrowseName = ua.QualifiedName.from_string("Writable")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11575")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Whether the file is writable.")
    attrs.DisplayName = ua.LocalizedText("Writable")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12686")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12686")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12686")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12687")
    node.BrowseName = ua.QualifiedName.from_string("UserWritable")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11575")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Whether the file is writable by the current user.")
    attrs.DisplayName = ua.LocalizedText("UserWritable")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12687")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12687")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12687")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11579")
    node.BrowseName = ua.QualifiedName.from_string("OpenCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11575")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The current number of open file handles.")
    attrs.DisplayName = ua.LocalizedText("OpenCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11579")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11579")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11579")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13341")
    node.BrowseName = ua.QualifiedName.from_string("MimeType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11575")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The content of the file.")
    attrs.DisplayName = ua.LocalizedText("MimeType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13341")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13341")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13341")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11580")
    node.BrowseName = ua.QualifiedName.from_string("Open")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11575")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Open")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11580")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11581")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11580")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11582")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11580")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11580")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11581")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11580")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'Mode'
    extobj.DataType = ua.NodeId.from_string("i=3")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11581")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11581")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11581")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11580")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11582")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11580")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11582")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11582")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11582")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11580")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11583")
    node.BrowseName = ua.QualifiedName.from_string("Close")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11575")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Close")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11583")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11584")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11583")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11583")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11584")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11583")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11584")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11584")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11584")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11583")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11585")
    node.BrowseName = ua.QualifiedName.from_string("Read")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11575")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Read")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11585")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11586")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11585")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11587")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11585")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11585")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11586")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11585")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Length'
    extobj.DataType = ua.NodeId.from_string("i=6")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11586")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11586")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11586")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11585")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11587")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11585")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'Data'
    extobj.DataType = ua.NodeId.from_string("i=15")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11587")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11587")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11587")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11585")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11588")
    node.BrowseName = ua.QualifiedName.from_string("Write")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11575")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Write")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11588")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11589")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11588")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11588")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11589")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11588")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Data'
    extobj.DataType = ua.NodeId.from_string("i=15")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11589")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11589")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11589")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11588")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11590")
    node.BrowseName = ua.QualifiedName.from_string("GetPosition")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11575")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("GetPosition")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11590")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11591")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11590")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11592")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11590")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11590")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11591")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11590")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11591")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11591")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11591")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11590")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11592")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11590")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'Position'
    extobj.DataType = ua.NodeId.from_string("i=9")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11592")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11592")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11592")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11590")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11593")
    node.BrowseName = ua.QualifiedName.from_string("SetPosition")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11575")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("SetPosition")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11593")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11594")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11593")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11593")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11594")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11593")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Position'
    extobj.DataType = ua.NodeId.from_string("i=9")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11594")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11594")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11594")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11593")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11595")
    node.BrowseName = ua.QualifiedName.from_string("AddressSpaceFileType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=11575")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("A file used to store a namespace exported from the server.")
    attrs.DisplayName = ua.LocalizedText("AddressSpaceFileType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11595")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11615")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11595")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11615")
    node.BrowseName = ua.QualifiedName.from_string("ExportNamespace")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11595")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.Description = ua.LocalizedText("Updates the file by exporting the server namespace.")
    attrs.DisplayName = ua.LocalizedText("ExportNamespace")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11615")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11615")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11595")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11616")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceMetadataType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("Provides the metadata for a namespace used by the server.")
    attrs.DisplayName = ua.LocalizedText("NamespaceMetadataType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11617")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11618")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11619")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11620")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11621")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11622")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11623")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11624")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16137")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16138")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16139")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11617")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11616")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The URI of the namespace.")
    attrs.DisplayName = ua.LocalizedText("NamespaceUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11618")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceVersion")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11616")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The human readable string representing version of the namespace.")
    attrs.DisplayName = ua.LocalizedText("NamespaceVersion")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11618")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11618")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11618")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11619")
    node.BrowseName = ua.QualifiedName.from_string("NamespacePublicationDate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11616")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The publication date for the namespace.")
    attrs.DisplayName = ua.LocalizedText("NamespacePublicationDate")
    attrs.DataType = ua.NodeId(ua.ObjectIds.DateTime)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11619")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11619")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11619")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11620")
    node.BrowseName = ua.QualifiedName.from_string("IsNamespaceSubset")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11616")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("If TRUE then the server only supports a subset of the namespace.")
    attrs.DisplayName = ua.LocalizedText("IsNamespaceSubset")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11621")
    node.BrowseName = ua.QualifiedName.from_string("StaticNodeIdTypes")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11616")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of IdTypes for nodes which are the same in every server that exposes them.")
    attrs.DisplayName = ua.LocalizedText("StaticNodeIdTypes")
    attrs.DataType = ua.NodeId.from_string("i=256")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11621")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11621")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11621")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11622")
    node.BrowseName = ua.QualifiedName.from_string("StaticNumericNodeIdRange")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11616")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of ranges for numeric node ids which are the same in every server that exposes them.")
    attrs.DisplayName = ua.LocalizedText("StaticNumericNodeIdRange")
    attrs.DataType = ua.NodeId.from_string("i=291")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11622")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11622")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11622")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11623")
    node.BrowseName = ua.QualifiedName.from_string("StaticStringNodeIdPattern")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11616")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A regular expression which matches string node ids are the same in every server that exposes them.")
    attrs.DisplayName = ua.LocalizedText("StaticStringNodeIdPattern")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11623")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11623")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11623")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11624")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceFile")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=11616")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=11595")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("A file containing the nodes of the namespace.")
    attrs.DisplayName = ua.LocalizedText("NamespaceFile")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11625")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12690")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12691")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11628")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11629")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11632")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11634")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11637")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11639")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11642")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11595")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11625")
    node.BrowseName = ua.QualifiedName.from_string("Size")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11624")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The size of the file in bytes.")
    attrs.DisplayName = ua.LocalizedText("Size")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt64)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11625")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11625")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11625")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11624")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12690")
    node.BrowseName = ua.QualifiedName.from_string("Writable")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11624")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Whether the file is writable.")
    attrs.DisplayName = ua.LocalizedText("Writable")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12690")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12690")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12690")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11624")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12691")
    node.BrowseName = ua.QualifiedName.from_string("UserWritable")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11624")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Whether the file is writable by the current user.")
    attrs.DisplayName = ua.LocalizedText("UserWritable")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12691")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12691")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12691")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11624")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11628")
    node.BrowseName = ua.QualifiedName.from_string("OpenCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11624")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The current number of open file handles.")
    attrs.DisplayName = ua.LocalizedText("OpenCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11628")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11628")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11628")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11624")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11629")
    node.BrowseName = ua.QualifiedName.from_string("Open")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11624")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Open")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11629")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11630")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11629")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11631")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11629")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11629")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11624")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11630")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11629")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'Mode'
    extobj.DataType = ua.NodeId.from_string("i=3")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11630")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11630")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11630")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11629")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11631")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11629")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11631")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11631")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11631")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11629")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11632")
    node.BrowseName = ua.QualifiedName.from_string("Close")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11624")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Close")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11632")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11633")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11632")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11632")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11624")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11633")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11632")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11633")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11633")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11633")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11632")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11634")
    node.BrowseName = ua.QualifiedName.from_string("Read")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11624")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Read")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11634")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11635")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11634")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11636")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11634")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11634")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11624")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11635")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11634")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Length'
    extobj.DataType = ua.NodeId.from_string("i=6")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11635")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11635")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11635")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11634")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11636")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11634")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'Data'
    extobj.DataType = ua.NodeId.from_string("i=15")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11636")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11636")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11636")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11634")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11637")
    node.BrowseName = ua.QualifiedName.from_string("Write")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11624")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Write")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11637")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11638")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11637")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11637")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11624")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11638")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11637")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Data'
    extobj.DataType = ua.NodeId.from_string("i=15")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11638")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11638")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11638")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11637")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11639")
    node.BrowseName = ua.QualifiedName.from_string("GetPosition")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11624")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("GetPosition")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11639")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11640")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11639")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11641")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11639")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11639")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11624")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11640")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11639")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11640")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11640")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11640")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11639")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11641")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11639")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'Position'
    extobj.DataType = ua.NodeId.from_string("i=9")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11641")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11641")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11641")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11639")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11642")
    node.BrowseName = ua.QualifiedName.from_string("SetPosition")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=11624")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("SetPosition")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11642")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11643")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11642")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11642")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11624")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11643")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11642")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Position'
    extobj.DataType = ua.NodeId.from_string("i=9")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11643")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11643")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11643")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11642")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16137")
    node.BrowseName = ua.QualifiedName.from_string("DefaultRolePermissions")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11616")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DefaultRolePermissions")
    attrs.DataType = ua.NodeId.from_string("i=96")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16137")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16137")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16137")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16138")
    node.BrowseName = ua.QualifiedName.from_string("DefaultUserRolePermissions")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11616")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DefaultUserRolePermissions")
    attrs.DataType = ua.NodeId.from_string("i=96")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16139")
    node.BrowseName = ua.QualifiedName.from_string("DefaultAccessRestrictions")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11616")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DefaultAccessRestrictions")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16139")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16139")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16139")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11645")
    node.BrowseName = ua.QualifiedName.from_string("NamespacesType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("A container for the namespace metadata provided by the server.")
    attrs.DisplayName = ua.LocalizedText("NamespacesType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11645")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11646")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11645")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11646")
    node.BrowseName = ua.QualifiedName.from_string("<NamespaceIdentifier>")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=11645")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=11616")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("<NamespaceIdentifier>")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11646")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11647")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11646")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11648")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11646")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11649")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11646")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11650")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11646")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11651")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11646")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11652")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11646")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11653")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11646")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11616")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11646")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11508")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11646")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11645")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11647")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11646")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The URI of the namespace.")
    attrs.DisplayName = ua.LocalizedText("NamespaceUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11647")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11647")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11647")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11646")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11648")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceVersion")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11646")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The human readable string representing version of the namespace.")
    attrs.DisplayName = ua.LocalizedText("NamespaceVersion")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11648")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11648")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11648")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11646")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11649")
    node.BrowseName = ua.QualifiedName.from_string("NamespacePublicationDate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11646")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The publication date for the namespace.")
    attrs.DisplayName = ua.LocalizedText("NamespacePublicationDate")
    attrs.DataType = ua.NodeId(ua.ObjectIds.DateTime)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11649")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11649")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11649")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11646")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11650")
    node.BrowseName = ua.QualifiedName.from_string("IsNamespaceSubset")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11646")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("If TRUE then the server only supports a subset of the namespace.")
    attrs.DisplayName = ua.LocalizedText("IsNamespaceSubset")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11650")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11650")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11650")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11646")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11651")
    node.BrowseName = ua.QualifiedName.from_string("StaticNodeIdTypes")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11646")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of IdTypes for nodes which are the same in every server that exposes them.")
    attrs.DisplayName = ua.LocalizedText("StaticNodeIdTypes")
    attrs.DataType = ua.NodeId.from_string("i=256")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11651")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11651")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11651")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11646")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11652")
    node.BrowseName = ua.QualifiedName.from_string("StaticNumericNodeIdRange")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11646")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of ranges for numeric node ids which are the same in every server that exposes them.")
    attrs.DisplayName = ua.LocalizedText("StaticNumericNodeIdRange")
    attrs.DataType = ua.NodeId.from_string("i=291")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11652")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11652")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11652")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11646")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11653")
    node.BrowseName = ua.QualifiedName.from_string("StaticStringNodeIdPattern")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11646")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A regular expression which matches string node ids are the same in every server that exposes them.")
    attrs.DisplayName = ua.LocalizedText("StaticStringNodeIdPattern")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11653")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11653")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11653")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11646")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2041")
    node.BrowseName = ua.QualifiedName.from_string("BaseEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("The base type for all events.")
    attrs.DisplayName = ua.LocalizedText("BaseEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2042")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2043")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2044")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2045")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2046")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2047")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3190")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2050")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2051")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2042")
    node.BrowseName = ua.QualifiedName.from_string("EventId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A globally unique identifier for the event.")
    attrs.DisplayName = ua.LocalizedText("EventId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.ByteString)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2042")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2042")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2042")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2043")
    node.BrowseName = ua.QualifiedName.from_string("EventType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The identifier for the event type.")
    attrs.DisplayName = ua.LocalizedText("EventType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2043")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2043")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2043")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2044")
    node.BrowseName = ua.QualifiedName.from_string("SourceNode")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The source of the event.")
    attrs.DisplayName = ua.LocalizedText("SourceNode")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2044")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2044")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2044")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2045")
    node.BrowseName = ua.QualifiedName.from_string("SourceName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A description of the source of the event.")
    attrs.DisplayName = ua.LocalizedText("SourceName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2045")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2045")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2045")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2046")
    node.BrowseName = ua.QualifiedName.from_string("Time")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("When the event occurred.")
    attrs.DisplayName = ua.LocalizedText("Time")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2046")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2046")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2046")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2047")
    node.BrowseName = ua.QualifiedName.from_string("ReceiveTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("When the server received the event from the underlying system.")
    attrs.DisplayName = ua.LocalizedText("ReceiveTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2047")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2047")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2047")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3190")
    node.BrowseName = ua.QualifiedName.from_string("LocalTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Information about the local time where the event originated.")
    attrs.DisplayName = ua.LocalizedText("LocalTime")
    attrs.DataType = ua.NodeId.from_string("i=8912")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3190")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3190")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3190")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2050")
    node.BrowseName = ua.QualifiedName.from_string("Message")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A localized description of the event.")
    attrs.DisplayName = ua.LocalizedText("Message")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2050")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2050")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2050")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2051")
    node.BrowseName = ua.QualifiedName.from_string("Severity")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Indicates how urgent an event is.")
    attrs.DisplayName = ua.LocalizedText("Severity")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2051")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2051")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2051")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2052")
    node.BrowseName = ua.QualifiedName.from_string("AuditEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("A base type for events used to track client initiated changes to the server state.")
    attrs.DisplayName = ua.LocalizedText("AuditEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2052")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2053")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2052")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2054")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2052")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2055")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2052")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2056")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2052")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2057")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2052")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2053")
    node.BrowseName = ua.QualifiedName.from_string("ActionTimeStamp")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2052")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("When the action triggering the event occurred.")
    attrs.DisplayName = ua.LocalizedText("ActionTimeStamp")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2053")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2053")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2053")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2052")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2054")
    node.BrowseName = ua.QualifiedName.from_string("Status")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2052")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("If TRUE the action was performed. If FALSE the action failed and the server state did not change.")
    attrs.DisplayName = ua.LocalizedText("Status")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2054")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2054")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2054")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2052")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2055")
    node.BrowseName = ua.QualifiedName.from_string("ServerId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2052")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The unique identifier for the server generating the event.")
    attrs.DisplayName = ua.LocalizedText("ServerId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2055")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2055")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2055")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2052")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2056")
    node.BrowseName = ua.QualifiedName.from_string("ClientAuditEntryId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2052")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The log entry id provided in the request that initiated the action.")
    attrs.DisplayName = ua.LocalizedText("ClientAuditEntryId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2056")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2056")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2056")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2052")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2057")
    node.BrowseName = ua.QualifiedName.from_string("ClientUserId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2052")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The user identity associated with the session that initiated the action.")
    attrs.DisplayName = ua.LocalizedText("ClientUserId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2057")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2057")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2057")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2052")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2058")
    node.BrowseName = ua.QualifiedName.from_string("AuditSecurityEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2052")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("A base type for events used to track security related changes.")
    attrs.DisplayName = ua.LocalizedText("AuditSecurityEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2058")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17615")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2058")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2052")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17615")
    node.BrowseName = ua.QualifiedName.from_string("StatusCodeId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2058")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StatusCodeId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.StatusCode)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=17615")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=17615")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=17615")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2058")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2059")
    node.BrowseName = ua.QualifiedName.from_string("AuditChannelEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2058")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("A base type for events used to track related changes to a secure channel.")
    attrs.DisplayName = ua.LocalizedText("AuditChannelEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2059")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2745")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2059")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2058")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2745")
    node.BrowseName = ua.QualifiedName.from_string("SecureChannelId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2059")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The identifier for the secure channel that was changed.")
    attrs.DisplayName = ua.LocalizedText("SecureChannelId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2745")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2745")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2745")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2059")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2060")
    node.BrowseName = ua.QualifiedName.from_string("AuditOpenSecureChannelEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2059")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("An event that is raised when a secure channel is opened.")
    attrs.DisplayName = ua.LocalizedText("AuditOpenSecureChannelEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2060")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2061")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2060")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2746")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2060")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2062")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2060")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2063")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2060")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2065")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2060")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2066")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2060")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2059")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2061")
    node.BrowseName = ua.QualifiedName.from_string("ClientCertificate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2060")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The certificate provided by the client.")
    attrs.DisplayName = ua.LocalizedText("ClientCertificate")
    attrs.DataType = ua.NodeId(ua.ObjectIds.ByteString)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2061")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2061")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2061")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2060")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2746")
    node.BrowseName = ua.QualifiedName.from_string("ClientCertificateThumbprint")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2060")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The thumbprint for certificate provided by the client.")
    attrs.DisplayName = ua.LocalizedText("ClientCertificateThumbprint")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2060")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2062")
    node.BrowseName = ua.QualifiedName.from_string("RequestType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2060")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The type of request (NEW or RENEW).")
    attrs.DisplayName = ua.LocalizedText("RequestType")
    attrs.DataType = ua.NodeId.from_string("i=315")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2062")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2062")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2062")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2060")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2063")
    node.BrowseName = ua.QualifiedName.from_string("SecurityPolicyUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2060")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The security policy used by the channel.")
    attrs.DisplayName = ua.LocalizedText("SecurityPolicyUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2063")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2063")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2063")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2060")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2065")
    node.BrowseName = ua.QualifiedName.from_string("SecurityMode")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2060")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The security mode used by the channel.")
    attrs.DisplayName = ua.LocalizedText("SecurityMode")
    attrs.DataType = ua.NodeId.from_string("i=302")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2065")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2065")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2065")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2060")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2066")
    node.BrowseName = ua.QualifiedName.from_string("RequestedLifetime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2060")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The lifetime of the channel requested by the client.")
    attrs.DisplayName = ua.LocalizedText("RequestedLifetime")
    attrs.DataType = ua.NodeId.from_string("i=290")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2066")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2066")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2066")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2060")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2069")
    node.BrowseName = ua.QualifiedName.from_string("AuditSessionEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2058")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("A base type for events used to track related changes to a session.")
    attrs.DisplayName = ua.LocalizedText("AuditSessionEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2069")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2070")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2069")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2058")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2070")
    node.BrowseName = ua.QualifiedName.from_string("SessionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2069")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The unique identifier for the session,.")
    attrs.DisplayName = ua.LocalizedText("SessionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2070")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2070")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2070")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2069")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2071")
    node.BrowseName = ua.QualifiedName.from_string("AuditCreateSessionEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2069")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("An event that is raised when a session is created.")
    attrs.DisplayName = ua.LocalizedText("AuditCreateSessionEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2071")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2072")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2071")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2073")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2071")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2747")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2071")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2074")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2071")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2069")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2072")
    node.BrowseName = ua.QualifiedName.from_string("SecureChannelId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2071")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The secure channel associated with the session.")
    attrs.DisplayName = ua.LocalizedText("SecureChannelId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2072")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2072")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2072")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2071")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2073")
    node.BrowseName = ua.QualifiedName.from_string("ClientCertificate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2071")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The certificate provided by the client.")
    attrs.DisplayName = ua.LocalizedText("ClientCertificate")
    attrs.DataType = ua.NodeId(ua.ObjectIds.ByteString)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2073")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2073")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2073")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2071")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2747")
    node.BrowseName = ua.QualifiedName.from_string("ClientCertificateThumbprint")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2071")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The thumbprint of the certificate provided by the client.")
    attrs.DisplayName = ua.LocalizedText("ClientCertificateThumbprint")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2747")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2747")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2747")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2071")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2074")
    node.BrowseName = ua.QualifiedName.from_string("RevisedSessionTimeout")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2071")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The timeout for the session.")
    attrs.DisplayName = ua.LocalizedText("RevisedSessionTimeout")
    attrs.DataType = ua.NodeId.from_string("i=290")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2074")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2074")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2074")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2071")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2748")
    node.BrowseName = ua.QualifiedName.from_string("AuditUrlMismatchEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2071")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditUrlMismatchEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2748")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2749")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2748")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2071")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2749")
    node.BrowseName = ua.QualifiedName.from_string("EndpointUrl")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2748")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointUrl")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2749")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2749")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2749")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2748")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2075")
    node.BrowseName = ua.QualifiedName.from_string("AuditActivateSessionEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2069")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditActivateSessionEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2075")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2076")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2075")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2077")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2075")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11485")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2075")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2069")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2076")
    node.BrowseName = ua.QualifiedName.from_string("ClientSoftwareCertificates")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2075")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientSoftwareCertificates")
    attrs.DataType = ua.NodeId.from_string("i=344")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2076")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2076")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2076")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2075")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2077")
    node.BrowseName = ua.QualifiedName.from_string("UserIdentityToken")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2075")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UserIdentityToken")
    attrs.DataType = ua.NodeId.from_string("i=316")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2075")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11485")
    node.BrowseName = ua.QualifiedName.from_string("SecureChannelId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2075")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecureChannelId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11485")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11485")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11485")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2075")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2078")
    node.BrowseName = ua.QualifiedName.from_string("AuditCancelEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2069")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditCancelEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2078")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2079")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2078")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2069")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2079")
    node.BrowseName = ua.QualifiedName.from_string("RequestHandle")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2078")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RequestHandle")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2079")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2079")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2079")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2078")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2080")
    node.BrowseName = ua.QualifiedName.from_string("AuditCertificateEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2058")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditCertificateEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2080")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2081")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2080")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2058")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2081")
    node.BrowseName = ua.QualifiedName.from_string("Certificate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2080")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Certificate")
    attrs.DataType = ua.NodeId(ua.ObjectIds.ByteString)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2081")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2081")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2081")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2080")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2082")
    node.BrowseName = ua.QualifiedName.from_string("AuditCertificateDataMismatchEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2080")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditCertificateDataMismatchEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2082")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2083")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2082")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2084")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2082")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2080")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2083")
    node.BrowseName = ua.QualifiedName.from_string("InvalidHostname")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2082")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InvalidHostname")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2083")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2083")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2083")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2082")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2084")
    node.BrowseName = ua.QualifiedName.from_string("InvalidUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2082")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InvalidUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2084")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2084")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2084")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2082")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2085")
    node.BrowseName = ua.QualifiedName.from_string("AuditCertificateExpiredEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2080")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditCertificateExpiredEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2085")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2080")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2086")
    node.BrowseName = ua.QualifiedName.from_string("AuditCertificateInvalidEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2080")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditCertificateInvalidEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2086")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2080")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2087")
    node.BrowseName = ua.QualifiedName.from_string("AuditCertificateUntrustedEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2080")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditCertificateUntrustedEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2087")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2080")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2088")
    node.BrowseName = ua.QualifiedName.from_string("AuditCertificateRevokedEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2080")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditCertificateRevokedEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2088")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2080")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2089")
    node.BrowseName = ua.QualifiedName.from_string("AuditCertificateMismatchEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2080")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditCertificateMismatchEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2089")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2080")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2090")
    node.BrowseName = ua.QualifiedName.from_string("AuditNodeManagementEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2052")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditNodeManagementEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2090")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2052")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2091")
    node.BrowseName = ua.QualifiedName.from_string("AuditAddNodesEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2090")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditAddNodesEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2091")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2092")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2091")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2090")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2092")
    node.BrowseName = ua.QualifiedName.from_string("NodesToAdd")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2091")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NodesToAdd")
    attrs.DataType = ua.NodeId.from_string("i=376")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2092")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2092")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2092")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2091")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2093")
    node.BrowseName = ua.QualifiedName.from_string("AuditDeleteNodesEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2090")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditDeleteNodesEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2093")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2094")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2093")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2090")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2094")
    node.BrowseName = ua.QualifiedName.from_string("NodesToDelete")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2093")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NodesToDelete")
    attrs.DataType = ua.NodeId.from_string("i=382")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2094")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2094")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2094")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2093")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2095")
    node.BrowseName = ua.QualifiedName.from_string("AuditAddReferencesEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2090")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditAddReferencesEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2096")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2090")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2096")
    node.BrowseName = ua.QualifiedName.from_string("ReferencesToAdd")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2095")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ReferencesToAdd")
    attrs.DataType = ua.NodeId.from_string("i=379")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2096")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2096")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2096")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2095")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2097")
    node.BrowseName = ua.QualifiedName.from_string("AuditDeleteReferencesEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2090")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditDeleteReferencesEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2097")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2098")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2097")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2090")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2098")
    node.BrowseName = ua.QualifiedName.from_string("ReferencesToDelete")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2097")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ReferencesToDelete")
    attrs.DataType = ua.NodeId.from_string("i=385")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2097")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2099")
    node.BrowseName = ua.QualifiedName.from_string("AuditUpdateEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2052")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditUpdateEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2099")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2052")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2100")
    node.BrowseName = ua.QualifiedName.from_string("AuditWriteUpdateEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2099")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditWriteUpdateEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2100")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2750")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2100")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2101")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2100")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2102")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2100")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2103")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2100")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2099")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2750")
    node.BrowseName = ua.QualifiedName.from_string("AttributeId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2100")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AttributeId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2750")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2750")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2750")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2100")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2101")
    node.BrowseName = ua.QualifiedName.from_string("IndexRange")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2100")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("IndexRange")
    attrs.DataType = ua.NodeId.from_string("i=291")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2101")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2101")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2101")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2100")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2102")
    node.BrowseName = ua.QualifiedName.from_string("OldValue")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2100")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OldValue")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2102")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2102")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2102")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2100")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2103")
    node.BrowseName = ua.QualifiedName.from_string("NewValue")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2100")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NewValue")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2103")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2103")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2103")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2100")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2104")
    node.BrowseName = ua.QualifiedName.from_string("AuditHistoryUpdateEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2099")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditHistoryUpdateEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2751")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2099")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2751")
    node.BrowseName = ua.QualifiedName.from_string("ParameterDataTypeId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2104")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ParameterDataTypeId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2751")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2751")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2751")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2104")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2127")
    node.BrowseName = ua.QualifiedName.from_string("AuditUpdateMethodEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2052")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditUpdateMethodEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2127")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2128")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2127")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2129")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2127")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2052")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2128")
    node.BrowseName = ua.QualifiedName.from_string("MethodId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2127")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MethodId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2128")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2128")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2128")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2127")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2129")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2127")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2129")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2129")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2129")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2127")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2130")
    node.BrowseName = ua.QualifiedName.from_string("SystemEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SystemEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2130")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2131")
    node.BrowseName = ua.QualifiedName.from_string("DeviceFailureEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2130")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("DeviceFailureEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2131")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2130")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11446")
    node.BrowseName = ua.QualifiedName.from_string("SystemStatusChangeEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2130")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SystemStatusChangeEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11446")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11696")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11446")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2130")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11696")
    node.BrowseName = ua.QualifiedName.from_string("SystemState")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11446")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SystemState")
    attrs.DataType = ua.NodeId.from_string("i=852")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11696")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11696")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11696")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11446")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2132")
    node.BrowseName = ua.QualifiedName.from_string("BaseModelChangeEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("BaseModelChangeEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2132")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2133")
    node.BrowseName = ua.QualifiedName.from_string("GeneralModelChangeEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2132")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("GeneralModelChangeEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2133")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2134")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2133")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2132")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2134")
    node.BrowseName = ua.QualifiedName.from_string("Changes")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2133")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Changes")
    attrs.DataType = ua.NodeId.from_string("i=877")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2134")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2134")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2134")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2133")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2738")
    node.BrowseName = ua.QualifiedName.from_string("SemanticChangeEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2132")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SemanticChangeEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2738")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2739")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2738")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2132")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2739")
    node.BrowseName = ua.QualifiedName.from_string("Changes")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2738")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Changes")
    attrs.DataType = ua.NodeId.from_string("i=897")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2739")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2739")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2739")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2738")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3035")
    node.BrowseName = ua.QualifiedName.from_string("EventQueueOverflowEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("EventQueueOverflowEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=3035")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11436")
    node.BrowseName = ua.QualifiedName.from_string("ProgressEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ProgressEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11436")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12502")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11436")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12503")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11436")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12502")
    node.BrowseName = ua.QualifiedName.from_string("Context")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11436")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Context")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12502")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12502")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12502")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11436")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12503")
    node.BrowseName = ua.QualifiedName.from_string("Progress")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11436")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Progress")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12503")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12503")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12503")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11436")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2340")
    node.BrowseName = ua.QualifiedName.from_string("AggregateFunctionType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AggregateFunctionType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2340")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2137")
    node.BrowseName = ua.QualifiedName.from_string("ServerVendorCapabilityType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerVendorCapabilityType")
    attrs.IsAbstract = True
    attrs.DisplayName = ua.LocalizedText("ServerVendorCapabilityType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2137")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2138")
    node.BrowseName = ua.QualifiedName.from_string("ServerStatusType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerStatusType")
    attrs.DisplayName = ua.LocalizedText("ServerStatusType")
    attrs.DataType = ua.NodeId.from_string("i=862")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2139")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2140")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2141")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2142")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2752")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2753")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2138")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2139")
    node.BrowseName = ua.QualifiedName.from_string("StartTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2138")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StartTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2139")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2139")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2139")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2138")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2140")
    node.BrowseName = ua.QualifiedName.from_string("CurrentTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2138")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2140")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2140")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2140")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2138")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2141")
    node.BrowseName = ua.QualifiedName.from_string("State")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2138")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("State")
    attrs.DataType = ua.NodeId.from_string("i=852")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2141")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2141")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2141")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2138")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2142")
    node.BrowseName = ua.QualifiedName.from_string("BuildInfo")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2138")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=3051")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BuildInfo")
    attrs.DataType = ua.NodeId.from_string("i=338")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3698")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3699")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3700")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3701")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3702")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3703")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3051")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2142")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2138")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3698")
    node.BrowseName = ua.QualifiedName.from_string("ProductUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("ProductUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3698")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3698")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3698")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3699")
    node.BrowseName = ua.QualifiedName.from_string("ManufacturerName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("ManufacturerName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3699")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3699")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3699")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3700")
    node.BrowseName = ua.QualifiedName.from_string("ProductName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("ProductName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3700")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3700")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3700")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3701")
    node.BrowseName = ua.QualifiedName.from_string("SoftwareVersion")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("SoftwareVersion")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3701")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3701")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3701")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3702")
    node.BrowseName = ua.QualifiedName.from_string("BuildNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("BuildNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3702")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3702")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3702")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3703")
    node.BrowseName = ua.QualifiedName.from_string("BuildDate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2142")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("BuildDate")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3703")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3703")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3703")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2142")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2752")
    node.BrowseName = ua.QualifiedName.from_string("SecondsTillShutdown")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2138")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecondsTillShutdown")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2752")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2752")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2752")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2138")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2753")
    node.BrowseName = ua.QualifiedName.from_string("ShutdownReason")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2138")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ShutdownReason")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2753")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2753")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2753")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2138")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3051")
    node.BrowseName = ua.QualifiedName.from_string("BuildInfoType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("BuildInfoType")
    attrs.DisplayName = ua.LocalizedText("BuildInfoType")
    attrs.DataType = ua.NodeId.from_string("i=338")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3051")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3052")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3051")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3053")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3051")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3054")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3051")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3055")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3051")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3056")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3051")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3057")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=3051")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3052")
    node.BrowseName = ua.QualifiedName.from_string("ProductUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3051")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("ProductUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3052")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3052")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3052")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3051")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3053")
    node.BrowseName = ua.QualifiedName.from_string("ManufacturerName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3051")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("ManufacturerName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3053")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3053")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3053")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3051")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3054")
    node.BrowseName = ua.QualifiedName.from_string("ProductName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3051")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("ProductName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3054")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3054")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3054")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3051")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3055")
    node.BrowseName = ua.QualifiedName.from_string("SoftwareVersion")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3051")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("SoftwareVersion")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3055")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3055")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3055")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3051")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3056")
    node.BrowseName = ua.QualifiedName.from_string("BuildNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3051")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("BuildNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3056")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3056")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3056")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3051")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3057")
    node.BrowseName = ua.QualifiedName.from_string("BuildDate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3051")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("BuildDate")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3057")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3057")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3057")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3051")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2150")
    node.BrowseName = ua.QualifiedName.from_string("ServerDiagnosticsSummaryType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerDiagnosticsSummaryType")
    attrs.DisplayName = ua.LocalizedText("ServerDiagnosticsSummaryType")
    attrs.DataType = ua.NodeId.from_string("i=859")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2151")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2152")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2153")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2154")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2155")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2156")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2157")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2159")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2160")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2161")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2162")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2163")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2151")
    node.BrowseName = ua.QualifiedName.from_string("ServerViewCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2150")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerViewCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2151")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2151")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2151")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2152")
    node.BrowseName = ua.QualifiedName.from_string("CurrentSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2150")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2152")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2152")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2152")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2153")
    node.BrowseName = ua.QualifiedName.from_string("CumulatedSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2150")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CumulatedSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2153")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2153")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2153")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2154")
    node.BrowseName = ua.QualifiedName.from_string("SecurityRejectedSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2150")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityRejectedSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2154")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2154")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2154")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2155")
    node.BrowseName = ua.QualifiedName.from_string("RejectedSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2150")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RejectedSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2155")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2155")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2155")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2156")
    node.BrowseName = ua.QualifiedName.from_string("SessionTimeoutCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2150")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionTimeoutCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2156")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2156")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2156")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2157")
    node.BrowseName = ua.QualifiedName.from_string("SessionAbortCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2150")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionAbortCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2157")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2157")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2157")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2159")
    node.BrowseName = ua.QualifiedName.from_string("PublishingIntervalCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2150")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishingIntervalCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2159")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2159")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2159")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2160")
    node.BrowseName = ua.QualifiedName.from_string("CurrentSubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2150")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentSubscriptionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2160")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2160")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2160")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2161")
    node.BrowseName = ua.QualifiedName.from_string("CumulatedSubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2150")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CumulatedSubscriptionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2161")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2161")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2161")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2162")
    node.BrowseName = ua.QualifiedName.from_string("SecurityRejectedRequestsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2150")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityRejectedRequestsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2163")
    node.BrowseName = ua.QualifiedName.from_string("RejectedRequestsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2150")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RejectedRequestsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2163")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2163")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2163")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2164")
    node.BrowseName = ua.QualifiedName.from_string("SamplingIntervalDiagnosticsArrayType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SamplingIntervalDiagnosticsArrayType")
    attrs.DisplayName = ua.LocalizedText("SamplingIntervalDiagnosticsArrayType")
    attrs.DataType = ua.NodeId.from_string("i=856")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2164")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12779")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2164")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12779")
    node.BrowseName = ua.QualifiedName.from_string("SamplingIntervalDiagnostics")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2164")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2165")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SamplingIntervalDiagnostics")
    attrs.DataType = ua.NodeId.from_string("i=856")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12779")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12780")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12779")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12781")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12779")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12782")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12779")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12783")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12779")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2165")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12779")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=83")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12779")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2164")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12780")
    node.BrowseName = ua.QualifiedName.from_string("SamplingInterval")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12779")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SamplingInterval")
    attrs.DataType = ua.NodeId.from_string("i=290")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12780")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12780")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12780")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12779")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12781")
    node.BrowseName = ua.QualifiedName.from_string("SampledMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12779")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SampledMonitoredItemsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12781")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12781")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12781")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12779")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12782")
    node.BrowseName = ua.QualifiedName.from_string("MaxSampledMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12779")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MaxSampledMonitoredItemsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12782")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12782")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12782")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12779")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12783")
    node.BrowseName = ua.QualifiedName.from_string("DisabledMonitoredItemsSamplingCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12779")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DisabledMonitoredItemsSamplingCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12783")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12783")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12783")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12779")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2165")
    node.BrowseName = ua.QualifiedName.from_string("SamplingIntervalDiagnosticsType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SamplingIntervalDiagnosticsType")
    attrs.DisplayName = ua.LocalizedText("SamplingIntervalDiagnosticsType")
    attrs.DataType = ua.NodeId.from_string("i=856")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2166")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11697")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11698")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11699")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2166")
    node.BrowseName = ua.QualifiedName.from_string("SamplingInterval")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2165")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SamplingInterval")
    attrs.DataType = ua.NodeId.from_string("i=290")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2166")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2166")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2166")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2165")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11697")
    node.BrowseName = ua.QualifiedName.from_string("SampledMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2165")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SampledMonitoredItemsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11697")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11697")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11697")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2165")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11698")
    node.BrowseName = ua.QualifiedName.from_string("MaxSampledMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2165")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MaxSampledMonitoredItemsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11698")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11698")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11698")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2165")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11699")
    node.BrowseName = ua.QualifiedName.from_string("DisabledMonitoredItemsSamplingCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2165")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DisabledMonitoredItemsSamplingCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11699")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11699")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11699")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2165")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2171")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionDiagnosticsArrayType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnosticsArrayType")
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnosticsArrayType")
    attrs.DataType = ua.NodeId.from_string("i=874")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2171")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2171")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12784")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionDiagnostics")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2171")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2172")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnostics")
    attrs.DataType = ua.NodeId.from_string("i=874")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12785")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12786")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12787")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12788")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12789")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12790")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12791")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12792")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12793")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12794")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12795")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12796")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12797")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12798")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12799")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12800")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12801")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12802")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12803")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12804")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12805")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12806")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12807")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12808")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12809")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12810")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12811")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12812")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12813")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12814")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12815")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=83")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2171")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12785")
    node.BrowseName = ua.QualifiedName.from_string("SessionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12785")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12785")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12785")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12786")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SubscriptionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12786")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12786")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12786")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12787")
    node.BrowseName = ua.QualifiedName.from_string("Priority")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Priority")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Byte)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12787")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12787")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12787")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12788")
    node.BrowseName = ua.QualifiedName.from_string("PublishingInterval")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishingInterval")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Double)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12788")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12788")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12788")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12789")
    node.BrowseName = ua.QualifiedName.from_string("MaxKeepAliveCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MaxKeepAliveCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12789")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12789")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12789")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12790")
    node.BrowseName = ua.QualifiedName.from_string("MaxLifetimeCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MaxLifetimeCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12790")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12790")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12790")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12791")
    node.BrowseName = ua.QualifiedName.from_string("MaxNotificationsPerPublish")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MaxNotificationsPerPublish")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12791")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12791")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12791")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12792")
    node.BrowseName = ua.QualifiedName.from_string("PublishingEnabled")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishingEnabled")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12792")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12792")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12792")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12793")
    node.BrowseName = ua.QualifiedName.from_string("ModifyCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ModifyCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12793")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12793")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12793")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12794")
    node.BrowseName = ua.QualifiedName.from_string("EnableCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnableCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12794")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12794")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12794")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12795")
    node.BrowseName = ua.QualifiedName.from_string("DisableCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DisableCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12795")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12795")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12795")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12796")
    node.BrowseName = ua.QualifiedName.from_string("RepublishRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RepublishRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12796")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12796")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12796")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12797")
    node.BrowseName = ua.QualifiedName.from_string("RepublishMessageRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RepublishMessageRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12797")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12797")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12797")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12798")
    node.BrowseName = ua.QualifiedName.from_string("RepublishMessageCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RepublishMessageCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12798")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12798")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12798")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12799")
    node.BrowseName = ua.QualifiedName.from_string("TransferRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransferRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12799")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12799")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12799")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12800")
    node.BrowseName = ua.QualifiedName.from_string("TransferredToAltClientCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransferredToAltClientCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12800")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12800")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12800")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12801")
    node.BrowseName = ua.QualifiedName.from_string("TransferredToSameClientCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransferredToSameClientCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12801")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12801")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12801")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12802")
    node.BrowseName = ua.QualifiedName.from_string("PublishRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12802")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12802")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12802")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12803")
    node.BrowseName = ua.QualifiedName.from_string("DataChangeNotificationsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataChangeNotificationsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12804")
    node.BrowseName = ua.QualifiedName.from_string("EventNotificationsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EventNotificationsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12804")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12804")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12804")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12805")
    node.BrowseName = ua.QualifiedName.from_string("NotificationsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NotificationsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12805")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12805")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12805")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12806")
    node.BrowseName = ua.QualifiedName.from_string("LatePublishRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("LatePublishRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12806")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12806")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12806")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12807")
    node.BrowseName = ua.QualifiedName.from_string("CurrentKeepAliveCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentKeepAliveCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12807")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12807")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12807")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12808")
    node.BrowseName = ua.QualifiedName.from_string("CurrentLifetimeCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentLifetimeCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12808")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12808")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12808")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12809")
    node.BrowseName = ua.QualifiedName.from_string("UnacknowledgedMessageCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UnacknowledgedMessageCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12809")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12809")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12809")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12810")
    node.BrowseName = ua.QualifiedName.from_string("DiscardedMessageCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DiscardedMessageCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12810")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12810")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12810")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12811")
    node.BrowseName = ua.QualifiedName.from_string("MonitoredItemCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MonitoredItemCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12811")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12811")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12811")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12812")
    node.BrowseName = ua.QualifiedName.from_string("DisabledMonitoredItemCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DisabledMonitoredItemCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12812")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12812")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12812")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12813")
    node.BrowseName = ua.QualifiedName.from_string("MonitoringQueueOverflowCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MonitoringQueueOverflowCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12813")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12813")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12813")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12814")
    node.BrowseName = ua.QualifiedName.from_string("NextSequenceNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NextSequenceNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12814")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12814")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12814")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12815")
    node.BrowseName = ua.QualifiedName.from_string("EventQueueOverflowCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12784")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EventQueueOverflowCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12815")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12815")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12815")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12784")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2172")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionDiagnosticsType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnosticsType")
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnosticsType")
    attrs.DataType = ua.NodeId.from_string("i=874")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2173")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2174")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2175")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2176")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2177")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8888")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2179")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2180")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2181")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2182")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2183")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2184")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2185")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2186")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2187")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2188")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2189")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2190")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2191")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2998")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2193")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8889")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8890")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8891")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8892")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8893")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8894")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8895")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8896")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8897")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8902")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2173")
    node.BrowseName = ua.QualifiedName.from_string("SessionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2173")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2173")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2173")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2174")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SubscriptionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2174")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2174")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2174")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2175")
    node.BrowseName = ua.QualifiedName.from_string("Priority")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Priority")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Byte)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2176")
    node.BrowseName = ua.QualifiedName.from_string("PublishingInterval")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishingInterval")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Double)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2176")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2176")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2176")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2177")
    node.BrowseName = ua.QualifiedName.from_string("MaxKeepAliveCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MaxKeepAliveCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2177")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2177")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2177")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8888")
    node.BrowseName = ua.QualifiedName.from_string("MaxLifetimeCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MaxLifetimeCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8888")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8888")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8888")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2179")
    node.BrowseName = ua.QualifiedName.from_string("MaxNotificationsPerPublish")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MaxNotificationsPerPublish")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2179")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2179")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2179")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2180")
    node.BrowseName = ua.QualifiedName.from_string("PublishingEnabled")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishingEnabled")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2180")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2180")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2180")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2181")
    node.BrowseName = ua.QualifiedName.from_string("ModifyCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ModifyCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2181")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2181")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2181")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2182")
    node.BrowseName = ua.QualifiedName.from_string("EnableCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnableCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2182")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2182")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2182")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2183")
    node.BrowseName = ua.QualifiedName.from_string("DisableCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DisableCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2184")
    node.BrowseName = ua.QualifiedName.from_string("RepublishRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RepublishRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2184")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2184")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2184")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2185")
    node.BrowseName = ua.QualifiedName.from_string("RepublishMessageRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RepublishMessageRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2185")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2185")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2185")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2186")
    node.BrowseName = ua.QualifiedName.from_string("RepublishMessageCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RepublishMessageCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2186")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2186")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2186")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2187")
    node.BrowseName = ua.QualifiedName.from_string("TransferRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransferRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2187")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2187")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2187")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2188")
    node.BrowseName = ua.QualifiedName.from_string("TransferredToAltClientCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransferredToAltClientCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2188")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2188")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2188")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2189")
    node.BrowseName = ua.QualifiedName.from_string("TransferredToSameClientCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransferredToSameClientCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2189")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2189")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2189")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2190")
    node.BrowseName = ua.QualifiedName.from_string("PublishRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2190")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2190")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2190")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2191")
    node.BrowseName = ua.QualifiedName.from_string("DataChangeNotificationsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataChangeNotificationsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2191")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2191")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2191")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2998")
    node.BrowseName = ua.QualifiedName.from_string("EventNotificationsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EventNotificationsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2998")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2998")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2998")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2193")
    node.BrowseName = ua.QualifiedName.from_string("NotificationsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NotificationsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2193")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2193")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2193")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8889")
    node.BrowseName = ua.QualifiedName.from_string("LatePublishRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("LatePublishRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8889")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8889")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8889")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8890")
    node.BrowseName = ua.QualifiedName.from_string("CurrentKeepAliveCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentKeepAliveCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8890")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8890")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8890")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8891")
    node.BrowseName = ua.QualifiedName.from_string("CurrentLifetimeCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentLifetimeCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8891")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8891")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8891")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8892")
    node.BrowseName = ua.QualifiedName.from_string("UnacknowledgedMessageCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UnacknowledgedMessageCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8892")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8892")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8892")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8893")
    node.BrowseName = ua.QualifiedName.from_string("DiscardedMessageCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DiscardedMessageCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8893")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8893")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8893")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8894")
    node.BrowseName = ua.QualifiedName.from_string("MonitoredItemCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MonitoredItemCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8894")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8894")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8894")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8895")
    node.BrowseName = ua.QualifiedName.from_string("DisabledMonitoredItemCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DisabledMonitoredItemCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8895")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8895")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8895")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8896")
    node.BrowseName = ua.QualifiedName.from_string("MonitoringQueueOverflowCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MonitoringQueueOverflowCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8896")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8896")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8896")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8897")
    node.BrowseName = ua.QualifiedName.from_string("NextSequenceNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NextSequenceNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8897")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8897")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8897")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8902")
    node.BrowseName = ua.QualifiedName.from_string("EventQueueOverflowCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2172")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EventQueueOverflowCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8902")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8902")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8902")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2172")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2196")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnosticsArrayType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionDiagnosticsArrayType")
    attrs.DisplayName = ua.LocalizedText("SessionDiagnosticsArrayType")
    attrs.DataType = ua.NodeId.from_string("i=865")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2196")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2196")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12816")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnostics")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2196")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2197")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionDiagnostics")
    attrs.DataType = ua.NodeId.from_string("i=865")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12817")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12818")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12819")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12820")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12821")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12822")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12823")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12824")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12825")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12826")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12827")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12828")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12829")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12830")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12831")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12832")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12833")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12834")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12835")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12836")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12837")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12838")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12839")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12840")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12841")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12842")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12843")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12844")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12845")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12846")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12847")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12848")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12849")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12850")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12851")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12852")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12853")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12854")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12855")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12856")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12857")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12858")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12859")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=83")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2196")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12817")
    node.BrowseName = ua.QualifiedName.from_string("SessionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12817")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12817")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12817")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12818")
    node.BrowseName = ua.QualifiedName.from_string("SessionName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12818")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12818")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12818")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12819")
    node.BrowseName = ua.QualifiedName.from_string("ClientDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientDescription")
    attrs.DataType = ua.NodeId.from_string("i=308")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12819")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12819")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12819")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12820")
    node.BrowseName = ua.QualifiedName.from_string("ServerUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12820")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12820")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12820")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12821")
    node.BrowseName = ua.QualifiedName.from_string("EndpointUrl")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointUrl")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12821")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12821")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12821")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12822")
    node.BrowseName = ua.QualifiedName.from_string("LocaleIds")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("LocaleIds")
    attrs.DataType = ua.NodeId.from_string("i=295")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12822")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12822")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12822")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12823")
    node.BrowseName = ua.QualifiedName.from_string("ActualSessionTimeout")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ActualSessionTimeout")
    attrs.DataType = ua.NodeId.from_string("i=290")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12823")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12823")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12823")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12824")
    node.BrowseName = ua.QualifiedName.from_string("MaxResponseMessageSize")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MaxResponseMessageSize")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12824")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12824")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12824")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12825")
    node.BrowseName = ua.QualifiedName.from_string("ClientConnectionTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientConnectionTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12825")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12825")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12825")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12826")
    node.BrowseName = ua.QualifiedName.from_string("ClientLastContactTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientLastContactTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12826")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12826")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12826")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12827")
    node.BrowseName = ua.QualifiedName.from_string("CurrentSubscriptionsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentSubscriptionsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12827")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12827")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12827")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12828")
    node.BrowseName = ua.QualifiedName.from_string("CurrentMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentMonitoredItemsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12828")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12828")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12828")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12829")
    node.BrowseName = ua.QualifiedName.from_string("CurrentPublishRequestsInQueue")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentPublishRequestsInQueue")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12829")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12829")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12829")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12830")
    node.BrowseName = ua.QualifiedName.from_string("TotalRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TotalRequestCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12830")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12830")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12830")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12831")
    node.BrowseName = ua.QualifiedName.from_string("UnauthorizedRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UnauthorizedRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12831")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12831")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12831")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12832")
    node.BrowseName = ua.QualifiedName.from_string("ReadCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ReadCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12832")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12832")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12832")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12833")
    node.BrowseName = ua.QualifiedName.from_string("HistoryReadCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryReadCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12833")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12833")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12833")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12834")
    node.BrowseName = ua.QualifiedName.from_string("WriteCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("WriteCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12834")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12834")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12834")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12835")
    node.BrowseName = ua.QualifiedName.from_string("HistoryUpdateCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryUpdateCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12835")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12835")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12835")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12836")
    node.BrowseName = ua.QualifiedName.from_string("CallCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CallCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12836")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12836")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12836")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12837")
    node.BrowseName = ua.QualifiedName.from_string("CreateMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateMonitoredItemsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12837")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12837")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12837")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12838")
    node.BrowseName = ua.QualifiedName.from_string("ModifyMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ModifyMonitoredItemsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12838")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12838")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12838")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12839")
    node.BrowseName = ua.QualifiedName.from_string("SetMonitoringModeCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SetMonitoringModeCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12839")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12839")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12839")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12840")
    node.BrowseName = ua.QualifiedName.from_string("SetTriggeringCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SetTriggeringCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12840")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12840")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12840")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12841")
    node.BrowseName = ua.QualifiedName.from_string("DeleteMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteMonitoredItemsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12841")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12841")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12841")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12842")
    node.BrowseName = ua.QualifiedName.from_string("CreateSubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateSubscriptionCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12842")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12842")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12842")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12843")
    node.BrowseName = ua.QualifiedName.from_string("ModifySubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ModifySubscriptionCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12843")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12843")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12843")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12844")
    node.BrowseName = ua.QualifiedName.from_string("SetPublishingModeCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SetPublishingModeCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12844")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12844")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12844")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12845")
    node.BrowseName = ua.QualifiedName.from_string("PublishCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12845")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12845")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12845")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12846")
    node.BrowseName = ua.QualifiedName.from_string("RepublishCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RepublishCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12846")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12846")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12846")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12847")
    node.BrowseName = ua.QualifiedName.from_string("TransferSubscriptionsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransferSubscriptionsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12847")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12847")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12847")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12848")
    node.BrowseName = ua.QualifiedName.from_string("DeleteSubscriptionsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteSubscriptionsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12848")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12848")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12848")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12849")
    node.BrowseName = ua.QualifiedName.from_string("AddNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AddNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12849")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12849")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12849")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12850")
    node.BrowseName = ua.QualifiedName.from_string("AddReferencesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AddReferencesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12850")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12850")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12850")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12851")
    node.BrowseName = ua.QualifiedName.from_string("DeleteNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12851")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12851")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12851")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12852")
    node.BrowseName = ua.QualifiedName.from_string("DeleteReferencesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteReferencesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12852")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12852")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12852")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12853")
    node.BrowseName = ua.QualifiedName.from_string("BrowseCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrowseCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12853")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12853")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12853")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12854")
    node.BrowseName = ua.QualifiedName.from_string("BrowseNextCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrowseNextCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12854")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12854")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12854")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12855")
    node.BrowseName = ua.QualifiedName.from_string("TranslateBrowsePathsToNodeIdsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TranslateBrowsePathsToNodeIdsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12855")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12855")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12855")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12856")
    node.BrowseName = ua.QualifiedName.from_string("QueryFirstCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("QueryFirstCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12856")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12856")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12856")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12857")
    node.BrowseName = ua.QualifiedName.from_string("QueryNextCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("QueryNextCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12857")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12857")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12857")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12858")
    node.BrowseName = ua.QualifiedName.from_string("RegisterNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RegisterNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12858")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12858")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12858")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12859")
    node.BrowseName = ua.QualifiedName.from_string("UnregisterNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12816")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UnregisterNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12859")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12859")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12859")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12816")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2197")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnosticsVariableType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionDiagnosticsVariableType")
    attrs.DisplayName = ua.LocalizedText("SessionDiagnosticsVariableType")
    attrs.DataType = ua.NodeId.from_string("i=865")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2198")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2199")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2200")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2201")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2202")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2203")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2204")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3050")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2205")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2206")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2207")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2208")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2209")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8900")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11892")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2217")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2218")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2219")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2220")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2221")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2222")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2223")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2224")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2225")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2226")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2227")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2228")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2229")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2230")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2231")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2232")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2233")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2234")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2235")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2236")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2237")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2238")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2239")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2240")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2241")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2242")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2730")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2731")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2198")
    node.BrowseName = ua.QualifiedName.from_string("SessionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2198")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2198")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2198")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2199")
    node.BrowseName = ua.QualifiedName.from_string("SessionName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2199")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2199")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2199")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2200")
    node.BrowseName = ua.QualifiedName.from_string("ClientDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientDescription")
    attrs.DataType = ua.NodeId.from_string("i=308")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2200")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2200")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2200")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2201")
    node.BrowseName = ua.QualifiedName.from_string("ServerUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2201")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2201")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2201")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2202")
    node.BrowseName = ua.QualifiedName.from_string("EndpointUrl")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointUrl")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2202")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2202")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2202")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2203")
    node.BrowseName = ua.QualifiedName.from_string("LocaleIds")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("LocaleIds")
    attrs.DataType = ua.NodeId.from_string("i=295")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2203")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2203")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2203")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2204")
    node.BrowseName = ua.QualifiedName.from_string("ActualSessionTimeout")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ActualSessionTimeout")
    attrs.DataType = ua.NodeId.from_string("i=290")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2204")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2204")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2204")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3050")
    node.BrowseName = ua.QualifiedName.from_string("MaxResponseMessageSize")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MaxResponseMessageSize")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3050")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3050")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3050")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2205")
    node.BrowseName = ua.QualifiedName.from_string("ClientConnectionTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientConnectionTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2205")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2205")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2205")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2206")
    node.BrowseName = ua.QualifiedName.from_string("ClientLastContactTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientLastContactTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2206")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2206")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2206")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2207")
    node.BrowseName = ua.QualifiedName.from_string("CurrentSubscriptionsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentSubscriptionsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2207")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2207")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2207")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2208")
    node.BrowseName = ua.QualifiedName.from_string("CurrentMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentMonitoredItemsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2208")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2208")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2208")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2209")
    node.BrowseName = ua.QualifiedName.from_string("CurrentPublishRequestsInQueue")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentPublishRequestsInQueue")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2209")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2209")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2209")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8900")
    node.BrowseName = ua.QualifiedName.from_string("TotalRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TotalRequestCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8900")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=8900")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8900")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11892")
    node.BrowseName = ua.QualifiedName.from_string("UnauthorizedRequestCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UnauthorizedRequestCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11892")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11892")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11892")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2217")
    node.BrowseName = ua.QualifiedName.from_string("ReadCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ReadCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2217")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2217")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2217")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2218")
    node.BrowseName = ua.QualifiedName.from_string("HistoryReadCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryReadCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2218")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2218")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2218")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2219")
    node.BrowseName = ua.QualifiedName.from_string("WriteCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("WriteCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2219")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2219")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2219")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2220")
    node.BrowseName = ua.QualifiedName.from_string("HistoryUpdateCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryUpdateCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2220")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2220")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2220")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2221")
    node.BrowseName = ua.QualifiedName.from_string("CallCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CallCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2221")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2221")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2221")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2222")
    node.BrowseName = ua.QualifiedName.from_string("CreateMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateMonitoredItemsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2222")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2222")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2222")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2223")
    node.BrowseName = ua.QualifiedName.from_string("ModifyMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ModifyMonitoredItemsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2223")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2223")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2223")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2224")
    node.BrowseName = ua.QualifiedName.from_string("SetMonitoringModeCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SetMonitoringModeCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2224")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2224")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2224")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2225")
    node.BrowseName = ua.QualifiedName.from_string("SetTriggeringCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SetTriggeringCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2225")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2225")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2225")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2226")
    node.BrowseName = ua.QualifiedName.from_string("DeleteMonitoredItemsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteMonitoredItemsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2226")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2226")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2226")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2227")
    node.BrowseName = ua.QualifiedName.from_string("CreateSubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateSubscriptionCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2227")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2227")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2227")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2228")
    node.BrowseName = ua.QualifiedName.from_string("ModifySubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ModifySubscriptionCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2228")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2228")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2228")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2229")
    node.BrowseName = ua.QualifiedName.from_string("SetPublishingModeCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SetPublishingModeCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2229")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2229")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2229")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2230")
    node.BrowseName = ua.QualifiedName.from_string("PublishCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2230")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2230")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2230")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2231")
    node.BrowseName = ua.QualifiedName.from_string("RepublishCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RepublishCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2231")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2231")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2231")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2232")
    node.BrowseName = ua.QualifiedName.from_string("TransferSubscriptionsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransferSubscriptionsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2232")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2232")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2232")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2233")
    node.BrowseName = ua.QualifiedName.from_string("DeleteSubscriptionsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteSubscriptionsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2233")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2233")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2233")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2234")
    node.BrowseName = ua.QualifiedName.from_string("AddNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AddNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2234")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2234")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2234")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2235")
    node.BrowseName = ua.QualifiedName.from_string("AddReferencesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AddReferencesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2235")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2235")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2235")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2236")
    node.BrowseName = ua.QualifiedName.from_string("DeleteNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2236")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2236")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2236")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2237")
    node.BrowseName = ua.QualifiedName.from_string("DeleteReferencesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteReferencesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2237")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2237")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2237")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2238")
    node.BrowseName = ua.QualifiedName.from_string("BrowseCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrowseCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2238")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2238")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2238")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2239")
    node.BrowseName = ua.QualifiedName.from_string("BrowseNextCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrowseNextCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2239")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2239")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2239")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2240")
    node.BrowseName = ua.QualifiedName.from_string("TranslateBrowsePathsToNodeIdsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TranslateBrowsePathsToNodeIdsCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2240")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2240")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2240")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2241")
    node.BrowseName = ua.QualifiedName.from_string("QueryFirstCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("QueryFirstCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2241")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2241")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2241")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2242")
    node.BrowseName = ua.QualifiedName.from_string("QueryNextCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("QueryNextCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2242")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2242")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2242")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2730")
    node.BrowseName = ua.QualifiedName.from_string("RegisterNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RegisterNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2730")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2730")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2730")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2731")
    node.BrowseName = ua.QualifiedName.from_string("UnregisterNodesCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UnregisterNodesCount")
    attrs.DataType = ua.NodeId.from_string("i=871")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2731")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2731")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2731")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2243")
    node.BrowseName = ua.QualifiedName.from_string("SessionSecurityDiagnosticsArrayType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnosticsArrayType")
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnosticsArrayType")
    attrs.DataType = ua.NodeId.from_string("i=868")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2243")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12860")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2243")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12860")
    node.BrowseName = ua.QualifiedName.from_string("SessionSecurityDiagnostics")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2243")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2244")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnostics")
    attrs.DataType = ua.NodeId.from_string("i=868")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12861")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12862")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12863")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12864")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12865")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12866")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12867")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12868")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12869")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2244")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=83")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2243")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12861")
    node.BrowseName = ua.QualifiedName.from_string("SessionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12860")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12861")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12861")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12861")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12860")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12862")
    node.BrowseName = ua.QualifiedName.from_string("ClientUserIdOfSession")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12860")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientUserIdOfSession")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12862")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12862")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12862")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12860")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12863")
    node.BrowseName = ua.QualifiedName.from_string("ClientUserIdHistory")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12860")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientUserIdHistory")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12863")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12863")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12863")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12860")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12864")
    node.BrowseName = ua.QualifiedName.from_string("AuthenticationMechanism")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12860")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AuthenticationMechanism")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12864")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12864")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12864")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12860")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12865")
    node.BrowseName = ua.QualifiedName.from_string("Encoding")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12860")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Encoding")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12865")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12865")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12865")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12860")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12866")
    node.BrowseName = ua.QualifiedName.from_string("TransportProtocol")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12860")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransportProtocol")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12866")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12866")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12866")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12860")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12867")
    node.BrowseName = ua.QualifiedName.from_string("SecurityMode")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12860")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityMode")
    attrs.DataType = ua.NodeId.from_string("i=302")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12867")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12867")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12867")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12860")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12868")
    node.BrowseName = ua.QualifiedName.from_string("SecurityPolicyUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12860")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityPolicyUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12868")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12868")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12868")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12860")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12869")
    node.BrowseName = ua.QualifiedName.from_string("ClientCertificate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12860")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientCertificate")
    attrs.DataType = ua.NodeId(ua.ObjectIds.ByteString)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12869")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12869")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12869")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12860")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2244")
    node.BrowseName = ua.QualifiedName.from_string("SessionSecurityDiagnosticsType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnosticsType")
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnosticsType")
    attrs.DataType = ua.NodeId.from_string("i=868")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2245")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2246")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2247")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2248")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2249")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2250")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2251")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2252")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3058")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2245")
    node.BrowseName = ua.QualifiedName.from_string("SessionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2244")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2245")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2245")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2245")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2244")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2246")
    node.BrowseName = ua.QualifiedName.from_string("ClientUserIdOfSession")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2244")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientUserIdOfSession")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2246")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2246")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2246")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2244")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2247")
    node.BrowseName = ua.QualifiedName.from_string("ClientUserIdHistory")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2244")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientUserIdHistory")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2247")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2247")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2247")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2244")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2248")
    node.BrowseName = ua.QualifiedName.from_string("AuthenticationMechanism")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2244")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AuthenticationMechanism")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2248")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2248")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2248")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2244")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2249")
    node.BrowseName = ua.QualifiedName.from_string("Encoding")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2244")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Encoding")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2249")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2249")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2249")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2244")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2250")
    node.BrowseName = ua.QualifiedName.from_string("TransportProtocol")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2244")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransportProtocol")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2250")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2250")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2250")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2244")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2251")
    node.BrowseName = ua.QualifiedName.from_string("SecurityMode")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2244")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityMode")
    attrs.DataType = ua.NodeId.from_string("i=302")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2251")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2251")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2251")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2244")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2252")
    node.BrowseName = ua.QualifiedName.from_string("SecurityPolicyUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2244")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityPolicyUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2244")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3058")
    node.BrowseName = ua.QualifiedName.from_string("ClientCertificate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2244")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientCertificate")
    attrs.DataType = ua.NodeId(ua.ObjectIds.ByteString)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3058")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3058")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3058")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2244")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11487")
    node.BrowseName = ua.QualifiedName.from_string("OptionSetType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("OptionSetType")
    attrs.DisplayName = ua.LocalizedText("OptionSetType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11487")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11488")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11487")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11701")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11487")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11488")
    node.BrowseName = ua.QualifiedName.from_string("OptionSetValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11487")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OptionSetValues")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11488")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11488")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11488")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11487")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11701")
    node.BrowseName = ua.QualifiedName.from_string("BitMask")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11487")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BitMask")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11701")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11701")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11701")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11487")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16309")
    node.BrowseName = ua.QualifiedName.from_string("SelectionListType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SelectionListType")
    attrs.DisplayName = ua.LocalizedText("SelectionListType")
    attrs.DataType = ua.NodeId.from_string("i=862")
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16309")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17632")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16309")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17633")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16309")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16312")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=16309")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17632")
    node.BrowseName = ua.QualifiedName.from_string("Selections")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16309")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Selections")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=17632")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=17632")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=17632")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16309")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17633")
    node.BrowseName = ua.QualifiedName.from_string("SelectionDescriptions")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16309")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SelectionDescriptions")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=17633")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=17633")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=17633")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16309")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16312")
    node.BrowseName = ua.QualifiedName.from_string("RestrictToList")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16309")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RestrictToList")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16312")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16312")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16312")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16309")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17986")
    node.BrowseName = ua.QualifiedName.from_string("AudioVariableType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AudioVariableType")
    attrs.DisplayName = ua.LocalizedText("AudioVariableType")
    attrs.DataType = ua.NodeId.from_string("i=16307")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=17986")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17988")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=17986")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17989")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=17986")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17990")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=17986")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17988")
    node.BrowseName = ua.QualifiedName.from_string("ListId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=17986")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ListId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=17988")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=17988")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=17988")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17986")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17989")
    node.BrowseName = ua.QualifiedName.from_string("AgencyId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=17986")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AgencyId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=17989")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=17989")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=17989")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17986")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17990")
    node.BrowseName = ua.QualifiedName.from_string("VersionId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=17986")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("VersionId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=17990")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=17990")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=17990")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17986")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3048")
    node.BrowseName = ua.QualifiedName.from_string("EventTypes")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=86")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("EventTypes")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=3048")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=86")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=3048")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3048")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2253")
    node.BrowseName = ua.QualifiedName.from_string("Server")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=85")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=2004")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Server")
    attrs.EventNotifier = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2254")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2255")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2256")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2267")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2994")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12885")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2274")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2295")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2296")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11715")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11492")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12873")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12749")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12886")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16313")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=85")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2004")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2254")
    node.BrowseName = ua.QualifiedName.from_string("ServerArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("The list of server URIs used by the server.")
    attrs.DisplayName = ua.LocalizedText("ServerArray")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2254")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2254")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2255")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("The list of namespace URIs used by the server.")
    attrs.DisplayName = ua.LocalizedText("NamespaceArray")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2255")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2255")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2256")
    node.BrowseName = ua.QualifiedName.from_string("ServerStatus")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2138")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("The current status of the server.")
    attrs.DisplayName = ua.LocalizedText("ServerStatus")
    attrs.DataType = ua.NodeId.from_string("i=862")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2256")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2257")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2256")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2258")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2256")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2259")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2256")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2260")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2256")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2992")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2256")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2993")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2256")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2138")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2256")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2257")
    node.BrowseName = ua.QualifiedName.from_string("StartTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2256")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StartTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2257")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2257")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2256")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2258")
    node.BrowseName = ua.QualifiedName.from_string("CurrentTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2256")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2258")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2258")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2256")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2259")
    node.BrowseName = ua.QualifiedName.from_string("State")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2256")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("State")
    attrs.DataType = ua.NodeId.from_string("i=852")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2259")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2259")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2256")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2260")
    node.BrowseName = ua.QualifiedName.from_string("BuildInfo")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2256")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=3051")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BuildInfo")
    attrs.DataType = ua.NodeId.from_string("i=338")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2260")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2262")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2260")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2263")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2260")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2261")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2260")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2264")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2260")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2265")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2260")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2266")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2260")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3051")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2260")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2256")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2262")
    node.BrowseName = ua.QualifiedName.from_string("ProductUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2260")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("ProductUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2262")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2262")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2260")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2263")
    node.BrowseName = ua.QualifiedName.from_string("ManufacturerName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2260")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("ManufacturerName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2263")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2263")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2260")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2261")
    node.BrowseName = ua.QualifiedName.from_string("ProductName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2260")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("ProductName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2261")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2261")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2260")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2264")
    node.BrowseName = ua.QualifiedName.from_string("SoftwareVersion")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2260")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("SoftwareVersion")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2264")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2264")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2260")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2265")
    node.BrowseName = ua.QualifiedName.from_string("BuildNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2260")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("BuildNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2265")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2265")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2260")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2266")
    node.BrowseName = ua.QualifiedName.from_string("BuildDate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2260")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.DisplayName = ua.LocalizedText("BuildDate")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2266")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2266")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2260")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2992")
    node.BrowseName = ua.QualifiedName.from_string("SecondsTillShutdown")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2256")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecondsTillShutdown")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2992")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2992")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2256")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2993")
    node.BrowseName = ua.QualifiedName.from_string("ShutdownReason")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2256")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ShutdownReason")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2993")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2993")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2256")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2267")
    node.BrowseName = ua.QualifiedName.from_string("ServiceLevel")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("A value indicating the level of service the server can provide. 255 indicates the best.")
    attrs.DisplayName = ua.LocalizedText("ServiceLevel")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Byte)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2267")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2267")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2994")
    node.BrowseName = ua.QualifiedName.from_string("Auditing")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("A flag indicating whether the server is currently generating audit events.")
    attrs.DisplayName = ua.LocalizedText("Auditing")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2994")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2994")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12885")
    node.BrowseName = ua.QualifiedName.from_string("EstimatedReturnTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.MinimumSamplingInterval = 1000
    attrs.Description = ua.LocalizedText("Indicates the time at which the Server is expected to be available in the state RUNNING.")
    attrs.DisplayName = ua.LocalizedText("EstimatedReturnTime")
    attrs.DataType = ua.NodeId(ua.ObjectIds.DateTime)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12885")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12885")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2268")
    node.BrowseName = ua.QualifiedName.from_string("ServerCapabilities")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2013")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Describes capabilities supported by the server.")
    attrs.DisplayName = ua.LocalizedText("ServerCapabilities")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2269")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2271")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2272")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2735")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2736")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2737")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3704")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11702")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11703")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12911")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2996")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2997")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15606")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2013")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2269")
    node.BrowseName = ua.QualifiedName.from_string("ServerProfileArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of profiles supported by the server.")
    attrs.DisplayName = ua.LocalizedText("ServerProfileArray")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2269")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2269")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2271")
    node.BrowseName = ua.QualifiedName.from_string("LocaleIdArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of locales supported by the server.")
    attrs.DisplayName = ua.LocalizedText("LocaleIdArray")
    attrs.DataType = ua.NodeId.from_string("i=295")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2271")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2271")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2272")
    node.BrowseName = ua.QualifiedName.from_string("MinSupportedSampleRate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The minimum sampling interval supported by the server.")
    attrs.DisplayName = ua.LocalizedText("MinSupportedSampleRate")
    attrs.DataType = ua.NodeId.from_string("i=290")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2272")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2272")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2735")
    node.BrowseName = ua.QualifiedName.from_string("MaxBrowseContinuationPoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of continuation points for Browse operations per session.")
    attrs.DisplayName = ua.LocalizedText("MaxBrowseContinuationPoints")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2735")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2735")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2736")
    node.BrowseName = ua.QualifiedName.from_string("MaxQueryContinuationPoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of continuation points for Query operations per session.")
    attrs.DisplayName = ua.LocalizedText("MaxQueryContinuationPoints")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2736")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2736")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2737")
    node.BrowseName = ua.QualifiedName.from_string("MaxHistoryContinuationPoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of continuation points for ReadHistory operations per session.")
    attrs.DisplayName = ua.LocalizedText("MaxHistoryContinuationPoints")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2737")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2737")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3704")
    node.BrowseName = ua.QualifiedName.from_string("SoftwareCertificates")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The software certificates owned by the server.")
    attrs.DisplayName = ua.LocalizedText("SoftwareCertificates")
    attrs.DataType = ua.NodeId.from_string("i=344")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11702")
    node.BrowseName = ua.QualifiedName.from_string("MaxArrayLength")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum length for an array value supported by the server.")
    attrs.DisplayName = ua.LocalizedText("MaxArrayLength")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11702")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11702")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11703")
    node.BrowseName = ua.QualifiedName.from_string("MaxStringLength")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum length for a string value supported by the server.")
    attrs.DisplayName = ua.LocalizedText("MaxStringLength")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11703")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11703")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12911")
    node.BrowseName = ua.QualifiedName.from_string("MaxByteStringLength")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum length for a byte string value supported by the server.")
    attrs.DisplayName = ua.LocalizedText("MaxByteStringLength")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12911")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12911")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11704")
    node.BrowseName = ua.QualifiedName.from_string("OperationLimits")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=11564")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Defines the limits supported by the server for different operations.")
    attrs.DisplayName = ua.LocalizedText("OperationLimits")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11705")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12165")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12166")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11707")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12167")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12168")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11709")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11710")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11711")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11712")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11713")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11714")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11564")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11705")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerRead")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single Read request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerRead")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11705")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11705")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12165")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerHistoryReadData")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single data HistoryRead request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerHistoryReadData")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12166")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerHistoryReadEvents")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single event HistoryRead request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerHistoryReadEvents")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12166")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12166")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11707")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerWrite")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single Write request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerWrite")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11707")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11707")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12167")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerHistoryUpdateData")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single data HistoryUpdate request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerHistoryUpdateData")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12167")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12167")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12168")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerHistoryUpdateEvents")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single event HistoryUpdate request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerHistoryUpdateEvents")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12168")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12168")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11709")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerMethodCall")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single Call request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerMethodCall")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11709")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11709")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11710")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerBrowse")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single Browse request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerBrowse")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11710")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11710")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11711")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerRegisterNodes")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single RegisterNodes request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerRegisterNodes")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11711")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11711")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11712")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerTranslateBrowsePathsToNodeIds")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single TranslateBrowsePathsToNodeIds request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerTranslateBrowsePathsToNodeIds")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11712")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11712")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11713")
    node.BrowseName = ua.QualifiedName.from_string("MaxNodesPerNodeManagement")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single AddNodes, AddReferences, DeleteNodes or DeleteReferences request.")
    attrs.DisplayName = ua.LocalizedText("MaxNodesPerNodeManagement")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11713")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11713")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11714")
    node.BrowseName = ua.QualifiedName.from_string("MaxMonitoredItemsPerCall")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of operations in a single MonitoredItem related request.")
    attrs.DisplayName = ua.LocalizedText("MaxMonitoredItemsPerCall")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11714")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11714")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2996")
    node.BrowseName = ua.QualifiedName.from_string("ModellingRules")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("A folder for the modelling rules supported by the server.")
    attrs.DisplayName = ua.LocalizedText("ModellingRules")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2996")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2996")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2997")
    node.BrowseName = ua.QualifiedName.from_string("AggregateFunctions")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=61")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("A folder for the real time aggregates supported by the server.")
    attrs.DisplayName = ua.LocalizedText("AggregateFunctions")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2997")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2997")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15606")
    node.BrowseName = ua.QualifiedName.from_string("Roles")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2268")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=15607")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Describes the roles supported by the server.")
    attrs.DisplayName = ua.LocalizedText("Roles")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15606")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16301")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15606")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16304")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15606")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15607")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15606")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2268")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16301")
    node.BrowseName = ua.QualifiedName.from_string("AddRole")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15606")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddRole")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16301")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16302")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16301")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16303")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16301")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15606")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16302")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16301")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RoleName'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'NamespaceUri'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16302")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16302")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16301")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16303")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16301")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RoleNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16303")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16303")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16301")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16304")
    node.BrowseName = ua.QualifiedName.from_string("RemoveRole")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15606")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveRole")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16304")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16305")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16304")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15606")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16305")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16304")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RoleNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16305")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16305")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16304")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2274")
    node.BrowseName = ua.QualifiedName.from_string("ServerDiagnostics")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2020")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Reports diagnostics about the server.")
    attrs.DisplayName = ua.LocalizedText("ServerDiagnostics")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2274")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2274")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2289")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2274")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2290")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2274")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3706")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2274")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2294")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2274")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2020")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2274")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2275")
    node.BrowseName = ua.QualifiedName.from_string("ServerDiagnosticsSummary")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2274")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2150")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A summary of server level diagnostics.")
    attrs.DisplayName = ua.LocalizedText("ServerDiagnosticsSummary")
    attrs.DataType = ua.NodeId.from_string("i=859")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2276")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2277")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2278")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2279")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3705")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2281")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2282")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2284")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2285")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2286")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2287")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2288")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2150")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2274")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2276")
    node.BrowseName = ua.QualifiedName.from_string("ServerViewCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2275")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerViewCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2276")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2276")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2277")
    node.BrowseName = ua.QualifiedName.from_string("CurrentSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2275")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2277")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2277")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2278")
    node.BrowseName = ua.QualifiedName.from_string("CumulatedSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2275")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CumulatedSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2278")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2278")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2279")
    node.BrowseName = ua.QualifiedName.from_string("SecurityRejectedSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2275")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityRejectedSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2279")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2279")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3705")
    node.BrowseName = ua.QualifiedName.from_string("RejectedSessionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2275")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RejectedSessionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3705")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3705")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2281")
    node.BrowseName = ua.QualifiedName.from_string("SessionTimeoutCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2275")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionTimeoutCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2281")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2281")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2282")
    node.BrowseName = ua.QualifiedName.from_string("SessionAbortCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2275")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionAbortCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2282")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2282")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2284")
    node.BrowseName = ua.QualifiedName.from_string("PublishingIntervalCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2275")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishingIntervalCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2284")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2284")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2285")
    node.BrowseName = ua.QualifiedName.from_string("CurrentSubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2275")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentSubscriptionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2285")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2285")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2286")
    node.BrowseName = ua.QualifiedName.from_string("CumulatedSubscriptionCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2275")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CumulatedSubscriptionCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2286")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2286")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2287")
    node.BrowseName = ua.QualifiedName.from_string("SecurityRejectedRequestsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2275")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SecurityRejectedRequestsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2287")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2287")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2288")
    node.BrowseName = ua.QualifiedName.from_string("RejectedRequestsCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2275")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RejectedRequestsCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2288")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2288")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2275")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2289")
    node.BrowseName = ua.QualifiedName.from_string("SamplingIntervalDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2274")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2164")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of diagnostics for each sampling interval supported by the server.")
    attrs.DisplayName = ua.LocalizedText("SamplingIntervalDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=856")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2289")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2164")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2289")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2274")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2290")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2274")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2171")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of diagnostics for each active subscription.")
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=874")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2290")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2171")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2290")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2274")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3706")
    node.BrowseName = ua.QualifiedName.from_string("SessionsDiagnosticsSummary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2274")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2026")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("A summary of session level diagnostics.")
    attrs.DisplayName = ua.LocalizedText("SessionsDiagnosticsSummary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3706")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3707")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3706")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3708")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3706")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2026")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3706")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2274")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3707")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3706")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2196")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of diagnostics for each active session.")
    attrs.DisplayName = ua.LocalizedText("SessionDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=865")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3707")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2196")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3707")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3706")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3708")
    node.BrowseName = ua.QualifiedName.from_string("SessionSecurityDiagnosticsArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=3706")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2243")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A list of security related diagnostics for each active session.")
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnosticsArray")
    attrs.DataType = ua.NodeId.from_string("i=868")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3708")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2243")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=3708")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3706")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2294")
    node.BrowseName = ua.QualifiedName.from_string("EnabledFlag")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2274")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("If TRUE the diagnostics collection is enabled.")
    attrs.DisplayName = ua.LocalizedText("EnabledFlag")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    attrs.AccessLevel = 3
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2294")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2294")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2274")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2295")
    node.BrowseName = ua.QualifiedName.from_string("VendorServerInfo")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2033")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Server information provided by the vendor.")
    attrs.DisplayName = ua.LocalizedText("VendorServerInfo")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2295")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2033")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2295")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2296")
    node.BrowseName = ua.QualifiedName.from_string("ServerRedundancy")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2034")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Describes the redundancy capabilities of the server.")
    attrs.DisplayName = ua.LocalizedText("ServerRedundancy")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2296")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3709")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2296")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11312")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2296")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11313")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2296")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11314")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2296")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14415")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2296")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2034")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2296")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3709")
    node.BrowseName = ua.QualifiedName.from_string("RedundancySupport")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2296")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Indicates what style of redundancy is supported by the server.")
    attrs.DisplayName = ua.LocalizedText("RedundancySupport")
    attrs.DataType = ua.NodeId.from_string("i=851")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3709")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3709")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2296")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11312")
    node.BrowseName = ua.QualifiedName.from_string("CurrentServerId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2296")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentServerId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11312")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11312")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2296")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11313")
    node.BrowseName = ua.QualifiedName.from_string("RedundantServerArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2296")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RedundantServerArray")
    attrs.DataType = ua.NodeId.from_string("i=853")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11313")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11313")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2296")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11314")
    node.BrowseName = ua.QualifiedName.from_string("ServerUriArray")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2296")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerUriArray")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11314")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11314")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2296")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14415")
    node.BrowseName = ua.QualifiedName.from_string("ServerNetworkGroups")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2296")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerNetworkGroups")
    attrs.DataType = ua.NodeId.from_string("i=11944")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14415")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=14415")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2296")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11715")
    node.BrowseName = ua.QualifiedName.from_string("Namespaces")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=11645")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("Describes the namespaces supported by the server.")
    attrs.DisplayName = ua.LocalizedText("Namespaces")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11715")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11645")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11715")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11492")
    node.BrowseName = ua.QualifiedName.from_string("GetMonitoredItems")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("GetMonitoredItems")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11492")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11493")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11492")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11494")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11492")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11493")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11492")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'SubscriptionId'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11493")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11493")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11492")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11494")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=11492")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'ServerHandles'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = 1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'ClientHandles'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = 1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11494")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11494")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11492")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12873")
    node.BrowseName = ua.QualifiedName.from_string("ResendData")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("ResendData")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12873")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12874")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12873")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12874")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12873")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'SubscriptionId'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12874")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12874")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12873")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12749")
    node.BrowseName = ua.QualifiedName.from_string("SetSubscriptionDurable")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("SetSubscriptionDurable")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12749")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12750")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12749")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12751")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12749")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12750")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12749")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'SubscriptionId'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'LifetimeInHours'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12750")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12750")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12749")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12751")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12749")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RevisedLifetimeInHours'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12751")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12751")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12749")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12886")
    node.BrowseName = ua.QualifiedName.from_string("RequestServerStateChange")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RequestServerStateChange")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12886")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12887")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12886")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12887")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=12886")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'State'
    extobj.DataType = ua.NodeId.from_string("i=852")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'EstimatedReturnTime'
    extobj.DataType = ua.NodeId.from_string("i=13")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'SecondsTillShutdown'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Reason'
    extobj.DataType = ua.NodeId.from_string("i=21")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Restart'
    extobj.DataType = ua.NodeId.from_string("i=1")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12887")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12887")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12886")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16313")
    node.BrowseName = ua.QualifiedName.from_string("CurrentTimeZone")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2253")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentTimeZone")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16313")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16313")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2253")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11737")
    node.BrowseName = ua.QualifiedName.from_string("BitFieldMaskDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=9")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A mask of 32 bits that can be updated individually by using the top 32 bits as a mask.")
    attrs.DisplayName = ua.LocalizedText("BitFieldMaskDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11737")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=9")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14533")
    node.BrowseName = ua.QualifiedName.from_string("KeyValuePair")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("KeyValuePair")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=14533")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15528")
    node.BrowseName = ua.QualifiedName.from_string("EndpointType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=15528")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2299")
    node.BrowseName = ua.QualifiedName.from_string("StateMachineType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("StateMachineType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2299")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2769")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2299")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2770")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2299")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2769")
    node.BrowseName = ua.QualifiedName.from_string("CurrentState")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2299")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2755")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentState")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2769")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3720")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2769")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2755")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2769")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2769")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2299")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3720")
    node.BrowseName = ua.QualifiedName.from_string("Id")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2769")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Id")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3720")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3720")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3720")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2769")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2770")
    node.BrowseName = ua.QualifiedName.from_string("LastTransition")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2299")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2762")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("LastTransition")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2770")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3724")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2770")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2762")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2770")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2770")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2299")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3724")
    node.BrowseName = ua.QualifiedName.from_string("Id")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2770")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Id")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3724")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3724")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3724")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2770")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2755")
    node.BrowseName = ua.QualifiedName.from_string("StateVariableType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("StateVariableType")
    attrs.DisplayName = ua.LocalizedText("StateVariableType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2755")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2756")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2755")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2757")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2755")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2758")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2755")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2759")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2755")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2756")
    node.BrowseName = ua.QualifiedName.from_string("Id")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2755")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Id")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2756")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2756")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2756")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2755")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2757")
    node.BrowseName = ua.QualifiedName.from_string("Name")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2755")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Name")
    attrs.DataType = ua.NodeId(ua.ObjectIds.QualifiedName)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2757")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2757")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2757")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2755")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2758")
    node.BrowseName = ua.QualifiedName.from_string("Number")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2755")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Number")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2758")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2758")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2758")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2755")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2759")
    node.BrowseName = ua.QualifiedName.from_string("EffectiveDisplayName")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2755")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EffectiveDisplayName")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2759")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2759")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2759")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2755")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2762")
    node.BrowseName = ua.QualifiedName.from_string("TransitionVariableType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=63")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionVariableType")
    attrs.DisplayName = ua.LocalizedText("TransitionVariableType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2762")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2763")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2762")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2764")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2762")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2765")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2762")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2766")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2762")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11456")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2762")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2763")
    node.BrowseName = ua.QualifiedName.from_string("Id")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2762")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Id")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2763")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2763")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2763")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2762")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2764")
    node.BrowseName = ua.QualifiedName.from_string("Name")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2762")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Name")
    attrs.DataType = ua.NodeId(ua.ObjectIds.QualifiedName)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2764")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2764")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2764")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2762")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2765")
    node.BrowseName = ua.QualifiedName.from_string("Number")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2762")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Number")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2765")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2765")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2765")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2762")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2766")
    node.BrowseName = ua.QualifiedName.from_string("TransitionTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2762")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2766")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2766")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2766")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2762")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11456")
    node.BrowseName = ua.QualifiedName.from_string("EffectiveTransitionTime")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2762")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EffectiveTransitionTime")
    attrs.DataType = ua.NodeId.from_string("i=294")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11456")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11456")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11456")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2762")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2771")
    node.BrowseName = ua.QualifiedName.from_string("FiniteStateMachineType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2299")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("FiniteStateMachineType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2771")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2772")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2771")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2773")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2771")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17635")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2771")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17636")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2771")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2299")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2772")
    node.BrowseName = ua.QualifiedName.from_string("CurrentState")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2771")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2760")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentState")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2772")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3728")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2772")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2760")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2772")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2772")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2771")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3728")
    node.BrowseName = ua.QualifiedName.from_string("Id")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2772")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Id")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3728")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3728")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3728")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2772")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2773")
    node.BrowseName = ua.QualifiedName.from_string("LastTransition")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2771")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2767")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("LastTransition")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2773")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3732")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2773")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2767")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2773")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2773")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2771")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3732")
    node.BrowseName = ua.QualifiedName.from_string("Id")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2773")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Id")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3732")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3732")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3732")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2773")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17635")
    node.BrowseName = ua.QualifiedName.from_string("AvailableStates")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2771")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AvailableStates")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=17635")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=17635")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=17635")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2771")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17636")
    node.BrowseName = ua.QualifiedName.from_string("AvailableTransitions")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2771")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=63")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AvailableTransitions")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=17636")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=63")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=17636")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=17636")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2771")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2760")
    node.BrowseName = ua.QualifiedName.from_string("FiniteStateVariableType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=2755")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("FiniteStateVariableType")
    attrs.DisplayName = ua.LocalizedText("FiniteStateVariableType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2760")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2761")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2760")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2755")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2761")
    node.BrowseName = ua.QualifiedName.from_string("Id")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2760")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Id")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2761")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2761")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2761")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2760")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2767")
    node.BrowseName = ua.QualifiedName.from_string("FiniteTransitionVariableType")
    node.NodeClass = ua.NodeClass.VariableType
    node.ParentNodeId = ua.NodeId.from_string("i=2762")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.VariableTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("FiniteTransitionVariableType")
    attrs.DisplayName = ua.LocalizedText("FiniteTransitionVariableType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2767")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2768")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2767")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2762")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2768")
    node.BrowseName = ua.QualifiedName.from_string("Id")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2767")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Id")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2768")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2768")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2768")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2767")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2307")
    node.BrowseName = ua.QualifiedName.from_string("StateType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("StateType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2307")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2308")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2307")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2308")
    node.BrowseName = ua.QualifiedName.from_string("StateNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2307")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StateNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2308")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2308")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2308")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2307")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2309")
    node.BrowseName = ua.QualifiedName.from_string("InitialStateType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2307")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("InitialStateType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2309")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2307")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2310")
    node.BrowseName = ua.QualifiedName.from_string("TransitionType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2310")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2312")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2310")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2312")
    node.BrowseName = ua.QualifiedName.from_string("TransitionNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2310")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2312")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2312")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2312")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2310")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2311")
    node.BrowseName = ua.QualifiedName.from_string("TransitionEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionEventType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2311")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2774")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2311")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2775")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2311")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2776")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2311")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2774")
    node.BrowseName = ua.QualifiedName.from_string("Transition")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2311")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2762")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Transition")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2774")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3754")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2774")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2762")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2774")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2774")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2311")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3754")
    node.BrowseName = ua.QualifiedName.from_string("Id")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2774")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Id")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3754")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3754")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3754")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2774")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2775")
    node.BrowseName = ua.QualifiedName.from_string("FromState")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2311")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2755")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("FromState")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2775")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3746")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2775")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2755")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2775")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2775")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2311")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3746")
    node.BrowseName = ua.QualifiedName.from_string("Id")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2775")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Id")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2775")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2776")
    node.BrowseName = ua.QualifiedName.from_string("ToState")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2311")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2755")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ToState")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2776")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3750")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2776")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2755")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2776")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=2776")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2311")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3750")
    node.BrowseName = ua.QualifiedName.from_string("Id")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2776")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Id")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3750")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=3750")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=3750")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2776")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2315")
    node.BrowseName = ua.QualifiedName.from_string("AuditUpdateStateEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2127")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AuditUpdateStateEventType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2315")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2777")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2315")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2778")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2315")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2127")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2777")
    node.BrowseName = ua.QualifiedName.from_string("OldStateId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2315")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OldStateId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2777")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2777")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2777")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2315")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2778")
    node.BrowseName = ua.QualifiedName.from_string("NewStateId")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=2315")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NewStateId")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=2778")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=2778")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=2778")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2315")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13353")
    node.BrowseName = ua.QualifiedName.from_string("FileDirectoryType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=61")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("FileDirectoryType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13353")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13354")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13353")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13366")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13353")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13387")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13353")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13390")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13353")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13393")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13353")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13395")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=13353")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=61")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13354")
    node.BrowseName = ua.QualifiedName.from_string("<FileDirectoryName>")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=13353")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=13353")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("<FileDirectoryName>")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13354")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13355")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13354")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13358")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13354")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17718")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13354")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13363")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13354")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13353")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13354")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11508")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13354")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13353")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13355")
    node.BrowseName = ua.QualifiedName.from_string("CreateDirectory")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13354")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateDirectory")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13355")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13356")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13355")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13357")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13355")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13355")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13354")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13356")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13355")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'DirectoryName'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13356")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13356")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13356")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13355")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13357")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13355")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'DirectoryNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13357")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13357")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13357")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13355")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13358")
    node.BrowseName = ua.QualifiedName.from_string("CreateFile")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13354")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateFile")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13358")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13359")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13358")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13360")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13358")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13358")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13354")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13359")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13358")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileName'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'RequestFileOpen'
    extobj.DataType = ua.NodeId.from_string("i=1")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13359")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13359")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13359")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13358")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13360")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13358")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13360")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13360")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13360")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13358")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17718")
    node.BrowseName = ua.QualifiedName.from_string("Delete")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13354")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Delete")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=17718")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17719")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=17718")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=17718")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13354")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17719")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=17718")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'ObjectToDelete'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=17719")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=17719")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=17719")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17718")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13363")
    node.BrowseName = ua.QualifiedName.from_string("MoveOrCopy")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13354")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("MoveOrCopy")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13363")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13364")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13363")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13365")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13363")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13363")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13354")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13364")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13363")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'ObjectToMoveOrCopy'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'TargetDirectory'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'CreateCopy'
    extobj.DataType = ua.NodeId.from_string("i=1")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'NewName'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13364")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13364")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13364")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13363")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13365")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13363")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'NewNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13365")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13365")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13365")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13363")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13366")
    node.BrowseName = ua.QualifiedName.from_string("<FileName>")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=13353")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=11575")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("<FileName>")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13367")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13368")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13369")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13370")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13372")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13375")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13377")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13380")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13382")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13385")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11575")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11508")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13353")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13367")
    node.BrowseName = ua.QualifiedName.from_string("Size")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13366")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The size of the file in bytes.")
    attrs.DisplayName = ua.LocalizedText("Size")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt64)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13367")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13367")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13367")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13366")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13368")
    node.BrowseName = ua.QualifiedName.from_string("Writable")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13366")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Whether the file is writable.")
    attrs.DisplayName = ua.LocalizedText("Writable")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13368")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13368")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13368")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13366")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13369")
    node.BrowseName = ua.QualifiedName.from_string("UserWritable")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13366")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Whether the file is writable by the current user.")
    attrs.DisplayName = ua.LocalizedText("UserWritable")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13369")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13369")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13369")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13366")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13370")
    node.BrowseName = ua.QualifiedName.from_string("OpenCount")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13366")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The current number of open file handles.")
    attrs.DisplayName = ua.LocalizedText("OpenCount")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt16)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13370")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13370")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13370")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13366")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13372")
    node.BrowseName = ua.QualifiedName.from_string("Open")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13366")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Open")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13372")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13373")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13372")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13374")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13372")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13372")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13366")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13373")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13372")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'Mode'
    extobj.DataType = ua.NodeId.from_string("i=3")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13373")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13373")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13373")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13372")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13374")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13372")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13374")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13374")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13374")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13372")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13375")
    node.BrowseName = ua.QualifiedName.from_string("Close")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13366")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Close")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13375")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13376")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13375")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13375")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13366")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13376")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13375")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13376")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13376")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13376")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13375")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13377")
    node.BrowseName = ua.QualifiedName.from_string("Read")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13366")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Read")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13377")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13378")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13377")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13379")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13377")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13377")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13366")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13378")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13377")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Length'
    extobj.DataType = ua.NodeId.from_string("i=6")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13378")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13378")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13378")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13377")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13379")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13377")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'Data'
    extobj.DataType = ua.NodeId.from_string("i=15")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13379")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13379")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13379")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13377")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13380")
    node.BrowseName = ua.QualifiedName.from_string("Write")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13366")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Write")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13380")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13381")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13380")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13380")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13366")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13381")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13380")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Data'
    extobj.DataType = ua.NodeId.from_string("i=15")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13381")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13381")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13381")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13380")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13382")
    node.BrowseName = ua.QualifiedName.from_string("GetPosition")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13366")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("GetPosition")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13382")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13383")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13382")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13384")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13382")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13382")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13366")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13383")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13382")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13383")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13383")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13383")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13382")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13384")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13382")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'Position'
    extobj.DataType = ua.NodeId.from_string("i=9")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13384")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13384")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13384")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13382")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13385")
    node.BrowseName = ua.QualifiedName.from_string("SetPosition")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13366")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("SetPosition")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13385")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13386")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13385")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13385")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13366")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13386")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13385")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'Position'
    extobj.DataType = ua.NodeId.from_string("i=9")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13386")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13386")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13386")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13385")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13387")
    node.BrowseName = ua.QualifiedName.from_string("CreateDirectory")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13353")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateDirectory")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13387")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13388")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13387")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13389")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13387")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13387")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13353")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13388")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13387")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'DirectoryName'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13388")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13388")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13388")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13387")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13389")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13387")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'DirectoryNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13389")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13389")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13389")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13387")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13390")
    node.BrowseName = ua.QualifiedName.from_string("CreateFile")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13353")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateFile")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13390")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13391")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13390")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13392")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13390")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13390")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13353")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13391")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13390")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileName'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'RequestFileOpen'
    extobj.DataType = ua.NodeId.from_string("i=1")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13391")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13391")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13391")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13390")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13392")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13390")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13392")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13392")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13392")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13390")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13393")
    node.BrowseName = ua.QualifiedName.from_string("Delete")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13353")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Delete")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13393")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13394")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13393")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13393")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13353")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13394")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13393")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'ObjectToDelete'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13394")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13394")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13394")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13393")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13395")
    node.BrowseName = ua.QualifiedName.from_string("MoveOrCopy")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=13353")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("MoveOrCopy")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13395")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13396")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13395")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13397")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13395")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=13395")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13353")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13396")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13395")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'ObjectToMoveOrCopy'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'TargetDirectory'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'CreateCopy'
    extobj.DataType = ua.NodeId.from_string("i=1")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'NewName'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13396")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13396")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13396")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13395")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13397")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=13395")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'NewNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=13397")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=13397")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=13397")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13395")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16314")
    node.BrowseName = ua.QualifiedName.from_string("FileSystem")
    node.NodeClass = ua.NodeClass.Object
    node.TypeDefinition = ua.NodeId.from_string("i=13353")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("FileSystem")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16314")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16348")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16314")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16351")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16314")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16354")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16314")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16356")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16314")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13353")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16348")
    node.BrowseName = ua.QualifiedName.from_string("CreateDirectory")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=16314")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateDirectory")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16348")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16349")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16348")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16350")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16348")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16314")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16349")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16348")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'DirectoryName'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16349")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16349")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16348")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16350")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16348")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'DirectoryNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16350")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16350")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16348")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16351")
    node.BrowseName = ua.QualifiedName.from_string("CreateFile")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=16314")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("CreateFile")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16351")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16352")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16351")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16353")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16351")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16314")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16352")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16351")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileName'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'RequestFileOpen'
    extobj.DataType = ua.NodeId.from_string("i=1")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16352")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16352")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16351")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16353")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16351")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16353")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16353")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16351")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16354")
    node.BrowseName = ua.QualifiedName.from_string("Delete")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=16314")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Delete")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16354")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16355")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16354")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16314")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16355")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16354")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'ObjectToDelete'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16355")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16355")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16354")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16356")
    node.BrowseName = ua.QualifiedName.from_string("MoveOrCopy")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=16314")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("MoveOrCopy")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16356")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16357")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16356")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16358")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16356")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16314")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16357")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16356")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'ObjectToMoveOrCopy'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'TargetDirectory'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'CreateCopy'
    extobj.DataType = ua.NodeId.from_string("i=1")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'NewName'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16357")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16357")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16356")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16358")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16356")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'NewNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16358")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16358")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16356")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15744")
    node.BrowseName = ua.QualifiedName.from_string("TemporaryFileTransferType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("TemporaryFileTransferType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15744")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15745")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15744")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15746")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15744")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15749")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15744")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15751")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15744")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15754")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=15744")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15745")
    node.BrowseName = ua.QualifiedName.from_string("ClientProcessingTimeout")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15744")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ClientProcessingTimeout")
    attrs.DataType = ua.NodeId.from_string("i=290")
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15745")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15745")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15745")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15744")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15746")
    node.BrowseName = ua.QualifiedName.from_string("GenerateFileForRead")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15744")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("GenerateFileForRead")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15747")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15748")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15746")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15744")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15747")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15746")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'GenerateOptions'
    extobj.DataType = ua.NodeId.from_string("i=24")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15747")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15747")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15747")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15746")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15748")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15746")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'CompletionStateMachine'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15748")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15748")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15748")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15746")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15749")
    node.BrowseName = ua.QualifiedName.from_string("GenerateFileForWrite")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15744")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("GenerateFileForWrite")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15749")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16359")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15749")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15750")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15749")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15749")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15744")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16359")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15749")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'GenerateOptions'
    extobj.DataType = ua.NodeId.from_string("i=24")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16359")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16359")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16359")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15749")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15750")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15749")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15750")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15750")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15750")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15749")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15751")
    node.BrowseName = ua.QualifiedName.from_string("CloseAndCommit")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15744")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("CloseAndCommit")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15751")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15752")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15751")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15753")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15751")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15751")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15744")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15752")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15751")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'FileHandle'
    extobj.DataType = ua.NodeId.from_string("i=7")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15752")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15752")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15752")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15751")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15753")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15751")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'CompletionStateMachine'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15753")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15753")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15753")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15751")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15754")
    node.BrowseName = ua.QualifiedName.from_string("<TransferState>")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15744")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=15803")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("<TransferState>")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15754")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15755")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15754")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15794")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15754")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15754")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11508")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15754")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15744")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15755")
    node.BrowseName = ua.QualifiedName.from_string("CurrentState")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15754")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2760")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("CurrentState")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15755")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15756")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15755")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2760")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15755")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15755")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15754")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15756")
    node.BrowseName = ua.QualifiedName.from_string("Id")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15755")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Id")
    attrs.DataType = ua.NodeId(ua.ObjectIds.NodeId)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15756")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15756")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15756")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15755")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15794")
    node.BrowseName = ua.QualifiedName.from_string("Reset")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15754")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Reset")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15794")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15794")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15754")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15803")
    node.BrowseName = ua.QualifiedName.from_string("FileTransferStateMachineType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2771")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("FileTransferStateMachineType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15815")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15817")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15819")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15821")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15823")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15825")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15827")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15829")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15831")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15833")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15835")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15837")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15839")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15841")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15843")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=15803")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2771")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15815")
    node.BrowseName = ua.QualifiedName.from_string("Idle")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2309")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Idle")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15815")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15816")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15815")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2309")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15815")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15816")
    node.BrowseName = ua.QualifiedName.from_string("StateNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15815")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StateNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15816")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15815")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15817")
    node.BrowseName = ua.QualifiedName.from_string("ReadPrepare")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2307")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("ReadPrepare")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15817")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15818")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15817")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2307")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15817")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15818")
    node.BrowseName = ua.QualifiedName.from_string("StateNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15817")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StateNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15818")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15818")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15818")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15817")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15819")
    node.BrowseName = ua.QualifiedName.from_string("ReadTransfer")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2307")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("ReadTransfer")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15819")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15820")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15819")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2307")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15819")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15820")
    node.BrowseName = ua.QualifiedName.from_string("StateNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15819")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StateNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15820")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15820")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15820")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15819")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15821")
    node.BrowseName = ua.QualifiedName.from_string("ApplyWrite")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2307")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplyWrite")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15821")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15822")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15821")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2307")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15821")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15822")
    node.BrowseName = ua.QualifiedName.from_string("StateNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15821")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StateNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15822")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15822")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15822")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15821")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15823")
    node.BrowseName = ua.QualifiedName.from_string("Error")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2307")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Error")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15823")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15824")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15823")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2307")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15823")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15824")
    node.BrowseName = ua.QualifiedName.from_string("StateNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15823")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StateNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15824")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15824")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15824")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15823")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15825")
    node.BrowseName = ua.QualifiedName.from_string("IdleToReadPrepare")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2310")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("IdleToReadPrepare")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15825")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15826")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15825")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2310")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15825")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15826")
    node.BrowseName = ua.QualifiedName.from_string("TransitionNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15825")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15826")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15826")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15826")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15825")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15827")
    node.BrowseName = ua.QualifiedName.from_string("ReadPrepareToReadTransfer")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2310")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("ReadPrepareToReadTransfer")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15827")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15828")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15827")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2310")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15827")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15828")
    node.BrowseName = ua.QualifiedName.from_string("TransitionNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15827")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15828")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15828")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15828")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15827")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15829")
    node.BrowseName = ua.QualifiedName.from_string("ReadTransferToIdle")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2310")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("ReadTransferToIdle")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15829")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15830")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15829")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2310")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15829")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15830")
    node.BrowseName = ua.QualifiedName.from_string("TransitionNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15829")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15830")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15830")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15830")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15829")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15831")
    node.BrowseName = ua.QualifiedName.from_string("IdleToApplyWrite")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2310")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("IdleToApplyWrite")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15831")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15832")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15831")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2310")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15831")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15832")
    node.BrowseName = ua.QualifiedName.from_string("TransitionNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15831")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15832")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15832")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15832")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15831")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15833")
    node.BrowseName = ua.QualifiedName.from_string("ApplyWriteToIdle")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2310")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplyWriteToIdle")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15833")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15834")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15833")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2310")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15833")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15834")
    node.BrowseName = ua.QualifiedName.from_string("TransitionNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15833")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15834")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15834")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15834")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15833")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15835")
    node.BrowseName = ua.QualifiedName.from_string("ReadPrepareToError")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2310")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("ReadPrepareToError")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15835")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15836")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15835")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2310")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15835")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15836")
    node.BrowseName = ua.QualifiedName.from_string("TransitionNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15835")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15836")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15836")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15836")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15835")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15837")
    node.BrowseName = ua.QualifiedName.from_string("ReadTransferToError")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2310")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("ReadTransferToError")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15837")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15838")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15837")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2310")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15837")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15838")
    node.BrowseName = ua.QualifiedName.from_string("TransitionNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15837")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15838")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15838")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15838")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15837")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15839")
    node.BrowseName = ua.QualifiedName.from_string("ApplyWriteToError")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2310")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplyWriteToError")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15839")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15840")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15839")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2310")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15839")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15840")
    node.BrowseName = ua.QualifiedName.from_string("TransitionNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15839")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15840")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15840")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15840")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15839")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15841")
    node.BrowseName = ua.QualifiedName.from_string("ErrorToIdle")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=2310")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("ErrorToIdle")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15841")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15842")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15841")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2310")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15841")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15842")
    node.BrowseName = ua.QualifiedName.from_string("TransitionNumber")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15841")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TransitionNumber")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15842")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15842")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15842")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15841")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15843")
    node.BrowseName = ua.QualifiedName.from_string("Reset")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15803")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("Reset")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15843")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15843")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15803")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15607")
    node.BrowseName = ua.QualifiedName.from_string("RoleSetType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.Description = ua.LocalizedText("A container for the roles supported by the server.")
    attrs.DisplayName = ua.LocalizedText("RoleSetType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15607")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15608")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15607")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15997")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15607")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16000")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=15607")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15608")
    node.BrowseName = ua.QualifiedName.from_string("<RoleName>")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15607")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=15620")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("<RoleName>")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15608")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16162")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15608")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15608")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11508")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15608")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15607")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16162")
    node.BrowseName = ua.QualifiedName.from_string("Identities")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15608")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Identities")
    attrs.DataType = ua.NodeId.from_string("i=15634")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15608")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15997")
    node.BrowseName = ua.QualifiedName.from_string("AddRole")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15607")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddRole")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15997")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15998")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15997")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15999")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15997")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15997")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15607")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15998")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15997")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RoleName'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    extobj = ua.Argument()
    extobj.Name = 'NamespaceUri'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15998")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15998")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15998")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15997")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15999")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15997")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RoleNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15999")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15999")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15999")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15997")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16000")
    node.BrowseName = ua.QualifiedName.from_string("RemoveRole")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15607")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveRole")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16000")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16001")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16000")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16000")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15607")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16001")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16000")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RoleNodeId'
    extobj.DataType = ua.NodeId.from_string("i=17")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16001")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16001")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16001")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16000")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15620")
    node.BrowseName = ua.QualifiedName.from_string("RoleType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=58")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("RoleType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16173")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16174")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15410")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16175")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15411")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15624")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15626")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16176")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16178")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16180")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16182")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=15620")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16173")
    node.BrowseName = ua.QualifiedName.from_string("Identities")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15620")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Identities")
    attrs.DataType = ua.NodeId.from_string("i=15634")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16173")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16173")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16173")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16174")
    node.BrowseName = ua.QualifiedName.from_string("Applications")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15620")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Applications")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16174")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16174")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16174")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15410")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15620")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplicationsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15410")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15410")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15410")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16175")
    node.BrowseName = ua.QualifiedName.from_string("Endpoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15620")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Endpoints")
    attrs.DataType = ua.NodeId.from_string("i=15528")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15411")
    node.BrowseName = ua.QualifiedName.from_string("EndpointsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15620")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15411")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15411")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15411")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15624")
    node.BrowseName = ua.QualifiedName.from_string("AddIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15620")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15625")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15624")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15625")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15624")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15625")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15625")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15625")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15624")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15626")
    node.BrowseName = ua.QualifiedName.from_string("RemoveIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15620")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15626")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15627")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15626")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15626")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15627")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15626")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15627")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15627")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15627")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15626")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16176")
    node.BrowseName = ua.QualifiedName.from_string("AddApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15620")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16176")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16177")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16176")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16176")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16177")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16176")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16177")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16177")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16177")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16176")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16178")
    node.BrowseName = ua.QualifiedName.from_string("RemoveApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15620")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16178")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16179")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16178")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16178")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16179")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16178")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16179")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16179")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16179")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16178")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16180")
    node.BrowseName = ua.QualifiedName.from_string("AddEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15620")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16180")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16181")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16180")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16180")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16181")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16180")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16181")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16181")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16181")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16180")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16182")
    node.BrowseName = ua.QualifiedName.from_string("RemoveEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15620")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16182")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16183")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16182")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=80")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16182")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16183")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16182")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=16183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16182")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15632")
    node.BrowseName = ua.QualifiedName.from_string("IdentityCriteriaType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("IdentityCriteriaType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15632")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15633")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=15632")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15633")
    node.BrowseName = ua.QualifiedName.from_string("EnumValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15632")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumValues")
    attrs.DataType = ua.NodeId.from_string("i=7594")
    value = []
    extobj = ua.EnumValueType()
    extobj.Value = 1
    extobj.DisplayName.Text = 'UserName'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 2
    extobj.DisplayName.Text = 'Thumbprint'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 3
    extobj.DisplayName.Text = 'Role'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 4
    extobj.DisplayName.Text = 'GroupId'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 5
    extobj.DisplayName.Text = 'Anonymous'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 6
    extobj.DisplayName.Text = 'AuthenticatedUser'
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15633")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15633")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15633")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15632")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15634")
    node.BrowseName = ua.QualifiedName.from_string("IdentityMappingRuleType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("IdentityMappingRuleType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=15634")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17641")
    node.BrowseName = ua.QualifiedName.from_string("RoleMappingRuleChangedAuditEventType")
    node.NodeClass = ua.NodeClass.ObjectType
    node.ParentNodeId = ua.NodeId.from_string("i=2127")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ObjectTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("RoleMappingRuleChangedAuditEventType")
    attrs.IsAbstract = False
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=17641")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=2127")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15644")
    node.BrowseName = ua.QualifiedName.from_string("AnonymousRole")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15606")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=15620")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The Role has very limited access for use when a Session has anonymous credentials.")
    attrs.DisplayName = ua.LocalizedText("Anonymous")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16192")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16193")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15412")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16194")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15413")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15648")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15650")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16195")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16197")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16199")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16201")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15606")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15644")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16192")
    node.BrowseName = ua.QualifiedName.from_string("Identities")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15644")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Identities")
    attrs.DataType = ua.NodeId.from_string("i=15634")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16192")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16192")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15644")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16193")
    node.BrowseName = ua.QualifiedName.from_string("Applications")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15644")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Applications")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16193")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16193")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15644")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15412")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15644")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplicationsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15412")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15412")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15644")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16194")
    node.BrowseName = ua.QualifiedName.from_string("Endpoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15644")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Endpoints")
    attrs.DataType = ua.NodeId.from_string("i=15528")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16194")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16194")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15644")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15413")
    node.BrowseName = ua.QualifiedName.from_string("EndpointsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15644")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15413")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15413")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15644")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15648")
    node.BrowseName = ua.QualifiedName.from_string("AddIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15644")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15648")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15649")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15648")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15644")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15649")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15648")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15649")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15649")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15648")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15650")
    node.BrowseName = ua.QualifiedName.from_string("RemoveIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15644")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15650")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15651")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15650")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15644")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15651")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15650")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15651")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15651")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15650")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16195")
    node.BrowseName = ua.QualifiedName.from_string("AddApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15644")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16195")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16196")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16195")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15644")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16196")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16195")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16196")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16196")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16195")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16197")
    node.BrowseName = ua.QualifiedName.from_string("RemoveApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15644")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16198")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16197")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15644")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16198")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16197")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16198")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16198")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16197")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16199")
    node.BrowseName = ua.QualifiedName.from_string("AddEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15644")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16199")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16200")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16199")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15644")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16200")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16199")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16200")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16200")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16199")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16201")
    node.BrowseName = ua.QualifiedName.from_string("RemoveEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15644")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16201")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16202")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16201")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15644")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16202")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16201")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16202")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16202")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16201")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15656")
    node.BrowseName = ua.QualifiedName.from_string("AuthenticatedUserRole")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15606")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=15620")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The Role has limited access for use when a Session has valid non-anonymous credentials but has not been explicity granted access to a Role.")
    attrs.DisplayName = ua.LocalizedText("AuthenticatedUser")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16203")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16204")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15414")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16205")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15415")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15660")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15662")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16206")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16208")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16210")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16212")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15606")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16203")
    node.BrowseName = ua.QualifiedName.from_string("Identities")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15656")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Identities")
    attrs.DataType = ua.NodeId.from_string("i=15634")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16203")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16203")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15656")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16204")
    node.BrowseName = ua.QualifiedName.from_string("Applications")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15656")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Applications")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16204")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16204")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15656")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15414")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15656")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplicationsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15414")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15414")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15656")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16205")
    node.BrowseName = ua.QualifiedName.from_string("Endpoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15656")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Endpoints")
    attrs.DataType = ua.NodeId.from_string("i=15528")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16205")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16205")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15656")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15415")
    node.BrowseName = ua.QualifiedName.from_string("EndpointsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15656")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15415")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15415")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15656")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15660")
    node.BrowseName = ua.QualifiedName.from_string("AddIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15656")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15660")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15661")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15660")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15656")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15661")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15660")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15661")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15661")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15660")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15662")
    node.BrowseName = ua.QualifiedName.from_string("RemoveIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15656")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15662")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15663")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15662")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15656")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15663")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15662")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15663")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15663")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15662")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16206")
    node.BrowseName = ua.QualifiedName.from_string("AddApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15656")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16206")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16207")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16206")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15656")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16207")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16206")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16207")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16207")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16206")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16208")
    node.BrowseName = ua.QualifiedName.from_string("RemoveApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15656")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16208")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16209")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16208")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15656")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16209")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16208")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16209")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16209")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16208")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16210")
    node.BrowseName = ua.QualifiedName.from_string("AddEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15656")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16210")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16211")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16210")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15656")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16211")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16210")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16211")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16211")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16210")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16212")
    node.BrowseName = ua.QualifiedName.from_string("RemoveEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15656")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16212")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16213")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16212")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15656")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16213")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16212")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16213")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16213")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16212")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15668")
    node.BrowseName = ua.QualifiedName.from_string("ObserverRole")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15606")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=15620")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The Role is allowed to browse, read live data, read historical data/events or subscribe to data/events.")
    attrs.DisplayName = ua.LocalizedText("Observer")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16214")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16215")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15416")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16216")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15417")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15672")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15674")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16217")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16219")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16221")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16223")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15606")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16214")
    node.BrowseName = ua.QualifiedName.from_string("Identities")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15668")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Identities")
    attrs.DataType = ua.NodeId.from_string("i=15634")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16214")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16214")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15668")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16215")
    node.BrowseName = ua.QualifiedName.from_string("Applications")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15668")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Applications")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16215")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16215")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15668")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15416")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15668")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplicationsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15416")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15416")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15668")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16216")
    node.BrowseName = ua.QualifiedName.from_string("Endpoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15668")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Endpoints")
    attrs.DataType = ua.NodeId.from_string("i=15528")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16216")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16216")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15668")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15417")
    node.BrowseName = ua.QualifiedName.from_string("EndpointsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15668")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15417")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15417")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15668")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15672")
    node.BrowseName = ua.QualifiedName.from_string("AddIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15668")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15672")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15673")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15672")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15668")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15673")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15672")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15673")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15673")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15672")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15674")
    node.BrowseName = ua.QualifiedName.from_string("RemoveIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15668")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15674")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15675")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15674")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15668")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15675")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15674")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15675")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15675")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15674")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16217")
    node.BrowseName = ua.QualifiedName.from_string("AddApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15668")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16217")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16218")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16217")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15668")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16218")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16217")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16218")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16218")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16217")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16219")
    node.BrowseName = ua.QualifiedName.from_string("RemoveApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15668")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16219")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16220")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16219")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15668")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16220")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16219")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16220")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16220")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16219")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16221")
    node.BrowseName = ua.QualifiedName.from_string("AddEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15668")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16221")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16222")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16221")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15668")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16222")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16221")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16222")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16222")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16221")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16223")
    node.BrowseName = ua.QualifiedName.from_string("RemoveEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15668")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16223")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16224")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16223")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15668")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16224")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16223")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16224")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16224")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16223")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15680")
    node.BrowseName = ua.QualifiedName.from_string("OperatorRole")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15606")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=15620")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The Role is allowed to browse, read live data, read historical data/events or subscribe to data/events.")
    attrs.DisplayName = ua.LocalizedText("Operator")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16225")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16226")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15418")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16227")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15423")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15684")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15686")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16228")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16230")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16232")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16234")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15606")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16225")
    node.BrowseName = ua.QualifiedName.from_string("Identities")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15680")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Identities")
    attrs.DataType = ua.NodeId.from_string("i=15634")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16225")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16225")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15680")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16226")
    node.BrowseName = ua.QualifiedName.from_string("Applications")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15680")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Applications")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16226")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16226")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15680")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15418")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15680")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplicationsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15418")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15418")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15680")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16227")
    node.BrowseName = ua.QualifiedName.from_string("Endpoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15680")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Endpoints")
    attrs.DataType = ua.NodeId.from_string("i=15528")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16227")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16227")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15680")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15423")
    node.BrowseName = ua.QualifiedName.from_string("EndpointsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15680")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15423")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15423")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15680")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15684")
    node.BrowseName = ua.QualifiedName.from_string("AddIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15680")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15684")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15685")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15684")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15680")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15685")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15684")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15685")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15685")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15684")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15686")
    node.BrowseName = ua.QualifiedName.from_string("RemoveIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15680")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15686")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15687")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15686")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15680")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15687")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15686")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15687")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15687")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15686")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16228")
    node.BrowseName = ua.QualifiedName.from_string("AddApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15680")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16228")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16229")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16228")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15680")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16229")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16228")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16229")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16229")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16228")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16230")
    node.BrowseName = ua.QualifiedName.from_string("RemoveApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15680")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16230")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16231")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16230")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15680")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16231")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16230")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16231")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16231")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16230")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16232")
    node.BrowseName = ua.QualifiedName.from_string("AddEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15680")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16232")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16233")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16232")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15680")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16233")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16232")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16233")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16233")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16232")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16234")
    node.BrowseName = ua.QualifiedName.from_string("RemoveEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15680")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16234")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16235")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16234")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15680")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16235")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16234")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16235")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16235")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16234")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16036")
    node.BrowseName = ua.QualifiedName.from_string("EngineerRole")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15606")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=15620")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The Role is allowed to browse, read live data, read and update historical data/events, call methods or subscribe to data/events.")
    attrs.DisplayName = ua.LocalizedText("Engineer")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16236")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16237")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15424")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16238")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15425")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16041")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16043")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16239")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16241")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16243")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16245")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15606")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16036")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16236")
    node.BrowseName = ua.QualifiedName.from_string("Identities")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Identities")
    attrs.DataType = ua.NodeId.from_string("i=15634")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16236")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16236")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16237")
    node.BrowseName = ua.QualifiedName.from_string("Applications")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Applications")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16237")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16237")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15424")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplicationsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15424")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15424")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16238")
    node.BrowseName = ua.QualifiedName.from_string("Endpoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Endpoints")
    attrs.DataType = ua.NodeId.from_string("i=15528")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16238")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16238")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15425")
    node.BrowseName = ua.QualifiedName.from_string("EndpointsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15425")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15425")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16041")
    node.BrowseName = ua.QualifiedName.from_string("AddIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=16036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16042")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16042")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16041")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16042")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16042")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16041")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16043")
    node.BrowseName = ua.QualifiedName.from_string("RemoveIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=16036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16043")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16044")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16043")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16044")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16043")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16044")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16044")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16043")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16239")
    node.BrowseName = ua.QualifiedName.from_string("AddApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=16036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16239")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16240")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16239")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16240")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16239")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16240")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16240")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16239")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16241")
    node.BrowseName = ua.QualifiedName.from_string("RemoveApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=16036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16241")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16242")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16241")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16242")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16241")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16242")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16242")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16241")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16243")
    node.BrowseName = ua.QualifiedName.from_string("AddEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=16036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16243")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16244")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16243")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16244")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16243")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16243")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16245")
    node.BrowseName = ua.QualifiedName.from_string("RemoveEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=16036")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16245")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16246")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16245")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16036")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16246")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16245")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16246")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16246")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16245")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15692")
    node.BrowseName = ua.QualifiedName.from_string("SupervisorRole")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15606")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=15620")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The Role is allowed to browse, read live data, read and historical data/events, call methods or subscribe to data/events.")
    attrs.DisplayName = ua.LocalizedText("Supervisor")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16247")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16248")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15426")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16249")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15427")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15696")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15698")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16250")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16252")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16254")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16256")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15606")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16247")
    node.BrowseName = ua.QualifiedName.from_string("Identities")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15692")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Identities")
    attrs.DataType = ua.NodeId.from_string("i=15634")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16247")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16247")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15692")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16248")
    node.BrowseName = ua.QualifiedName.from_string("Applications")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15692")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Applications")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16248")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16248")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15692")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15426")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15692")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplicationsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15426")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15426")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15692")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16249")
    node.BrowseName = ua.QualifiedName.from_string("Endpoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15692")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Endpoints")
    attrs.DataType = ua.NodeId.from_string("i=15528")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16249")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16249")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15692")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15427")
    node.BrowseName = ua.QualifiedName.from_string("EndpointsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15692")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15427")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15427")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15692")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15696")
    node.BrowseName = ua.QualifiedName.from_string("AddIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15692")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15696")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15697")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15696")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15692")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15697")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15696")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15697")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15697")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15696")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15698")
    node.BrowseName = ua.QualifiedName.from_string("RemoveIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15692")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15698")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15699")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15698")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15692")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15699")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15698")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15699")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15699")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15698")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16250")
    node.BrowseName = ua.QualifiedName.from_string("AddApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15692")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16250")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16251")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16250")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15692")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16251")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16250")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16251")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16251")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16250")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16252")
    node.BrowseName = ua.QualifiedName.from_string("RemoveApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15692")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16253")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15692")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16253")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16253")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16254")
    node.BrowseName = ua.QualifiedName.from_string("AddEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15692")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16254")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16255")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16254")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15692")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16255")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16254")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16255")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16255")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16254")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16256")
    node.BrowseName = ua.QualifiedName.from_string("RemoveEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15692")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16256")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16257")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16256")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15692")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16257")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16256")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16257")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16257")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16256")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15716")
    node.BrowseName = ua.QualifiedName.from_string("ConfigureAdminRole")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15606")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=15620")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The Role is allowed to change the non-security related configuration settings.")
    attrs.DisplayName = ua.LocalizedText("ConfigureAdmin")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16269")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16270")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15428")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16271")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15429")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15720")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15722")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16272")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16274")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16276")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16278")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15606")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15716")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16269")
    node.BrowseName = ua.QualifiedName.from_string("Identities")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15716")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Identities")
    attrs.DataType = ua.NodeId.from_string("i=15634")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16269")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16269")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15716")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16270")
    node.BrowseName = ua.QualifiedName.from_string("Applications")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15716")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Applications")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16270")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16270")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15716")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15428")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15716")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplicationsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15428")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15428")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15716")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16271")
    node.BrowseName = ua.QualifiedName.from_string("Endpoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15716")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Endpoints")
    attrs.DataType = ua.NodeId.from_string("i=15528")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16271")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16271")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15716")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15429")
    node.BrowseName = ua.QualifiedName.from_string("EndpointsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15716")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15429")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15429")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15716")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15720")
    node.BrowseName = ua.QualifiedName.from_string("AddIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15716")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15720")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15721")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15720")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15716")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15721")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15720")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15721")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15721")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15720")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15722")
    node.BrowseName = ua.QualifiedName.from_string("RemoveIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15716")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15722")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15723")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15722")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15716")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15723")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15722")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15723")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15723")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15722")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16272")
    node.BrowseName = ua.QualifiedName.from_string("AddApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15716")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16272")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16273")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16272")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15716")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16273")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16272")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16273")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16273")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16272")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16274")
    node.BrowseName = ua.QualifiedName.from_string("RemoveApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15716")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16274")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16275")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16274")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15716")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16275")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16274")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16275")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16274")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16276")
    node.BrowseName = ua.QualifiedName.from_string("AddEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15716")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16276")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16277")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16276")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15716")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16277")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16276")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16277")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16277")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16276")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16278")
    node.BrowseName = ua.QualifiedName.from_string("RemoveEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15716")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16278")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16279")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16278")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15716")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16279")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16278")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16279")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16279")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16278")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15704")
    node.BrowseName = ua.QualifiedName.from_string("SecurityAdminRole")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15606")
    node.ReferenceTypeId = ua.NodeId.from_string("i=35")
    node.TypeDefinition = ua.NodeId.from_string("i=15620")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The Role is allowed to change security related settings.")
    attrs.DisplayName = ua.LocalizedText("SecurityAdmin")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16258")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16259")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15430")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16260")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15527")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15708")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15710")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16261")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16263")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16265")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16267")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=35")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15606")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15704")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15620")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16258")
    node.BrowseName = ua.QualifiedName.from_string("Identities")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Identities")
    attrs.DataType = ua.NodeId.from_string("i=15634")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16258")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16258")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16259")
    node.BrowseName = ua.QualifiedName.from_string("Applications")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Applications")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16259")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16259")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15430")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplicationsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15430")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15430")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16260")
    node.BrowseName = ua.QualifiedName.from_string("Endpoints")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Endpoints")
    attrs.DataType = ua.NodeId.from_string("i=15528")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16260")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16260")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15527")
    node.BrowseName = ua.QualifiedName.from_string("EndpointsExclude")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointsExclude")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15527")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15527")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15708")
    node.BrowseName = ua.QualifiedName.from_string("AddIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15708")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15709")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15708")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15709")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15708")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15709")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15709")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15708")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15710")
    node.BrowseName = ua.QualifiedName.from_string("RemoveIdentity")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveIdentity")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15710")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15711")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15710")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15711")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15710")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=15634")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15711")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15711")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15710")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16261")
    node.BrowseName = ua.QualifiedName.from_string("AddApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16261")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16262")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16261")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16262")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16261")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16262")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16262")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16261")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16263")
    node.BrowseName = ua.QualifiedName.from_string("RemoveApplication")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveApplication")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16263")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16264")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16263")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16264")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16263")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16264")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16264")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16263")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16265")
    node.BrowseName = ua.QualifiedName.from_string("AddEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("AddEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16265")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16266")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16265")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16266")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16265")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToAdd'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16266")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16266")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16265")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16267")
    node.BrowseName = ua.QualifiedName.from_string("RemoveEndpoint")
    node.NodeClass = ua.NodeClass.Method
    node.ParentNodeId = ua.NodeId.from_string("i=15704")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    attrs = ua.MethodAttributes()
    attrs.DisplayName = ua.LocalizedText("RemoveEndpoint")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16267")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16268")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16267")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15704")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16268")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=16267")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    value = []
    extobj = ua.Argument()
    extobj.Name = 'RuleToRemove'
    extobj.DataType = ua.NodeId.from_string("i=12")
    extobj.ValueRank = -1
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=16268")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16267")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=338")
    node.BrowseName = ua.QualifiedName.from_string("BuildInfo")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("BuildInfo")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=338")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=851")
    node.BrowseName = ua.QualifiedName.from_string("RedundancySupport")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("RedundancySupport")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=851")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7611")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=851")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7611")
    node.BrowseName = ua.QualifiedName.from_string("EnumStrings")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=851")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumStrings")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('None'),ua.LocalizedText('Cold'),ua.LocalizedText('Warm'),ua.LocalizedText('Hot'),ua.LocalizedText('Transparent'),ua.LocalizedText('HotAndMirrored')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7611")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=7611")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=7611")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=851")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=852")
    node.BrowseName = ua.QualifiedName.from_string("ServerState")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerState")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=852")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7612")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=852")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7612")
    node.BrowseName = ua.QualifiedName.from_string("EnumStrings")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=852")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumStrings")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('Running'),ua.LocalizedText('Failed'),ua.LocalizedText('NoConfiguration'),ua.LocalizedText('Suspended'),ua.LocalizedText('Shutdown'),ua.LocalizedText('Test'),ua.LocalizedText('CommunicationFault'),ua.LocalizedText('Unknown')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7612")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=7612")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=7612")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=852")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=853")
    node.BrowseName = ua.QualifiedName.from_string("RedundantServerDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("RedundantServerDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=853")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11943")
    node.BrowseName = ua.QualifiedName.from_string("EndpointUrlListDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointUrlListDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11943")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11944")
    node.BrowseName = ua.QualifiedName.from_string("NetworkGroupDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("NetworkGroupDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11944")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=856")
    node.BrowseName = ua.QualifiedName.from_string("SamplingIntervalDiagnosticsDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SamplingIntervalDiagnosticsDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=856")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=859")
    node.BrowseName = ua.QualifiedName.from_string("ServerDiagnosticsSummaryDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerDiagnosticsSummaryDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=859")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=862")
    node.BrowseName = ua.QualifiedName.from_string("ServerStatusDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerStatusDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=862")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=865")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnosticsDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionDiagnosticsDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=865")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=868")
    node.BrowseName = ua.QualifiedName.from_string("SessionSecurityDiagnosticsDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnosticsDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=868")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=871")
    node.BrowseName = ua.QualifiedName.from_string("ServiceCounterDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ServiceCounterDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=871")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=299")
    node.BrowseName = ua.QualifiedName.from_string("StatusResult")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("StatusResult")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=299")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=874")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionDiagnosticsDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnosticsDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=874")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=877")
    node.BrowseName = ua.QualifiedName.from_string("ModelChangeStructureDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("ModelChangeStructureDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=877")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=897")
    node.BrowseName = ua.QualifiedName.from_string("SemanticChangeStructureDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("SemanticChangeStructureDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=897")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14846")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=14533")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=14846")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14533")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=14846")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14873")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14846")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15671")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15528")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15671")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15528")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=15671")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15734")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15671")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15736")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15634")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15736")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15634")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=15736")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15738")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15736")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=340")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=338")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=340")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=338")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=340")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7692")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=340")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=855")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=853")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=855")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=853")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=855")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8208")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=855")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11957")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=11943")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=11957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11943")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=11957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11959")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11957")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11958")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=11944")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=11958")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11944")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=11958")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11962")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11958")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=858")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=856")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=858")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=856")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=858")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8211")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=858")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=861")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=859")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=861")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=859")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=861")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8214")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=861")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=864")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=862")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=864")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=862")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=864")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8217")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=864")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=867")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=865")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=867")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=865")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=867")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8220")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=867")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=870")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=868")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=870")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=868")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=870")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8223")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=870")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=873")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=871")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=873")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=871")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=873")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8226")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=873")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=301")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=299")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=301")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=299")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=301")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7659")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=301")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=876")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=874")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=876")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=874")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=876")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8229")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=876")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=879")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=877")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=879")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=877")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=879")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8232")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=879")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=899")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=897")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=899")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=897")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=899")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8235")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=899")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7617")
    node.BrowseName = ua.QualifiedName.from_string("Opc.Ua")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=93")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=72")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Opc.Ua")
    attrs.DataType = ua.NodeId(ua.ObjectIds.ByteString)
    attrs.Value = ua.Variant(b'<opc:TypeDictionary\r\n  xmlns:opc="http://opcfoundation.org/BinarySchema/"\r\n  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"\r\n  xmlns:ua="http://opcfoundation.org/UA/"\r\n  xmlns:tns="http://opcfoundation.org/UA/"\r\n  DefaultByteOrder="LittleEndian"\r\n  TargetNamespace="http://opcfoundation.org/UA/"\r\n>\r\n\r\n  <opc:Import Namespace="http://opcfoundation.org/BinarySchema/" />\r\n\r\n  <opc:StructuredType Name="XmlElement">\r\n    <opc:Documentation>An XML element encoded as a UTF-8 string.</opc:Documentation>\r\n    <opc:Field Name="Length" TypeName="opc:Int32" />\r\n    <opc:Field Name="Value" TypeName="opc:Char" LengthField="Length" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="NodeIdType" LengthInBits="6">\r\n    <opc:Documentation>The possible encodings for a NodeId value.</opc:Documentation>\r\n    <opc:EnumeratedValue Name="TwoByte" Value="0" />\r\n    <opc:EnumeratedValue Name="FourByte" Value="1" />\r\n    <opc:EnumeratedValue Name="Numeric" Value="2" />\r\n    <opc:EnumeratedValue Name="String" Value="3" />\r\n    <opc:EnumeratedValue Name="Guid" Value="4" />\r\n    <opc:EnumeratedValue Name="ByteString" Value="5" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="TwoByteNodeId">\r\n    <opc:Field Name="Identifier" TypeName="opc:Byte" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="FourByteNodeId">\r\n    <opc:Field Name="NamespaceIndex" TypeName="opc:Byte" />\r\n    <opc:Field Name="Identifier" TypeName="opc:UInt16" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="NumericNodeId">\r\n    <opc:Field Name="NamespaceIndex" TypeName="opc:UInt16" />\r\n    <opc:Field Name="Identifier" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="StringNodeId">\r\n    <opc:Field Name="NamespaceIndex" TypeName="opc:UInt16" />\r\n    <opc:Field Name="Identifier" TypeName="opc:CharArray" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="GuidNodeId">\r\n    <opc:Field Name="NamespaceIndex" TypeName="opc:UInt16" />\r\n    <opc:Field Name="Identifier" TypeName="opc:Guid" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ByteStringNodeId">\r\n    <opc:Field Name="NamespaceIndex" TypeName="opc:UInt16" />\r\n    <opc:Field Name="Identifier" TypeName="opc:ByteString" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="NodeId">\r\n    <opc:Documentation>An identifier for a node in a UA server address space.</opc:Documentation>\r\n    <opc:Field Name="NodeIdType" TypeName="ua:NodeIdType" />\r\n    <opc:Field Name="Reserved1" TypeName="opc:Bit" Length="2" />\r\n    <opc:Field Name="TwoByte" TypeName="ua:TwoByteNodeId" SwitchField="NodeIdType" SwitchValue="0" />\r\n    <opc:Field Name="FourByte" TypeName="ua:FourByteNodeId" SwitchField="NodeIdType" SwitchValue="1" />\r\n    <opc:Field Name="Numeric" TypeName="ua:NumericNodeId" SwitchField="NodeIdType" SwitchValue="2" />\r\n    <opc:Field Name="String" TypeName="ua:StringNodeId" SwitchField="NodeIdType" SwitchValue="3" />\r\n    <opc:Field Name="Guid" TypeName="ua:GuidNodeId" SwitchField="NodeIdType" SwitchValue="4" />\r\n    <opc:Field Name="ByteString" TypeName="ua:ByteStringNodeId" SwitchField="NodeIdType" SwitchValue="5" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ExpandedNodeId">\r\n    <opc:Documentation>An identifier for a node in a UA server address space qualified with a complete namespace string.</opc:Documentation>\r\n    <opc:Field Name="NodeIdType" TypeName="ua:NodeIdType" />\r\n    <opc:Field Name="ServerIndexSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="NamespaceURISpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="TwoByte" TypeName="ua:TwoByteNodeId" SwitchField="NodeIdType" SwitchValue="0" />\r\n    <opc:Field Name="FourByte" TypeName="ua:FourByteNodeId" SwitchField="NodeIdType" SwitchValue="1" />\r\n    <opc:Field Name="Numeric" TypeName="ua:NumericNodeId" SwitchField="NodeIdType" SwitchValue="2" />\r\n    <opc:Field Name="String" TypeName="ua:StringNodeId" SwitchField="NodeIdType" SwitchValue="3" />\r\n    <opc:Field Name="Guid" TypeName="ua:GuidNodeId" SwitchField="NodeIdType" SwitchValue="4" />\r\n    <opc:Field Name="ByteString" TypeName="ua:ByteStringNodeId" SwitchField="NodeIdType" SwitchValue="5" />\r\n    <opc:Field Name="NamespaceURI" TypeName="opc:CharArray" SwitchField="NamespaceURISpecified"/>\r\n    <opc:Field Name="ServerIndex" TypeName="opc:UInt32" SwitchField="ServerIndexSpecified"/>\r\n  </opc:StructuredType>\r\n\r\n  <opc:OpaqueType Name="StatusCode" LengthInBits="32" ByteOrderSignificant="true">\r\n    <opc:Documentation>A 32-bit status code value.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:StructuredType Name="DiagnosticInfo">\r\n    <opc:Documentation>A recursive structure containing diagnostic information associated with a status code.</opc:Documentation>\r\n    <opc:Field Name="SymbolicIdSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="NamespaceURISpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="LocaleSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="LocalizedTextSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="AdditionalInfoSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="InnerStatusCodeSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="InnerDiagnosticInfoSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="Reserved1" TypeName="opc:Bit" Length="2" />\r\n    <opc:Field Name="SymbolicId" TypeName="opc:Int32" SwitchField="SymbolicIdSpecified" />\r\n    <opc:Field Name="NamespaceURI" TypeName="opc:Int32" SwitchField="NamespaceURISpecified" />\r\n    <opc:Field Name="Locale" TypeName="opc:Int32" SwitchField="LocaleSpecified" />\r\n    <opc:Field Name="LocalizedText" TypeName="opc:Int32" SwitchField="LocalizedTextSpecified" />\r\n    <opc:Field Name="AdditionalInfo" TypeName="opc:CharArray" SwitchField="AdditionalInfoSpecified" />\r\n    <opc:Field Name="InnerStatusCode" TypeName="ua:StatusCode" SwitchField="InnerStatusCodeSpecified" />\r\n    <opc:Field Name="InnerDiagnosticInfo" TypeName="ua:DiagnosticInfo" SwitchField="InnerDiagnosticInfoSpecified" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="QualifiedName">\r\n    <opc:Documentation>A string qualified with a namespace index.</opc:Documentation>\r\n    <opc:Field Name="NamespaceIndex" TypeName="opc:Int32" />\r\n    <opc:Field Name="Name" TypeName="opc:CharArray" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="LocalizedText">\r\n    <opc:Documentation>A string qualified with a namespace index.</opc:Documentation>\r\n    <opc:Field Name="LocaleSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="TextSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="Reserved1" TypeName="opc:Bit" Length="6" />\r\n    <opc:Field Name="Locale" TypeName="opc:CharArray" SwitchField="LocaleSpecified" />\r\n    <opc:Field Name="Text" TypeName="opc:CharArray" SwitchField="TextSpecified" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DataValue">\r\n    <opc:Documentation>A value with an associated timestamp, and quality.</opc:Documentation>\r\n    <opc:Field Name="ValueSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="StatusCodeSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="SourceTimestampSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="SourcePicosecondsSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="ServerTimestampSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="ServerPicosecondsSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="Reserved1" TypeName="opc:Bit" Length="2" />\r\n    <opc:Field Name="Value" TypeName="ua:Variant" SwitchField="ValueSpecified" />\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" SwitchField="StatusCodeSpecified" />\r\n    <opc:Field Name="SourceTimestamp" TypeName="opc:DateTime" SwitchField="SourceTimestampSpecified" />\r\n    <opc:Field Name="SourcePicoseconds" TypeName="opc:UInt16" SwitchField="SourcePicosecondsSpecified" />\r\n    <opc:Field Name="ServerTimestamp" TypeName="opc:DateTime" SwitchField="ServerTimestampSpecified" />\r\n    <opc:Field Name="ServerPicoseconds" TypeName="opc:UInt16" SwitchField="ServerPicosecondsSpecified" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ExtensionObject">\r\n    <opc:Documentation>A serialized object prefixed with its data type identifier.</opc:Documentation>\r\n    <opc:Field Name="TypeIdSpecified" TypeName="opc:Bit" />\r\n    <opc:Field Name="BinaryBody" TypeName="opc:Bit" />\r\n    <opc:Field Name="XmlBody" TypeName="opc:Bit" />\r\n    <opc:Field Name="Reserved1" TypeName="opc:Bit" Length="5" />\r\n    <opc:Field Name="TypeId" TypeName="ua:ExpandedNodeId" SwitchField="TypeIdSpecified" />\r\n    <opc:Field Name="BodyLength" TypeName="opc:Int32" />\r\n    <opc:Field Name="Body" TypeName="opc:Byte" LengthField="BodyLength" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="Variant">\r\n    <opc:Documentation>A union of several types.</opc:Documentation>\r\n    <opc:Field Name="VariantType" TypeName="opc:Bit" Length="6" />\r\n    <opc:Field Name="ArrayDimensionsSpecified" TypeName="opc:Bit" Length="1"/>\r\n    <opc:Field Name="ArrayLengthSpecified" TypeName="opc:Bit" Length="1"/>\r\n    <opc:Field Name="ArrayLength" TypeName="opc:Int32" SwitchField="ArrayLengthSpecified" />\r\n    <opc:Field Name="Boolean" TypeName="opc:Boolean" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="1" />\r\n    <opc:Field Name="SByte" TypeName="opc:SByte" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="2" />\r\n    <opc:Field Name="Byte" TypeName="opc:Byte" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="3" />\r\n    <opc:Field Name="Int16" TypeName="opc:Int16" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="4" />\r\n    <opc:Field Name="UInt16" TypeName="opc:UInt16" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="5" />\r\n    <opc:Field Name="Int32" TypeName="opc:Int32" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="6" />\r\n    <opc:Field Name="UInt32" TypeName="opc:UInt32" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="7" />\r\n    <opc:Field Name="Int64" TypeName="opc:Int64" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="8" />\r\n    <opc:Field Name="UInt64" TypeName="opc:UInt64" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="9" />\r\n    <opc:Field Name="Float" TypeName="opc:Float" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="10" />\r\n    <opc:Field Name="Double" TypeName="opc:Double" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="11" />\r\n    <opc:Field Name="String" TypeName="opc:CharArray" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="12" />\r\n    <opc:Field Name="DateTime" TypeName="opc:DateTime" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="13" />\r\n    <opc:Field Name="Guid" TypeName="opc:Guid" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="14" />\r\n    <opc:Field Name="ByteString" TypeName="opc:ByteString" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="15" />\r\n    <opc:Field Name="XmlElement" TypeName="ua:XmlElement" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="16" />\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="17" />\r\n    <opc:Field Name="ExpandedNodeId" TypeName="ua:ExpandedNodeId" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="18" />\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="19" />\r\n    <opc:Field Name="QualifiedName" TypeName="ua:QualifiedName" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="20" />\r\n    <opc:Field Name="LocalizedText" TypeName="ua:LocalizedText" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="21" />\r\n    <opc:Field Name="ExtensionObject" TypeName="ua:ExtensionObject" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="22" />\r\n    <opc:Field Name="DataValue" TypeName="ua:DataValue" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="23" />\r\n    <opc:Field Name="Variant" TypeName="ua:Variant" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="24" />\r\n    <opc:Field Name="DiagnosticInfo" TypeName="ua:DiagnosticInfo" LengthField="ArrayLength" SwitchField="VariantType" SwitchValue="25" />\r\n    <opc:Field Name="NoOfArrayDimensions" TypeName="opc:Int32" SwitchField="ArrayDimensionsSpecified" />\r\n    <opc:Field Name="ArrayDimensions" TypeName="opc:Int32" LengthField="NoOfArrayDimensions" SwitchField="ArrayDimensionsSpecified" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="NamingRuleType" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Mandatory" Value="1" />\r\n    <opc:EnumeratedValue Name="Optional" Value="2" />\r\n    <opc:EnumeratedValue Name="Constraint" Value="3" />\r\n  </opc:EnumeratedType>\r\n    \r\n\r\n  <opc:OpaqueType Name="ImageBMP">\r\n    <opc:Documentation>An image encoded in BMP format.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="ImageGIF">\r\n    <opc:Documentation>An image encoded in GIF format.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="ImageJPG">\r\n    <opc:Documentation>An image encoded in JPEG format.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="ImagePNG">\r\n    <opc:Documentation>An image encoded in PNG format.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="AudioDataType">\r\n    <opc:Documentation>An image encoded in PNG format.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="BitFieldMaskDataType">\r\n    <opc:Documentation>A mask of 32 bits that can be updated individually by using the top 32 bits as a mask.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:StructuredType Name="KeyValuePair" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Key" TypeName="ua:QualifiedName" />\r\n    <opc:Field Name="Value" TypeName="ua:Variant" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="EndpointType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="EndpointUrl" TypeName="opc:String" />\r\n    <opc:Field Name="SecurityMode" TypeName="tns:MessageSecurityMode" />\r\n    <opc:Field Name="SecurityPolicyUri" TypeName="opc:String" />\r\n    <opc:Field Name="TransportProfileUri" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="OpenFileMode" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Read" Value="1" />\r\n    <opc:EnumeratedValue Name="Write" Value="2" />\r\n    <opc:EnumeratedValue Name="EraseExisting" Value="4" />\r\n    <opc:EnumeratedValue Name="Append" Value="8" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="IdentityCriteriaType" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="UserName" Value="1" />\r\n    <opc:EnumeratedValue Name="Thumbprint" Value="2" />\r\n    <opc:EnumeratedValue Name="Role" Value="3" />\r\n    <opc:EnumeratedValue Name="GroupId" Value="4" />\r\n    <opc:EnumeratedValue Name="Anonymous" Value="5" />\r\n    <opc:EnumeratedValue Name="AuthenticatedUser" Value="6" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="IdentityMappingRuleType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="CriteriaType" TypeName="tns:IdentityCriteriaType" />\r\n    <opc:Field Name="Criteria" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="TrustListMasks" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="None" Value="0" />\r\n    <opc:EnumeratedValue Name="TrustedCertificates" Value="1" />\r\n    <opc:EnumeratedValue Name="TrustedCrls" Value="2" />\r\n    <opc:EnumeratedValue Name="IssuerCertificates" Value="4" />\r\n    <opc:EnumeratedValue Name="IssuerCrls" Value="8" />\r\n    <opc:EnumeratedValue Name="All" Value="15" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="TrustListDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="SpecifiedLists" TypeName="opc:UInt32" />\r\n    <opc:Field Name="NoOfTrustedCertificates" TypeName="opc:Int32" />\r\n    <opc:Field Name="TrustedCertificates" TypeName="opc:ByteString" LengthField="NoOfTrustedCertificates" />\r\n    <opc:Field Name="NoOfTrustedCrls" TypeName="opc:Int32" />\r\n    <opc:Field Name="TrustedCrls" TypeName="opc:ByteString" LengthField="NoOfTrustedCrls" />\r\n    <opc:Field Name="NoOfIssuerCertificates" TypeName="opc:Int32" />\r\n    <opc:Field Name="IssuerCertificates" TypeName="opc:ByteString" LengthField="NoOfIssuerCertificates" />\r\n    <opc:Field Name="NoOfIssuerCrls" TypeName="opc:Int32" />\r\n    <opc:Field Name="IssuerCrls" TypeName="opc:ByteString" LengthField="NoOfIssuerCrls" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DecimalDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Scale" TypeName="opc:Int16" />\r\n    <opc:Field Name="Value" TypeName="opc:ByteString" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DataTypeSchemaHeader" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NoOfNamespaces" TypeName="opc:Int32" />\r\n    <opc:Field Name="Namespaces" TypeName="opc:String" LengthField="NoOfNamespaces" />\r\n    <opc:Field Name="NoOfStructureDataTypes" TypeName="opc:Int32" />\r\n    <opc:Field Name="StructureDataTypes" TypeName="tns:StructureDescription" LengthField="NoOfStructureDataTypes" />\r\n    <opc:Field Name="NoOfEnumDataTypes" TypeName="opc:Int32" />\r\n    <opc:Field Name="EnumDataTypes" TypeName="tns:EnumDescription" LengthField="NoOfEnumDataTypes" />\r\n    <opc:Field Name="NoOfSimpleDataTypes" TypeName="opc:Int32" />\r\n    <opc:Field Name="SimpleDataTypes" TypeName="tns:SimpleTypeDescription" LengthField="NoOfSimpleDataTypes" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DataTypeDescription" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="DataTypeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="Name" TypeName="ua:QualifiedName" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="StructureDescription" BaseType="tns:DataTypeDescription">\r\n    <opc:Field Name="DataTypeId" TypeName="ua:NodeId" SourceType="tns:DataTypeDescription" />\r\n    <opc:Field Name="Name" TypeName="ua:QualifiedName" SourceType="tns:DataTypeDescription" />\r\n    <opc:Field Name="StructureDefinition" TypeName="tns:StructureDefinition" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="EnumDescription" BaseType="tns:DataTypeDescription">\r\n    <opc:Field Name="DataTypeId" TypeName="ua:NodeId" SourceType="tns:DataTypeDescription" />\r\n    <opc:Field Name="Name" TypeName="ua:QualifiedName" SourceType="tns:DataTypeDescription" />\r\n    <opc:Field Name="EnumDefinition" TypeName="tns:EnumDefinition" />\r\n    <opc:Field Name="BuiltInType" TypeName="opc:Byte" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SimpleTypeDescription" BaseType="tns:DataTypeDescription">\r\n    <opc:Field Name="DataTypeId" TypeName="ua:NodeId" SourceType="tns:DataTypeDescription" />\r\n    <opc:Field Name="Name" TypeName="ua:QualifiedName" SourceType="tns:DataTypeDescription" />\r\n    <opc:Field Name="BaseDataType" TypeName="ua:NodeId" />\r\n    <opc:Field Name="BuiltInType" TypeName="opc:Byte" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="UABinaryFileDataType" BaseType="tns:DataTypeSchemaHeader">\r\n    <opc:Field Name="NoOfNamespaces" TypeName="opc:Int32" />\r\n    <opc:Field Name="Namespaces" TypeName="opc:String" LengthField="NoOfNamespaces" />\r\n    <opc:Field Name="NoOfStructureDataTypes" TypeName="opc:Int32" />\r\n    <opc:Field Name="StructureDataTypes" TypeName="tns:StructureDescription" LengthField="NoOfStructureDataTypes" />\r\n    <opc:Field Name="NoOfEnumDataTypes" TypeName="opc:Int32" />\r\n    <opc:Field Name="EnumDataTypes" TypeName="tns:EnumDescription" LengthField="NoOfEnumDataTypes" />\r\n    <opc:Field Name="NoOfSimpleDataTypes" TypeName="opc:Int32" />\r\n    <opc:Field Name="SimpleDataTypes" TypeName="tns:SimpleTypeDescription" LengthField="NoOfSimpleDataTypes" />\r\n    <opc:Field Name="SchemaLocation" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfFileHeader" TypeName="opc:Int32" />\r\n    <opc:Field Name="FileHeader" TypeName="tns:KeyValuePair" LengthField="NoOfFileHeader" />\r\n    <opc:Field Name="Body" TypeName="ua:Variant" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="PubSubState" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Disabled" Value="0" />\r\n    <opc:EnumeratedValue Name="Paused" Value="1" />\r\n    <opc:EnumeratedValue Name="Operational" Value="2" />\r\n    <opc:EnumeratedValue Name="Error" Value="3" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="DataSetMetaDataType" BaseType="tns:DataTypeSchemaHeader">\r\n    <opc:Field Name="NoOfNamespaces" TypeName="opc:Int32" />\r\n    <opc:Field Name="Namespaces" TypeName="opc:String" LengthField="NoOfNamespaces" />\r\n    <opc:Field Name="NoOfStructureDataTypes" TypeName="opc:Int32" />\r\n    <opc:Field Name="StructureDataTypes" TypeName="tns:StructureDescription" LengthField="NoOfStructureDataTypes" />\r\n    <opc:Field Name="NoOfEnumDataTypes" TypeName="opc:Int32" />\r\n    <opc:Field Name="EnumDataTypes" TypeName="tns:EnumDescription" LengthField="NoOfEnumDataTypes" />\r\n    <opc:Field Name="NoOfSimpleDataTypes" TypeName="opc:Int32" />\r\n    <opc:Field Name="SimpleDataTypes" TypeName="tns:SimpleTypeDescription" LengthField="NoOfSimpleDataTypes" />\r\n    <opc:Field Name="Name" TypeName="opc:String" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" />\r\n    <opc:Field Name="NoOfFields" TypeName="opc:Int32" />\r\n    <opc:Field Name="Fields" TypeName="tns:FieldMetaData" LengthField="NoOfFields" />\r\n    <opc:Field Name="DataSetClassId" TypeName="opc:Guid" />\r\n    <opc:Field Name="ConfigurationVersion" TypeName="tns:ConfigurationVersionDataType" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="FieldMetaData" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Name" TypeName="opc:String" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" />\r\n    <opc:Field Name="FieldFlags" TypeName="tns:DataSetFieldFlags" />\r\n    <opc:Field Name="BuiltInType" TypeName="opc:Byte" />\r\n    <opc:Field Name="DataType" TypeName="ua:NodeId" />\r\n    <opc:Field Name="ValueRank" TypeName="opc:Int32" />\r\n    <opc:Field Name="NoOfArrayDimensions" TypeName="opc:Int32" />\r\n    <opc:Field Name="ArrayDimensions" TypeName="opc:UInt32" LengthField="NoOfArrayDimensions" />\r\n    <opc:Field Name="MaxStringLength" TypeName="opc:UInt32" />\r\n    <opc:Field Name="DataSetFieldId" TypeName="opc:Guid" />\r\n    <opc:Field Name="NoOfProperties" TypeName="opc:Int32" />\r\n    <opc:Field Name="Properties" TypeName="tns:KeyValuePair" LengthField="NoOfProperties" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="DataSetFieldFlags" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="PromotedField" Value="1" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="ConfigurationVersionDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="MajorVersion" TypeName="opc:UInt32" />\r\n    <opc:Field Name="MinorVersion" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="PublishedDataSetDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Name" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfDataSetFolder" TypeName="opc:Int32" />\r\n    <opc:Field Name="DataSetFolder" TypeName="opc:String" LengthField="NoOfDataSetFolder" />\r\n    <opc:Field Name="DataSetMetaData" TypeName="tns:DataSetMetaDataType" />\r\n    <opc:Field Name="NoOfExtensionFields" TypeName="opc:Int32" />\r\n    <opc:Field Name="ExtensionFields" TypeName="tns:KeyValuePair" LengthField="NoOfExtensionFields" />\r\n    <opc:Field Name="DataSetSource" TypeName="ua:ExtensionObject" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="PublishedDataSetSourceDataType" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="PublishedVariableDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="PublishedVariable" TypeName="ua:NodeId" />\r\n    <opc:Field Name="AttributeId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="SamplingIntervalHint" TypeName="opc:Double" />\r\n    <opc:Field Name="DeadbandType" TypeName="opc:UInt32" />\r\n    <opc:Field Name="DeadbandValue" TypeName="opc:Double" />\r\n    <opc:Field Name="IndexRange" TypeName="opc:String" />\r\n    <opc:Field Name="SubstituteValue" TypeName="ua:Variant" />\r\n    <opc:Field Name="NoOfMetaDataProperties" TypeName="opc:Int32" />\r\n    <opc:Field Name="MetaDataProperties" TypeName="ua:QualifiedName" LengthField="NoOfMetaDataProperties" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="PublishedDataItemsDataType" BaseType="tns:PublishedDataSetSourceDataType">\r\n    <opc:Field Name="NoOfPublishedData" TypeName="opc:Int32" />\r\n    <opc:Field Name="PublishedData" TypeName="tns:PublishedVariableDataType" LengthField="NoOfPublishedData" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="PublishedEventsDataType" BaseType="tns:PublishedDataSetSourceDataType">\r\n    <opc:Field Name="EventNotifier" TypeName="ua:NodeId" />\r\n    <opc:Field Name="NoOfSelectedFields" TypeName="opc:Int32" />\r\n    <opc:Field Name="SelectedFields" TypeName="tns:SimpleAttributeOperand" LengthField="NoOfSelectedFields" />\r\n    <opc:Field Name="Filter" TypeName="tns:ContentFilter" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="DataSetFieldContentMask" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="StatusCode" Value="1" />\r\n    <opc:EnumeratedValue Name="SourceTimestamp" Value="2" />\r\n    <opc:EnumeratedValue Name="ServerTimestamp" Value="4" />\r\n    <opc:EnumeratedValue Name="SourcePicoSeconds" Value="8" />\r\n    <opc:EnumeratedValue Name="ServerPicoSeconds" Value="16" />\r\n    <opc:EnumeratedValue Name="RawDataEncoding" Value="32" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="DataSetWriterDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Name" TypeName="opc:String" />\r\n    <opc:Field Name="Enabled" TypeName="opc:Boolean" />\r\n    <opc:Field Name="DataSetWriterId" TypeName="opc:UInt16" />\r\n    <opc:Field Name="DataSetFieldContentMask" TypeName="tns:DataSetFieldContentMask" />\r\n    <opc:Field Name="KeyFrameCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="DataSetName" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfDataSetWriterProperties" TypeName="opc:Int32" />\r\n    <opc:Field Name="DataSetWriterProperties" TypeName="tns:KeyValuePair" LengthField="NoOfDataSetWriterProperties" />\r\n    <opc:Field Name="TransportSettings" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="MessageSettings" TypeName="ua:ExtensionObject" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DataSetWriterTransportDataType" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DataSetWriterMessageDataType" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="PubSubGroupDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Name" TypeName="opc:String" />\r\n    <opc:Field Name="Enabled" TypeName="opc:Boolean" />\r\n    <opc:Field Name="SecurityMode" TypeName="tns:MessageSecurityMode" />\r\n    <opc:Field Name="SecurityGroupId" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfSecurityKeyServices" TypeName="opc:Int32" />\r\n    <opc:Field Name="SecurityKeyServices" TypeName="tns:EndpointDescription" LengthField="NoOfSecurityKeyServices" />\r\n    <opc:Field Name="MaxNetworkMessageSize" TypeName="opc:UInt32" />\r\n    <opc:Field Name="NoOfGroupProperties" TypeName="opc:Int32" />\r\n    <opc:Field Name="GroupProperties" TypeName="tns:KeyValuePair" LengthField="NoOfGroupProperties" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="WriterGroupDataType" BaseType="tns:PubSubGroupDataType">\r\n    <opc:Field Name="Name" TypeName="opc:String" SourceType="tns:PubSubGroupDataType" />\r\n    <opc:Field Name="Enabled" TypeName="opc:Boolean" SourceType="tns:PubSubGroupDataType" />\r\n    <opc:Field Name="SecurityMode" TypeName="tns:MessageSecurityMode" SourceType="tns:PubSubGroupDataType" />\r\n    <opc:Field Name="SecurityGroupId" TypeName="opc:String" SourceType="tns:PubSubGroupDataType" />\r\n    <opc:Field Name="NoOfSecurityKeyServices" TypeName="opc:Int32" />\r\n    <opc:Field Name="SecurityKeyServices" TypeName="tns:EndpointDescription" LengthField="NoOfSecurityKeyServices" />\r\n    <opc:Field Name="MaxNetworkMessageSize" TypeName="opc:UInt32" SourceType="tns:PubSubGroupDataType" />\r\n    <opc:Field Name="NoOfGroupProperties" TypeName="opc:Int32" />\r\n    <opc:Field Name="GroupProperties" TypeName="tns:KeyValuePair" LengthField="NoOfGroupProperties" />\r\n    <opc:Field Name="WriterGroupId" TypeName="opc:UInt16" />\r\n    <opc:Field Name="PublishingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="KeepAliveTime" TypeName="opc:Double" />\r\n    <opc:Field Name="Priority" TypeName="opc:Byte" />\r\n    <opc:Field Name="NoOfLocaleIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="LocaleIds" TypeName="opc:String" LengthField="NoOfLocaleIds" />\r\n    <opc:Field Name="TransportSettings" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="MessageSettings" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="NoOfDataSetWriters" TypeName="opc:Int32" />\r\n    <opc:Field Name="DataSetWriters" TypeName="tns:DataSetWriterDataType" LengthField="NoOfDataSetWriters" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="WriterGroupTransportDataType" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="WriterGroupMessageDataType" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="PubSubConnectionDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Name" TypeName="opc:String" />\r\n    <opc:Field Name="Enabled" TypeName="opc:Boolean" />\r\n    <opc:Field Name="PublisherId" TypeName="ua:Variant" />\r\n    <opc:Field Name="TransportProfileUri" TypeName="opc:String" />\r\n    <opc:Field Name="Address" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="NoOfConnectionProperties" TypeName="opc:Int32" />\r\n    <opc:Field Name="ConnectionProperties" TypeName="tns:KeyValuePair" LengthField="NoOfConnectionProperties" />\r\n    <opc:Field Name="TransportSettings" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="NoOfWriterGroups" TypeName="opc:Int32" />\r\n    <opc:Field Name="WriterGroups" TypeName="tns:WriterGroupDataType" LengthField="NoOfWriterGroups" />\r\n    <opc:Field Name="NoOfReaderGroups" TypeName="opc:Int32" />\r\n    <opc:Field Name="ReaderGroups" TypeName="tns:ReaderGroupDataType" LengthField="NoOfReaderGroups" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ConnectionTransportDataType" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="NetworkAddressDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NetworkInterface" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="NetworkAddressUrlDataType" BaseType="tns:NetworkAddressDataType">\r\n    <opc:Field Name="NetworkInterface" TypeName="opc:String" SourceType="tns:NetworkAddressDataType" />\r\n    <opc:Field Name="Url" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ReaderGroupDataType" BaseType="tns:PubSubGroupDataType">\r\n    <opc:Field Name="Name" TypeName="opc:String" SourceType="tns:PubSubGroupDataType" />\r\n    <opc:Field Name="Enabled" TypeName="opc:Boolean" SourceType="tns:PubSubGroupDataType" />\r\n    <opc:Field Name="SecurityMode" TypeName="tns:MessageSecurityMode" SourceType="tns:PubSubGroupDataType" />\r\n    <opc:Field Name="SecurityGroupId" TypeName="opc:String" SourceType="tns:PubSubGroupDataType" />\r\n    <opc:Field Name="NoOfSecurityKeyServices" TypeName="opc:Int32" />\r\n    <opc:Field Name="SecurityKeyServices" TypeName="tns:EndpointDescription" LengthField="NoOfSecurityKeyServices" />\r\n    <opc:Field Name="MaxNetworkMessageSize" TypeName="opc:UInt32" SourceType="tns:PubSubGroupDataType" />\r\n    <opc:Field Name="NoOfGroupProperties" TypeName="opc:Int32" />\r\n    <opc:Field Name="GroupProperties" TypeName="tns:KeyValuePair" LengthField="NoOfGroupProperties" />\r\n    <opc:Field Name="TransportSettings" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="MessageSettings" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="NoOfDataSetReaders" TypeName="opc:Int32" />\r\n    <opc:Field Name="DataSetReaders" TypeName="tns:DataSetReaderDataType" LengthField="NoOfDataSetReaders" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ReaderGroupTransportDataType" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ReaderGroupMessageDataType" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DataSetReaderDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Name" TypeName="opc:String" />\r\n    <opc:Field Name="Enabled" TypeName="opc:Boolean" />\r\n    <opc:Field Name="PublisherId" TypeName="ua:Variant" />\r\n    <opc:Field Name="WriterGroupId" TypeName="opc:UInt16" />\r\n    <opc:Field Name="DataSetWriterId" TypeName="opc:UInt16" />\r\n    <opc:Field Name="DataSetMetaData" TypeName="tns:DataSetMetaDataType" />\r\n    <opc:Field Name="DataSetFieldContentMask" TypeName="tns:DataSetFieldContentMask" />\r\n    <opc:Field Name="MessageReceiveTimeout" TypeName="opc:Double" />\r\n    <opc:Field Name="SecurityMode" TypeName="tns:MessageSecurityMode" />\r\n    <opc:Field Name="SecurityGroupId" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfSecurityKeyServices" TypeName="opc:Int32" />\r\n    <opc:Field Name="SecurityKeyServices" TypeName="tns:EndpointDescription" LengthField="NoOfSecurityKeyServices" />\r\n    <opc:Field Name="NoOfDataSetReaderProperties" TypeName="opc:Int32" />\r\n    <opc:Field Name="DataSetReaderProperties" TypeName="tns:KeyValuePair" LengthField="NoOfDataSetReaderProperties" />\r\n    <opc:Field Name="TransportSettings" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="MessageSettings" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="SubscribedDataSet" TypeName="ua:ExtensionObject" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DataSetReaderTransportDataType" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DataSetReaderMessageDataType" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SubscribedDataSetDataType" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="TargetVariablesDataType" BaseType="tns:SubscribedDataSetDataType">\r\n    <opc:Field Name="NoOfTargetVariables" TypeName="opc:Int32" />\r\n    <opc:Field Name="TargetVariables" TypeName="tns:FieldTargetDataType" LengthField="NoOfTargetVariables" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="FieldTargetDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="DataSetFieldId" TypeName="opc:Guid" />\r\n    <opc:Field Name="ReceiverIndexRange" TypeName="opc:String" />\r\n    <opc:Field Name="TargetNodeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="AttributeId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="WriteIndexRange" TypeName="opc:String" />\r\n    <opc:Field Name="OverrideValueHandling" TypeName="tns:OverrideValueHandling" />\r\n    <opc:Field Name="OverrideValue" TypeName="ua:Variant" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="OverrideValueHandling" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Disabled" Value="0" />\r\n    <opc:EnumeratedValue Name="LastUseableValue" Value="1" />\r\n    <opc:EnumeratedValue Name="OverrideValue" Value="2" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="SubscribedDataSetMirrorDataType" BaseType="tns:SubscribedDataSetDataType">\r\n    <opc:Field Name="ParentNodeName" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="RolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfRolePermissions" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="PubSubConfigurationDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NoOfPublishedDataSets" TypeName="opc:Int32" />\r\n    <opc:Field Name="PublishedDataSets" TypeName="tns:PublishedDataSetDataType" LengthField="NoOfPublishedDataSets" />\r\n    <opc:Field Name="NoOfConnections" TypeName="opc:Int32" />\r\n    <opc:Field Name="Connections" TypeName="tns:PubSubConnectionDataType" LengthField="NoOfConnections" />\r\n    <opc:Field Name="Enabled" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="DataSetOrderingType" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Undefined" Value="0" />\r\n    <opc:EnumeratedValue Name="AscendingWriterId" Value="1" />\r\n    <opc:EnumeratedValue Name="AscendingWriterIdSingle" Value="2" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="UadpNetworkMessageContentMask" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="PublisherId" Value="1" />\r\n    <opc:EnumeratedValue Name="GroupHeader" Value="2" />\r\n    <opc:EnumeratedValue Name="WriterGroupId" Value="4" />\r\n    <opc:EnumeratedValue Name="GroupVersion" Value="8" />\r\n    <opc:EnumeratedValue Name="NetworkMessageNumber" Value="16" />\r\n    <opc:EnumeratedValue Name="SequenceNumber" Value="32" />\r\n    <opc:EnumeratedValue Name="PayloadHeader" Value="64" />\r\n    <opc:EnumeratedValue Name="Timestamp" Value="128" />\r\n    <opc:EnumeratedValue Name="Picoseconds" Value="256" />\r\n    <opc:EnumeratedValue Name="DataSetClassId" Value="512" />\r\n    <opc:EnumeratedValue Name="PromotedFields" Value="1024" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="UadpWriterGroupMessageDataType" BaseType="tns:WriterGroupMessageDataType">\r\n    <opc:Field Name="GroupVersion" TypeName="opc:UInt32" />\r\n    <opc:Field Name="DataSetOrdering" TypeName="tns:DataSetOrderingType" />\r\n    <opc:Field Name="NetworkMessageContentMask" TypeName="tns:UadpNetworkMessageContentMask" />\r\n    <opc:Field Name="SamplingOffset" TypeName="opc:Double" />\r\n    <opc:Field Name="NoOfPublishingOffset" TypeName="opc:Int32" />\r\n    <opc:Field Name="PublishingOffset" TypeName="opc:Double" LengthField="NoOfPublishingOffset" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="UadpDataSetMessageContentMask" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Timestamp" Value="1" />\r\n    <opc:EnumeratedValue Name="PicoSeconds" Value="2" />\r\n    <opc:EnumeratedValue Name="Status" Value="4" />\r\n    <opc:EnumeratedValue Name="MajorVersion" Value="8" />\r\n    <opc:EnumeratedValue Name="MinorVersion" Value="16" />\r\n    <opc:EnumeratedValue Name="SequenceNumber" Value="32" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="UadpDataSetWriterMessageDataType" BaseType="tns:DataSetWriterMessageDataType">\r\n    <opc:Field Name="DataSetMessageContentMask" TypeName="tns:UadpDataSetMessageContentMask" />\r\n    <opc:Field Name="ConfiguredSize" TypeName="opc:UInt16" />\r\n    <opc:Field Name="NetworkMessageNumber" TypeName="opc:UInt16" />\r\n    <opc:Field Name="DataSetOffset" TypeName="opc:UInt16" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="UadpDataSetReaderMessageDataType" BaseType="tns:DataSetReaderMessageDataType">\r\n    <opc:Field Name="GroupVersion" TypeName="opc:UInt32" />\r\n    <opc:Field Name="NetworkMessageNumber" TypeName="opc:UInt16" />\r\n    <opc:Field Name="DataSetOffset" TypeName="opc:UInt16" />\r\n    <opc:Field Name="DataSetClassId" TypeName="opc:Guid" />\r\n    <opc:Field Name="NetworkMessageContentMask" TypeName="tns:UadpNetworkMessageContentMask" />\r\n    <opc:Field Name="DataSetMessageContentMask" TypeName="tns:UadpDataSetMessageContentMask" />\r\n    <opc:Field Name="PublishingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="ReceiveOffset" TypeName="opc:Double" />\r\n    <opc:Field Name="ProcessingOffset" TypeName="opc:Double" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="JsonNetworkMessageContentMask" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="NetworkMessageHeader" Value="1" />\r\n    <opc:EnumeratedValue Name="DataSetMessageHeader" Value="2" />\r\n    <opc:EnumeratedValue Name="SingleDataSetMessage" Value="4" />\r\n    <opc:EnumeratedValue Name="PublisherId" Value="8" />\r\n    <opc:EnumeratedValue Name="DataSetClassId" Value="16" />\r\n    <opc:EnumeratedValue Name="ReplyTo" Value="32" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="JsonWriterGroupMessageDataType" BaseType="tns:WriterGroupMessageDataType">\r\n    <opc:Field Name="NetworkMessageContentMask" TypeName="tns:JsonNetworkMessageContentMask" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="JsonDataSetMessageContentMask" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="DataSetWriterId" Value="1" />\r\n    <opc:EnumeratedValue Name="MetaDataVersion" Value="2" />\r\n    <opc:EnumeratedValue Name="SequenceNumber" Value="4" />\r\n    <opc:EnumeratedValue Name="Timestamp" Value="8" />\r\n    <opc:EnumeratedValue Name="Status" Value="16" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="JsonDataSetWriterMessageDataType" BaseType="tns:DataSetWriterMessageDataType">\r\n    <opc:Field Name="DataSetMessageContentMask" TypeName="tns:JsonDataSetMessageContentMask" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="JsonDataSetReaderMessageDataType" BaseType="tns:DataSetReaderMessageDataType">\r\n    <opc:Field Name="NetworkMessageContentMask" TypeName="tns:JsonNetworkMessageContentMask" />\r\n    <opc:Field Name="DataSetMessageContentMask" TypeName="tns:JsonDataSetMessageContentMask" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DatagramConnectionTransportDataType" BaseType="tns:ConnectionTransportDataType">\r\n    <opc:Field Name="DiscoveryAddress" TypeName="ua:ExtensionObject" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DatagramWriterGroupTransportDataType" BaseType="tns:WriterGroupTransportDataType">\r\n    <opc:Field Name="MessageRepeatCount" TypeName="opc:Byte" />\r\n    <opc:Field Name="MessageRepeatDelay" TypeName="opc:Double" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="BrokerConnectionTransportDataType" BaseType="tns:ConnectionTransportDataType">\r\n    <opc:Field Name="ResourceUri" TypeName="opc:String" />\r\n    <opc:Field Name="AuthenticationProfileUri" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="BrokerTransportQualityOfService" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="NotSpecified" Value="0" />\r\n    <opc:EnumeratedValue Name="BestEffort" Value="1" />\r\n    <opc:EnumeratedValue Name="AtLeastOnce" Value="2" />\r\n    <opc:EnumeratedValue Name="AtMostOnce" Value="3" />\r\n    <opc:EnumeratedValue Name="ExactlyOnce" Value="4" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="BrokerWriterGroupTransportDataType" BaseType="tns:WriterGroupTransportDataType">\r\n    <opc:Field Name="QueueName" TypeName="opc:String" />\r\n    <opc:Field Name="ResourceUri" TypeName="opc:String" />\r\n    <opc:Field Name="AuthenticationProfileUri" TypeName="opc:String" />\r\n    <opc:Field Name="RequestedDeliveryGuarantee" TypeName="tns:BrokerTransportQualityOfService" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="BrokerDataSetWriterTransportDataType" BaseType="tns:DataSetWriterTransportDataType">\r\n    <opc:Field Name="QueueName" TypeName="opc:String" />\r\n    <opc:Field Name="ResourceUri" TypeName="opc:String" />\r\n    <opc:Field Name="AuthenticationProfileUri" TypeName="opc:String" />\r\n    <opc:Field Name="MetaDataQueueName" TypeName="opc:String" />\r\n    <opc:Field Name="MetaDataUpdateTime" TypeName="opc:Double" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="BrokerDataSetReaderTransportDataType" BaseType="tns:DataSetReaderTransportDataType">\r\n    <opc:Field Name="QueueName" TypeName="opc:String" />\r\n    <opc:Field Name="ResourceUri" TypeName="opc:String" />\r\n    <opc:Field Name="AuthenticationProfileUri" TypeName="opc:String" />\r\n    <opc:Field Name="RequestedDeliveryGuarantee" TypeName="tns:BrokerTransportQualityOfService" />\r\n    <opc:Field Name="MetaDataQueueName" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="DiagnosticsLevel" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Basic" Value="0" />\r\n    <opc:EnumeratedValue Name="Advanced" Value="1" />\r\n    <opc:EnumeratedValue Name="Info" Value="2" />\r\n    <opc:EnumeratedValue Name="Log" Value="3" />\r\n    <opc:EnumeratedValue Name="Debug" Value="4" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="PubSubDiagnosticsCounterClassification" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Information" Value="0" />\r\n    <opc:EnumeratedValue Name="Error" Value="1" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="IdType" LengthInBits="32">\r\n    <opc:Documentation>The type of identifier used in a node id.</opc:Documentation>\r\n    <opc:EnumeratedValue Name="Numeric" Value="0" />\r\n    <opc:EnumeratedValue Name="String" Value="1" />\r\n    <opc:EnumeratedValue Name="Guid" Value="2" />\r\n    <opc:EnumeratedValue Name="Opaque" Value="3" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="NodeClass" LengthInBits="32">\r\n    <opc:Documentation>A mask specifying the class of the node.</opc:Documentation>\r\n    <opc:EnumeratedValue Name="Unspecified" Value="0" />\r\n    <opc:EnumeratedValue Name="Object" Value="1" />\r\n    <opc:EnumeratedValue Name="Variable" Value="2" />\r\n    <opc:EnumeratedValue Name="Method" Value="4" />\r\n    <opc:EnumeratedValue Name="ObjectType" Value="8" />\r\n    <opc:EnumeratedValue Name="VariableType" Value="16" />\r\n    <opc:EnumeratedValue Name="ReferenceType" Value="32" />\r\n    <opc:EnumeratedValue Name="DataType" Value="64" />\r\n    <opc:EnumeratedValue Name="View" Value="128" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="AccessLevelType" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="None" Value="0" />\r\n    <opc:EnumeratedValue Name="CurrentRead" Value="1" />\r\n    <opc:EnumeratedValue Name="CurrentWrite" Value="2" />\r\n    <opc:EnumeratedValue Name="HistoryRead" Value="4" />\r\n    <opc:EnumeratedValue Name="HistoryWrite" Value="16" />\r\n    <opc:EnumeratedValue Name="StatusWrite" Value="32" />\r\n    <opc:EnumeratedValue Name="TimestampWrite" Value="64" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="AccessLevelExType" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="None" Value="0" />\r\n    <opc:EnumeratedValue Name="CurrentRead" Value="1" />\r\n    <opc:EnumeratedValue Name="CurrentWrite" Value="2" />\r\n    <opc:EnumeratedValue Name="HistoryRead" Value="4" />\r\n    <opc:EnumeratedValue Name="HistoryWrite" Value="16" />\r\n    <opc:EnumeratedValue Name="StatusWrite" Value="32" />\r\n    <opc:EnumeratedValue Name="TimestampWrite" Value="64" />\r\n    <opc:EnumeratedValue Name="NonatomicRead" Value="65536" />\r\n    <opc:EnumeratedValue Name="NonatomicWrite" Value="131072" />\r\n    <opc:EnumeratedValue Name="WriteFullArrayOnly" Value="262144" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="EventNotifierType" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="None" Value="0" />\r\n    <opc:EnumeratedValue Name="SubscribeToEvents" Value="1" />\r\n    <opc:EnumeratedValue Name="HistoryRead" Value="4" />\r\n    <opc:EnumeratedValue Name="HistoryWrite" Value="8" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="RolePermissionType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RoleId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="Permissions" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="StructureType" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Structure" Value="0" />\r\n    <opc:EnumeratedValue Name="StructureWithOptionalFields" Value="1" />\r\n    <opc:EnumeratedValue Name="Union" Value="2" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="StructureField" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Name" TypeName="opc:String" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" />\r\n    <opc:Field Name="DataType" TypeName="ua:NodeId" />\r\n    <opc:Field Name="ValueRank" TypeName="opc:Int32" />\r\n    <opc:Field Name="NoOfArrayDimensions" TypeName="opc:Int32" />\r\n    <opc:Field Name="ArrayDimensions" TypeName="opc:UInt32" LengthField="NoOfArrayDimensions" />\r\n    <opc:Field Name="MaxStringLength" TypeName="opc:UInt32" />\r\n    <opc:Field Name="IsOptional" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="StructureDefinition" BaseType="tns:DataTypeDefinition">\r\n    <opc:Field Name="DefaultEncodingId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="BaseDataType" TypeName="ua:NodeId" />\r\n    <opc:Field Name="StructureType" TypeName="tns:StructureType" />\r\n    <opc:Field Name="NoOfFields" TypeName="opc:Int32" />\r\n    <opc:Field Name="Fields" TypeName="tns:StructureField" LengthField="NoOfFields" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="EnumDefinition" BaseType="tns:DataTypeDefinition">\r\n    <opc:Field Name="NoOfFields" TypeName="opc:Int32" />\r\n    <opc:Field Name="Fields" TypeName="tns:EnumField" LengthField="NoOfFields" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="Node" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Specifies the attributes which belong to all nodes.</opc:Documentation>\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" />\r\n    <opc:Field Name="NoOfRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="RolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfRolePermissions" />\r\n    <opc:Field Name="NoOfUserRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="UserRolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfUserRolePermissions" />\r\n    <opc:Field Name="AccessRestrictions" TypeName="opc:UInt16" />\r\n    <opc:Field Name="NoOfReferences" TypeName="opc:Int32" />\r\n    <opc:Field Name="References" TypeName="tns:ReferenceNode" LengthField="NoOfReferences" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="InstanceNode" BaseType="tns:Node">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:Node" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" SourceType="tns:Node" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" SourceType="tns:Node" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="RolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfRolePermissions" />\r\n    <opc:Field Name="NoOfUserRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="UserRolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfUserRolePermissions" />\r\n    <opc:Field Name="AccessRestrictions" TypeName="opc:UInt16" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfReferences" TypeName="opc:Int32" />\r\n    <opc:Field Name="References" TypeName="tns:ReferenceNode" LengthField="NoOfReferences" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="TypeNode" BaseType="tns:Node">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:Node" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" SourceType="tns:Node" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" SourceType="tns:Node" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="RolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfRolePermissions" />\r\n    <opc:Field Name="NoOfUserRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="UserRolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfUserRolePermissions" />\r\n    <opc:Field Name="AccessRestrictions" TypeName="opc:UInt16" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfReferences" TypeName="opc:Int32" />\r\n    <opc:Field Name="References" TypeName="tns:ReferenceNode" LengthField="NoOfReferences" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ObjectNode" BaseType="tns:InstanceNode">\r\n    <opc:Documentation>Specifies the attributes which belong to object nodes.</opc:Documentation>\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:Node" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" SourceType="tns:Node" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" SourceType="tns:Node" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="RolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfRolePermissions" />\r\n    <opc:Field Name="NoOfUserRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="UserRolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfUserRolePermissions" />\r\n    <opc:Field Name="AccessRestrictions" TypeName="opc:UInt16" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfReferences" TypeName="opc:Int32" />\r\n    <opc:Field Name="References" TypeName="tns:ReferenceNode" LengthField="NoOfReferences" />\r\n    <opc:Field Name="EventNotifier" TypeName="opc:Byte" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ObjectTypeNode" BaseType="tns:TypeNode">\r\n    <opc:Documentation>Specifies the attributes which belong to object type nodes.</opc:Documentation>\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:Node" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" SourceType="tns:Node" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" SourceType="tns:Node" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="RolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfRolePermissions" />\r\n    <opc:Field Name="NoOfUserRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="UserRolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfUserRolePermissions" />\r\n    <opc:Field Name="AccessRestrictions" TypeName="opc:UInt16" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfReferences" TypeName="opc:Int32" />\r\n    <opc:Field Name="References" TypeName="tns:ReferenceNode" LengthField="NoOfReferences" />\r\n    <opc:Field Name="IsAbstract" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="VariableNode" BaseType="tns:InstanceNode">\r\n    <opc:Documentation>Specifies the attributes which belong to variable nodes.</opc:Documentation>\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:Node" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" SourceType="tns:Node" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" SourceType="tns:Node" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="RolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfRolePermissions" />\r\n    <opc:Field Name="NoOfUserRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="UserRolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfUserRolePermissions" />\r\n    <opc:Field Name="AccessRestrictions" TypeName="opc:UInt16" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfReferences" TypeName="opc:Int32" />\r\n    <opc:Field Name="References" TypeName="tns:ReferenceNode" LengthField="NoOfReferences" />\r\n    <opc:Field Name="Value" TypeName="ua:Variant" />\r\n    <opc:Field Name="DataType" TypeName="ua:NodeId" />\r\n    <opc:Field Name="ValueRank" TypeName="opc:Int32" />\r\n    <opc:Field Name="NoOfArrayDimensions" TypeName="opc:Int32" />\r\n    <opc:Field Name="ArrayDimensions" TypeName="opc:UInt32" LengthField="NoOfArrayDimensions" />\r\n    <opc:Field Name="AccessLevel" TypeName="opc:Byte" />\r\n    <opc:Field Name="UserAccessLevel" TypeName="opc:Byte" />\r\n    <opc:Field Name="MinimumSamplingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="Historizing" TypeName="opc:Boolean" />\r\n    <opc:Field Name="AccessLevelEx" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="VariableTypeNode" BaseType="tns:TypeNode">\r\n    <opc:Documentation>Specifies the attributes which belong to variable type nodes.</opc:Documentation>\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:Node" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" SourceType="tns:Node" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" SourceType="tns:Node" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="RolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfRolePermissions" />\r\n    <opc:Field Name="NoOfUserRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="UserRolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfUserRolePermissions" />\r\n    <opc:Field Name="AccessRestrictions" TypeName="opc:UInt16" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfReferences" TypeName="opc:Int32" />\r\n    <opc:Field Name="References" TypeName="tns:ReferenceNode" LengthField="NoOfReferences" />\r\n    <opc:Field Name="Value" TypeName="ua:Variant" />\r\n    <opc:Field Name="DataType" TypeName="ua:NodeId" />\r\n    <opc:Field Name="ValueRank" TypeName="opc:Int32" />\r\n    <opc:Field Name="NoOfArrayDimensions" TypeName="opc:Int32" />\r\n    <opc:Field Name="ArrayDimensions" TypeName="opc:UInt32" LengthField="NoOfArrayDimensions" />\r\n    <opc:Field Name="IsAbstract" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ReferenceTypeNode" BaseType="tns:TypeNode">\r\n    <opc:Documentation>Specifies the attributes which belong to reference type nodes.</opc:Documentation>\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:Node" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" SourceType="tns:Node" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" SourceType="tns:Node" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="RolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfRolePermissions" />\r\n    <opc:Field Name="NoOfUserRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="UserRolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfUserRolePermissions" />\r\n    <opc:Field Name="AccessRestrictions" TypeName="opc:UInt16" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfReferences" TypeName="opc:Int32" />\r\n    <opc:Field Name="References" TypeName="tns:ReferenceNode" LengthField="NoOfReferences" />\r\n    <opc:Field Name="IsAbstract" TypeName="opc:Boolean" />\r\n    <opc:Field Name="Symmetric" TypeName="opc:Boolean" />\r\n    <opc:Field Name="InverseName" TypeName="ua:LocalizedText" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="MethodNode" BaseType="tns:InstanceNode">\r\n    <opc:Documentation>Specifies the attributes which belong to method nodes.</opc:Documentation>\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:Node" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" SourceType="tns:Node" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" SourceType="tns:Node" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="RolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfRolePermissions" />\r\n    <opc:Field Name="NoOfUserRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="UserRolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfUserRolePermissions" />\r\n    <opc:Field Name="AccessRestrictions" TypeName="opc:UInt16" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfReferences" TypeName="opc:Int32" />\r\n    <opc:Field Name="References" TypeName="tns:ReferenceNode" LengthField="NoOfReferences" />\r\n    <opc:Field Name="Executable" TypeName="opc:Boolean" />\r\n    <opc:Field Name="UserExecutable" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ViewNode" BaseType="tns:InstanceNode">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:Node" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" SourceType="tns:Node" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" SourceType="tns:Node" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="RolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfRolePermissions" />\r\n    <opc:Field Name="NoOfUserRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="UserRolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfUserRolePermissions" />\r\n    <opc:Field Name="AccessRestrictions" TypeName="opc:UInt16" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfReferences" TypeName="opc:Int32" />\r\n    <opc:Field Name="References" TypeName="tns:ReferenceNode" LengthField="NoOfReferences" />\r\n    <opc:Field Name="ContainsNoLoops" TypeName="opc:Boolean" />\r\n    <opc:Field Name="EventNotifier" TypeName="opc:Byte" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DataTypeNode" BaseType="tns:TypeNode">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:Node" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" SourceType="tns:Node" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" SourceType="tns:Node" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:Node" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="RolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfRolePermissions" />\r\n    <opc:Field Name="NoOfUserRolePermissions" TypeName="opc:Int32" />\r\n    <opc:Field Name="UserRolePermissions" TypeName="tns:RolePermissionType" LengthField="NoOfUserRolePermissions" />\r\n    <opc:Field Name="AccessRestrictions" TypeName="opc:UInt16" SourceType="tns:Node" />\r\n    <opc:Field Name="NoOfReferences" TypeName="opc:Int32" />\r\n    <opc:Field Name="References" TypeName="tns:ReferenceNode" LengthField="NoOfReferences" />\r\n    <opc:Field Name="IsAbstract" TypeName="opc:Boolean" />\r\n    <opc:Field Name="DataTypeDefinition" TypeName="ua:ExtensionObject" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ReferenceNode" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Specifies a reference which belongs to a node.</opc:Documentation>\r\n    <opc:Field Name="ReferenceTypeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="IsInverse" TypeName="opc:Boolean" />\r\n    <opc:Field Name="TargetId" TypeName="ua:ExpandedNodeId" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="Argument" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>An argument for a method.</opc:Documentation>\r\n    <opc:Field Name="Name" TypeName="opc:String" />\r\n    <opc:Field Name="DataType" TypeName="ua:NodeId" />\r\n    <opc:Field Name="ValueRank" TypeName="opc:Int32" />\r\n    <opc:Field Name="NoOfArrayDimensions" TypeName="opc:Int32" />\r\n    <opc:Field Name="ArrayDimensions" TypeName="opc:UInt32" LengthField="NoOfArrayDimensions" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="EnumValueType" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A mapping between a value of an enumerated type and a name and description.</opc:Documentation>\r\n    <opc:Field Name="Value" TypeName="opc:Int64" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="EnumField" BaseType="tns:EnumValueType">\r\n    <opc:Field Name="Value" TypeName="opc:Int64" SourceType="tns:EnumValueType" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:EnumValueType" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:EnumValueType" />\r\n    <opc:Field Name="Name" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="OptionSet" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>This abstract Structured DataType is the base DataType for all DataTypes representing a bit mask.</opc:Documentation>\r\n    <opc:Field Name="Value" TypeName="opc:ByteString" />\r\n    <opc:Field Name="ValidBits" TypeName="opc:ByteString" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="Union" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>This abstract DataType is the base DataType for all union DataTypes.</opc:Documentation>\r\n  </opc:StructuredType>\r\n\r\n  <opc:OpaqueType Name="NormalizedString">\r\n    <opc:Documentation>A string normalized based on the rules in the unicode specification.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="DecimalString">\r\n    <opc:Documentation>An arbitraty numeric value.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="DurationString">\r\n    <opc:Documentation>A period of time formatted as defined in ISO 8601-2000.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="TimeString">\r\n    <opc:Documentation>A time formatted as defined in ISO 8601-2000.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="DateString">\r\n    <opc:Documentation>A date formatted as defined in ISO 8601-2000.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="Duration">\r\n    <opc:Documentation>A period of time measured in milliseconds.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="UtcTime">\r\n    <opc:Documentation>A date/time value specified in Universal Coordinated Time (UTC).</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="LocaleId">\r\n    <opc:Documentation>An identifier for a user locale.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:StructuredType Name="TimeZoneDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Offset" TypeName="opc:Int16" />\r\n    <opc:Field Name="DaylightSavingInOffset" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:OpaqueType Name="IntegerId">\r\n    <opc:Documentation>A numeric identifier for an object.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:EnumeratedType Name="ApplicationType" LengthInBits="32">\r\n    <opc:Documentation>The types of applications.</opc:Documentation>\r\n    <opc:EnumeratedValue Name="Server" Value="0" />\r\n    <opc:EnumeratedValue Name="Client" Value="1" />\r\n    <opc:EnumeratedValue Name="ClientAndServer" Value="2" />\r\n    <opc:EnumeratedValue Name="DiscoveryServer" Value="3" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="ApplicationDescription" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Describes an application and how to find it.</opc:Documentation>\r\n    <opc:Field Name="ApplicationUri" TypeName="opc:String" />\r\n    <opc:Field Name="ProductUri" TypeName="opc:String" />\r\n    <opc:Field Name="ApplicationName" TypeName="ua:LocalizedText" />\r\n    <opc:Field Name="ApplicationType" TypeName="tns:ApplicationType" />\r\n    <opc:Field Name="GatewayServerUri" TypeName="opc:String" />\r\n    <opc:Field Name="DiscoveryProfileUri" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfDiscoveryUrls" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiscoveryUrls" TypeName="opc:String" LengthField="NoOfDiscoveryUrls" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="RequestHeader" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>The header passed with every server request.</opc:Documentation>\r\n    <opc:Field Name="AuthenticationToken" TypeName="ua:NodeId" />\r\n    <opc:Field Name="Timestamp" TypeName="opc:DateTime" />\r\n    <opc:Field Name="RequestHandle" TypeName="opc:UInt32" />\r\n    <opc:Field Name="ReturnDiagnostics" TypeName="opc:UInt32" />\r\n    <opc:Field Name="AuditEntryId" TypeName="opc:String" />\r\n    <opc:Field Name="TimeoutHint" TypeName="opc:UInt32" />\r\n    <opc:Field Name="AdditionalHeader" TypeName="ua:ExtensionObject" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ResponseHeader" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>The header passed with every server response.</opc:Documentation>\r\n    <opc:Field Name="Timestamp" TypeName="opc:DateTime" />\r\n    <opc:Field Name="RequestHandle" TypeName="opc:UInt32" />\r\n    <opc:Field Name="ServiceResult" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="ServiceDiagnostics" TypeName="ua:DiagnosticInfo" />\r\n    <opc:Field Name="NoOfStringTable" TypeName="opc:Int32" />\r\n    <opc:Field Name="StringTable" TypeName="opc:String" LengthField="NoOfStringTable" />\r\n    <opc:Field Name="AdditionalHeader" TypeName="ua:ExtensionObject" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:OpaqueType Name="VersionTime">\r\n  </opc:OpaqueType>\r\n\r\n  <opc:StructuredType Name="ServiceFault" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>The response returned by all services when there is a service level error.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SessionlessInvokeRequestType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NoOfUrisVersion" TypeName="opc:Int32" />\r\n    <opc:Field Name="UrisVersion" TypeName="opc:UInt32" LengthField="NoOfUrisVersion" />\r\n    <opc:Field Name="NoOfNamespaceUris" TypeName="opc:Int32" />\r\n    <opc:Field Name="NamespaceUris" TypeName="opc:String" LengthField="NoOfNamespaceUris" />\r\n    <opc:Field Name="NoOfServerUris" TypeName="opc:Int32" />\r\n    <opc:Field Name="ServerUris" TypeName="opc:String" LengthField="NoOfServerUris" />\r\n    <opc:Field Name="NoOfLocaleIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="LocaleIds" TypeName="opc:String" LengthField="NoOfLocaleIds" />\r\n    <opc:Field Name="ServiceId" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SessionlessInvokeResponseType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NoOfNamespaceUris" TypeName="opc:Int32" />\r\n    <opc:Field Name="NamespaceUris" TypeName="opc:String" LengthField="NoOfNamespaceUris" />\r\n    <opc:Field Name="NoOfServerUris" TypeName="opc:Int32" />\r\n    <opc:Field Name="ServerUris" TypeName="opc:String" LengthField="NoOfServerUris" />\r\n    <opc:Field Name="ServiceId" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="FindServersRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Finds the servers known to the discovery server.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="EndpointUrl" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfLocaleIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="LocaleIds" TypeName="opc:String" LengthField="NoOfLocaleIds" />\r\n    <opc:Field Name="NoOfServerUris" TypeName="opc:Int32" />\r\n    <opc:Field Name="ServerUris" TypeName="opc:String" LengthField="NoOfServerUris" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="FindServersResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Finds the servers known to the discovery server.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfServers" TypeName="opc:Int32" />\r\n    <opc:Field Name="Servers" TypeName="tns:ApplicationDescription" LengthField="NoOfServers" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ServerOnNetwork" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RecordId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="ServerName" TypeName="opc:String" />\r\n    <opc:Field Name="DiscoveryUrl" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfServerCapabilities" TypeName="opc:Int32" />\r\n    <opc:Field Name="ServerCapabilities" TypeName="opc:String" LengthField="NoOfServerCapabilities" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="FindServersOnNetworkRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="StartingRecordId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="MaxRecordsToReturn" TypeName="opc:UInt32" />\r\n    <opc:Field Name="NoOfServerCapabilityFilter" TypeName="opc:Int32" />\r\n    <opc:Field Name="ServerCapabilityFilter" TypeName="opc:String" LengthField="NoOfServerCapabilityFilter" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="FindServersOnNetworkResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="LastCounterResetTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="NoOfServers" TypeName="opc:Int32" />\r\n    <opc:Field Name="Servers" TypeName="tns:ServerOnNetwork" LengthField="NoOfServers" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:OpaqueType Name="ApplicationInstanceCertificate">\r\n    <opc:Documentation>A certificate for an instance of an application.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:EnumeratedType Name="MessageSecurityMode" LengthInBits="32">\r\n    <opc:Documentation>The type of security to use on a message.</opc:Documentation>\r\n    <opc:EnumeratedValue Name="Invalid" Value="0" />\r\n    <opc:EnumeratedValue Name="None" Value="1" />\r\n    <opc:EnumeratedValue Name="Sign" Value="2" />\r\n    <opc:EnumeratedValue Name="SignAndEncrypt" Value="3" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="UserTokenType" LengthInBits="32">\r\n    <opc:Documentation>The possible user token types.</opc:Documentation>\r\n    <opc:EnumeratedValue Name="Anonymous" Value="0" />\r\n    <opc:EnumeratedValue Name="UserName" Value="1" />\r\n    <opc:EnumeratedValue Name="Certificate" Value="2" />\r\n    <opc:EnumeratedValue Name="IssuedToken" Value="3" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="UserTokenPolicy" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Describes a user token that can be used with a server.</opc:Documentation>\r\n    <opc:Field Name="PolicyId" TypeName="opc:String" />\r\n    <opc:Field Name="TokenType" TypeName="tns:UserTokenType" />\r\n    <opc:Field Name="IssuedTokenType" TypeName="opc:String" />\r\n    <opc:Field Name="IssuerEndpointUrl" TypeName="opc:String" />\r\n    <opc:Field Name="SecurityPolicyUri" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="EndpointDescription" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>The description of a endpoint that can be used to access a server.</opc:Documentation>\r\n    <opc:Field Name="EndpointUrl" TypeName="opc:String" />\r\n    <opc:Field Name="Server" TypeName="tns:ApplicationDescription" />\r\n    <opc:Field Name="ServerCertificate" TypeName="opc:ByteString" />\r\n    <opc:Field Name="SecurityMode" TypeName="tns:MessageSecurityMode" />\r\n    <opc:Field Name="SecurityPolicyUri" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfUserIdentityTokens" TypeName="opc:Int32" />\r\n    <opc:Field Name="UserIdentityTokens" TypeName="tns:UserTokenPolicy" LengthField="NoOfUserIdentityTokens" />\r\n    <opc:Field Name="TransportProfileUri" TypeName="opc:String" />\r\n    <opc:Field Name="SecurityLevel" TypeName="opc:Byte" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="GetEndpointsRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Gets the endpoints used by the server.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="EndpointUrl" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfLocaleIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="LocaleIds" TypeName="opc:String" LengthField="NoOfLocaleIds" />\r\n    <opc:Field Name="NoOfProfileUris" TypeName="opc:Int32" />\r\n    <opc:Field Name="ProfileUris" TypeName="opc:String" LengthField="NoOfProfileUris" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="GetEndpointsResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Gets the endpoints used by the server.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfEndpoints" TypeName="opc:Int32" />\r\n    <opc:Field Name="Endpoints" TypeName="tns:EndpointDescription" LengthField="NoOfEndpoints" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="RegisteredServer" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>The information required to register a server with a discovery server.</opc:Documentation>\r\n    <opc:Field Name="ServerUri" TypeName="opc:String" />\r\n    <opc:Field Name="ProductUri" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfServerNames" TypeName="opc:Int32" />\r\n    <opc:Field Name="ServerNames" TypeName="ua:LocalizedText" LengthField="NoOfServerNames" />\r\n    <opc:Field Name="ServerType" TypeName="tns:ApplicationType" />\r\n    <opc:Field Name="GatewayServerUri" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfDiscoveryUrls" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiscoveryUrls" TypeName="opc:String" LengthField="NoOfDiscoveryUrls" />\r\n    <opc:Field Name="SemaphoreFilePath" TypeName="opc:String" />\r\n    <opc:Field Name="IsOnline" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="RegisterServerRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Registers a server with the discovery server.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="Server" TypeName="tns:RegisteredServer" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="RegisterServerResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Registers a server with the discovery server.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DiscoveryConfiguration" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A base type for discovery configuration information.</opc:Documentation>\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="MdnsDiscoveryConfiguration" BaseType="tns:DiscoveryConfiguration">\r\n    <opc:Documentation>The discovery information needed for mDNS registration.</opc:Documentation>\r\n    <opc:Field Name="MdnsServerName" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfServerCapabilities" TypeName="opc:Int32" />\r\n    <opc:Field Name="ServerCapabilities" TypeName="opc:String" LengthField="NoOfServerCapabilities" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="RegisterServer2Request" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="Server" TypeName="tns:RegisteredServer" />\r\n    <opc:Field Name="NoOfDiscoveryConfiguration" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiscoveryConfiguration" TypeName="ua:ExtensionObject" LengthField="NoOfDiscoveryConfiguration" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="RegisterServer2Response" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfConfigurationResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="ConfigurationResults" TypeName="ua:StatusCode" LengthField="NoOfConfigurationResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="SecurityTokenRequestType" LengthInBits="32">\r\n    <opc:Documentation>Indicates whether a token if being created or renewed.</opc:Documentation>\r\n    <opc:EnumeratedValue Name="Issue" Value="0" />\r\n    <opc:EnumeratedValue Name="Renew" Value="1" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="ChannelSecurityToken" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>The token that identifies a set of keys for an active secure channel.</opc:Documentation>\r\n    <opc:Field Name="ChannelId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="TokenId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="CreatedAt" TypeName="opc:DateTime" />\r\n    <opc:Field Name="RevisedLifetime" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="OpenSecureChannelRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Creates a secure channel with a server.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="ClientProtocolVersion" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RequestType" TypeName="tns:SecurityTokenRequestType" />\r\n    <opc:Field Name="SecurityMode" TypeName="tns:MessageSecurityMode" />\r\n    <opc:Field Name="ClientNonce" TypeName="opc:ByteString" />\r\n    <opc:Field Name="RequestedLifetime" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="OpenSecureChannelResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Creates a secure channel with a server.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="ServerProtocolVersion" TypeName="opc:UInt32" />\r\n    <opc:Field Name="SecurityToken" TypeName="tns:ChannelSecurityToken" />\r\n    <opc:Field Name="ServerNonce" TypeName="opc:ByteString" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CloseSecureChannelRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Closes a secure channel.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CloseSecureChannelResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Closes a secure channel.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SignedSoftwareCertificate" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A software certificate with a digital signature.</opc:Documentation>\r\n    <opc:Field Name="CertificateData" TypeName="opc:ByteString" />\r\n    <opc:Field Name="Signature" TypeName="opc:ByteString" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:OpaqueType Name="SessionAuthenticationToken">\r\n    <opc:Documentation>A unique identifier for a session used to authenticate requests.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:StructuredType Name="SignatureData" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A digital signature.</opc:Documentation>\r\n    <opc:Field Name="Algorithm" TypeName="opc:String" />\r\n    <opc:Field Name="Signature" TypeName="opc:ByteString" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CreateSessionRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Creates a new session with the server.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="ClientDescription" TypeName="tns:ApplicationDescription" />\r\n    <opc:Field Name="ServerUri" TypeName="opc:String" />\r\n    <opc:Field Name="EndpointUrl" TypeName="opc:String" />\r\n    <opc:Field Name="SessionName" TypeName="opc:String" />\r\n    <opc:Field Name="ClientNonce" TypeName="opc:ByteString" />\r\n    <opc:Field Name="ClientCertificate" TypeName="opc:ByteString" />\r\n    <opc:Field Name="RequestedSessionTimeout" TypeName="opc:Double" />\r\n    <opc:Field Name="MaxResponseMessageSize" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CreateSessionResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Creates a new session with the server.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="SessionId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="AuthenticationToken" TypeName="ua:NodeId" />\r\n    <opc:Field Name="RevisedSessionTimeout" TypeName="opc:Double" />\r\n    <opc:Field Name="ServerNonce" TypeName="opc:ByteString" />\r\n    <opc:Field Name="ServerCertificate" TypeName="opc:ByteString" />\r\n    <opc:Field Name="NoOfServerEndpoints" TypeName="opc:Int32" />\r\n    <opc:Field Name="ServerEndpoints" TypeName="tns:EndpointDescription" LengthField="NoOfServerEndpoints" />\r\n    <opc:Field Name="NoOfServerSoftwareCertificates" TypeName="opc:Int32" />\r\n    <opc:Field Name="ServerSoftwareCertificates" TypeName="tns:SignedSoftwareCertificate" LengthField="NoOfServerSoftwareCertificates" />\r\n    <opc:Field Name="ServerSignature" TypeName="tns:SignatureData" />\r\n    <opc:Field Name="MaxRequestMessageSize" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="UserIdentityToken" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A base type for a user identity token.</opc:Documentation>\r\n    <opc:Field Name="PolicyId" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AnonymousIdentityToken" BaseType="tns:UserIdentityToken">\r\n    <opc:Documentation>A token representing an anonymous user.</opc:Documentation>\r\n    <opc:Field Name="PolicyId" TypeName="opc:String" SourceType="tns:UserIdentityToken" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="UserNameIdentityToken" BaseType="tns:UserIdentityToken">\r\n    <opc:Documentation>A token representing a user identified by a user name and password.</opc:Documentation>\r\n    <opc:Field Name="PolicyId" TypeName="opc:String" SourceType="tns:UserIdentityToken" />\r\n    <opc:Field Name="UserName" TypeName="opc:String" />\r\n    <opc:Field Name="Password" TypeName="opc:ByteString" />\r\n    <opc:Field Name="EncryptionAlgorithm" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="X509IdentityToken" BaseType="tns:UserIdentityToken">\r\n    <opc:Documentation>A token representing a user identified by an X509 certificate.</opc:Documentation>\r\n    <opc:Field Name="PolicyId" TypeName="opc:String" SourceType="tns:UserIdentityToken" />\r\n    <opc:Field Name="CertificateData" TypeName="opc:ByteString" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="IssuedIdentityToken" BaseType="tns:UserIdentityToken">\r\n    <opc:Documentation>A token representing a user identified by a WS-Security XML token.</opc:Documentation>\r\n    <opc:Field Name="PolicyId" TypeName="opc:String" SourceType="tns:UserIdentityToken" />\r\n    <opc:Field Name="TokenData" TypeName="opc:ByteString" />\r\n    <opc:Field Name="EncryptionAlgorithm" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ActivateSessionRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Activates a session with the server.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="ClientSignature" TypeName="tns:SignatureData" />\r\n    <opc:Field Name="NoOfClientSoftwareCertificates" TypeName="opc:Int32" />\r\n    <opc:Field Name="ClientSoftwareCertificates" TypeName="tns:SignedSoftwareCertificate" LengthField="NoOfClientSoftwareCertificates" />\r\n    <opc:Field Name="NoOfLocaleIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="LocaleIds" TypeName="opc:String" LengthField="NoOfLocaleIds" />\r\n    <opc:Field Name="UserIdentityToken" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="UserTokenSignature" TypeName="tns:SignatureData" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ActivateSessionResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Activates a session with the server.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="ServerNonce" TypeName="opc:ByteString" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="ua:StatusCode" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CloseSessionRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Closes a session with the server.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="DeleteSubscriptions" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CloseSessionResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Closes a session with the server.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CancelRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Cancels an outstanding request.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="RequestHandle" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CancelResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Cancels an outstanding request.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="CancelCount" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="NodeAttributesMask" LengthInBits="32">\r\n    <opc:Documentation>The bits used to specify default attributes for a new node.</opc:Documentation>\r\n    <opc:EnumeratedValue Name="None" Value="0" />\r\n    <opc:EnumeratedValue Name="AccessLevel" Value="1" />\r\n    <opc:EnumeratedValue Name="ArrayDimensions" Value="2" />\r\n    <opc:EnumeratedValue Name="BrowseName" Value="4" />\r\n    <opc:EnumeratedValue Name="ContainsNoLoops" Value="8" />\r\n    <opc:EnumeratedValue Name="DataType" Value="16" />\r\n    <opc:EnumeratedValue Name="Description" Value="32" />\r\n    <opc:EnumeratedValue Name="DisplayName" Value="64" />\r\n    <opc:EnumeratedValue Name="EventNotifier" Value="128" />\r\n    <opc:EnumeratedValue Name="Executable" Value="256" />\r\n    <opc:EnumeratedValue Name="Historizing" Value="512" />\r\n    <opc:EnumeratedValue Name="InverseName" Value="1024" />\r\n    <opc:EnumeratedValue Name="IsAbstract" Value="2048" />\r\n    <opc:EnumeratedValue Name="MinimumSamplingInterval" Value="4096" />\r\n    <opc:EnumeratedValue Name="NodeClass" Value="8192" />\r\n    <opc:EnumeratedValue Name="NodeId" Value="16384" />\r\n    <opc:EnumeratedValue Name="Symmetric" Value="32768" />\r\n    <opc:EnumeratedValue Name="UserAccessLevel" Value="65536" />\r\n    <opc:EnumeratedValue Name="UserExecutable" Value="131072" />\r\n    <opc:EnumeratedValue Name="UserWriteMask" Value="262144" />\r\n    <opc:EnumeratedValue Name="ValueRank" Value="524288" />\r\n    <opc:EnumeratedValue Name="WriteMask" Value="1048576" />\r\n    <opc:EnumeratedValue Name="Value" Value="2097152" />\r\n    <opc:EnumeratedValue Name="DataTypeDefinition" Value="4194304" />\r\n    <opc:EnumeratedValue Name="RolePermissions" Value="8388608" />\r\n    <opc:EnumeratedValue Name="AccessRestrictions" Value="16777216" />\r\n    <opc:EnumeratedValue Name="All" Value="33554431" />\r\n    <opc:EnumeratedValue Name="BaseNode" Value="26501220" />\r\n    <opc:EnumeratedValue Name="Object" Value="26501348" />\r\n    <opc:EnumeratedValue Name="ObjectType" Value="26503268" />\r\n    <opc:EnumeratedValue Name="Variable" Value="26571383" />\r\n    <opc:EnumeratedValue Name="VariableType" Value="28600438" />\r\n    <opc:EnumeratedValue Name="Method" Value="26632548" />\r\n    <opc:EnumeratedValue Name="ReferenceType" Value="26537060" />\r\n    <opc:EnumeratedValue Name="View" Value="26501356" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="NodeAttributes" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>The base attributes for all nodes.</opc:Documentation>\r\n    <opc:Field Name="SpecifiedAttributes" TypeName="opc:UInt32" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ObjectAttributes" BaseType="tns:NodeAttributes">\r\n    <opc:Documentation>The attributes for an object node.</opc:Documentation>\r\n    <opc:Field Name="SpecifiedAttributes" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="EventNotifier" TypeName="opc:Byte" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="VariableAttributes" BaseType="tns:NodeAttributes">\r\n    <opc:Documentation>The attributes for a variable node.</opc:Documentation>\r\n    <opc:Field Name="SpecifiedAttributes" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="Value" TypeName="ua:Variant" />\r\n    <opc:Field Name="DataType" TypeName="ua:NodeId" />\r\n    <opc:Field Name="ValueRank" TypeName="opc:Int32" />\r\n    <opc:Field Name="NoOfArrayDimensions" TypeName="opc:Int32" />\r\n    <opc:Field Name="ArrayDimensions" TypeName="opc:UInt32" LengthField="NoOfArrayDimensions" />\r\n    <opc:Field Name="AccessLevel" TypeName="opc:Byte" />\r\n    <opc:Field Name="UserAccessLevel" TypeName="opc:Byte" />\r\n    <opc:Field Name="MinimumSamplingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="Historizing" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="MethodAttributes" BaseType="tns:NodeAttributes">\r\n    <opc:Documentation>The attributes for a method node.</opc:Documentation>\r\n    <opc:Field Name="SpecifiedAttributes" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="Executable" TypeName="opc:Boolean" />\r\n    <opc:Field Name="UserExecutable" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ObjectTypeAttributes" BaseType="tns:NodeAttributes">\r\n    <opc:Documentation>The attributes for an object type node.</opc:Documentation>\r\n    <opc:Field Name="SpecifiedAttributes" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="IsAbstract" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="VariableTypeAttributes" BaseType="tns:NodeAttributes">\r\n    <opc:Documentation>The attributes for a variable type node.</opc:Documentation>\r\n    <opc:Field Name="SpecifiedAttributes" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="Value" TypeName="ua:Variant" />\r\n    <opc:Field Name="DataType" TypeName="ua:NodeId" />\r\n    <opc:Field Name="ValueRank" TypeName="opc:Int32" />\r\n    <opc:Field Name="NoOfArrayDimensions" TypeName="opc:Int32" />\r\n    <opc:Field Name="ArrayDimensions" TypeName="opc:UInt32" LengthField="NoOfArrayDimensions" />\r\n    <opc:Field Name="IsAbstract" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ReferenceTypeAttributes" BaseType="tns:NodeAttributes">\r\n    <opc:Documentation>The attributes for a reference type node.</opc:Documentation>\r\n    <opc:Field Name="SpecifiedAttributes" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="IsAbstract" TypeName="opc:Boolean" />\r\n    <opc:Field Name="Symmetric" TypeName="opc:Boolean" />\r\n    <opc:Field Name="InverseName" TypeName="ua:LocalizedText" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DataTypeAttributes" BaseType="tns:NodeAttributes">\r\n    <opc:Documentation>The attributes for a data type node.</opc:Documentation>\r\n    <opc:Field Name="SpecifiedAttributes" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="IsAbstract" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ViewAttributes" BaseType="tns:NodeAttributes">\r\n    <opc:Documentation>The attributes for a view node.</opc:Documentation>\r\n    <opc:Field Name="SpecifiedAttributes" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="ContainsNoLoops" TypeName="opc:Boolean" />\r\n    <opc:Field Name="EventNotifier" TypeName="opc:Byte" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="GenericAttributeValue" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="AttributeId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="Value" TypeName="ua:Variant" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="GenericAttributes" BaseType="tns:NodeAttributes">\r\n    <opc:Field Name="SpecifiedAttributes" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="WriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="UserWriteMask" TypeName="opc:UInt32" SourceType="tns:NodeAttributes" />\r\n    <opc:Field Name="NoOfAttributeValues" TypeName="opc:Int32" />\r\n    <opc:Field Name="AttributeValues" TypeName="tns:GenericAttributeValue" LengthField="NoOfAttributeValues" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AddNodesItem" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A request to add a node to the server address space.</opc:Documentation>\r\n    <opc:Field Name="ParentNodeId" TypeName="ua:ExpandedNodeId" />\r\n    <opc:Field Name="ReferenceTypeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="RequestedNewNodeId" TypeName="ua:ExpandedNodeId" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" />\r\n    <opc:Field Name="NodeAttributes" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="TypeDefinition" TypeName="ua:ExpandedNodeId" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AddNodesResult" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A result of an add node operation.</opc:Documentation>\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="AddedNodeId" TypeName="ua:NodeId" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AddNodesRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Adds one or more nodes to the server address space.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfNodesToAdd" TypeName="opc:Int32" />\r\n    <opc:Field Name="NodesToAdd" TypeName="tns:AddNodesItem" LengthField="NoOfNodesToAdd" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AddNodesResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Adds one or more nodes to the server address space.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="tns:AddNodesResult" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AddReferencesItem" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A request to add a reference to the server address space.</opc:Documentation>\r\n    <opc:Field Name="SourceNodeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="ReferenceTypeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="IsForward" TypeName="opc:Boolean" />\r\n    <opc:Field Name="TargetServerUri" TypeName="opc:String" />\r\n    <opc:Field Name="TargetNodeId" TypeName="ua:ExpandedNodeId" />\r\n    <opc:Field Name="TargetNodeClass" TypeName="tns:NodeClass" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AddReferencesRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Adds one or more references to the server address space.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfReferencesToAdd" TypeName="opc:Int32" />\r\n    <opc:Field Name="ReferencesToAdd" TypeName="tns:AddReferencesItem" LengthField="NoOfReferencesToAdd" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AddReferencesResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Adds one or more references to the server address space.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="ua:StatusCode" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteNodesItem" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A request to delete a node to the server address space.</opc:Documentation>\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="DeleteTargetReferences" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteNodesRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Delete one or more nodes from the server address space.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfNodesToDelete" TypeName="opc:Int32" />\r\n    <opc:Field Name="NodesToDelete" TypeName="tns:DeleteNodesItem" LengthField="NoOfNodesToDelete" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteNodesResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Delete one or more nodes from the server address space.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="ua:StatusCode" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteReferencesItem" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A request to delete a node from the server address space.</opc:Documentation>\r\n    <opc:Field Name="SourceNodeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="ReferenceTypeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="IsForward" TypeName="opc:Boolean" />\r\n    <opc:Field Name="TargetNodeId" TypeName="ua:ExpandedNodeId" />\r\n    <opc:Field Name="DeleteBidirectional" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteReferencesRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Delete one or more references from the server address space.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfReferencesToDelete" TypeName="opc:Int32" />\r\n    <opc:Field Name="ReferencesToDelete" TypeName="tns:DeleteReferencesItem" LengthField="NoOfReferencesToDelete" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteReferencesResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Delete one or more references from the server address space.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="ua:StatusCode" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="AttributeWriteMask" LengthInBits="32">\r\n    <opc:Documentation>Define bits used to indicate which attributes are writable.</opc:Documentation>\r\n    <opc:EnumeratedValue Name="None" Value="0" />\r\n    <opc:EnumeratedValue Name="AccessLevel" Value="1" />\r\n    <opc:EnumeratedValue Name="ArrayDimensions" Value="2" />\r\n    <opc:EnumeratedValue Name="BrowseName" Value="4" />\r\n    <opc:EnumeratedValue Name="ContainsNoLoops" Value="8" />\r\n    <opc:EnumeratedValue Name="DataType" Value="16" />\r\n    <opc:EnumeratedValue Name="Description" Value="32" />\r\n    <opc:EnumeratedValue Name="DisplayName" Value="64" />\r\n    <opc:EnumeratedValue Name="EventNotifier" Value="128" />\r\n    <opc:EnumeratedValue Name="Executable" Value="256" />\r\n    <opc:EnumeratedValue Name="Historizing" Value="512" />\r\n    <opc:EnumeratedValue Name="InverseName" Value="1024" />\r\n    <opc:EnumeratedValue Name="IsAbstract" Value="2048" />\r\n    <opc:EnumeratedValue Name="MinimumSamplingInterval" Value="4096" />\r\n    <opc:EnumeratedValue Name="NodeClass" Value="8192" />\r\n    <opc:EnumeratedValue Name="NodeId" Value="16384" />\r\n    <opc:EnumeratedValue Name="Symmetric" Value="32768" />\r\n    <opc:EnumeratedValue Name="UserAccessLevel" Value="65536" />\r\n    <opc:EnumeratedValue Name="UserExecutable" Value="131072" />\r\n    <opc:EnumeratedValue Name="UserWriteMask" Value="262144" />\r\n    <opc:EnumeratedValue Name="ValueRank" Value="524288" />\r\n    <opc:EnumeratedValue Name="WriteMask" Value="1048576" />\r\n    <opc:EnumeratedValue Name="ValueForVariableType" Value="2097152" />\r\n    <opc:EnumeratedValue Name="DataTypeDefinition" Value="4194304" />\r\n    <opc:EnumeratedValue Name="RolePermissions" Value="8388608" />\r\n    <opc:EnumeratedValue Name="AccessRestrictions" Value="16777216" />\r\n    <opc:EnumeratedValue Name="AccessLevelEx" Value="33554432" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="BrowseDirection" LengthInBits="32">\r\n    <opc:Documentation>The directions of the references to return.</opc:Documentation>\r\n    <opc:EnumeratedValue Name="Forward" Value="0" />\r\n    <opc:EnumeratedValue Name="Inverse" Value="1" />\r\n    <opc:EnumeratedValue Name="Both" Value="2" />\r\n    <opc:EnumeratedValue Name="Invalid" Value="3" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="ViewDescription" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>The view to browse.</opc:Documentation>\r\n    <opc:Field Name="ViewId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="Timestamp" TypeName="opc:DateTime" />\r\n    <opc:Field Name="ViewVersion" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="BrowseDescription" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A request to browse the the references from a node.</opc:Documentation>\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="BrowseDirection" TypeName="tns:BrowseDirection" />\r\n    <opc:Field Name="ReferenceTypeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="IncludeSubtypes" TypeName="opc:Boolean" />\r\n    <opc:Field Name="NodeClassMask" TypeName="opc:UInt32" />\r\n    <opc:Field Name="ResultMask" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="BrowseResultMask" LengthInBits="32">\r\n    <opc:Documentation>A bit mask which specifies what should be returned in a browse response.</opc:Documentation>\r\n    <opc:EnumeratedValue Name="None" Value="0" />\r\n    <opc:EnumeratedValue Name="ReferenceTypeId" Value="1" />\r\n    <opc:EnumeratedValue Name="IsForward" Value="2" />\r\n    <opc:EnumeratedValue Name="NodeClass" Value="4" />\r\n    <opc:EnumeratedValue Name="BrowseName" Value="8" />\r\n    <opc:EnumeratedValue Name="DisplayName" Value="16" />\r\n    <opc:EnumeratedValue Name="TypeDefinition" Value="32" />\r\n    <opc:EnumeratedValue Name="All" Value="63" />\r\n    <opc:EnumeratedValue Name="ReferenceTypeInfo" Value="3" />\r\n    <opc:EnumeratedValue Name="TargetInfo" Value="60" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="ReferenceDescription" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>The description of a reference.</opc:Documentation>\r\n    <opc:Field Name="ReferenceTypeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="IsForward" TypeName="opc:Boolean" />\r\n    <opc:Field Name="NodeId" TypeName="ua:ExpandedNodeId" />\r\n    <opc:Field Name="BrowseName" TypeName="ua:QualifiedName" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" />\r\n    <opc:Field Name="NodeClass" TypeName="tns:NodeClass" />\r\n    <opc:Field Name="TypeDefinition" TypeName="ua:ExpandedNodeId" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:OpaqueType Name="ContinuationPoint">\r\n    <opc:Documentation>An identifier for a suspended query or browse operation.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:StructuredType Name="BrowseResult" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>The result of a browse operation.</opc:Documentation>\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="ContinuationPoint" TypeName="opc:ByteString" />\r\n    <opc:Field Name="NoOfReferences" TypeName="opc:Int32" />\r\n    <opc:Field Name="References" TypeName="tns:ReferenceDescription" LengthField="NoOfReferences" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="BrowseRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Browse the references for one or more nodes from the server address space.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="View" TypeName="tns:ViewDescription" />\r\n    <opc:Field Name="RequestedMaxReferencesPerNode" TypeName="opc:UInt32" />\r\n    <opc:Field Name="NoOfNodesToBrowse" TypeName="opc:Int32" />\r\n    <opc:Field Name="NodesToBrowse" TypeName="tns:BrowseDescription" LengthField="NoOfNodesToBrowse" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="BrowseResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Browse the references for one or more nodes from the server address space.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="tns:BrowseResult" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="BrowseNextRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Continues one or more browse operations.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="ReleaseContinuationPoints" TypeName="opc:Boolean" />\r\n    <opc:Field Name="NoOfContinuationPoints" TypeName="opc:Int32" />\r\n    <opc:Field Name="ContinuationPoints" TypeName="opc:ByteString" LengthField="NoOfContinuationPoints" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="BrowseNextResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Continues one or more browse operations.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="tns:BrowseResult" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="RelativePathElement" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>An element in a relative path.</opc:Documentation>\r\n    <opc:Field Name="ReferenceTypeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="IsInverse" TypeName="opc:Boolean" />\r\n    <opc:Field Name="IncludeSubtypes" TypeName="opc:Boolean" />\r\n    <opc:Field Name="TargetName" TypeName="ua:QualifiedName" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="RelativePath" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A relative path constructed from reference types and browse names.</opc:Documentation>\r\n    <opc:Field Name="NoOfElements" TypeName="opc:Int32" />\r\n    <opc:Field Name="Elements" TypeName="tns:RelativePathElement" LengthField="NoOfElements" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="BrowsePath" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>A request to translate a path into a node id.</opc:Documentation>\r\n    <opc:Field Name="StartingNode" TypeName="ua:NodeId" />\r\n    <opc:Field Name="RelativePath" TypeName="tns:RelativePath" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="BrowsePathTarget" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>The target of the translated path.</opc:Documentation>\r\n    <opc:Field Name="TargetId" TypeName="ua:ExpandedNodeId" />\r\n    <opc:Field Name="RemainingPathIndex" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="BrowsePathResult" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>The result of a translate opearation.</opc:Documentation>\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="NoOfTargets" TypeName="opc:Int32" />\r\n    <opc:Field Name="Targets" TypeName="tns:BrowsePathTarget" LengthField="NoOfTargets" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="TranslateBrowsePathsToNodeIdsRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Translates one or more paths in the server address space.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfBrowsePaths" TypeName="opc:Int32" />\r\n    <opc:Field Name="BrowsePaths" TypeName="tns:BrowsePath" LengthField="NoOfBrowsePaths" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="TranslateBrowsePathsToNodeIdsResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Translates one or more paths in the server address space.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="tns:BrowsePathResult" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="RegisterNodesRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Registers one or more nodes for repeated use within a session.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfNodesToRegister" TypeName="opc:Int32" />\r\n    <opc:Field Name="NodesToRegister" TypeName="ua:NodeId" LengthField="NoOfNodesToRegister" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="RegisterNodesResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Registers one or more nodes for repeated use within a session.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfRegisteredNodeIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="RegisteredNodeIds" TypeName="ua:NodeId" LengthField="NoOfRegisteredNodeIds" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="UnregisterNodesRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Unregisters one or more previously registered nodes.</opc:Documentation>\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfNodesToUnregister" TypeName="opc:Int32" />\r\n    <opc:Field Name="NodesToUnregister" TypeName="ua:NodeId" LengthField="NoOfNodesToUnregister" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="UnregisterNodesResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Documentation>Unregisters one or more previously registered nodes.</opc:Documentation>\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:OpaqueType Name="Counter">\r\n    <opc:Documentation>A monotonically increasing value.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="NumericRange">\r\n    <opc:Documentation>Specifies a range of array indexes.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="Time">\r\n    <opc:Documentation>A time value specified as HH:MM:SS.SSS.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:OpaqueType Name="Date">\r\n    <opc:Documentation>A date value.</opc:Documentation>\r\n  </opc:OpaqueType>\r\n\r\n  <opc:StructuredType Name="EndpointConfiguration" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="OperationTimeout" TypeName="opc:Int32" />\r\n    <opc:Field Name="UseBinaryEncoding" TypeName="opc:Boolean" />\r\n    <opc:Field Name="MaxStringLength" TypeName="opc:Int32" />\r\n    <opc:Field Name="MaxByteStringLength" TypeName="opc:Int32" />\r\n    <opc:Field Name="MaxArrayLength" TypeName="opc:Int32" />\r\n    <opc:Field Name="MaxMessageSize" TypeName="opc:Int32" />\r\n    <opc:Field Name="MaxBufferSize" TypeName="opc:Int32" />\r\n    <opc:Field Name="ChannelLifetime" TypeName="opc:Int32" />\r\n    <opc:Field Name="SecurityTokenLifetime" TypeName="opc:Int32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="QueryDataDescription" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RelativePath" TypeName="tns:RelativePath" />\r\n    <opc:Field Name="AttributeId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="IndexRange" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="NodeTypeDescription" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="TypeDefinitionNode" TypeName="ua:ExpandedNodeId" />\r\n    <opc:Field Name="IncludeSubTypes" TypeName="opc:Boolean" />\r\n    <opc:Field Name="NoOfDataToReturn" TypeName="opc:Int32" />\r\n    <opc:Field Name="DataToReturn" TypeName="tns:QueryDataDescription" LengthField="NoOfDataToReturn" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="FilterOperator" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Equals" Value="0" />\r\n    <opc:EnumeratedValue Name="IsNull" Value="1" />\r\n    <opc:EnumeratedValue Name="GreaterThan" Value="2" />\r\n    <opc:EnumeratedValue Name="LessThan" Value="3" />\r\n    <opc:EnumeratedValue Name="GreaterThanOrEqual" Value="4" />\r\n    <opc:EnumeratedValue Name="LessThanOrEqual" Value="5" />\r\n    <opc:EnumeratedValue Name="Like" Value="6" />\r\n    <opc:EnumeratedValue Name="Not" Value="7" />\r\n    <opc:EnumeratedValue Name="Between" Value="8" />\r\n    <opc:EnumeratedValue Name="InList" Value="9" />\r\n    <opc:EnumeratedValue Name="And" Value="10" />\r\n    <opc:EnumeratedValue Name="Or" Value="11" />\r\n    <opc:EnumeratedValue Name="Cast" Value="12" />\r\n    <opc:EnumeratedValue Name="InView" Value="13" />\r\n    <opc:EnumeratedValue Name="OfType" Value="14" />\r\n    <opc:EnumeratedValue Name="RelatedTo" Value="15" />\r\n    <opc:EnumeratedValue Name="BitwiseAnd" Value="16" />\r\n    <opc:EnumeratedValue Name="BitwiseOr" Value="17" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="QueryDataSet" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NodeId" TypeName="ua:ExpandedNodeId" />\r\n    <opc:Field Name="TypeDefinitionNode" TypeName="ua:ExpandedNodeId" />\r\n    <opc:Field Name="NoOfValues" TypeName="opc:Int32" />\r\n    <opc:Field Name="Values" TypeName="ua:Variant" LengthField="NoOfValues" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="NodeReference" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="ReferenceTypeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="IsForward" TypeName="opc:Boolean" />\r\n    <opc:Field Name="NoOfReferencedNodeIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="ReferencedNodeIds" TypeName="ua:NodeId" LengthField="NoOfReferencedNodeIds" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ContentFilterElement" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="FilterOperator" TypeName="tns:FilterOperator" />\r\n    <opc:Field Name="NoOfFilterOperands" TypeName="opc:Int32" />\r\n    <opc:Field Name="FilterOperands" TypeName="ua:ExtensionObject" LengthField="NoOfFilterOperands" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ContentFilter" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NoOfElements" TypeName="opc:Int32" />\r\n    <opc:Field Name="Elements" TypeName="tns:ContentFilterElement" LengthField="NoOfElements" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="FilterOperand" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ElementOperand" BaseType="tns:FilterOperand">\r\n    <opc:Field Name="Index" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="LiteralOperand" BaseType="tns:FilterOperand">\r\n    <opc:Field Name="Value" TypeName="ua:Variant" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AttributeOperand" BaseType="tns:FilterOperand">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="Alias" TypeName="opc:String" />\r\n    <opc:Field Name="BrowsePath" TypeName="tns:RelativePath" />\r\n    <opc:Field Name="AttributeId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="IndexRange" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SimpleAttributeOperand" BaseType="tns:FilterOperand">\r\n    <opc:Field Name="TypeDefinitionId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="NoOfBrowsePath" TypeName="opc:Int32" />\r\n    <opc:Field Name="BrowsePath" TypeName="ua:QualifiedName" LengthField="NoOfBrowsePath" />\r\n    <opc:Field Name="AttributeId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="IndexRange" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ContentFilterElementResult" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="NoOfOperandStatusCodes" TypeName="opc:Int32" />\r\n    <opc:Field Name="OperandStatusCodes" TypeName="ua:StatusCode" LengthField="NoOfOperandStatusCodes" />\r\n    <opc:Field Name="NoOfOperandDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="OperandDiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfOperandDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ContentFilterResult" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NoOfElementResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="ElementResults" TypeName="tns:ContentFilterElementResult" LengthField="NoOfElementResults" />\r\n    <opc:Field Name="NoOfElementDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="ElementDiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfElementDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ParsingResult" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="NoOfDataStatusCodes" TypeName="opc:Int32" />\r\n    <opc:Field Name="DataStatusCodes" TypeName="ua:StatusCode" LengthField="NoOfDataStatusCodes" />\r\n    <opc:Field Name="NoOfDataDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DataDiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDataDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="QueryFirstRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="View" TypeName="tns:ViewDescription" />\r\n    <opc:Field Name="NoOfNodeTypes" TypeName="opc:Int32" />\r\n    <opc:Field Name="NodeTypes" TypeName="tns:NodeTypeDescription" LengthField="NoOfNodeTypes" />\r\n    <opc:Field Name="Filter" TypeName="tns:ContentFilter" />\r\n    <opc:Field Name="MaxDataSetsToReturn" TypeName="opc:UInt32" />\r\n    <opc:Field Name="MaxReferencesToReturn" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="QueryFirstResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfQueryDataSets" TypeName="opc:Int32" />\r\n    <opc:Field Name="QueryDataSets" TypeName="tns:QueryDataSet" LengthField="NoOfQueryDataSets" />\r\n    <opc:Field Name="ContinuationPoint" TypeName="opc:ByteString" />\r\n    <opc:Field Name="NoOfParsingResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="ParsingResults" TypeName="tns:ParsingResult" LengthField="NoOfParsingResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n    <opc:Field Name="FilterResult" TypeName="tns:ContentFilterResult" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="QueryNextRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="ReleaseContinuationPoint" TypeName="opc:Boolean" />\r\n    <opc:Field Name="ContinuationPoint" TypeName="opc:ByteString" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="QueryNextResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfQueryDataSets" TypeName="opc:Int32" />\r\n    <opc:Field Name="QueryDataSets" TypeName="tns:QueryDataSet" LengthField="NoOfQueryDataSets" />\r\n    <opc:Field Name="RevisedContinuationPoint" TypeName="opc:ByteString" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="TimestampsToReturn" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Source" Value="0" />\r\n    <opc:EnumeratedValue Name="Server" Value="1" />\r\n    <opc:EnumeratedValue Name="Both" Value="2" />\r\n    <opc:EnumeratedValue Name="Neither" Value="3" />\r\n    <opc:EnumeratedValue Name="Invalid" Value="4" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="ReadValueId" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="AttributeId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="IndexRange" TypeName="opc:String" />\r\n    <opc:Field Name="DataEncoding" TypeName="ua:QualifiedName" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ReadRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="MaxAge" TypeName="opc:Double" />\r\n    <opc:Field Name="TimestampsToReturn" TypeName="tns:TimestampsToReturn" />\r\n    <opc:Field Name="NoOfNodesToRead" TypeName="opc:Int32" />\r\n    <opc:Field Name="NodesToRead" TypeName="tns:ReadValueId" LengthField="NoOfNodesToRead" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ReadResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="ua:DataValue" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryReadValueId" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="IndexRange" TypeName="opc:String" />\r\n    <opc:Field Name="DataEncoding" TypeName="ua:QualifiedName" />\r\n    <opc:Field Name="ContinuationPoint" TypeName="opc:ByteString" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryReadResult" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="ContinuationPoint" TypeName="opc:ByteString" />\r\n    <opc:Field Name="HistoryData" TypeName="ua:ExtensionObject" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryReadDetails" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ReadEventDetails" BaseType="tns:HistoryReadDetails">\r\n    <opc:Field Name="NumValuesPerNode" TypeName="opc:UInt32" />\r\n    <opc:Field Name="StartTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="EndTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="Filter" TypeName="tns:EventFilter" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ReadRawModifiedDetails" BaseType="tns:HistoryReadDetails">\r\n    <opc:Field Name="IsReadModified" TypeName="opc:Boolean" />\r\n    <opc:Field Name="StartTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="EndTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="NumValuesPerNode" TypeName="opc:UInt32" />\r\n    <opc:Field Name="ReturnBounds" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ReadProcessedDetails" BaseType="tns:HistoryReadDetails">\r\n    <opc:Field Name="StartTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="EndTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="ProcessingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="NoOfAggregateType" TypeName="opc:Int32" />\r\n    <opc:Field Name="AggregateType" TypeName="ua:NodeId" LengthField="NoOfAggregateType" />\r\n    <opc:Field Name="AggregateConfiguration" TypeName="tns:AggregateConfiguration" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ReadAtTimeDetails" BaseType="tns:HistoryReadDetails">\r\n    <opc:Field Name="NoOfReqTimes" TypeName="opc:Int32" />\r\n    <opc:Field Name="ReqTimes" TypeName="opc:DateTime" LengthField="NoOfReqTimes" />\r\n    <opc:Field Name="UseSimpleBounds" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryData" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NoOfDataValues" TypeName="opc:Int32" />\r\n    <opc:Field Name="DataValues" TypeName="ua:DataValue" LengthField="NoOfDataValues" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ModificationInfo" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ModificationTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="UpdateType" TypeName="tns:HistoryUpdateType" />\r\n    <opc:Field Name="UserName" TypeName="opc:String" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryModifiedData" BaseType="tns:HistoryData">\r\n    <opc:Field Name="NoOfDataValues" TypeName="opc:Int32" />\r\n    <opc:Field Name="DataValues" TypeName="ua:DataValue" LengthField="NoOfDataValues" />\r\n    <opc:Field Name="NoOfModificationInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="ModificationInfos" TypeName="tns:ModificationInfo" LengthField="NoOfModificationInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryEvent" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NoOfEvents" TypeName="opc:Int32" />\r\n    <opc:Field Name="Events" TypeName="tns:HistoryEventFieldList" LengthField="NoOfEvents" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryReadRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="HistoryReadDetails" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="TimestampsToReturn" TypeName="tns:TimestampsToReturn" />\r\n    <opc:Field Name="ReleaseContinuationPoints" TypeName="opc:Boolean" />\r\n    <opc:Field Name="NoOfNodesToRead" TypeName="opc:Int32" />\r\n    <opc:Field Name="NodesToRead" TypeName="tns:HistoryReadValueId" LengthField="NoOfNodesToRead" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryReadResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="tns:HistoryReadResult" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="WriteValue" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="AttributeId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="IndexRange" TypeName="opc:String" />\r\n    <opc:Field Name="Value" TypeName="ua:DataValue" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="WriteRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfNodesToWrite" TypeName="opc:Int32" />\r\n    <opc:Field Name="NodesToWrite" TypeName="tns:WriteValue" LengthField="NoOfNodesToWrite" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="WriteResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="ua:StatusCode" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryUpdateDetails" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="HistoryUpdateType" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Insert" Value="1" />\r\n    <opc:EnumeratedValue Name="Replace" Value="2" />\r\n    <opc:EnumeratedValue Name="Update" Value="3" />\r\n    <opc:EnumeratedValue Name="Delete" Value="4" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="PerformUpdateType" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Insert" Value="1" />\r\n    <opc:EnumeratedValue Name="Replace" Value="2" />\r\n    <opc:EnumeratedValue Name="Update" Value="3" />\r\n    <opc:EnumeratedValue Name="Remove" Value="4" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="UpdateDataDetails" BaseType="tns:HistoryUpdateDetails">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:HistoryUpdateDetails" />\r\n    <opc:Field Name="PerformInsertReplace" TypeName="tns:PerformUpdateType" />\r\n    <opc:Field Name="NoOfUpdateValues" TypeName="opc:Int32" />\r\n    <opc:Field Name="UpdateValues" TypeName="ua:DataValue" LengthField="NoOfUpdateValues" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="UpdateStructureDataDetails" BaseType="tns:HistoryUpdateDetails">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:HistoryUpdateDetails" />\r\n    <opc:Field Name="PerformInsertReplace" TypeName="tns:PerformUpdateType" />\r\n    <opc:Field Name="NoOfUpdateValues" TypeName="opc:Int32" />\r\n    <opc:Field Name="UpdateValues" TypeName="ua:DataValue" LengthField="NoOfUpdateValues" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="UpdateEventDetails" BaseType="tns:HistoryUpdateDetails">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:HistoryUpdateDetails" />\r\n    <opc:Field Name="PerformInsertReplace" TypeName="tns:PerformUpdateType" />\r\n    <opc:Field Name="Filter" TypeName="tns:EventFilter" />\r\n    <opc:Field Name="NoOfEventData" TypeName="opc:Int32" />\r\n    <opc:Field Name="EventData" TypeName="tns:HistoryEventFieldList" LengthField="NoOfEventData" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteRawModifiedDetails" BaseType="tns:HistoryUpdateDetails">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:HistoryUpdateDetails" />\r\n    <opc:Field Name="IsDeleteModified" TypeName="opc:Boolean" />\r\n    <opc:Field Name="StartTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="EndTime" TypeName="opc:DateTime" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteAtTimeDetails" BaseType="tns:HistoryUpdateDetails">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:HistoryUpdateDetails" />\r\n    <opc:Field Name="NoOfReqTimes" TypeName="opc:Int32" />\r\n    <opc:Field Name="ReqTimes" TypeName="opc:DateTime" LengthField="NoOfReqTimes" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteEventDetails" BaseType="tns:HistoryUpdateDetails">\r\n    <opc:Field Name="NodeId" TypeName="ua:NodeId" SourceType="tns:HistoryUpdateDetails" />\r\n    <opc:Field Name="NoOfEventIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="EventIds" TypeName="opc:ByteString" LengthField="NoOfEventIds" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryUpdateResult" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="NoOfOperationResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="OperationResults" TypeName="ua:StatusCode" LengthField="NoOfOperationResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryUpdateRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfHistoryUpdateDetails" TypeName="opc:Int32" />\r\n    <opc:Field Name="HistoryUpdateDetails" TypeName="ua:ExtensionObject" LengthField="NoOfHistoryUpdateDetails" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryUpdateResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="tns:HistoryUpdateResult" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CallMethodRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ObjectId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="MethodId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="NoOfInputArguments" TypeName="opc:Int32" />\r\n    <opc:Field Name="InputArguments" TypeName="ua:Variant" LengthField="NoOfInputArguments" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CallMethodResult" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="NoOfInputArgumentResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="InputArgumentResults" TypeName="ua:StatusCode" LengthField="NoOfInputArgumentResults" />\r\n    <opc:Field Name="NoOfInputArgumentDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="InputArgumentDiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfInputArgumentDiagnosticInfos" />\r\n    <opc:Field Name="NoOfOutputArguments" TypeName="opc:Int32" />\r\n    <opc:Field Name="OutputArguments" TypeName="ua:Variant" LengthField="NoOfOutputArguments" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CallRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfMethodsToCall" TypeName="opc:Int32" />\r\n    <opc:Field Name="MethodsToCall" TypeName="tns:CallMethodRequest" LengthField="NoOfMethodsToCall" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CallResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="tns:CallMethodResult" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="MonitoringMode" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Disabled" Value="0" />\r\n    <opc:EnumeratedValue Name="Sampling" Value="1" />\r\n    <opc:EnumeratedValue Name="Reporting" Value="2" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="DataChangeTrigger" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Status" Value="0" />\r\n    <opc:EnumeratedValue Name="StatusValue" Value="1" />\r\n    <opc:EnumeratedValue Name="StatusValueTimestamp" Value="2" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="DeadbandType" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="None" Value="0" />\r\n    <opc:EnumeratedValue Name="Absolute" Value="1" />\r\n    <opc:EnumeratedValue Name="Percent" Value="2" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="MonitoringFilter" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DataChangeFilter" BaseType="tns:MonitoringFilter">\r\n    <opc:Field Name="Trigger" TypeName="tns:DataChangeTrigger" />\r\n    <opc:Field Name="DeadbandType" TypeName="opc:UInt32" />\r\n    <opc:Field Name="DeadbandValue" TypeName="opc:Double" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="EventFilter" BaseType="tns:MonitoringFilter">\r\n    <opc:Field Name="NoOfSelectClauses" TypeName="opc:Int32" />\r\n    <opc:Field Name="SelectClauses" TypeName="tns:SimpleAttributeOperand" LengthField="NoOfSelectClauses" />\r\n    <opc:Field Name="WhereClause" TypeName="tns:ContentFilter" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AggregateConfiguration" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="UseServerCapabilitiesDefaults" TypeName="opc:Boolean" />\r\n    <opc:Field Name="TreatUncertainAsBad" TypeName="opc:Boolean" />\r\n    <opc:Field Name="PercentDataBad" TypeName="opc:Byte" />\r\n    <opc:Field Name="PercentDataGood" TypeName="opc:Byte" />\r\n    <opc:Field Name="UseSlopedExtrapolation" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AggregateFilter" BaseType="tns:MonitoringFilter">\r\n    <opc:Field Name="StartTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="AggregateType" TypeName="ua:NodeId" />\r\n    <opc:Field Name="ProcessingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="AggregateConfiguration" TypeName="tns:AggregateConfiguration" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="MonitoringFilterResult" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="EventFilterResult" BaseType="tns:MonitoringFilterResult">\r\n    <opc:Field Name="NoOfSelectClauseResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="SelectClauseResults" TypeName="ua:StatusCode" LengthField="NoOfSelectClauseResults" />\r\n    <opc:Field Name="NoOfSelectClauseDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="SelectClauseDiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfSelectClauseDiagnosticInfos" />\r\n    <opc:Field Name="WhereClauseResult" TypeName="tns:ContentFilterResult" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AggregateFilterResult" BaseType="tns:MonitoringFilterResult">\r\n    <opc:Field Name="RevisedStartTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="RevisedProcessingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="RevisedAggregateConfiguration" TypeName="tns:AggregateConfiguration" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="MonitoringParameters" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ClientHandle" TypeName="opc:UInt32" />\r\n    <opc:Field Name="SamplingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="Filter" TypeName="ua:ExtensionObject" />\r\n    <opc:Field Name="QueueSize" TypeName="opc:UInt32" />\r\n    <opc:Field Name="DiscardOldest" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="MonitoredItemCreateRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ItemToMonitor" TypeName="tns:ReadValueId" />\r\n    <opc:Field Name="MonitoringMode" TypeName="tns:MonitoringMode" />\r\n    <opc:Field Name="RequestedParameters" TypeName="tns:MonitoringParameters" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="MonitoredItemCreateResult" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="MonitoredItemId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RevisedSamplingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="RevisedQueueSize" TypeName="opc:UInt32" />\r\n    <opc:Field Name="FilterResult" TypeName="ua:ExtensionObject" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CreateMonitoredItemsRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="SubscriptionId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="TimestampsToReturn" TypeName="tns:TimestampsToReturn" />\r\n    <opc:Field Name="NoOfItemsToCreate" TypeName="opc:Int32" />\r\n    <opc:Field Name="ItemsToCreate" TypeName="tns:MonitoredItemCreateRequest" LengthField="NoOfItemsToCreate" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CreateMonitoredItemsResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="tns:MonitoredItemCreateResult" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="MonitoredItemModifyRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="MonitoredItemId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RequestedParameters" TypeName="tns:MonitoringParameters" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="MonitoredItemModifyResult" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="RevisedSamplingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="RevisedQueueSize" TypeName="opc:UInt32" />\r\n    <opc:Field Name="FilterResult" TypeName="ua:ExtensionObject" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ModifyMonitoredItemsRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="SubscriptionId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="TimestampsToReturn" TypeName="tns:TimestampsToReturn" />\r\n    <opc:Field Name="NoOfItemsToModify" TypeName="opc:Int32" />\r\n    <opc:Field Name="ItemsToModify" TypeName="tns:MonitoredItemModifyRequest" LengthField="NoOfItemsToModify" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ModifyMonitoredItemsResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="tns:MonitoredItemModifyResult" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SetMonitoringModeRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="SubscriptionId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="MonitoringMode" TypeName="tns:MonitoringMode" />\r\n    <opc:Field Name="NoOfMonitoredItemIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="MonitoredItemIds" TypeName="opc:UInt32" LengthField="NoOfMonitoredItemIds" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SetMonitoringModeResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="ua:StatusCode" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SetTriggeringRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="SubscriptionId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="TriggeringItemId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="NoOfLinksToAdd" TypeName="opc:Int32" />\r\n    <opc:Field Name="LinksToAdd" TypeName="opc:UInt32" LengthField="NoOfLinksToAdd" />\r\n    <opc:Field Name="NoOfLinksToRemove" TypeName="opc:Int32" />\r\n    <opc:Field Name="LinksToRemove" TypeName="opc:UInt32" LengthField="NoOfLinksToRemove" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SetTriggeringResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfAddResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="AddResults" TypeName="ua:StatusCode" LengthField="NoOfAddResults" />\r\n    <opc:Field Name="NoOfAddDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="AddDiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfAddDiagnosticInfos" />\r\n    <opc:Field Name="NoOfRemoveResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="RemoveResults" TypeName="ua:StatusCode" LengthField="NoOfRemoveResults" />\r\n    <opc:Field Name="NoOfRemoveDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="RemoveDiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfRemoveDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteMonitoredItemsRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="SubscriptionId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="NoOfMonitoredItemIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="MonitoredItemIds" TypeName="opc:UInt32" LengthField="NoOfMonitoredItemIds" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteMonitoredItemsResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="ua:StatusCode" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CreateSubscriptionRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="RequestedPublishingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="RequestedLifetimeCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RequestedMaxKeepAliveCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="MaxNotificationsPerPublish" TypeName="opc:UInt32" />\r\n    <opc:Field Name="PublishingEnabled" TypeName="opc:Boolean" />\r\n    <opc:Field Name="Priority" TypeName="opc:Byte" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="CreateSubscriptionResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="SubscriptionId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RevisedPublishingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="RevisedLifetimeCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RevisedMaxKeepAliveCount" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ModifySubscriptionRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="SubscriptionId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RequestedPublishingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="RequestedLifetimeCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RequestedMaxKeepAliveCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="MaxNotificationsPerPublish" TypeName="opc:UInt32" />\r\n    <opc:Field Name="Priority" TypeName="opc:Byte" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ModifySubscriptionResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="RevisedPublishingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="RevisedLifetimeCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RevisedMaxKeepAliveCount" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SetPublishingModeRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="PublishingEnabled" TypeName="opc:Boolean" />\r\n    <opc:Field Name="NoOfSubscriptionIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="SubscriptionIds" TypeName="opc:UInt32" LengthField="NoOfSubscriptionIds" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SetPublishingModeResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="ua:StatusCode" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="NotificationMessage" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="SequenceNumber" TypeName="opc:UInt32" />\r\n    <opc:Field Name="PublishTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="NoOfNotificationData" TypeName="opc:Int32" />\r\n    <opc:Field Name="NotificationData" TypeName="ua:ExtensionObject" LengthField="NoOfNotificationData" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="NotificationData" BaseType="ua:ExtensionObject">\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DataChangeNotification" BaseType="tns:NotificationData">\r\n    <opc:Field Name="NoOfMonitoredItems" TypeName="opc:Int32" />\r\n    <opc:Field Name="MonitoredItems" TypeName="tns:MonitoredItemNotification" LengthField="NoOfMonitoredItems" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="MonitoredItemNotification" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ClientHandle" TypeName="opc:UInt32" />\r\n    <opc:Field Name="Value" TypeName="ua:DataValue" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="EventNotificationList" BaseType="tns:NotificationData">\r\n    <opc:Field Name="NoOfEvents" TypeName="opc:Int32" />\r\n    <opc:Field Name="Events" TypeName="tns:EventFieldList" LengthField="NoOfEvents" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="EventFieldList" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ClientHandle" TypeName="opc:UInt32" />\r\n    <opc:Field Name="NoOfEventFields" TypeName="opc:Int32" />\r\n    <opc:Field Name="EventFields" TypeName="ua:Variant" LengthField="NoOfEventFields" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="HistoryEventFieldList" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NoOfEventFields" TypeName="opc:Int32" />\r\n    <opc:Field Name="EventFields" TypeName="ua:Variant" LengthField="NoOfEventFields" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="StatusChangeNotification" BaseType="tns:NotificationData">\r\n    <opc:Field Name="Status" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="DiagnosticInfo" TypeName="ua:DiagnosticInfo" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SubscriptionAcknowledgement" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="SubscriptionId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="SequenceNumber" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="PublishRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfSubscriptionAcknowledgements" TypeName="opc:Int32" />\r\n    <opc:Field Name="SubscriptionAcknowledgements" TypeName="tns:SubscriptionAcknowledgement" LengthField="NoOfSubscriptionAcknowledgements" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="PublishResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="SubscriptionId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="NoOfAvailableSequenceNumbers" TypeName="opc:Int32" />\r\n    <opc:Field Name="AvailableSequenceNumbers" TypeName="opc:UInt32" LengthField="NoOfAvailableSequenceNumbers" />\r\n    <opc:Field Name="MoreNotifications" TypeName="opc:Boolean" />\r\n    <opc:Field Name="NotificationMessage" TypeName="tns:NotificationMessage" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="ua:StatusCode" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="RepublishRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="SubscriptionId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RetransmitSequenceNumber" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="RepublishResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NotificationMessage" TypeName="tns:NotificationMessage" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="TransferResult" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="NoOfAvailableSequenceNumbers" TypeName="opc:Int32" />\r\n    <opc:Field Name="AvailableSequenceNumbers" TypeName="opc:UInt32" LengthField="NoOfAvailableSequenceNumbers" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="TransferSubscriptionsRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfSubscriptionIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="SubscriptionIds" TypeName="opc:UInt32" LengthField="NoOfSubscriptionIds" />\r\n    <opc:Field Name="SendInitialValues" TypeName="opc:Boolean" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="TransferSubscriptionsResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="tns:TransferResult" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteSubscriptionsRequest" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="RequestHeader" TypeName="tns:RequestHeader" />\r\n    <opc:Field Name="NoOfSubscriptionIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="SubscriptionIds" TypeName="opc:UInt32" LengthField="NoOfSubscriptionIds" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DeleteSubscriptionsResponse" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ResponseHeader" TypeName="tns:ResponseHeader" />\r\n    <opc:Field Name="NoOfResults" TypeName="opc:Int32" />\r\n    <opc:Field Name="Results" TypeName="ua:StatusCode" LengthField="NoOfResults" />\r\n    <opc:Field Name="NoOfDiagnosticInfos" TypeName="opc:Int32" />\r\n    <opc:Field Name="DiagnosticInfos" TypeName="ua:DiagnosticInfo" LengthField="NoOfDiagnosticInfos" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="BuildInfo" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ProductUri" TypeName="opc:String" />\r\n    <opc:Field Name="ManufacturerName" TypeName="opc:String" />\r\n    <opc:Field Name="ProductName" TypeName="opc:String" />\r\n    <opc:Field Name="SoftwareVersion" TypeName="opc:String" />\r\n    <opc:Field Name="BuildNumber" TypeName="opc:String" />\r\n    <opc:Field Name="BuildDate" TypeName="opc:DateTime" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="RedundancySupport" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="None" Value="0" />\r\n    <opc:EnumeratedValue Name="Cold" Value="1" />\r\n    <opc:EnumeratedValue Name="Warm" Value="2" />\r\n    <opc:EnumeratedValue Name="Hot" Value="3" />\r\n    <opc:EnumeratedValue Name="Transparent" Value="4" />\r\n    <opc:EnumeratedValue Name="HotAndMirrored" Value="5" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:EnumeratedType Name="ServerState" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Running" Value="0" />\r\n    <opc:EnumeratedValue Name="Failed" Value="1" />\r\n    <opc:EnumeratedValue Name="NoConfiguration" Value="2" />\r\n    <opc:EnumeratedValue Name="Suspended" Value="3" />\r\n    <opc:EnumeratedValue Name="Shutdown" Value="4" />\r\n    <opc:EnumeratedValue Name="Test" Value="5" />\r\n    <opc:EnumeratedValue Name="CommunicationFault" Value="6" />\r\n    <opc:EnumeratedValue Name="Unknown" Value="7" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="RedundantServerDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ServerId" TypeName="opc:String" />\r\n    <opc:Field Name="ServiceLevel" TypeName="opc:Byte" />\r\n    <opc:Field Name="ServerState" TypeName="tns:ServerState" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="EndpointUrlListDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NoOfEndpointUrlList" TypeName="opc:Int32" />\r\n    <opc:Field Name="EndpointUrlList" TypeName="opc:String" LengthField="NoOfEndpointUrlList" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="NetworkGroupDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ServerUri" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfNetworkPaths" TypeName="opc:Int32" />\r\n    <opc:Field Name="NetworkPaths" TypeName="tns:EndpointUrlListDataType" LengthField="NoOfNetworkPaths" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SamplingIntervalDiagnosticsDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="SamplingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="MonitoredItemCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="MaxMonitoredItemCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="DisabledMonitoredItemCount" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ServerDiagnosticsSummaryDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="ServerViewCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="CurrentSessionCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="CumulatedSessionCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="SecurityRejectedSessionCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RejectedSessionCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="SessionTimeoutCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="SessionAbortCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="CurrentSubscriptionCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="CumulatedSubscriptionCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="PublishingIntervalCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="SecurityRejectedRequestsCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RejectedRequestsCount" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ServerStatusDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="StartTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="CurrentTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="State" TypeName="tns:ServerState" />\r\n    <opc:Field Name="BuildInfo" TypeName="tns:BuildInfo" />\r\n    <opc:Field Name="SecondsTillShutdown" TypeName="opc:UInt32" />\r\n    <opc:Field Name="ShutdownReason" TypeName="ua:LocalizedText" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SessionDiagnosticsDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="SessionId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="SessionName" TypeName="opc:String" />\r\n    <opc:Field Name="ClientDescription" TypeName="tns:ApplicationDescription" />\r\n    <opc:Field Name="ServerUri" TypeName="opc:String" />\r\n    <opc:Field Name="EndpointUrl" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfLocaleIds" TypeName="opc:Int32" />\r\n    <opc:Field Name="LocaleIds" TypeName="opc:String" LengthField="NoOfLocaleIds" />\r\n    <opc:Field Name="ActualSessionTimeout" TypeName="opc:Double" />\r\n    <opc:Field Name="MaxResponseMessageSize" TypeName="opc:UInt32" />\r\n    <opc:Field Name="ClientConnectionTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="ClientLastContactTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="CurrentSubscriptionsCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="CurrentMonitoredItemsCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="CurrentPublishRequestsInQueue" TypeName="opc:UInt32" />\r\n    <opc:Field Name="TotalRequestCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="UnauthorizedRequestCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="ReadCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="HistoryReadCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="WriteCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="HistoryUpdateCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="CallCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="CreateMonitoredItemsCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="ModifyMonitoredItemsCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="SetMonitoringModeCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="SetTriggeringCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="DeleteMonitoredItemsCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="CreateSubscriptionCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="ModifySubscriptionCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="SetPublishingModeCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="PublishCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="RepublishCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="TransferSubscriptionsCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="DeleteSubscriptionsCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="AddNodesCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="AddReferencesCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="DeleteNodesCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="DeleteReferencesCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="BrowseCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="BrowseNextCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="TranslateBrowsePathsToNodeIdsCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="QueryFirstCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="QueryNextCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="RegisterNodesCount" TypeName="tns:ServiceCounterDataType" />\r\n    <opc:Field Name="UnregisterNodesCount" TypeName="tns:ServiceCounterDataType" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SessionSecurityDiagnosticsDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="SessionId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="ClientUserIdOfSession" TypeName="opc:String" />\r\n    <opc:Field Name="NoOfClientUserIdHistory" TypeName="opc:Int32" />\r\n    <opc:Field Name="ClientUserIdHistory" TypeName="opc:String" LengthField="NoOfClientUserIdHistory" />\r\n    <opc:Field Name="AuthenticationMechanism" TypeName="opc:String" />\r\n    <opc:Field Name="Encoding" TypeName="opc:String" />\r\n    <opc:Field Name="TransportProtocol" TypeName="opc:String" />\r\n    <opc:Field Name="SecurityMode" TypeName="tns:MessageSecurityMode" />\r\n    <opc:Field Name="SecurityPolicyUri" TypeName="opc:String" />\r\n    <opc:Field Name="ClientCertificate" TypeName="opc:ByteString" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ServiceCounterDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="TotalCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="ErrorCount" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="StatusResult" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="StatusCode" TypeName="ua:StatusCode" />\r\n    <opc:Field Name="DiagnosticInfo" TypeName="ua:DiagnosticInfo" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SubscriptionDiagnosticsDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="SessionId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="SubscriptionId" TypeName="opc:UInt32" />\r\n    <opc:Field Name="Priority" TypeName="opc:Byte" />\r\n    <opc:Field Name="PublishingInterval" TypeName="opc:Double" />\r\n    <opc:Field Name="MaxKeepAliveCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="MaxLifetimeCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="MaxNotificationsPerPublish" TypeName="opc:UInt32" />\r\n    <opc:Field Name="PublishingEnabled" TypeName="opc:Boolean" />\r\n    <opc:Field Name="ModifyCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="EnableCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="DisableCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RepublishRequestCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RepublishMessageRequestCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="RepublishMessageCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="TransferRequestCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="TransferredToAltClientCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="TransferredToSameClientCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="PublishRequestCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="DataChangeNotificationsCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="EventNotificationsCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="NotificationsCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="LatePublishRequestCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="CurrentKeepAliveCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="CurrentLifetimeCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="UnacknowledgedMessageCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="DiscardedMessageCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="MonitoredItemCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="DisabledMonitoredItemCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="MonitoringQueueOverflowCount" TypeName="opc:UInt32" />\r\n    <opc:Field Name="NextSequenceNumber" TypeName="opc:UInt32" />\r\n    <opc:Field Name="EventQueueOverFlowCount" TypeName="opc:UInt32" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="ModelChangeStructureVerbMask" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="NodeAdded" Value="1" />\r\n    <opc:EnumeratedValue Name="NodeDeleted" Value="2" />\r\n    <opc:EnumeratedValue Name="ReferenceAdded" Value="4" />\r\n    <opc:EnumeratedValue Name="ReferenceDeleted" Value="8" />\r\n    <opc:EnumeratedValue Name="DataTypeChanged" Value="16" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="ModelChangeStructureDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Affected" TypeName="ua:NodeId" />\r\n    <opc:Field Name="AffectedType" TypeName="ua:NodeId" />\r\n    <opc:Field Name="Verb" TypeName="opc:Byte" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="SemanticChangeStructureDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Affected" TypeName="ua:NodeId" />\r\n    <opc:Field Name="AffectedType" TypeName="ua:NodeId" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="Range" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Low" TypeName="opc:Double" />\r\n    <opc:Field Name="High" TypeName="opc:Double" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="EUInformation" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="NamespaceUri" TypeName="opc:String" />\r\n    <opc:Field Name="UnitId" TypeName="opc:Int32" />\r\n    <opc:Field Name="DisplayName" TypeName="ua:LocalizedText" />\r\n    <opc:Field Name="Description" TypeName="ua:LocalizedText" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="AxisScaleEnumeration" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="Linear" Value="0" />\r\n    <opc:EnumeratedValue Name="Log" Value="1" />\r\n    <opc:EnumeratedValue Name="Ln" Value="2" />\r\n  </opc:EnumeratedType>\r\n\r\n  <opc:StructuredType Name="ComplexNumberType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Real" TypeName="opc:Float" />\r\n    <opc:Field Name="Imaginary" TypeName="opc:Float" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="DoubleComplexNumberType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Real" TypeName="opc:Double" />\r\n    <opc:Field Name="Imaginary" TypeName="opc:Double" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="AxisInformation" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="EngineeringUnits" TypeName="tns:EUInformation" />\r\n    <opc:Field Name="EURange" TypeName="tns:Range" />\r\n    <opc:Field Name="Title" TypeName="ua:LocalizedText" />\r\n    <opc:Field Name="AxisScaleType" TypeName="tns:AxisScaleEnumeration" />\r\n    <opc:Field Name="NoOfAxisSteps" TypeName="opc:Int32" />\r\n    <opc:Field Name="AxisSteps" TypeName="opc:Double" LengthField="NoOfAxisSteps" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="XVType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="X" TypeName="opc:Double" />\r\n    <opc:Field Name="Value" TypeName="opc:Float" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ProgramDiagnosticDataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="CreateSessionId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="CreateClientName" TypeName="opc:String" />\r\n    <opc:Field Name="InvocationCreationTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="LastTransitionTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="LastMethodCall" TypeName="opc:String" />\r\n    <opc:Field Name="LastMethodSessionId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="NoOfLastMethodInputArguments" TypeName="opc:Int32" />\r\n    <opc:Field Name="LastMethodInputArguments" TypeName="tns:Argument" LengthField="NoOfLastMethodInputArguments" />\r\n    <opc:Field Name="NoOfLastMethodOutputArguments" TypeName="opc:Int32" />\r\n    <opc:Field Name="LastMethodOutputArguments" TypeName="tns:Argument" LengthField="NoOfLastMethodOutputArguments" />\r\n    <opc:Field Name="LastMethodCallTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="LastMethodReturnStatus" TypeName="tns:StatusResult" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="ProgramDiagnostic2DataType" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="CreateSessionId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="CreateClientName" TypeName="opc:String" />\r\n    <opc:Field Name="InvocationCreationTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="LastTransitionTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="LastMethodCall" TypeName="opc:String" />\r\n    <opc:Field Name="LastMethodSessionId" TypeName="ua:NodeId" />\r\n    <opc:Field Name="NoOfLastMethodInputArguments" TypeName="opc:Int32" />\r\n    <opc:Field Name="LastMethodInputArguments" TypeName="tns:Argument" LengthField="NoOfLastMethodInputArguments" />\r\n    <opc:Field Name="NoOfLastMethodOutputArguments" TypeName="opc:Int32" />\r\n    <opc:Field Name="LastMethodOutputArguments" TypeName="tns:Argument" LengthField="NoOfLastMethodOutputArguments" />\r\n    <opc:Field Name="NoOfLastMethodInputValues" TypeName="opc:Int32" />\r\n    <opc:Field Name="LastMethodInputValues" TypeName="ua:Variant" LengthField="NoOfLastMethodInputValues" />\r\n    <opc:Field Name="NoOfLastMethodOutputValues" TypeName="opc:Int32" />\r\n    <opc:Field Name="LastMethodOutputValues" TypeName="ua:Variant" LengthField="NoOfLastMethodOutputValues" />\r\n    <opc:Field Name="LastMethodCallTime" TypeName="opc:DateTime" />\r\n    <opc:Field Name="LastMethodReturnStatus" TypeName="tns:StatusResult" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:StructuredType Name="Annotation" BaseType="ua:ExtensionObject">\r\n    <opc:Field Name="Message" TypeName="opc:String" />\r\n    <opc:Field Name="UserName" TypeName="opc:String" />\r\n    <opc:Field Name="AnnotationTime" TypeName="opc:DateTime" />\r\n  </opc:StructuredType>\r\n\r\n  <opc:EnumeratedType Name="ExceptionDeviationFormat" LengthInBits="32">\r\n    <opc:EnumeratedValue Name="AbsoluteValue" Value="0" />\r\n    <opc:EnumeratedValue Name="PercentOfValue" Value="1" />\r\n    <opc:EnumeratedValue Name="PercentOfRange" Value="2" />\r\n    <opc:EnumeratedValue Name="PercentOfEURange" Value="3" />\r\n    <opc:EnumeratedValue Name="Unknown" Value="4" />\r\n  </opc:EnumeratedType>\r\n\r\n</opc:TypeDictionary>', ua.VariantType.ByteString)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7619")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15037")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14873")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15734")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15738")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12681")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15741")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14855")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15599")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15602")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15501")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15521")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14849")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14852")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14876")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15766")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15769")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14324")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15772")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15775")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15778")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15781")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15784")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15787")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21156")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15793")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15854")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15857")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15860")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21159")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21162")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21165")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15866")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15869")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15872")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15877")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15880")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15883")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15886")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21002")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15889")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21168")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15895")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15898")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15919")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15922")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15925")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15931")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17469")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21171")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15524")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15940")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15943")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15946")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16131")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18178")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18181")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18184")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18187")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7650")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7656")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14870")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12767")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12770")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8914")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7665")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12213")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7662")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7668")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7782")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12902")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12905")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7698")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7671")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7674")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7677")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7680")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7683")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7728")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7731")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7734")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7737")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12718")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12721")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7686")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7929")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7932")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7935")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7938")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7941")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7944")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7947")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8004")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8067")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8073")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8076")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8172")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7692")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8208")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11959")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11962")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8211")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8214")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8217")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8220")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8223")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8226")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7659")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8229")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8232")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8235")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8238")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8241")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12183")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12186")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12091")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12094")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8247")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15398")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8244")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=93")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7617")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=72")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7619")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A URI that uniquely identifies the dictionary.")
    attrs.DisplayName = ua.LocalizedText("NamespaceUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('http://opcfoundation.org/UA/', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7619")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=7619")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15037")
    node.BrowseName = ua.QualifiedName.from_string("Deprecated")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Indicates that all of the definitions for the dictionary are available through a DataTypeDefinition Attribute.")
    attrs.DisplayName = ua.LocalizedText("Deprecated")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.Value = ua.Variant(True, ua.VariantType.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15037")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15037")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14873")
    node.BrowseName = ua.QualifiedName.from_string("KeyValuePair")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("KeyValuePair")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('KeyValuePair', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14873")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14873")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15734")
    node.BrowseName = ua.QualifiedName.from_string("EndpointType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('EndpointType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15734")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15734")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15738")
    node.BrowseName = ua.QualifiedName.from_string("IdentityMappingRuleType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("IdentityMappingRuleType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('IdentityMappingRuleType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15738")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15738")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12681")
    node.BrowseName = ua.QualifiedName.from_string("TrustListDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TrustListDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('TrustListDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12681")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12681")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15741")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeSchemaHeader")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataTypeSchemaHeader")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DataTypeSchemaHeader', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15741")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15741")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14855")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataTypeDescription")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DataTypeDescription', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14855")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14855")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15599")
    node.BrowseName = ua.QualifiedName.from_string("StructureDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StructureDescription")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('StructureDescription', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15599")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15599")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15602")
    node.BrowseName = ua.QualifiedName.from_string("EnumDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumDescription")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('EnumDescription', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15602")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15602")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15501")
    node.BrowseName = ua.QualifiedName.from_string("SimpleTypeDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SimpleTypeDescription")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('SimpleTypeDescription', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15501")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15501")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15521")
    node.BrowseName = ua.QualifiedName.from_string("UABinaryFileDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UABinaryFileDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('UABinaryFileDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15521")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15521")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14849")
    node.BrowseName = ua.QualifiedName.from_string("DataSetMetaDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetMetaDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DataSetMetaDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14849")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14849")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14852")
    node.BrowseName = ua.QualifiedName.from_string("FieldMetaData")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("FieldMetaData")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('FieldMetaData', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14852")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14852")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14876")
    node.BrowseName = ua.QualifiedName.from_string("ConfigurationVersionDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ConfigurationVersionDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ConfigurationVersionDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14876")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14876")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15766")
    node.BrowseName = ua.QualifiedName.from_string("PublishedDataSetDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishedDataSetDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('PublishedDataSetDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15766")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15766")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15769")
    node.BrowseName = ua.QualifiedName.from_string("PublishedDataSetSourceDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishedDataSetSourceDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('PublishedDataSetSourceDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15769")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15769")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14324")
    node.BrowseName = ua.QualifiedName.from_string("PublishedVariableDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishedVariableDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('PublishedVariableDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14324")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14324")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15772")
    node.BrowseName = ua.QualifiedName.from_string("PublishedDataItemsDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishedDataItemsDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('PublishedDataItemsDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15772")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15772")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15775")
    node.BrowseName = ua.QualifiedName.from_string("PublishedEventsDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishedEventsDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('PublishedEventsDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15775")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15775")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15778")
    node.BrowseName = ua.QualifiedName.from_string("DataSetWriterDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetWriterDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DataSetWriterDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15778")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15778")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15781")
    node.BrowseName = ua.QualifiedName.from_string("DataSetWriterTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetWriterTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DataSetWriterTransportDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15781")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15781")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15784")
    node.BrowseName = ua.QualifiedName.from_string("DataSetWriterMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetWriterMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DataSetWriterMessageDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15784")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15787")
    node.BrowseName = ua.QualifiedName.from_string("PubSubGroupDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PubSubGroupDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('PubSubGroupDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15787")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15787")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21156")
    node.BrowseName = ua.QualifiedName.from_string("WriterGroupDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("WriterGroupDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('WriterGroupDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21156")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21156")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15793")
    node.BrowseName = ua.QualifiedName.from_string("WriterGroupTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("WriterGroupTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('WriterGroupTransportDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15793")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15793")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15854")
    node.BrowseName = ua.QualifiedName.from_string("WriterGroupMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("WriterGroupMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('WriterGroupMessageDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15854")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15854")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15857")
    node.BrowseName = ua.QualifiedName.from_string("PubSubConnectionDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PubSubConnectionDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('PubSubConnectionDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15857")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15857")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15860")
    node.BrowseName = ua.QualifiedName.from_string("ConnectionTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ConnectionTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ConnectionTransportDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21159")
    node.BrowseName = ua.QualifiedName.from_string("NetworkAddressDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NetworkAddressDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('NetworkAddressDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21159")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21159")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21162")
    node.BrowseName = ua.QualifiedName.from_string("NetworkAddressUrlDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NetworkAddressUrlDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('NetworkAddressUrlDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21162")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21165")
    node.BrowseName = ua.QualifiedName.from_string("ReaderGroupDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ReaderGroupDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ReaderGroupDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21165")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15866")
    node.BrowseName = ua.QualifiedName.from_string("ReaderGroupTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ReaderGroupTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ReaderGroupTransportDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15866")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15866")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15869")
    node.BrowseName = ua.QualifiedName.from_string("ReaderGroupMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ReaderGroupMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ReaderGroupMessageDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15869")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15869")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15872")
    node.BrowseName = ua.QualifiedName.from_string("DataSetReaderDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetReaderDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DataSetReaderDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15872")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15872")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15877")
    node.BrowseName = ua.QualifiedName.from_string("DataSetReaderTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetReaderTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DataSetReaderTransportDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15877")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15877")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15880")
    node.BrowseName = ua.QualifiedName.from_string("DataSetReaderMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetReaderMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DataSetReaderMessageDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15880")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15880")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15883")
    node.BrowseName = ua.QualifiedName.from_string("SubscribedDataSetDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SubscribedDataSetDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('SubscribedDataSetDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15883")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15883")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15886")
    node.BrowseName = ua.QualifiedName.from_string("TargetVariablesDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TargetVariablesDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('TargetVariablesDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15886")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15886")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21002")
    node.BrowseName = ua.QualifiedName.from_string("FieldTargetDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("FieldTargetDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('FieldTargetDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21002")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21002")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15889")
    node.BrowseName = ua.QualifiedName.from_string("SubscribedDataSetMirrorDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SubscribedDataSetMirrorDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('SubscribedDataSetMirrorDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15889")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15889")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21168")
    node.BrowseName = ua.QualifiedName.from_string("PubSubConfigurationDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PubSubConfigurationDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('PubSubConfigurationDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21168")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21168")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15895")
    node.BrowseName = ua.QualifiedName.from_string("UadpWriterGroupMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UadpWriterGroupMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('UadpWriterGroupMessageDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15895")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15895")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15898")
    node.BrowseName = ua.QualifiedName.from_string("UadpDataSetWriterMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UadpDataSetWriterMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('UadpDataSetWriterMessageDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15898")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15898")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15919")
    node.BrowseName = ua.QualifiedName.from_string("UadpDataSetReaderMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UadpDataSetReaderMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('UadpDataSetReaderMessageDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15919")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15919")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15922")
    node.BrowseName = ua.QualifiedName.from_string("JsonWriterGroupMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("JsonWriterGroupMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('JsonWriterGroupMessageDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15922")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15922")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15925")
    node.BrowseName = ua.QualifiedName.from_string("JsonDataSetWriterMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("JsonDataSetWriterMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('JsonDataSetWriterMessageDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15925")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15925")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15931")
    node.BrowseName = ua.QualifiedName.from_string("JsonDataSetReaderMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("JsonDataSetReaderMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('JsonDataSetReaderMessageDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15931")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15931")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17469")
    node.BrowseName = ua.QualifiedName.from_string("DatagramConnectionTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DatagramConnectionTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DatagramConnectionTransportDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=17469")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=17469")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21171")
    node.BrowseName = ua.QualifiedName.from_string("DatagramWriterGroupTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DatagramWriterGroupTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DatagramWriterGroupTransportDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21171")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21171")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15524")
    node.BrowseName = ua.QualifiedName.from_string("BrokerConnectionTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrokerConnectionTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('BrokerConnectionTransportDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15524")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15524")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15940")
    node.BrowseName = ua.QualifiedName.from_string("BrokerWriterGroupTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrokerWriterGroupTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('BrokerWriterGroupTransportDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15940")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15940")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15943")
    node.BrowseName = ua.QualifiedName.from_string("BrokerDataSetWriterTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrokerDataSetWriterTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('BrokerDataSetWriterTransportDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15943")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15943")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15946")
    node.BrowseName = ua.QualifiedName.from_string("BrokerDataSetReaderTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrokerDataSetReaderTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('BrokerDataSetReaderTransportDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15946")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15946")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16131")
    node.BrowseName = ua.QualifiedName.from_string("RolePermissionType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RolePermissionType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('RolePermissionType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16131")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16131")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=18178")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeDefinition")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataTypeDefinition")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DataTypeDefinition', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=18178")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=18178")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=18181")
    node.BrowseName = ua.QualifiedName.from_string("StructureField")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StructureField")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('StructureField', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=18181")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=18181")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=18184")
    node.BrowseName = ua.QualifiedName.from_string("StructureDefinition")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StructureDefinition")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('StructureDefinition', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=18184")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=18184")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=18187")
    node.BrowseName = ua.QualifiedName.from_string("EnumDefinition")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumDefinition")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('EnumDefinition', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=18187")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=18187")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7650")
    node.BrowseName = ua.QualifiedName.from_string("Argument")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Argument")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('Argument', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7650")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7650")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7656")
    node.BrowseName = ua.QualifiedName.from_string("EnumValueType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumValueType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('EnumValueType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7656")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14870")
    node.BrowseName = ua.QualifiedName.from_string("EnumField")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumField")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('EnumField', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14870")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14870")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12767")
    node.BrowseName = ua.QualifiedName.from_string("OptionSet")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OptionSet")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('OptionSet', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12767")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12767")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12770")
    node.BrowseName = ua.QualifiedName.from_string("Union")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Union")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('Union', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12770")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12770")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8914")
    node.BrowseName = ua.QualifiedName.from_string("TimeZoneDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TimeZoneDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('TimeZoneDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8914")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8914")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7665")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplicationDescription")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ApplicationDescription', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7665")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7665")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12213")
    node.BrowseName = ua.QualifiedName.from_string("ServerOnNetwork")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerOnNetwork")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ServerOnNetwork', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12213")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12213")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7662")
    node.BrowseName = ua.QualifiedName.from_string("UserTokenPolicy")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UserTokenPolicy")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('UserTokenPolicy', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7662")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7662")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7668")
    node.BrowseName = ua.QualifiedName.from_string("EndpointDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointDescription")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('EndpointDescription', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7668")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7782")
    node.BrowseName = ua.QualifiedName.from_string("RegisteredServer")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RegisteredServer")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('RegisteredServer', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7782")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7782")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12902")
    node.BrowseName = ua.QualifiedName.from_string("DiscoveryConfiguration")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DiscoveryConfiguration")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DiscoveryConfiguration', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12902")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12902")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12905")
    node.BrowseName = ua.QualifiedName.from_string("MdnsDiscoveryConfiguration")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MdnsDiscoveryConfiguration")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('MdnsDiscoveryConfiguration', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12905")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12905")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7698")
    node.BrowseName = ua.QualifiedName.from_string("SignedSoftwareCertificate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SignedSoftwareCertificate")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('SignedSoftwareCertificate', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7698")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7698")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7671")
    node.BrowseName = ua.QualifiedName.from_string("UserIdentityToken")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UserIdentityToken")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('UserIdentityToken', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7671")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7671")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7674")
    node.BrowseName = ua.QualifiedName.from_string("AnonymousIdentityToken")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AnonymousIdentityToken")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('AnonymousIdentityToken', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7674")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7674")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7677")
    node.BrowseName = ua.QualifiedName.from_string("UserNameIdentityToken")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UserNameIdentityToken")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('UserNameIdentityToken', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7677")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7677")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7680")
    node.BrowseName = ua.QualifiedName.from_string("X509IdentityToken")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("X509IdentityToken")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('X509IdentityToken', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7680")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7683")
    node.BrowseName = ua.QualifiedName.from_string("IssuedIdentityToken")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("IssuedIdentityToken")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('IssuedIdentityToken', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7683")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7683")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7728")
    node.BrowseName = ua.QualifiedName.from_string("AddNodesItem")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AddNodesItem")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('AddNodesItem', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7728")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7728")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7731")
    node.BrowseName = ua.QualifiedName.from_string("AddReferencesItem")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AddReferencesItem")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('AddReferencesItem', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7731")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7731")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7734")
    node.BrowseName = ua.QualifiedName.from_string("DeleteNodesItem")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteNodesItem")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DeleteNodesItem', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7734")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7734")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7737")
    node.BrowseName = ua.QualifiedName.from_string("DeleteReferencesItem")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteReferencesItem")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DeleteReferencesItem', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7737")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7737")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12718")
    node.BrowseName = ua.QualifiedName.from_string("RelativePathElement")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RelativePathElement")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('RelativePathElement', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12718")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12718")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12721")
    node.BrowseName = ua.QualifiedName.from_string("RelativePath")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RelativePath")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('RelativePath', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12721")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12721")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7686")
    node.BrowseName = ua.QualifiedName.from_string("EndpointConfiguration")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointConfiguration")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('EndpointConfiguration', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7686")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7686")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7929")
    node.BrowseName = ua.QualifiedName.from_string("ContentFilterElement")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ContentFilterElement")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ContentFilterElement', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7929")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7929")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7932")
    node.BrowseName = ua.QualifiedName.from_string("ContentFilter")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ContentFilter")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ContentFilter', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7932")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7932")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7935")
    node.BrowseName = ua.QualifiedName.from_string("FilterOperand")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("FilterOperand")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('FilterOperand', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7935")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7935")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7938")
    node.BrowseName = ua.QualifiedName.from_string("ElementOperand")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ElementOperand")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ElementOperand', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7938")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7938")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7941")
    node.BrowseName = ua.QualifiedName.from_string("LiteralOperand")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("LiteralOperand")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('LiteralOperand', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7941")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7941")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7944")
    node.BrowseName = ua.QualifiedName.from_string("AttributeOperand")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AttributeOperand")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('AttributeOperand', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7944")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7944")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7947")
    node.BrowseName = ua.QualifiedName.from_string("SimpleAttributeOperand")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SimpleAttributeOperand")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('SimpleAttributeOperand', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7947")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7947")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8004")
    node.BrowseName = ua.QualifiedName.from_string("HistoryEvent")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryEvent")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('HistoryEvent', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8004")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8067")
    node.BrowseName = ua.QualifiedName.from_string("MonitoringFilter")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MonitoringFilter")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('MonitoringFilter', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8067")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8067")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8073")
    node.BrowseName = ua.QualifiedName.from_string("EventFilter")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EventFilter")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('EventFilter', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8073")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8073")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8076")
    node.BrowseName = ua.QualifiedName.from_string("AggregateConfiguration")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AggregateConfiguration")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('AggregateConfiguration', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8076")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8076")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8172")
    node.BrowseName = ua.QualifiedName.from_string("HistoryEventFieldList")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryEventFieldList")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('HistoryEventFieldList', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7692")
    node.BrowseName = ua.QualifiedName.from_string("BuildInfo")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BuildInfo")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('BuildInfo', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7692")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8208")
    node.BrowseName = ua.QualifiedName.from_string("RedundantServerDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RedundantServerDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('RedundantServerDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8208")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8208")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11959")
    node.BrowseName = ua.QualifiedName.from_string("EndpointUrlListDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointUrlListDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('EndpointUrlListDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11959")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11959")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11962")
    node.BrowseName = ua.QualifiedName.from_string("NetworkGroupDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NetworkGroupDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('NetworkGroupDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11962")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11962")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8211")
    node.BrowseName = ua.QualifiedName.from_string("SamplingIntervalDiagnosticsDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SamplingIntervalDiagnosticsDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('SamplingIntervalDiagnosticsDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8211")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8211")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8214")
    node.BrowseName = ua.QualifiedName.from_string("ServerDiagnosticsSummaryDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerDiagnosticsSummaryDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ServerDiagnosticsSummaryDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8214")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8214")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8217")
    node.BrowseName = ua.QualifiedName.from_string("ServerStatusDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerStatusDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ServerStatusDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8217")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8217")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8220")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnosticsDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionDiagnosticsDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('SessionDiagnosticsDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8220")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8220")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8223")
    node.BrowseName = ua.QualifiedName.from_string("SessionSecurityDiagnosticsDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnosticsDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('SessionSecurityDiagnosticsDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8223")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8223")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8226")
    node.BrowseName = ua.QualifiedName.from_string("ServiceCounterDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServiceCounterDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ServiceCounterDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8226")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8226")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7659")
    node.BrowseName = ua.QualifiedName.from_string("StatusResult")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StatusResult")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('StatusResult', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7659")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=7659")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8229")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionDiagnosticsDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnosticsDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('SubscriptionDiagnosticsDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8229")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8229")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8232")
    node.BrowseName = ua.QualifiedName.from_string("ModelChangeStructureDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ModelChangeStructureDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ModelChangeStructureDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8232")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8232")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8235")
    node.BrowseName = ua.QualifiedName.from_string("SemanticChangeStructureDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SemanticChangeStructureDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('SemanticChangeStructureDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8235")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8235")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8238")
    node.BrowseName = ua.QualifiedName.from_string("Range")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Range")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('Range', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8238")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8238")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8241")
    node.BrowseName = ua.QualifiedName.from_string("EUInformation")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EUInformation")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('EUInformation', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8241")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8241")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12183")
    node.BrowseName = ua.QualifiedName.from_string("ComplexNumberType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ComplexNumberType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ComplexNumberType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12186")
    node.BrowseName = ua.QualifiedName.from_string("DoubleComplexNumberType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DoubleComplexNumberType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('DoubleComplexNumberType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12186")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12186")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12091")
    node.BrowseName = ua.QualifiedName.from_string("AxisInformation")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AxisInformation")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('AxisInformation', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12091")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12091")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12094")
    node.BrowseName = ua.QualifiedName.from_string("XVType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("XVType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('XVType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12094")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12094")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8247")
    node.BrowseName = ua.QualifiedName.from_string("ProgramDiagnosticDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ProgramDiagnosticDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ProgramDiagnosticDataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8247")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8247")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15398")
    node.BrowseName = ua.QualifiedName.from_string("ProgramDiagnostic2DataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ProgramDiagnostic2DataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('ProgramDiagnostic2DataType', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15398")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15398")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8244")
    node.BrowseName = ua.QualifiedName.from_string("Annotation")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=7617")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Annotation")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('Annotation', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8244")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7617")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14802")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=14533")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=14802")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14533")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=14802")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14829")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14802")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15949")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15528")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15949")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15528")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=15949")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16024")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15949")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15728")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15634")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15728")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15634")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=15728")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15730")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15728")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=339")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=338")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=339")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=338")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=339")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8327")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=339")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=854")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=853")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=854")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=853")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=854")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8843")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=854")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11949")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=11943")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=11949")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11943")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=11949")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11951")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11949")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11950")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=11944")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=11950")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11944")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=11950")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11954")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11950")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=857")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=856")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=857")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=856")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=857")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8846")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=857")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=860")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=859")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=859")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8849")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=860")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=863")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=862")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=863")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=862")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=863")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8852")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=863")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=866")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=865")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=866")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=865")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=866")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8855")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=866")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=869")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=868")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=869")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=868")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=869")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8858")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=869")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=872")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=871")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=872")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=871")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=872")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8861")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=872")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=300")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=299")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=300")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=299")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=300")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8294")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=300")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=875")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=874")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=875")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=874")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=875")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8864")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=875")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=878")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=877")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=878")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=877")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=878")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8867")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=878")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=898")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=897")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=898")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=897")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=898")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8870")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=898")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8252")
    node.BrowseName = ua.QualifiedName.from_string("Opc.Ua")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=92")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=72")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Opc.Ua")
    attrs.DataType = ua.NodeId(ua.ObjectIds.ByteString)
    attrs.Value = ua.Variant(b'<xs:schema\r\n  xmlns:xs="http://www.w3.org/2001/XMLSchema"\r\n  xmlns:ua="http://opcfoundation.org/UA/2008/02/Types.xsd"\r\n  xmlns:tns="http://opcfoundation.org/UA/2008/02/Types.xsd"\r\n  targetNamespace="http://opcfoundation.org/UA/2008/02/Types.xsd"\r\n  elementFormDefault="qualified"\r\n>\r\n  <xs:element name="Boolean" nillable="true" type="xs:boolean" />\r\n\r\n  <xs:complexType name="ListOfBoolean">\r\n    <xs:sequence>\r\n      <xs:element name="Boolean" type="xs:boolean" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfBoolean" type="tns:ListOfBoolean" nillable="true"></xs:element>\r\n\r\n  <xs:element name="SByte" nillable="true" type="xs:byte" />\r\n\r\n  <xs:complexType name="ListOfSByte">\r\n    <xs:sequence>\r\n      <xs:element name="SByte" type="xs:byte" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfSByte" type="tns:ListOfSByte" nillable="true"></xs:element>\r\n\r\n  <xs:element name="Byte" nillable="true" type="xs:unsignedByte" />\r\n\r\n  <xs:complexType name="ListOfByte">\r\n    <xs:sequence>\r\n      <xs:element name="Byte" type="xs:unsignedByte" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfByte" type="tns:ListOfByte" nillable="true"></xs:element>\r\n\r\n  <xs:element name="Int16" nillable="true" type="xs:short" />\r\n\r\n  <xs:complexType name="ListOfInt16">\r\n    <xs:sequence>\r\n      <xs:element name="Int16" type="xs:short" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfInt16" type="tns:ListOfInt16" nillable="true"></xs:element>\r\n\r\n  <xs:element name="UInt16" nillable="true" type="xs:unsignedShort" />\r\n\r\n  <xs:complexType name="ListOfUInt16">\r\n    <xs:sequence>\r\n      <xs:element name="UInt16" type="xs:unsignedShort" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfUInt16" type="tns:ListOfUInt16" nillable="true"></xs:element>\r\n\r\n  <xs:element name="Int32" nillable="true" type="xs:int" />\r\n\r\n  <xs:complexType name="ListOfInt32">\r\n    <xs:sequence>\r\n      <xs:element name="Int32" type="xs:int" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfInt32" type="tns:ListOfInt32" nillable="true"></xs:element>\r\n\r\n  <xs:element name="UInt32" nillable="true" type="xs:unsignedInt" />\r\n\r\n  <xs:complexType name="ListOfUInt32">\r\n    <xs:sequence>\r\n      <xs:element name="UInt32" type="xs:unsignedInt" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfUInt32" type="tns:ListOfUInt32" nillable="true"></xs:element>\r\n\r\n  <xs:element name="Int64" nillable="true" type="xs:long" />\r\n\r\n  <xs:complexType name="ListOfInt64">\r\n    <xs:sequence>\r\n      <xs:element name="Int64" type="xs:long" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfInt64" type="tns:ListOfInt64" nillable="true"></xs:element>\r\n\r\n  <xs:element name="UInt64" nillable="true" type="xs:unsignedLong" />\r\n\r\n  <xs:complexType name="ListOfUInt64">\r\n    <xs:sequence>\r\n      <xs:element name="UInt64" type="xs:unsignedLong" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfUInt64" type="tns:ListOfUInt64" nillable="true"></xs:element>\r\n\r\n  <xs:element name="Float" nillable="true" type="xs:float" />\r\n\r\n  <xs:complexType name="ListOfFloat">\r\n    <xs:sequence>\r\n      <xs:element name="Float" type="xs:float" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfFloat" type="tns:ListOfFloat" nillable="true"></xs:element>\r\n\r\n  <xs:element name="Double" nillable="true" type="xs:double" />\r\n\r\n  <xs:complexType name="ListOfDouble">\r\n    <xs:sequence>\r\n      <xs:element name="Double" type="xs:double" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDouble" type="tns:ListOfDouble" nillable="true"></xs:element>\r\n\r\n  <xs:element name="String" nillable="true" type="xs:string" />\r\n\r\n  <xs:complexType name="ListOfString">\r\n    <xs:sequence>\r\n      <xs:element name="String" type="xs:string" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfString" type="tns:ListOfString" nillable="true"></xs:element>\r\n\r\n  <xs:element name="DateTime" nillable="true" type="xs:dateTime" />\r\n\r\n  <xs:complexType name="ListOfDateTime">\r\n    <xs:sequence>\r\n      <xs:element name="DateTime" type="xs:dateTime" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDateTime" type="tns:ListOfDateTime" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="Guid">\r\n    <xs:annotation>\r\n      <xs:appinfo>\r\n        <IsValueType xmlns="http://schemas.microsoft.com/2003/10/Serialization/">true</IsValueType>\r\n      </xs:appinfo>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="String" type="xs:string" minOccurs="0" maxOccurs="1" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="Guid" type="tns:Guid" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ListOfGuid">\r\n    <xs:sequence>\r\n      <xs:element name="Guid" type="tns:Guid" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfGuid" type="tns:ListOfGuid" nillable="true"></xs:element>\r\n\r\n  <xs:element name="ByteString" nillable="true" type="xs:base64Binary" />\r\n\r\n  <xs:complexType name="ListOfByteString">\r\n    <xs:sequence>\r\n      <xs:element name="ByteString" type="xs:base64Binary" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfByteString" type="tns:ListOfByteString" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ListOfXmlElement">\r\n    <xs:sequence>\r\n      <xs:element name="XmlElement" minOccurs="0" maxOccurs="unbounded" nillable="true">\r\n        <xs:complexType>\r\n          <xs:sequence>\r\n            <xs:any minOccurs="0" processContents="lax"/>\r\n          </xs:sequence>\r\n        </xs:complexType>\r\n      </xs:element>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfXmlElement" type="tns:ListOfXmlElement" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="NodeId">\r\n    <xs:sequence>\r\n      <xs:element name="Identifier" type="xs:string" minOccurs="0" maxOccurs="1" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="NodeId" type="tns:NodeId" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ListOfNodeId">\r\n    <xs:sequence>\r\n      <xs:element name="NodeId" type="tns:NodeId" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfNodeId" type="tns:ListOfNodeId" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ExpandedNodeId">\r\n    <xs:sequence>\r\n      <xs:element name="Identifier" type="xs:string" minOccurs="0" maxOccurs="1" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ExpandedNodeId" type="tns:ExpandedNodeId" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ListOfExpandedNodeId">\r\n    <xs:sequence>\r\n      <xs:element name="ExpandedNodeId" type="tns:ExpandedNodeId" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfExpandedNodeId" type="tns:ListOfExpandedNodeId" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="StatusCode">\r\n    <xs:annotation>\r\n      <xs:appinfo>\r\n        <IsValueType xmlns="http://schemas.microsoft.com/2003/10/Serialization/">true</IsValueType>\r\n      </xs:appinfo>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="Code" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="StatusCode" type="tns:StatusCode" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ListOfStatusCode">\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="tns:StatusCode" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfStatusCode" type="tns:ListOfStatusCode" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DiagnosticInfo">\r\n    <xs:sequence>\r\n      <xs:element name="SymbolicId" type="xs:int" minOccurs="0" />\r\n      <xs:element name="NamespaceUri" type="xs:int" minOccurs="0" />\r\n      <xs:element name="Locale" type="xs:int" minOccurs="0" />\r\n      <xs:element name="LocalizedText" type="xs:int" minOccurs="0" />\r\n      <xs:element name="AdditionalInfo" type="xs:string" minOccurs="0" />\r\n      <xs:element name="InnerStatusCode" type="tns:StatusCode" minOccurs="0" />\r\n      <xs:element name="InnerDiagnosticInfo" type="tns:DiagnosticInfo" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DiagnosticInfo" type="tns:DiagnosticInfo" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ListOfDiagnosticInfo">\r\n    <xs:sequence>\r\n      <xs:element name="DiagnosticInfo" type="tns:DiagnosticInfo" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDiagnosticInfo" type="tns:ListOfDiagnosticInfo" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="LocalizedText">\r\n    <xs:sequence>\r\n      <xs:element name="Locale" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="Text" type="xs:string" minOccurs="0"  nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="LocalizedText" type="tns:LocalizedText" nillable="true" />\r\n\r\n  <xs:complexType name="ListOfLocalizedText">\r\n    <xs:sequence>\r\n      <xs:element name="LocalizedText" type="tns:LocalizedText" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfLocalizedText" type="tns:ListOfLocalizedText" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="QualifiedName">\r\n    <xs:sequence>\r\n      <xs:element name="NamespaceIndex" type="xs:unsignedShort" minOccurs="0" />\r\n      <xs:element name="Name" type="xs:string" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="QualifiedName" type="tns:QualifiedName" nillable="true" />\r\n\r\n  <xs:complexType name="ListOfQualifiedName">\r\n    <xs:sequence>\r\n      <xs:element name="QualifiedName" type="tns:QualifiedName" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfQualifiedName" type="tns:ListOfQualifiedName" nillable="true"></xs:element>\r\n\r\n  <!--\r\n    Some environments require a WSDL/XSD which explicitly defines all possible types.\r\n    The UA WSDL/XSD can be modified to support these environments by replacing the\r\n    definitions of the ExtensionObjectBody and VariantValue complex types with the\r\n    definitions in the comments shown here. Developers would then define subtypes\r\n    of the ExtensionObjectBody type which explicitly declare a choice between all of the\r\n    complex types used by the system. The ExampleExtensionObjectBody subtype is provides\r\n    a template based on a few common UA-defined complex types.\r\n    -->\r\n\r\n  <!--\r\n    <xs:complexType name="ExtensionObjectBody" />\r\n\r\n    <xs:complexType name="ExampleExtensionObjectBody">\r\n      <xs:complexContent>\r\n        <xs:extension base="tns:ExtensionObjectBody">\r\n          <xs:choice>\r\n            <xs:element name="Argument" type="tns:Argument" minOccurs="0" nillable="true" />\r\n            <xs:element name="UserIdentityToken" type="tns:UserIdentityToken" minOccurs="0" nillable="true" />\r\n            <xs:element name="UserNameIdentityToken" type="tns:UserNameIdentityToken" minOccurs="0" nillable="true" />\r\n          </xs:choice>\r\n        </xs:extension>\r\n      </xs:complexContent>\r\n    </xs:complexType>\r\n\r\n    <xs:complexType name="ExtensionObject">\r\n      <xs:sequence>\r\n        <xs:element name="TypeId" type="tns:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n        <xs:element name="Body" minOccurs="0" type="tns:ExtensionObjectBody" nillable="true" />\r\n      </xs:sequence>\r\n    </xs:complexType>\r\n    <xs:element name="ExtensionObject" type="tns:ExtensionObject" nillable="true" />\r\n    -->\r\n\r\n  <xs:complexType name="ExtensionObject">\r\n    <xs:sequence>\r\n      <xs:element name="TypeId" type="tns:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="Body" minOccurs="0" nillable="true">\r\n        <xs:complexType>\r\n          <xs:sequence>\r\n            <xs:any minOccurs="0" processContents="lax"/>\r\n          </xs:sequence>\r\n        </xs:complexType>\r\n      </xs:element>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ExtensionObject" type="tns:ExtensionObject" nillable="true" />\r\n\r\n  <xs:complexType name="ListOfExtensionObject">\r\n    <xs:sequence>\r\n      <xs:element name="ExtensionObject" type="tns:ExtensionObject" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfExtensionObject" type="tns:ListOfExtensionObject" nillable="true"></xs:element>\r\n\r\n  <!--\r\n    Some WSDL/XML compilers have issues with the xs:choice construct. For that reason\r\n    the default declaration of a Variant uses xs:any construct. The schema acutually\r\n    defined by the specification is provided by the Matrix and VariantValue complex types\r\n    shown in comments below. Application developers can replace the VariantValue declaration\r\n    with the specific declaration if they have a development environment that can handle\r\n    the xs:choice construct in a reasonable way.\r\n    -->\r\n\r\n  <!--\r\n    <xs:complexType name="Matrix">\r\n      <xs:sequence>\r\n        <xs:element name="Dimensions" type="tns:ListOfUInt32" minOccurs="0" nillable="true" />\r\n        <xs:element name="Value" minOccurs="0" nillable="true">\r\n          <xs:complexType mixed="false">\r\n            <xs:choice maxOccurs="unbounded">\r\n              <xs:element name="Boolean" type="xs:boolean" minOccurs="0" />\r\n              <xs:element name="SByte" type="xs:byte" minOccurs="0" />\r\n              <xs:element name="Byte" type="xs:unsignedByte" minOccurs="0" />\r\n              <xs:element name="Int16" type="xs:short" minOccurs="0" />\r\n              <xs:element name="UInt16" type="xs:unsignedShort" minOccurs="0" />\r\n              <xs:element name="Int32" type="xs:int" minOccurs="0" />\r\n              <xs:element name="UInt32" type="xs:unsignedInt" minOccurs="0" />\r\n              <xs:element name="Int64" type="xs:long" minOccurs="0" />\r\n              <xs:element name="UInt64" type="xs:unsignedLong" minOccurs="0" />\r\n              <xs:element name="Float" type="xs:float" minOccurs="0" />\r\n              <xs:element name="Double" type="xs:double" minOccurs="0" />\r\n              <xs:element name="String" type="xs:string" minOccurs="0" />\r\n              <xs:element name="DateTime" type="xs:dateTime" minOccurs="0" />\r\n              <xs:element name="Guid" type="tns:Guid" minOccurs="0" />\r\n              <xs:element name="ByteString" type="xs:base64Binary" minOccurs="0" />\r\n              <xs:element name="XmlElement" minOccurs="0" nillable="true">\r\n                <xs:complexType>\r\n                  <xs:sequence>\r\n                    <xs:any minOccurs="0" processContents="lax" />\r\n                  </xs:sequence>\r\n                </xs:complexType>\r\n              </xs:element>\r\n              <xs:element name="StatusCode" type="tns:StatusCode" minOccurs="0" />\r\n              <xs:element name="NodeId" type="tns:NodeId" minOccurs="0" />\r\n              <xs:element name="ExpandedNodeId" type="tns:ExpandedNodeId" minOccurs="0" />\r\n              <xs:element name="QualifiedName" type="tns:QualifiedName" minOccurs="0" />\r\n              <xs:element name="LocalizedText" type="tns:LocalizedText" minOccurs="0" />\r\n              <xs:element name="ExtensionObject" type="tns:ExtensionObject" minOccurs="0" />\r\n              <xs:element name="Variant" type="tns:Variant" minOccurs="0" />\r\n            </xs:choice>\r\n          </xs:complexType>\r\n        </xs:element>\r\n      </xs:sequence>\r\n    </xs:complexType>\r\n    <xs:element name="Matrix" type="tns:Matrix" nillable="true" />\r\n\r\n    <xs:complexType name="VariantValue">\r\n      <xs:choice>\r\n        <xs:element name="Boolean" type="xs:boolean" minOccurs="0" />\r\n        <xs:element name="SByte" type="xs:byte" minOccurs="0" />\r\n        <xs:element name="Byte" type="xs:unsignedByte" minOccurs="0" />\r\n        <xs:element name="Int16" type="xs:short" minOccurs="0" />\r\n        <xs:element name="UInt16" type="xs:unsignedShort" minOccurs="0" />\r\n        <xs:element name="Int32" type="xs:int" minOccurs="0" />\r\n        <xs:element name="UInt32" type="xs:unsignedInt" minOccurs="0" />\r\n        <xs:element name="Int64" type="xs:long" minOccurs="0" />\r\n        <xs:element name="UInt64" type="xs:unsignedLong" minOccurs="0" />\r\n        <xs:element name="Float" type="xs:float" minOccurs="0" />\r\n        <xs:element name="Double" type="xs:double" minOccurs="0" />\r\n        <xs:element name="String" type="xs:string" minOccurs="0" />\r\n        <xs:element name="DateTime" type="xs:dateTime" minOccurs="0" />\r\n        <xs:element name="Guid" type="tns:Guid" minOccurs="0" />\r\n        <xs:element name="ByteString" type="xs:base64Binary" minOccurs="0" />\r\n        <xs:element name="XmlElement" minOccurs="0" nillable="true">\r\n          <xs:complexType>\r\n            <xs:sequence>\r\n              <xs:any minOccurs="0" processContents="lax" />\r\n            </xs:sequence>\r\n          </xs:complexType>\r\n        </xs:element>\r\n        <xs:element name="StatusCode" type="tns:StatusCode" minOccurs="0" />\r\n        <xs:element name="NodeId" type="tns:NodeId" minOccurs="0" />\r\n        <xs:element name="ExpandedNodeId" type="tns:ExpandedNodeId" minOccurs="0" />\r\n        <xs:element name="QualifiedName" type="tns:QualifiedName" minOccurs="0" />\r\n        <xs:element name="LocalizedText" type="tns:LocalizedText" minOccurs="0" />\r\n        <xs:element name="ExtensionObject" type="tns:ExtensionObject" minOccurs="0" />\r\n        <xs:element name="ListOfBoolean" type="tns:ListOfBoolean" minOccurs="0" />\r\n        <xs:element name="ListOfSByte" type="tns:ListOfSByte" minOccurs="0" />\r\n        <xs:element name="ListOfByte" type="tns:ListOfByte" minOccurs="0" />\r\n        <xs:element name="ListOfInt16" type="tns:ListOfInt16" minOccurs="0" />\r\n        <xs:element name="ListOfUInt16" type="tns:ListOfUInt16" minOccurs="0" />\r\n        <xs:element name="ListOfInt32" type="tns:ListOfInt32" minOccurs="0" />\r\n        <xs:element name="ListOfUInt32" type="tns:ListOfUInt32" minOccurs="0" />\r\n        <xs:element name="ListOfInt64" type="tns:ListOfInt64" minOccurs="0" />\r\n        <xs:element name="ListOfUInt64" type="tns:ListOfUInt64" minOccurs="0" />\r\n        <xs:element name="ListOfFloat" type="tns:ListOfFloat" minOccurs="0" />\r\n        <xs:element name="ListOfDouble" type="tns:ListOfDouble" minOccurs="0" />\r\n        <xs:element name="ListOfString" type="tns:ListOfString" minOccurs="0" />\r\n        <xs:element name="ListOfDateTime" type="tns:ListOfDateTime" minOccurs="0" />\r\n        <xs:element name="ListOfGuid" type="tns:ListOfGuid" minOccurs="0" />\r\n        <xs:element name="ListOfByteString" type="tns:ListOfByteString" minOccurs="0" />\r\n        <xs:element name="ListOfXmlElement" type="tns:ListOfXmlElement" minOccurs="0" />\r\n        <xs:element name="ListOfStatusCode" type="tns:ListOfStatusCode" minOccurs="0" />\r\n        <xs:element name="ListOfNodeId" type="tns:ListOfNodeId" minOccurs="0" />\r\n        <xs:element name="ListOfExpandedNodeId" type="tns:ListOfExpandedNodeId" minOccurs="0" />\r\n        <xs:element name="ListOfQualifiedName" type="tns:ListOfQualifiedName" minOccurs="0" />\r\n        <xs:element name="ListOfLocalizedText" type="tns:ListOfLocalizedText" minOccurs="0" />\r\n        <xs:element name="ListOfExtensionObject" type="tns:ListOfExtensionObject" minOccurs="0" />\r\n        <xs:element name="ListOfVariant" type="tns:ListOfVariant" minOccurs="0" />\r\n        <xs:element name="Matrix" type="tns:Matrix" minOccurs="0" />\r\n      </xs:choice>\r\n    </xs:complexType>\r\n\r\n    <xs:complexType name="Variant">\r\n      <xs:sequence>\r\n        <xs:element name="Value" type="tns:VariantValue" minOccurs="0" nillable="true" />\r\n      </xs:sequence>\r\n    </xs:complexType>\r\n    <xs:element name="Variant" type="tns:Variant" nillable="true" />\r\n    -->\r\n\r\n  <xs:complexType name="Variant">\r\n    <xs:annotation>\r\n      <xs:appinfo>\r\n        <IsValueType xmlns="http://schemas.microsoft.com/2003/10/Serialization/">true</IsValueType>\r\n      </xs:appinfo>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="Value" minOccurs="0" nillable="true">\r\n        <xs:complexType>\r\n          <xs:sequence>\r\n            <xs:any minOccurs="0" processContents="lax" />\r\n          </xs:sequence>\r\n        </xs:complexType>\r\n      </xs:element>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="Variant" type="tns:Variant" nillable="true" />\r\n\r\n  <xs:complexType name="ListOfVariant">\r\n    <xs:sequence>\r\n      <xs:element name="Variant" type="tns:Variant" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfVariant" type="tns:ListOfVariant" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DataValue">\r\n    <xs:sequence>\r\n      <xs:element name="Value" type="tns:Variant" minOccurs="0" />\r\n      <xs:element name="StatusCode" type="tns:StatusCode" minOccurs="0" />\r\n      <xs:element name="SourceTimestamp" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="SourcePicoseconds" type="xs:unsignedShort" minOccurs="0" />\r\n      <xs:element name="ServerTimestamp" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="ServerPicoseconds" type="xs:unsignedShort" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DataValue" type="tns:DataValue" nillable="true"/>\r\n\r\n  <xs:complexType name="ListOfDataValue">\r\n    <xs:sequence>\r\n      <xs:element name="DataValue" type="tns:DataValue" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataValue" type="tns:ListOfDataValue" nillable="true"></xs:element>\r\n\r\n  <xs:element name="InvokeServiceRequest" type="xs:base64Binary" nillable="true" />\r\n  <xs:element name="InvokeServiceResponse" type="xs:base64Binary" nillable="true" />\r\n\r\n  <xs:element name="ImageBMP" type="xs:base64Binary" />\r\n\r\n  <xs:element name="ImageGIF" type="xs:base64Binary" />\r\n\r\n  <xs:element name="ImageJPG" type="xs:base64Binary" />\r\n\r\n  <xs:element name="ImagePNG" type="xs:base64Binary" />\r\n\r\n  <xs:element name="AudioDataType" type="xs:base64Binary" />\r\n\r\n  <xs:element name="BitFieldMaskDataType" type="xs:unsignedLong" />\r\n\r\n  <xs:complexType name="KeyValuePair">\r\n    <xs:sequence>\r\n      <xs:element name="Key" type="ua:QualifiedName" minOccurs="0" nillable="true" />\r\n      <xs:element name="Value" type="ua:Variant" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="KeyValuePair" type="tns:KeyValuePair" />\r\n\r\n  <xs:complexType name="ListOfKeyValuePair">\r\n    <xs:sequence>\r\n      <xs:element name="KeyValuePair" type="tns:KeyValuePair" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfKeyValuePair" type="tns:ListOfKeyValuePair" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="EndpointType">\r\n    <xs:sequence>\r\n      <xs:element name="EndpointUrl" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="SecurityMode" type="tns:MessageSecurityMode" minOccurs="0" />\r\n      <xs:element name="SecurityPolicyUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="TransportProfileUri" type="xs:string" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="EndpointType" type="tns:EndpointType" />\r\n\r\n  <xs:complexType name="ListOfEndpointType">\r\n    <xs:sequence>\r\n      <xs:element name="EndpointType" type="tns:EndpointType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfEndpointType" type="tns:ListOfEndpointType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="OpenFileMode">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Read_1" />\r\n      <xs:enumeration value="Write_2" />\r\n      <xs:enumeration value="EraseExisting_4" />\r\n      <xs:enumeration value="Append_8" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="OpenFileMode" type="tns:OpenFileMode" />\r\n\r\n  <xs:complexType name="ListOfOpenFileMode">\r\n    <xs:sequence>\r\n      <xs:element name="OpenFileMode" type="tns:OpenFileMode" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfOpenFileMode" type="tns:ListOfOpenFileMode" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="IdentityCriteriaType">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="UserName_1" />\r\n      <xs:enumeration value="Thumbprint_2" />\r\n      <xs:enumeration value="Role_3" />\r\n      <xs:enumeration value="GroupId_4" />\r\n      <xs:enumeration value="Anonymous_5" />\r\n      <xs:enumeration value="AuthenticatedUser_6" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="IdentityCriteriaType" type="tns:IdentityCriteriaType" />\r\n\r\n  <xs:complexType name="ListOfIdentityCriteriaType">\r\n    <xs:sequence>\r\n      <xs:element name="IdentityCriteriaType" type="tns:IdentityCriteriaType" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfIdentityCriteriaType" type="tns:ListOfIdentityCriteriaType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="IdentityMappingRuleType">\r\n    <xs:sequence>\r\n      <xs:element name="CriteriaType" type="tns:IdentityCriteriaType" minOccurs="0" />\r\n      <xs:element name="Criteria" type="xs:string" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="IdentityMappingRuleType" type="tns:IdentityMappingRuleType" />\r\n\r\n  <xs:complexType name="ListOfIdentityMappingRuleType">\r\n    <xs:sequence>\r\n      <xs:element name="IdentityMappingRuleType" type="tns:IdentityMappingRuleType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfIdentityMappingRuleType" type="tns:ListOfIdentityMappingRuleType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="TrustListMasks">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="None_0" />\r\n      <xs:enumeration value="TrustedCertificates_1" />\r\n      <xs:enumeration value="TrustedCrls_2" />\r\n      <xs:enumeration value="IssuerCertificates_4" />\r\n      <xs:enumeration value="IssuerCrls_8" />\r\n      <xs:enumeration value="All_15" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="TrustListMasks" type="tns:TrustListMasks" />\r\n\r\n  <xs:complexType name="TrustListDataType">\r\n    <xs:sequence>\r\n      <xs:element name="SpecifiedLists" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="TrustedCertificates" type="ua:ListOfByteString" minOccurs="0" nillable="true" />\r\n      <xs:element name="TrustedCrls" type="ua:ListOfByteString" minOccurs="0" nillable="true" />\r\n      <xs:element name="IssuerCertificates" type="ua:ListOfByteString" minOccurs="0" nillable="true" />\r\n      <xs:element name="IssuerCrls" type="ua:ListOfByteString" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="TrustListDataType" type="tns:TrustListDataType" />\r\n\r\n  <xs:complexType name="ListOfTrustListDataType">\r\n    <xs:sequence>\r\n      <xs:element name="TrustListDataType" type="tns:TrustListDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfTrustListDataType" type="tns:ListOfTrustListDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DecimalDataType">\r\n    <xs:sequence>\r\n      <xs:element name="Scale" type="xs:short" minOccurs="0" />\r\n      <xs:element name="Value" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DecimalDataType" type="tns:DecimalDataType" />\r\n\r\n  <xs:complexType name="DataTypeSchemaHeader">\r\n    <xs:sequence>\r\n      <xs:element name="Namespaces" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="StructureDataTypes" type="tns:ListOfStructureDescription" minOccurs="0" nillable="true" />\r\n      <xs:element name="EnumDataTypes" type="tns:ListOfEnumDescription" minOccurs="0" nillable="true" />\r\n      <xs:element name="SimpleDataTypes" type="tns:ListOfSimpleTypeDescription" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DataTypeSchemaHeader" type="tns:DataTypeSchemaHeader" />\r\n\r\n  <xs:complexType name="ListOfDataTypeSchemaHeader">\r\n    <xs:sequence>\r\n      <xs:element name="DataTypeSchemaHeader" type="tns:DataTypeSchemaHeader" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataTypeSchemaHeader" type="tns:ListOfDataTypeSchemaHeader" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DataTypeDescription">\r\n    <xs:sequence>\r\n      <xs:element name="DataTypeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="Name" type="ua:QualifiedName" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DataTypeDescription" type="tns:DataTypeDescription" />\r\n\r\n  <xs:complexType name="ListOfDataTypeDescription">\r\n    <xs:sequence>\r\n      <xs:element name="DataTypeDescription" type="tns:DataTypeDescription" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataTypeDescription" type="tns:ListOfDataTypeDescription" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="StructureDescription">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataTypeDescription">\r\n        <xs:sequence>\r\n          <xs:element name="StructureDefinition" type="tns:StructureDefinition" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="StructureDescription" type="tns:StructureDescription" />\r\n\r\n  <xs:complexType name="ListOfStructureDescription">\r\n    <xs:sequence>\r\n      <xs:element name="StructureDescription" type="tns:StructureDescription" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfStructureDescription" type="tns:ListOfStructureDescription" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="EnumDescription">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataTypeDescription">\r\n        <xs:sequence>\r\n          <xs:element name="EnumDefinition" type="tns:EnumDefinition" minOccurs="0" nillable="true" />\r\n          <xs:element name="BuiltInType" type="xs:unsignedByte" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="EnumDescription" type="tns:EnumDescription" />\r\n\r\n  <xs:complexType name="ListOfEnumDescription">\r\n    <xs:sequence>\r\n      <xs:element name="EnumDescription" type="tns:EnumDescription" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfEnumDescription" type="tns:ListOfEnumDescription" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="SimpleTypeDescription">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataTypeDescription">\r\n        <xs:sequence>\r\n          <xs:element name="BaseDataType" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n          <xs:element name="BuiltInType" type="xs:unsignedByte" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="SimpleTypeDescription" type="tns:SimpleTypeDescription" />\r\n\r\n  <xs:complexType name="ListOfSimpleTypeDescription">\r\n    <xs:sequence>\r\n      <xs:element name="SimpleTypeDescription" type="tns:SimpleTypeDescription" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfSimpleTypeDescription" type="tns:ListOfSimpleTypeDescription" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="UABinaryFileDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataTypeSchemaHeader">\r\n        <xs:sequence>\r\n          <xs:element name="SchemaLocation" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="FileHeader" type="tns:ListOfKeyValuePair" minOccurs="0" nillable="true" />\r\n          <xs:element name="Body" type="ua:Variant" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="UABinaryFileDataType" type="tns:UABinaryFileDataType" />\r\n\r\n  <xs:complexType name="ListOfUABinaryFileDataType">\r\n    <xs:sequence>\r\n      <xs:element name="UABinaryFileDataType" type="tns:UABinaryFileDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfUABinaryFileDataType" type="tns:ListOfUABinaryFileDataType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="PubSubState">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Disabled_0" />\r\n      <xs:enumeration value="Paused_1" />\r\n      <xs:enumeration value="Operational_2" />\r\n      <xs:enumeration value="Error_3" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="PubSubState" type="tns:PubSubState" />\r\n\r\n  <xs:complexType name="ListOfPubSubState">\r\n    <xs:sequence>\r\n      <xs:element name="PubSubState" type="tns:PubSubState" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfPubSubState" type="tns:ListOfPubSubState" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DataSetMetaDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataTypeSchemaHeader">\r\n        <xs:sequence>\r\n          <xs:element name="Name" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="Description" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n          <xs:element name="Fields" type="tns:ListOfFieldMetaData" minOccurs="0" nillable="true" />\r\n          <xs:element name="DataSetClassId" type="ua:Guid" minOccurs="0" />\r\n          <xs:element name="ConfigurationVersion" type="tns:ConfigurationVersionDataType" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="DataSetMetaDataType" type="tns:DataSetMetaDataType" />\r\n\r\n  <xs:complexType name="ListOfDataSetMetaDataType">\r\n    <xs:sequence>\r\n      <xs:element name="DataSetMetaDataType" type="tns:DataSetMetaDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataSetMetaDataType" type="tns:ListOfDataSetMetaDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="FieldMetaData">\r\n    <xs:sequence>\r\n      <xs:element name="Name" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="Description" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n      <xs:element name="FieldFlags" type="tns:DataSetFieldFlags" minOccurs="0" />\r\n      <xs:element name="BuiltInType" type="xs:unsignedByte" minOccurs="0" />\r\n      <xs:element name="DataType" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="ValueRank" type="xs:int" minOccurs="0" />\r\n      <xs:element name="ArrayDimensions" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n      <xs:element name="MaxStringLength" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="DataSetFieldId" type="ua:Guid" minOccurs="0" />\r\n      <xs:element name="Properties" type="tns:ListOfKeyValuePair" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="FieldMetaData" type="tns:FieldMetaData" />\r\n\r\n  <xs:complexType name="ListOfFieldMetaData">\r\n    <xs:sequence>\r\n      <xs:element name="FieldMetaData" type="tns:FieldMetaData" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfFieldMetaData" type="tns:ListOfFieldMetaData" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="DataSetFieldFlags">\r\n    <xs:restriction base="xs:unsignedShort">\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="DataSetFieldFlags" type="tns:DataSetFieldFlags" />\r\n\r\n  <xs:complexType name="ConfigurationVersionDataType">\r\n    <xs:sequence>\r\n      <xs:element name="MajorVersion" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="MinorVersion" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ConfigurationVersionDataType" type="tns:ConfigurationVersionDataType" />\r\n\r\n  <xs:complexType name="ListOfConfigurationVersionDataType">\r\n    <xs:sequence>\r\n      <xs:element name="ConfigurationVersionDataType" type="tns:ConfigurationVersionDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfConfigurationVersionDataType" type="tns:ListOfConfigurationVersionDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="PublishedDataSetDataType">\r\n    <xs:sequence>\r\n      <xs:element name="Name" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="DataSetFolder" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="DataSetMetaData" type="tns:DataSetMetaDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="ExtensionFields" type="tns:ListOfKeyValuePair" minOccurs="0" nillable="true" />\r\n      <xs:element name="DataSetSource" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="PublishedDataSetDataType" type="tns:PublishedDataSetDataType" />\r\n\r\n  <xs:complexType name="ListOfPublishedDataSetDataType">\r\n    <xs:sequence>\r\n      <xs:element name="PublishedDataSetDataType" type="tns:PublishedDataSetDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfPublishedDataSetDataType" type="tns:ListOfPublishedDataSetDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="PublishedDataSetSourceDataType">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="PublishedDataSetSourceDataType" type="tns:PublishedDataSetSourceDataType" />\r\n\r\n  <xs:complexType name="ListOfPublishedDataSetSourceDataType">\r\n    <xs:sequence>\r\n      <xs:element name="PublishedDataSetSourceDataType" type="tns:PublishedDataSetSourceDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfPublishedDataSetSourceDataType" type="tns:ListOfPublishedDataSetSourceDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="PublishedVariableDataType">\r\n    <xs:sequence>\r\n      <xs:element name="PublishedVariable" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="AttributeId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="SamplingIntervalHint" type="xs:double" minOccurs="0" />\r\n      <xs:element name="DeadbandType" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="DeadbandValue" type="xs:double" minOccurs="0" />\r\n      <xs:element name="IndexRange" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubstituteValue" type="ua:Variant" minOccurs="0" />\r\n      <xs:element name="MetaDataProperties" type="ua:ListOfQualifiedName" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="PublishedVariableDataType" type="tns:PublishedVariableDataType" />\r\n\r\n  <xs:complexType name="ListOfPublishedVariableDataType">\r\n    <xs:sequence>\r\n      <xs:element name="PublishedVariableDataType" type="tns:PublishedVariableDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfPublishedVariableDataType" type="tns:ListOfPublishedVariableDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="PublishedDataItemsDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:PublishedDataSetSourceDataType">\r\n        <xs:sequence>\r\n          <xs:element name="PublishedData" type="tns:ListOfPublishedVariableDataType" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="PublishedDataItemsDataType" type="tns:PublishedDataItemsDataType" />\r\n\r\n  <xs:complexType name="ListOfPublishedDataItemsDataType">\r\n    <xs:sequence>\r\n      <xs:element name="PublishedDataItemsDataType" type="tns:PublishedDataItemsDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfPublishedDataItemsDataType" type="tns:ListOfPublishedDataItemsDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="PublishedEventsDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:PublishedDataSetSourceDataType">\r\n        <xs:sequence>\r\n          <xs:element name="EventNotifier" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n          <xs:element name="SelectedFields" type="tns:ListOfSimpleAttributeOperand" minOccurs="0" nillable="true" />\r\n          <xs:element name="Filter" type="tns:ContentFilter" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="PublishedEventsDataType" type="tns:PublishedEventsDataType" />\r\n\r\n  <xs:complexType name="ListOfPublishedEventsDataType">\r\n    <xs:sequence>\r\n      <xs:element name="PublishedEventsDataType" type="tns:PublishedEventsDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfPublishedEventsDataType" type="tns:ListOfPublishedEventsDataType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="DataSetFieldContentMask">\r\n    <xs:restriction base="xs:unsignedInt">\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="DataSetFieldContentMask" type="tns:DataSetFieldContentMask" />\r\n\r\n  <xs:complexType name="ListOfDataSetFieldContentMask">\r\n    <xs:sequence>\r\n      <xs:element name="DataSetFieldContentMask" type="tns:DataSetFieldContentMask" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataSetFieldContentMask" type="tns:ListOfDataSetFieldContentMask" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DataSetWriterDataType">\r\n    <xs:sequence>\r\n      <xs:element name="Name" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="Enabled" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="DataSetWriterId" type="xs:unsignedShort" minOccurs="0" />\r\n      <xs:element name="DataSetFieldContentMask" type="tns:DataSetFieldContentMask" minOccurs="0" />\r\n      <xs:element name="KeyFrameCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="DataSetName" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="DataSetWriterProperties" type="tns:ListOfKeyValuePair" minOccurs="0" nillable="true" />\r\n      <xs:element name="TransportSettings" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n      <xs:element name="MessageSettings" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DataSetWriterDataType" type="tns:DataSetWriterDataType" />\r\n\r\n  <xs:complexType name="ListOfDataSetWriterDataType">\r\n    <xs:sequence>\r\n      <xs:element name="DataSetWriterDataType" type="tns:DataSetWriterDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataSetWriterDataType" type="tns:ListOfDataSetWriterDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DataSetWriterTransportDataType">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DataSetWriterTransportDataType" type="tns:DataSetWriterTransportDataType" />\r\n\r\n  <xs:complexType name="ListOfDataSetWriterTransportDataType">\r\n    <xs:sequence>\r\n      <xs:element name="DataSetWriterTransportDataType" type="tns:DataSetWriterTransportDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataSetWriterTransportDataType" type="tns:ListOfDataSetWriterTransportDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DataSetWriterMessageDataType">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DataSetWriterMessageDataType" type="tns:DataSetWriterMessageDataType" />\r\n\r\n  <xs:complexType name="ListOfDataSetWriterMessageDataType">\r\n    <xs:sequence>\r\n      <xs:element name="DataSetWriterMessageDataType" type="tns:DataSetWriterMessageDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataSetWriterMessageDataType" type="tns:ListOfDataSetWriterMessageDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="PubSubGroupDataType">\r\n    <xs:sequence>\r\n      <xs:element name="Name" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="Enabled" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="SecurityMode" type="tns:MessageSecurityMode" minOccurs="0" />\r\n      <xs:element name="SecurityGroupId" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="SecurityKeyServices" type="tns:ListOfEndpointDescription" minOccurs="0" nillable="true" />\r\n      <xs:element name="MaxNetworkMessageSize" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="GroupProperties" type="tns:ListOfKeyValuePair" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="PubSubGroupDataType" type="tns:PubSubGroupDataType" />\r\n\r\n  <xs:complexType name="ListOfPubSubGroupDataType">\r\n    <xs:sequence>\r\n      <xs:element name="PubSubGroupDataType" type="tns:PubSubGroupDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfPubSubGroupDataType" type="tns:ListOfPubSubGroupDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="WriterGroupDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:PubSubGroupDataType">\r\n        <xs:sequence>\r\n          <xs:element name="WriterGroupId" type="xs:unsignedShort" minOccurs="0" />\r\n          <xs:element name="PublishingInterval" type="xs:double" minOccurs="0" />\r\n          <xs:element name="KeepAliveTime" type="xs:double" minOccurs="0" />\r\n          <xs:element name="Priority" type="xs:unsignedByte" minOccurs="0" />\r\n          <xs:element name="LocaleIds" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n          <xs:element name="TransportSettings" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n          <xs:element name="MessageSettings" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n          <xs:element name="DataSetWriters" type="tns:ListOfDataSetWriterDataType" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="WriterGroupDataType" type="tns:WriterGroupDataType" />\r\n\r\n  <xs:complexType name="ListOfWriterGroupDataType">\r\n    <xs:sequence>\r\n      <xs:element name="WriterGroupDataType" type="tns:WriterGroupDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfWriterGroupDataType" type="tns:ListOfWriterGroupDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="WriterGroupTransportDataType">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="WriterGroupTransportDataType" type="tns:WriterGroupTransportDataType" />\r\n\r\n  <xs:complexType name="ListOfWriterGroupTransportDataType">\r\n    <xs:sequence>\r\n      <xs:element name="WriterGroupTransportDataType" type="tns:WriterGroupTransportDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfWriterGroupTransportDataType" type="tns:ListOfWriterGroupTransportDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="WriterGroupMessageDataType">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="WriterGroupMessageDataType" type="tns:WriterGroupMessageDataType" />\r\n\r\n  <xs:complexType name="ListOfWriterGroupMessageDataType">\r\n    <xs:sequence>\r\n      <xs:element name="WriterGroupMessageDataType" type="tns:WriterGroupMessageDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfWriterGroupMessageDataType" type="tns:ListOfWriterGroupMessageDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="PubSubConnectionDataType">\r\n    <xs:sequence>\r\n      <xs:element name="Name" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="Enabled" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="PublisherId" type="ua:Variant" minOccurs="0" />\r\n      <xs:element name="TransportProfileUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="Address" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n      <xs:element name="ConnectionProperties" type="tns:ListOfKeyValuePair" minOccurs="0" nillable="true" />\r\n      <xs:element name="TransportSettings" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n      <xs:element name="WriterGroups" type="tns:ListOfWriterGroupDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="ReaderGroups" type="tns:ListOfReaderGroupDataType" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="PubSubConnectionDataType" type="tns:PubSubConnectionDataType" />\r\n\r\n  <xs:complexType name="ListOfPubSubConnectionDataType">\r\n    <xs:sequence>\r\n      <xs:element name="PubSubConnectionDataType" type="tns:PubSubConnectionDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfPubSubConnectionDataType" type="tns:ListOfPubSubConnectionDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ConnectionTransportDataType">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ConnectionTransportDataType" type="tns:ConnectionTransportDataType" />\r\n\r\n  <xs:complexType name="ListOfConnectionTransportDataType">\r\n    <xs:sequence>\r\n      <xs:element name="ConnectionTransportDataType" type="tns:ConnectionTransportDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfConnectionTransportDataType" type="tns:ListOfConnectionTransportDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="NetworkAddressDataType">\r\n    <xs:sequence>\r\n      <xs:element name="NetworkInterface" type="xs:string" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="NetworkAddressDataType" type="tns:NetworkAddressDataType" />\r\n\r\n  <xs:complexType name="ListOfNetworkAddressDataType">\r\n    <xs:sequence>\r\n      <xs:element name="NetworkAddressDataType" type="tns:NetworkAddressDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfNetworkAddressDataType" type="tns:ListOfNetworkAddressDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="NetworkAddressUrlDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NetworkAddressDataType">\r\n        <xs:sequence>\r\n          <xs:element name="Url" type="xs:string" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="NetworkAddressUrlDataType" type="tns:NetworkAddressUrlDataType" />\r\n\r\n  <xs:complexType name="ListOfNetworkAddressUrlDataType">\r\n    <xs:sequence>\r\n      <xs:element name="NetworkAddressUrlDataType" type="tns:NetworkAddressUrlDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfNetworkAddressUrlDataType" type="tns:ListOfNetworkAddressUrlDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ReaderGroupDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:PubSubGroupDataType">\r\n        <xs:sequence>\r\n          <xs:element name="TransportSettings" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n          <xs:element name="MessageSettings" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n          <xs:element name="DataSetReaders" type="tns:ListOfDataSetReaderDataType" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ReaderGroupDataType" type="tns:ReaderGroupDataType" />\r\n\r\n  <xs:complexType name="ListOfReaderGroupDataType">\r\n    <xs:sequence>\r\n      <xs:element name="ReaderGroupDataType" type="tns:ReaderGroupDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfReaderGroupDataType" type="tns:ListOfReaderGroupDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ReaderGroupTransportDataType">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ReaderGroupTransportDataType" type="tns:ReaderGroupTransportDataType" />\r\n\r\n  <xs:complexType name="ListOfReaderGroupTransportDataType">\r\n    <xs:sequence>\r\n      <xs:element name="ReaderGroupTransportDataType" type="tns:ReaderGroupTransportDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfReaderGroupTransportDataType" type="tns:ListOfReaderGroupTransportDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ReaderGroupMessageDataType">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ReaderGroupMessageDataType" type="tns:ReaderGroupMessageDataType" />\r\n\r\n  <xs:complexType name="ListOfReaderGroupMessageDataType">\r\n    <xs:sequence>\r\n      <xs:element name="ReaderGroupMessageDataType" type="tns:ReaderGroupMessageDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfReaderGroupMessageDataType" type="tns:ListOfReaderGroupMessageDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DataSetReaderDataType">\r\n    <xs:sequence>\r\n      <xs:element name="Name" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="Enabled" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="PublisherId" type="ua:Variant" minOccurs="0" />\r\n      <xs:element name="WriterGroupId" type="xs:unsignedShort" minOccurs="0" />\r\n      <xs:element name="DataSetWriterId" type="xs:unsignedShort" minOccurs="0" />\r\n      <xs:element name="DataSetMetaData" type="tns:DataSetMetaDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="DataSetFieldContentMask" type="tns:DataSetFieldContentMask" minOccurs="0" />\r\n      <xs:element name="MessageReceiveTimeout" type="xs:double" minOccurs="0" />\r\n      <xs:element name="SecurityMode" type="tns:MessageSecurityMode" minOccurs="0" />\r\n      <xs:element name="SecurityGroupId" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="SecurityKeyServices" type="tns:ListOfEndpointDescription" minOccurs="0" nillable="true" />\r\n      <xs:element name="DataSetReaderProperties" type="tns:ListOfKeyValuePair" minOccurs="0" nillable="true" />\r\n      <xs:element name="TransportSettings" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n      <xs:element name="MessageSettings" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscribedDataSet" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DataSetReaderDataType" type="tns:DataSetReaderDataType" />\r\n\r\n  <xs:complexType name="ListOfDataSetReaderDataType">\r\n    <xs:sequence>\r\n      <xs:element name="DataSetReaderDataType" type="tns:DataSetReaderDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataSetReaderDataType" type="tns:ListOfDataSetReaderDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DataSetReaderTransportDataType">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DataSetReaderTransportDataType" type="tns:DataSetReaderTransportDataType" />\r\n\r\n  <xs:complexType name="ListOfDataSetReaderTransportDataType">\r\n    <xs:sequence>\r\n      <xs:element name="DataSetReaderTransportDataType" type="tns:DataSetReaderTransportDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataSetReaderTransportDataType" type="tns:ListOfDataSetReaderTransportDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DataSetReaderMessageDataType">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DataSetReaderMessageDataType" type="tns:DataSetReaderMessageDataType" />\r\n\r\n  <xs:complexType name="ListOfDataSetReaderMessageDataType">\r\n    <xs:sequence>\r\n      <xs:element name="DataSetReaderMessageDataType" type="tns:DataSetReaderMessageDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataSetReaderMessageDataType" type="tns:ListOfDataSetReaderMessageDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="SubscribedDataSetDataType">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SubscribedDataSetDataType" type="tns:SubscribedDataSetDataType" />\r\n\r\n  <xs:complexType name="ListOfSubscribedDataSetDataType">\r\n    <xs:sequence>\r\n      <xs:element name="SubscribedDataSetDataType" type="tns:SubscribedDataSetDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfSubscribedDataSetDataType" type="tns:ListOfSubscribedDataSetDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="TargetVariablesDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:SubscribedDataSetDataType">\r\n        <xs:sequence>\r\n          <xs:element name="TargetVariables" type="tns:ListOfFieldTargetDataType" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="TargetVariablesDataType" type="tns:TargetVariablesDataType" />\r\n\r\n  <xs:complexType name="ListOfTargetVariablesDataType">\r\n    <xs:sequence>\r\n      <xs:element name="TargetVariablesDataType" type="tns:TargetVariablesDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfTargetVariablesDataType" type="tns:ListOfTargetVariablesDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="FieldTargetDataType">\r\n    <xs:sequence>\r\n      <xs:element name="DataSetFieldId" type="ua:Guid" minOccurs="0" />\r\n      <xs:element name="ReceiverIndexRange" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="TargetNodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="AttributeId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="WriteIndexRange" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="OverrideValueHandling" type="tns:OverrideValueHandling" minOccurs="0" />\r\n      <xs:element name="OverrideValue" type="ua:Variant" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="FieldTargetDataType" type="tns:FieldTargetDataType" />\r\n\r\n  <xs:complexType name="ListOfFieldTargetDataType">\r\n    <xs:sequence>\r\n      <xs:element name="FieldTargetDataType" type="tns:FieldTargetDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfFieldTargetDataType" type="tns:ListOfFieldTargetDataType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="OverrideValueHandling">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Disabled_0" />\r\n      <xs:enumeration value="LastUseableValue_1" />\r\n      <xs:enumeration value="OverrideValue_2" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="OverrideValueHandling" type="tns:OverrideValueHandling" />\r\n\r\n  <xs:complexType name="ListOfOverrideValueHandling">\r\n    <xs:sequence>\r\n      <xs:element name="OverrideValueHandling" type="tns:OverrideValueHandling" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfOverrideValueHandling" type="tns:ListOfOverrideValueHandling" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="SubscribedDataSetMirrorDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:SubscribedDataSetDataType">\r\n        <xs:sequence>\r\n          <xs:element name="ParentNodeName" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="RolePermissions" type="tns:ListOfRolePermissionType" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="SubscribedDataSetMirrorDataType" type="tns:SubscribedDataSetMirrorDataType" />\r\n\r\n  <xs:complexType name="ListOfSubscribedDataSetMirrorDataType">\r\n    <xs:sequence>\r\n      <xs:element name="SubscribedDataSetMirrorDataType" type="tns:SubscribedDataSetMirrorDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfSubscribedDataSetMirrorDataType" type="tns:ListOfSubscribedDataSetMirrorDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="PubSubConfigurationDataType">\r\n    <xs:sequence>\r\n      <xs:element name="PublishedDataSets" type="tns:ListOfPublishedDataSetDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="Connections" type="tns:ListOfPubSubConnectionDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="Enabled" type="xs:boolean" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="PubSubConfigurationDataType" type="tns:PubSubConfigurationDataType" />\r\n\r\n  <xs:complexType name="ListOfPubSubConfigurationDataType">\r\n    <xs:sequence>\r\n      <xs:element name="PubSubConfigurationDataType" type="tns:PubSubConfigurationDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfPubSubConfigurationDataType" type="tns:ListOfPubSubConfigurationDataType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="DataSetOrderingType">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Undefined_0" />\r\n      <xs:enumeration value="AscendingWriterId_1" />\r\n      <xs:enumeration value="AscendingWriterIdSingle_2" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="DataSetOrderingType" type="tns:DataSetOrderingType" />\r\n\r\n  <xs:complexType name="ListOfDataSetOrderingType">\r\n    <xs:sequence>\r\n      <xs:element name="DataSetOrderingType" type="tns:DataSetOrderingType" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataSetOrderingType" type="tns:ListOfDataSetOrderingType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="UadpNetworkMessageContentMask">\r\n    <xs:restriction base="xs:unsignedInt">\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="UadpNetworkMessageContentMask" type="tns:UadpNetworkMessageContentMask" />\r\n\r\n  <xs:complexType name="ListOfUadpNetworkMessageContentMask">\r\n    <xs:sequence>\r\n      <xs:element name="UadpNetworkMessageContentMask" type="tns:UadpNetworkMessageContentMask" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfUadpNetworkMessageContentMask" type="tns:ListOfUadpNetworkMessageContentMask" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="UadpWriterGroupMessageDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:WriterGroupMessageDataType">\r\n        <xs:sequence>\r\n          <xs:element name="GroupVersion" type="xs:unsignedInt" minOccurs="0" />\r\n          <xs:element name="DataSetOrdering" type="tns:DataSetOrderingType" minOccurs="0" />\r\n          <xs:element name="NetworkMessageContentMask" type="tns:UadpNetworkMessageContentMask" minOccurs="0" />\r\n          <xs:element name="SamplingOffset" type="xs:double" minOccurs="0" />\r\n          <xs:element name="PublishingOffset" type="ua:ListOfDouble" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="UadpWriterGroupMessageDataType" type="tns:UadpWriterGroupMessageDataType" />\r\n\r\n  <xs:complexType name="ListOfUadpWriterGroupMessageDataType">\r\n    <xs:sequence>\r\n      <xs:element name="UadpWriterGroupMessageDataType" type="tns:UadpWriterGroupMessageDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfUadpWriterGroupMessageDataType" type="tns:ListOfUadpWriterGroupMessageDataType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="UadpDataSetMessageContentMask">\r\n    <xs:restriction base="xs:unsignedInt">\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="UadpDataSetMessageContentMask" type="tns:UadpDataSetMessageContentMask" />\r\n\r\n  <xs:complexType name="ListOfUadpDataSetMessageContentMask">\r\n    <xs:sequence>\r\n      <xs:element name="UadpDataSetMessageContentMask" type="tns:UadpDataSetMessageContentMask" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfUadpDataSetMessageContentMask" type="tns:ListOfUadpDataSetMessageContentMask" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="UadpDataSetWriterMessageDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataSetWriterMessageDataType">\r\n        <xs:sequence>\r\n          <xs:element name="DataSetMessageContentMask" type="tns:UadpDataSetMessageContentMask" minOccurs="0" />\r\n          <xs:element name="ConfiguredSize" type="xs:unsignedShort" minOccurs="0" />\r\n          <xs:element name="NetworkMessageNumber" type="xs:unsignedShort" minOccurs="0" />\r\n          <xs:element name="DataSetOffset" type="xs:unsignedShort" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="UadpDataSetWriterMessageDataType" type="tns:UadpDataSetWriterMessageDataType" />\r\n\r\n  <xs:complexType name="ListOfUadpDataSetWriterMessageDataType">\r\n    <xs:sequence>\r\n      <xs:element name="UadpDataSetWriterMessageDataType" type="tns:UadpDataSetWriterMessageDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfUadpDataSetWriterMessageDataType" type="tns:ListOfUadpDataSetWriterMessageDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="UadpDataSetReaderMessageDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataSetReaderMessageDataType">\r\n        <xs:sequence>\r\n          <xs:element name="GroupVersion" type="xs:unsignedInt" minOccurs="0" />\r\n          <xs:element name="NetworkMessageNumber" type="xs:unsignedShort" minOccurs="0" />\r\n          <xs:element name="DataSetOffset" type="xs:unsignedShort" minOccurs="0" />\r\n          <xs:element name="DataSetClassId" type="ua:Guid" minOccurs="0" />\r\n          <xs:element name="NetworkMessageContentMask" type="tns:UadpNetworkMessageContentMask" minOccurs="0" />\r\n          <xs:element name="DataSetMessageContentMask" type="tns:UadpDataSetMessageContentMask" minOccurs="0" />\r\n          <xs:element name="PublishingInterval" type="xs:double" minOccurs="0" />\r\n          <xs:element name="ReceiveOffset" type="xs:double" minOccurs="0" />\r\n          <xs:element name="ProcessingOffset" type="xs:double" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="UadpDataSetReaderMessageDataType" type="tns:UadpDataSetReaderMessageDataType" />\r\n\r\n  <xs:complexType name="ListOfUadpDataSetReaderMessageDataType">\r\n    <xs:sequence>\r\n      <xs:element name="UadpDataSetReaderMessageDataType" type="tns:UadpDataSetReaderMessageDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfUadpDataSetReaderMessageDataType" type="tns:ListOfUadpDataSetReaderMessageDataType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="JsonNetworkMessageContentMask">\r\n    <xs:restriction base="xs:unsignedInt">\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="JsonNetworkMessageContentMask" type="tns:JsonNetworkMessageContentMask" />\r\n\r\n  <xs:complexType name="ListOfJsonNetworkMessageContentMask">\r\n    <xs:sequence>\r\n      <xs:element name="JsonNetworkMessageContentMask" type="tns:JsonNetworkMessageContentMask" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfJsonNetworkMessageContentMask" type="tns:ListOfJsonNetworkMessageContentMask" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="JsonWriterGroupMessageDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:WriterGroupMessageDataType">\r\n        <xs:sequence>\r\n          <xs:element name="NetworkMessageContentMask" type="tns:JsonNetworkMessageContentMask" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="JsonWriterGroupMessageDataType" type="tns:JsonWriterGroupMessageDataType" />\r\n\r\n  <xs:complexType name="ListOfJsonWriterGroupMessageDataType">\r\n    <xs:sequence>\r\n      <xs:element name="JsonWriterGroupMessageDataType" type="tns:JsonWriterGroupMessageDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfJsonWriterGroupMessageDataType" type="tns:ListOfJsonWriterGroupMessageDataType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="JsonDataSetMessageContentMask">\r\n    <xs:restriction base="xs:unsignedInt">\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="JsonDataSetMessageContentMask" type="tns:JsonDataSetMessageContentMask" />\r\n\r\n  <xs:complexType name="ListOfJsonDataSetMessageContentMask">\r\n    <xs:sequence>\r\n      <xs:element name="JsonDataSetMessageContentMask" type="tns:JsonDataSetMessageContentMask" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfJsonDataSetMessageContentMask" type="tns:ListOfJsonDataSetMessageContentMask" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="JsonDataSetWriterMessageDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataSetWriterMessageDataType">\r\n        <xs:sequence>\r\n          <xs:element name="DataSetMessageContentMask" type="tns:JsonDataSetMessageContentMask" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="JsonDataSetWriterMessageDataType" type="tns:JsonDataSetWriterMessageDataType" />\r\n\r\n  <xs:complexType name="ListOfJsonDataSetWriterMessageDataType">\r\n    <xs:sequence>\r\n      <xs:element name="JsonDataSetWriterMessageDataType" type="tns:JsonDataSetWriterMessageDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfJsonDataSetWriterMessageDataType" type="tns:ListOfJsonDataSetWriterMessageDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="JsonDataSetReaderMessageDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataSetReaderMessageDataType">\r\n        <xs:sequence>\r\n          <xs:element name="NetworkMessageContentMask" type="tns:JsonNetworkMessageContentMask" minOccurs="0" />\r\n          <xs:element name="DataSetMessageContentMask" type="tns:JsonDataSetMessageContentMask" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="JsonDataSetReaderMessageDataType" type="tns:JsonDataSetReaderMessageDataType" />\r\n\r\n  <xs:complexType name="ListOfJsonDataSetReaderMessageDataType">\r\n    <xs:sequence>\r\n      <xs:element name="JsonDataSetReaderMessageDataType" type="tns:JsonDataSetReaderMessageDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfJsonDataSetReaderMessageDataType" type="tns:ListOfJsonDataSetReaderMessageDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DatagramConnectionTransportDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:ConnectionTransportDataType">\r\n        <xs:sequence>\r\n          <xs:element name="DiscoveryAddress" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="DatagramConnectionTransportDataType" type="tns:DatagramConnectionTransportDataType" />\r\n\r\n  <xs:complexType name="ListOfDatagramConnectionTransportDataType">\r\n    <xs:sequence>\r\n      <xs:element name="DatagramConnectionTransportDataType" type="tns:DatagramConnectionTransportDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDatagramConnectionTransportDataType" type="tns:ListOfDatagramConnectionTransportDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DatagramWriterGroupTransportDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:WriterGroupTransportDataType">\r\n        <xs:sequence>\r\n          <xs:element name="MessageRepeatCount" type="xs:unsignedByte" minOccurs="0" />\r\n          <xs:element name="MessageRepeatDelay" type="xs:double" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="DatagramWriterGroupTransportDataType" type="tns:DatagramWriterGroupTransportDataType" />\r\n\r\n  <xs:complexType name="ListOfDatagramWriterGroupTransportDataType">\r\n    <xs:sequence>\r\n      <xs:element name="DatagramWriterGroupTransportDataType" type="tns:DatagramWriterGroupTransportDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDatagramWriterGroupTransportDataType" type="tns:ListOfDatagramWriterGroupTransportDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="BrokerConnectionTransportDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:ConnectionTransportDataType">\r\n        <xs:sequence>\r\n          <xs:element name="ResourceUri" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="AuthenticationProfileUri" type="xs:string" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="BrokerConnectionTransportDataType" type="tns:BrokerConnectionTransportDataType" />\r\n\r\n  <xs:complexType name="ListOfBrokerConnectionTransportDataType">\r\n    <xs:sequence>\r\n      <xs:element name="BrokerConnectionTransportDataType" type="tns:BrokerConnectionTransportDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfBrokerConnectionTransportDataType" type="tns:ListOfBrokerConnectionTransportDataType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="BrokerTransportQualityOfService">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="NotSpecified_0" />\r\n      <xs:enumeration value="BestEffort_1" />\r\n      <xs:enumeration value="AtLeastOnce_2" />\r\n      <xs:enumeration value="AtMostOnce_3" />\r\n      <xs:enumeration value="ExactlyOnce_4" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="BrokerTransportQualityOfService" type="tns:BrokerTransportQualityOfService" />\r\n\r\n  <xs:complexType name="ListOfBrokerTransportQualityOfService">\r\n    <xs:sequence>\r\n      <xs:element name="BrokerTransportQualityOfService" type="tns:BrokerTransportQualityOfService" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfBrokerTransportQualityOfService" type="tns:ListOfBrokerTransportQualityOfService" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="BrokerWriterGroupTransportDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:WriterGroupTransportDataType">\r\n        <xs:sequence>\r\n          <xs:element name="QueueName" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="ResourceUri" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="AuthenticationProfileUri" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="RequestedDeliveryGuarantee" type="tns:BrokerTransportQualityOfService" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="BrokerWriterGroupTransportDataType" type="tns:BrokerWriterGroupTransportDataType" />\r\n\r\n  <xs:complexType name="ListOfBrokerWriterGroupTransportDataType">\r\n    <xs:sequence>\r\n      <xs:element name="BrokerWriterGroupTransportDataType" type="tns:BrokerWriterGroupTransportDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfBrokerWriterGroupTransportDataType" type="tns:ListOfBrokerWriterGroupTransportDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="BrokerDataSetWriterTransportDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataSetWriterTransportDataType">\r\n        <xs:sequence>\r\n          <xs:element name="QueueName" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="ResourceUri" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="AuthenticationProfileUri" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="MetaDataQueueName" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="MetaDataUpdateTime" type="xs:double" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="BrokerDataSetWriterTransportDataType" type="tns:BrokerDataSetWriterTransportDataType" />\r\n\r\n  <xs:complexType name="ListOfBrokerDataSetWriterTransportDataType">\r\n    <xs:sequence>\r\n      <xs:element name="BrokerDataSetWriterTransportDataType" type="tns:BrokerDataSetWriterTransportDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfBrokerDataSetWriterTransportDataType" type="tns:ListOfBrokerDataSetWriterTransportDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="BrokerDataSetReaderTransportDataType">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataSetReaderTransportDataType">\r\n        <xs:sequence>\r\n          <xs:element name="QueueName" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="ResourceUri" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="AuthenticationProfileUri" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="RequestedDeliveryGuarantee" type="tns:BrokerTransportQualityOfService" minOccurs="0" />\r\n          <xs:element name="MetaDataQueueName" type="xs:string" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="BrokerDataSetReaderTransportDataType" type="tns:BrokerDataSetReaderTransportDataType" />\r\n\r\n  <xs:complexType name="ListOfBrokerDataSetReaderTransportDataType">\r\n    <xs:sequence>\r\n      <xs:element name="BrokerDataSetReaderTransportDataType" type="tns:BrokerDataSetReaderTransportDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfBrokerDataSetReaderTransportDataType" type="tns:ListOfBrokerDataSetReaderTransportDataType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="DiagnosticsLevel">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Basic_0" />\r\n      <xs:enumeration value="Advanced_1" />\r\n      <xs:enumeration value="Info_2" />\r\n      <xs:enumeration value="Log_3" />\r\n      <xs:enumeration value="Debug_4" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="DiagnosticsLevel" type="tns:DiagnosticsLevel" />\r\n\r\n  <xs:complexType name="ListOfDiagnosticsLevel">\r\n    <xs:sequence>\r\n      <xs:element name="DiagnosticsLevel" type="tns:DiagnosticsLevel" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDiagnosticsLevel" type="tns:ListOfDiagnosticsLevel" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="PubSubDiagnosticsCounterClassification">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Information_0" />\r\n      <xs:enumeration value="Error_1" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="PubSubDiagnosticsCounterClassification" type="tns:PubSubDiagnosticsCounterClassification" />\r\n\r\n  <xs:complexType name="ListOfPubSubDiagnosticsCounterClassification">\r\n    <xs:sequence>\r\n      <xs:element name="PubSubDiagnosticsCounterClassification" type="tns:PubSubDiagnosticsCounterClassification" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfPubSubDiagnosticsCounterClassification" type="tns:ListOfPubSubDiagnosticsCounterClassification" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="IdType">\r\n    <xs:annotation>\r\n      <xs:documentation>The type of identifier used in a node id.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Numeric_0" />\r\n      <xs:enumeration value="String_1" />\r\n      <xs:enumeration value="Guid_2" />\r\n      <xs:enumeration value="Opaque_3" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="IdType" type="tns:IdType" />\r\n\r\n  <xs:complexType name="ListOfIdType">\r\n    <xs:sequence>\r\n      <xs:element name="IdType" type="tns:IdType" minOccurs="0" maxOccurs="unbounded" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfIdType" type="tns:ListOfIdType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="NodeClass">\r\n    <xs:annotation>\r\n      <xs:documentation>A mask specifying the class of the node.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Unspecified_0" />\r\n      <xs:enumeration value="Object_1" />\r\n      <xs:enumeration value="Variable_2" />\r\n      <xs:enumeration value="Method_4" />\r\n      <xs:enumeration value="ObjectType_8" />\r\n      <xs:enumeration value="VariableType_16" />\r\n      <xs:enumeration value="ReferenceType_32" />\r\n      <xs:enumeration value="DataType_64" />\r\n      <xs:enumeration value="View_128" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="NodeClass" type="tns:NodeClass" />\r\n\r\n  <xs:simpleType  name="AccessLevelType">\r\n    <xs:restriction base="xs:unsignedByte">\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="AccessLevelType" type="tns:AccessLevelType" />\r\n\r\n  <xs:simpleType  name="AccessLevelExType">\r\n    <xs:restriction base="xs:unsignedInt">\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="AccessLevelExType" type="tns:AccessLevelExType" />\r\n\r\n  <xs:simpleType  name="EventNotifierType">\r\n    <xs:restriction base="xs:unsignedInt">\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="EventNotifierType" type="tns:EventNotifierType" />\r\n\r\n  <xs:complexType name="RolePermissionType">\r\n    <xs:sequence>\r\n      <xs:element name="RoleId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="Permissions" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RolePermissionType" type="tns:RolePermissionType" />\r\n\r\n  <xs:complexType name="ListOfRolePermissionType">\r\n    <xs:sequence>\r\n      <xs:element name="RolePermissionType" type="tns:RolePermissionType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfRolePermissionType" type="tns:ListOfRolePermissionType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DataTypeDefinition">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DataTypeDefinition" type="tns:DataTypeDefinition" />\r\n\r\n  <xs:complexType name="ListOfDataTypeDefinition">\r\n    <xs:sequence>\r\n      <xs:element name="DataTypeDefinition" type="tns:DataTypeDefinition" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDataTypeDefinition" type="tns:ListOfDataTypeDefinition" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="StructureType">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Structure_0" />\r\n      <xs:enumeration value="StructureWithOptionalFields_1" />\r\n      <xs:enumeration value="Union_2" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="StructureType" type="tns:StructureType" />\r\n\r\n  <xs:complexType name="StructureField">\r\n    <xs:sequence>\r\n      <xs:element name="Name" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="Description" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n      <xs:element name="DataType" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="ValueRank" type="xs:int" minOccurs="0" />\r\n      <xs:element name="ArrayDimensions" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n      <xs:element name="MaxStringLength" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="IsOptional" type="xs:boolean" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="StructureField" type="tns:StructureField" />\r\n\r\n  <xs:complexType name="ListOfStructureField">\r\n    <xs:sequence>\r\n      <xs:element name="StructureField" type="tns:StructureField" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfStructureField" type="tns:ListOfStructureField" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="StructureDefinition">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataTypeDefinition">\r\n        <xs:sequence>\r\n          <xs:element name="DefaultEncodingId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n          <xs:element name="BaseDataType" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n          <xs:element name="StructureType" type="tns:StructureType" minOccurs="0" />\r\n          <xs:element name="Fields" type="tns:ListOfStructureField" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="StructureDefinition" type="tns:StructureDefinition" />\r\n\r\n  <xs:complexType name="ListOfStructureDefinition">\r\n    <xs:sequence>\r\n      <xs:element name="StructureDefinition" type="tns:StructureDefinition" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfStructureDefinition" type="tns:ListOfStructureDefinition" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="EnumDefinition">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DataTypeDefinition">\r\n        <xs:sequence>\r\n          <xs:element name="Fields" type="tns:ListOfEnumField" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="EnumDefinition" type="tns:EnumDefinition" />\r\n\r\n  <xs:complexType name="ListOfEnumDefinition">\r\n    <xs:sequence>\r\n      <xs:element name="EnumDefinition" type="tns:EnumDefinition" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfEnumDefinition" type="tns:ListOfEnumDefinition" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="Node">\r\n    <xs:annotation>\r\n      <xs:documentation>Specifies the attributes which belong to all nodes.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="NodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="NodeClass" type="tns:NodeClass" minOccurs="0" />\r\n      <xs:element name="BrowseName" type="ua:QualifiedName" minOccurs="0" nillable="true" />\r\n      <xs:element name="DisplayName" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n      <xs:element name="Description" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n      <xs:element name="WriteMask" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="UserWriteMask" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RolePermissions" type="tns:ListOfRolePermissionType" minOccurs="0" nillable="true" />\r\n      <xs:element name="UserRolePermissions" type="tns:ListOfRolePermissionType" minOccurs="0" nillable="true" />\r\n      <xs:element name="AccessRestrictions" type="xs:unsignedShort" minOccurs="0" />\r\n      <xs:element name="References" type="tns:ListOfReferenceNode" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="Node" type="tns:Node" />\r\n\r\n  <xs:complexType name="ListOfNode">\r\n    <xs:sequence>\r\n      <xs:element name="Node" type="tns:Node" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfNode" type="tns:ListOfNode" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="InstanceNode">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:Node">\r\n        <xs:sequence>\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="InstanceNode" type="tns:InstanceNode" />\r\n\r\n  <xs:complexType name="TypeNode">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:Node">\r\n        <xs:sequence>\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="TypeNode" type="tns:TypeNode" />\r\n\r\n  <xs:complexType name="ObjectNode">\r\n    <xs:annotation>\r\n      <xs:documentation>Specifies the attributes which belong to object nodes.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:InstanceNode">\r\n        <xs:sequence>\r\n          <xs:element name="EventNotifier" type="xs:unsignedByte" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ObjectNode" type="tns:ObjectNode" />\r\n\r\n  <xs:complexType name="ObjectTypeNode">\r\n    <xs:annotation>\r\n      <xs:documentation>Specifies the attributes which belong to object type nodes.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:TypeNode">\r\n        <xs:sequence>\r\n          <xs:element name="IsAbstract" type="xs:boolean" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ObjectTypeNode" type="tns:ObjectTypeNode" />\r\n\r\n  <xs:complexType name="VariableNode">\r\n    <xs:annotation>\r\n      <xs:documentation>Specifies the attributes which belong to variable nodes.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:InstanceNode">\r\n        <xs:sequence>\r\n          <xs:element name="Value" type="ua:Variant" minOccurs="0" />\r\n          <xs:element name="DataType" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n          <xs:element name="ValueRank" type="xs:int" minOccurs="0" />\r\n          <xs:element name="ArrayDimensions" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n          <xs:element name="AccessLevel" type="xs:unsignedByte" minOccurs="0" />\r\n          <xs:element name="UserAccessLevel" type="xs:unsignedByte" minOccurs="0" />\r\n          <xs:element name="MinimumSamplingInterval" type="xs:double" minOccurs="0" />\r\n          <xs:element name="Historizing" type="xs:boolean" minOccurs="0" />\r\n          <xs:element name="AccessLevelEx" type="xs:unsignedInt" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="VariableNode" type="tns:VariableNode" />\r\n\r\n  <xs:complexType name="VariableTypeNode">\r\n    <xs:annotation>\r\n      <xs:documentation>Specifies the attributes which belong to variable type nodes.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:TypeNode">\r\n        <xs:sequence>\r\n          <xs:element name="Value" type="ua:Variant" minOccurs="0" />\r\n          <xs:element name="DataType" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n          <xs:element name="ValueRank" type="xs:int" minOccurs="0" />\r\n          <xs:element name="ArrayDimensions" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n          <xs:element name="IsAbstract" type="xs:boolean" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="VariableTypeNode" type="tns:VariableTypeNode" />\r\n\r\n  <xs:complexType name="ReferenceTypeNode">\r\n    <xs:annotation>\r\n      <xs:documentation>Specifies the attributes which belong to reference type nodes.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:TypeNode">\r\n        <xs:sequence>\r\n          <xs:element name="IsAbstract" type="xs:boolean" minOccurs="0" />\r\n          <xs:element name="Symmetric" type="xs:boolean" minOccurs="0" />\r\n          <xs:element name="InverseName" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ReferenceTypeNode" type="tns:ReferenceTypeNode" />\r\n\r\n  <xs:complexType name="MethodNode">\r\n    <xs:annotation>\r\n      <xs:documentation>Specifies the attributes which belong to method nodes.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:InstanceNode">\r\n        <xs:sequence>\r\n          <xs:element name="Executable" type="xs:boolean" minOccurs="0" />\r\n          <xs:element name="UserExecutable" type="xs:boolean" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="MethodNode" type="tns:MethodNode" />\r\n\r\n  <xs:complexType name="ViewNode">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:InstanceNode">\r\n        <xs:sequence>\r\n          <xs:element name="ContainsNoLoops" type="xs:boolean" minOccurs="0" />\r\n          <xs:element name="EventNotifier" type="xs:unsignedByte" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ViewNode" type="tns:ViewNode" />\r\n\r\n  <xs:complexType name="DataTypeNode">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:TypeNode">\r\n        <xs:sequence>\r\n          <xs:element name="IsAbstract" type="xs:boolean" minOccurs="0" />\r\n          <xs:element name="DataTypeDefinition" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="DataTypeNode" type="tns:DataTypeNode" />\r\n\r\n  <xs:complexType name="ReferenceNode">\r\n    <xs:annotation>\r\n      <xs:documentation>Specifies a reference which belongs to a node.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ReferenceTypeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="IsInverse" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="TargetId" type="ua:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ReferenceNode" type="tns:ReferenceNode" />\r\n\r\n  <xs:complexType name="ListOfReferenceNode">\r\n    <xs:sequence>\r\n      <xs:element name="ReferenceNode" type="tns:ReferenceNode" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfReferenceNode" type="tns:ListOfReferenceNode" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="Argument">\r\n    <xs:annotation>\r\n      <xs:documentation>An argument for a method.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="Name" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="DataType" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="ValueRank" type="xs:int" minOccurs="0" />\r\n      <xs:element name="ArrayDimensions" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n      <xs:element name="Description" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="Argument" type="tns:Argument" />\r\n\r\n  <xs:complexType name="ListOfArgument">\r\n    <xs:sequence>\r\n      <xs:element name="Argument" type="tns:Argument" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfArgument" type="tns:ListOfArgument" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="EnumValueType">\r\n    <xs:annotation>\r\n      <xs:documentation>A mapping between a value of an enumerated type and a name and description.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="Value" type="xs:long" minOccurs="0" />\r\n      <xs:element name="DisplayName" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n      <xs:element name="Description" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="EnumValueType" type="tns:EnumValueType" />\r\n\r\n  <xs:complexType name="ListOfEnumValueType">\r\n    <xs:sequence>\r\n      <xs:element name="EnumValueType" type="tns:EnumValueType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfEnumValueType" type="tns:ListOfEnumValueType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="EnumField">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:EnumValueType">\r\n        <xs:sequence>\r\n          <xs:element name="Name" type="xs:string" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="EnumField" type="tns:EnumField" />\r\n\r\n  <xs:complexType name="ListOfEnumField">\r\n    <xs:sequence>\r\n      <xs:element name="EnumField" type="tns:EnumField" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfEnumField" type="tns:ListOfEnumField" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="OptionSet">\r\n    <xs:annotation>\r\n      <xs:documentation>This abstract Structured DataType is the base DataType for all DataTypes representing a bit mask.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="Value" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n      <xs:element name="ValidBits" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="OptionSet" type="tns:OptionSet" />\r\n\r\n  <xs:complexType name="ListOfOptionSet">\r\n    <xs:sequence>\r\n      <xs:element name="OptionSet" type="tns:OptionSet" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfOptionSet" type="tns:ListOfOptionSet" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="Union">\r\n    <xs:annotation>\r\n      <xs:documentation>This abstract DataType is the base DataType for all union DataTypes.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="Union" type="tns:Union" />\r\n\r\n  <xs:complexType name="ListOfUnion">\r\n    <xs:sequence>\r\n      <xs:element name="Union" type="tns:Union" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfUnion" type="tns:ListOfUnion" nillable="true"></xs:element>\r\n\r\n  <xs:element name="NormalizedString" type="xs:string" />\r\n\r\n  <xs:element name="DecimalString" type="xs:string" />\r\n\r\n  <xs:element name="DurationString" type="xs:string" />\r\n\r\n  <xs:element name="TimeString" type="xs:string" />\r\n\r\n  <xs:element name="DateString" type="xs:string" />\r\n\r\n  <xs:element name="Duration" type="xs:double" />\r\n\r\n  <xs:element name="UtcTime" type="xs:dateTime" />\r\n\r\n  <xs:element name="LocaleId" type="xs:string" />\r\n\r\n  <xs:complexType name="TimeZoneDataType">\r\n    <xs:sequence>\r\n      <xs:element name="Offset" type="xs:short" minOccurs="0" />\r\n      <xs:element name="DaylightSavingInOffset" type="xs:boolean" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="TimeZoneDataType" type="tns:TimeZoneDataType" />\r\n\r\n  <xs:complexType name="ListOfTimeZoneDataType">\r\n    <xs:sequence>\r\n      <xs:element name="TimeZoneDataType" type="tns:TimeZoneDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfTimeZoneDataType" type="tns:ListOfTimeZoneDataType" nillable="true"></xs:element>\r\n\r\n  <xs:element name="IntegerId" type="xs:unsignedInt" />\r\n\r\n  <xs:simpleType  name="ApplicationType">\r\n    <xs:annotation>\r\n      <xs:documentation>The types of applications.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Server_0" />\r\n      <xs:enumeration value="Client_1" />\r\n      <xs:enumeration value="ClientAndServer_2" />\r\n      <xs:enumeration value="DiscoveryServer_3" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="ApplicationType" type="tns:ApplicationType" />\r\n\r\n  <xs:complexType name="ApplicationDescription">\r\n    <xs:annotation>\r\n      <xs:documentation>Describes an application and how to find it.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ApplicationUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="ProductUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="ApplicationName" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n      <xs:element name="ApplicationType" type="tns:ApplicationType" minOccurs="0" />\r\n      <xs:element name="GatewayServerUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiscoveryProfileUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiscoveryUrls" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ApplicationDescription" type="tns:ApplicationDescription" />\r\n\r\n  <xs:complexType name="ListOfApplicationDescription">\r\n    <xs:sequence>\r\n      <xs:element name="ApplicationDescription" type="tns:ApplicationDescription" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfApplicationDescription" type="tns:ListOfApplicationDescription" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="RequestHeader">\r\n    <xs:annotation>\r\n      <xs:documentation>The header passed with every server request.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="AuthenticationToken" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="Timestamp" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="RequestHandle" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="ReturnDiagnostics" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="AuditEntryId" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="TimeoutHint" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="AdditionalHeader" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RequestHeader" type="tns:RequestHeader" />\r\n\r\n  <xs:complexType name="ResponseHeader">\r\n    <xs:annotation>\r\n      <xs:documentation>The header passed with every server response.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="Timestamp" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="RequestHandle" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="ServiceResult" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="ServiceDiagnostics" type="ua:DiagnosticInfo" minOccurs="0" nillable="true" />\r\n      <xs:element name="StringTable" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="AdditionalHeader" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ResponseHeader" type="tns:ResponseHeader" />\r\n\r\n  <xs:element name="VersionTime" type="xs:unsignedInt" />\r\n\r\n  <xs:complexType name="ServiceFault">\r\n    <xs:annotation>\r\n      <xs:documentation>The response returned by all services when there is a service level error.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ServiceFault" type="tns:ServiceFault" />\r\n\r\n  <xs:complexType name="SessionlessInvokeRequestType">\r\n    <xs:sequence>\r\n      <xs:element name="UrisVersion" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n      <xs:element name="NamespaceUris" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerUris" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="LocaleIds" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServiceId" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SessionlessInvokeRequestType" type="tns:SessionlessInvokeRequestType" />\r\n\r\n  <xs:complexType name="SessionlessInvokeResponseType">\r\n    <xs:sequence>\r\n      <xs:element name="NamespaceUris" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerUris" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServiceId" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SessionlessInvokeResponseType" type="tns:SessionlessInvokeResponseType" />\r\n\r\n  <xs:complexType name="FindServersRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Finds the servers known to the discovery server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="EndpointUrl" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="LocaleIds" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerUris" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="FindServersRequest" type="tns:FindServersRequest" />\r\n\r\n  <xs:complexType name="FindServersResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Finds the servers known to the discovery server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Servers" type="tns:ListOfApplicationDescription" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="FindServersResponse" type="tns:FindServersResponse" />\r\n\r\n  <xs:complexType name="ServerOnNetwork">\r\n    <xs:sequence>\r\n      <xs:element name="RecordId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="ServerName" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiscoveryUrl" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerCapabilities" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ServerOnNetwork" type="tns:ServerOnNetwork" />\r\n\r\n  <xs:complexType name="ListOfServerOnNetwork">\r\n    <xs:sequence>\r\n      <xs:element name="ServerOnNetwork" type="tns:ServerOnNetwork" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfServerOnNetwork" type="tns:ListOfServerOnNetwork" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="FindServersOnNetworkRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="StartingRecordId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="MaxRecordsToReturn" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="ServerCapabilityFilter" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="FindServersOnNetworkRequest" type="tns:FindServersOnNetworkRequest" />\r\n\r\n  <xs:complexType name="FindServersOnNetworkResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="LastCounterResetTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="Servers" type="tns:ListOfServerOnNetwork" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="FindServersOnNetworkResponse" type="tns:FindServersOnNetworkResponse" />\r\n\r\n  <xs:element name="ApplicationInstanceCertificate" type="xs:base64Binary" />\r\n\r\n  <xs:simpleType  name="MessageSecurityMode">\r\n    <xs:annotation>\r\n      <xs:documentation>The type of security to use on a message.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Invalid_0" />\r\n      <xs:enumeration value="None_1" />\r\n      <xs:enumeration value="Sign_2" />\r\n      <xs:enumeration value="SignAndEncrypt_3" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="MessageSecurityMode" type="tns:MessageSecurityMode" />\r\n\r\n  <xs:simpleType  name="UserTokenType">\r\n    <xs:annotation>\r\n      <xs:documentation>The possible user token types.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Anonymous_0" />\r\n      <xs:enumeration value="UserName_1" />\r\n      <xs:enumeration value="Certificate_2" />\r\n      <xs:enumeration value="IssuedToken_3" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="UserTokenType" type="tns:UserTokenType" />\r\n\r\n  <xs:complexType name="UserTokenPolicy">\r\n    <xs:annotation>\r\n      <xs:documentation>Describes a user token that can be used with a server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="PolicyId" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="TokenType" type="tns:UserTokenType" minOccurs="0" />\r\n      <xs:element name="IssuedTokenType" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="IssuerEndpointUrl" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="SecurityPolicyUri" type="xs:string" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="UserTokenPolicy" type="tns:UserTokenPolicy" />\r\n\r\n  <xs:complexType name="ListOfUserTokenPolicy">\r\n    <xs:sequence>\r\n      <xs:element name="UserTokenPolicy" type="tns:UserTokenPolicy" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfUserTokenPolicy" type="tns:ListOfUserTokenPolicy" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="EndpointDescription">\r\n    <xs:annotation>\r\n      <xs:documentation>The description of a endpoint that can be used to access a server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="EndpointUrl" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="Server" type="tns:ApplicationDescription" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerCertificate" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n      <xs:element name="SecurityMode" type="tns:MessageSecurityMode" minOccurs="0" />\r\n      <xs:element name="SecurityPolicyUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="UserIdentityTokens" type="tns:ListOfUserTokenPolicy" minOccurs="0" nillable="true" />\r\n      <xs:element name="TransportProfileUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="SecurityLevel" type="xs:unsignedByte" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="EndpointDescription" type="tns:EndpointDescription" />\r\n\r\n  <xs:complexType name="ListOfEndpointDescription">\r\n    <xs:sequence>\r\n      <xs:element name="EndpointDescription" type="tns:EndpointDescription" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfEndpointDescription" type="tns:ListOfEndpointDescription" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="GetEndpointsRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Gets the endpoints used by the server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="EndpointUrl" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="LocaleIds" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="ProfileUris" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="GetEndpointsRequest" type="tns:GetEndpointsRequest" />\r\n\r\n  <xs:complexType name="GetEndpointsResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Gets the endpoints used by the server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Endpoints" type="tns:ListOfEndpointDescription" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="GetEndpointsResponse" type="tns:GetEndpointsResponse" />\r\n\r\n  <xs:complexType name="RegisteredServer">\r\n    <xs:annotation>\r\n      <xs:documentation>The information required to register a server with a discovery server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ServerUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="ProductUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerNames" type="ua:ListOfLocalizedText" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerType" type="tns:ApplicationType" minOccurs="0" />\r\n      <xs:element name="GatewayServerUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiscoveryUrls" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="SemaphoreFilePath" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="IsOnline" type="xs:boolean" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RegisteredServer" type="tns:RegisteredServer" />\r\n\r\n  <xs:complexType name="ListOfRegisteredServer">\r\n    <xs:sequence>\r\n      <xs:element name="RegisteredServer" type="tns:RegisteredServer" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfRegisteredServer" type="tns:ListOfRegisteredServer" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="RegisterServerRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Registers a server with the discovery server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Server" type="tns:RegisteredServer" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RegisterServerRequest" type="tns:RegisterServerRequest" />\r\n\r\n  <xs:complexType name="RegisterServerResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Registers a server with the discovery server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RegisterServerResponse" type="tns:RegisterServerResponse" />\r\n\r\n  <xs:complexType name="DiscoveryConfiguration">\r\n    <xs:annotation>\r\n      <xs:documentation>A base type for discovery configuration information.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DiscoveryConfiguration" type="tns:DiscoveryConfiguration" />\r\n\r\n  <xs:complexType name="MdnsDiscoveryConfiguration">\r\n    <xs:annotation>\r\n      <xs:documentation>The discovery information needed for mDNS registration.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:DiscoveryConfiguration">\r\n        <xs:sequence>\r\n          <xs:element name="MdnsServerName" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="ServerCapabilities" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="MdnsDiscoveryConfiguration" type="tns:MdnsDiscoveryConfiguration" />\r\n\r\n  <xs:complexType name="RegisterServer2Request">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Server" type="tns:RegisteredServer" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiscoveryConfiguration" type="ua:ListOfExtensionObject" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RegisterServer2Request" type="tns:RegisterServer2Request" />\r\n\r\n  <xs:complexType name="RegisterServer2Response">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="ConfigurationResults" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RegisterServer2Response" type="tns:RegisterServer2Response" />\r\n\r\n  <xs:simpleType  name="SecurityTokenRequestType">\r\n    <xs:annotation>\r\n      <xs:documentation>Indicates whether a token if being created or renewed.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Issue_0" />\r\n      <xs:enumeration value="Renew_1" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="SecurityTokenRequestType" type="tns:SecurityTokenRequestType" />\r\n\r\n  <xs:complexType name="ChannelSecurityToken">\r\n    <xs:annotation>\r\n      <xs:documentation>The token that identifies a set of keys for an active secure channel.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ChannelId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="TokenId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="CreatedAt" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="RevisedLifetime" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ChannelSecurityToken" type="tns:ChannelSecurityToken" />\r\n\r\n  <xs:complexType name="OpenSecureChannelRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Creates a secure channel with a server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="ClientProtocolVersion" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RequestType" type="tns:SecurityTokenRequestType" minOccurs="0" />\r\n      <xs:element name="SecurityMode" type="tns:MessageSecurityMode" minOccurs="0" />\r\n      <xs:element name="ClientNonce" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n      <xs:element name="RequestedLifetime" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="OpenSecureChannelRequest" type="tns:OpenSecureChannelRequest" />\r\n\r\n  <xs:complexType name="OpenSecureChannelResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Creates a secure channel with a server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerProtocolVersion" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="SecurityToken" type="tns:ChannelSecurityToken" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerNonce" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="OpenSecureChannelResponse" type="tns:OpenSecureChannelResponse" />\r\n\r\n  <xs:complexType name="CloseSecureChannelRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Closes a secure channel.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CloseSecureChannelRequest" type="tns:CloseSecureChannelRequest" />\r\n\r\n  <xs:complexType name="CloseSecureChannelResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Closes a secure channel.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CloseSecureChannelResponse" type="tns:CloseSecureChannelResponse" />\r\n\r\n  <xs:complexType name="SignedSoftwareCertificate">\r\n    <xs:annotation>\r\n      <xs:documentation>A software certificate with a digital signature.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="CertificateData" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n      <xs:element name="Signature" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SignedSoftwareCertificate" type="tns:SignedSoftwareCertificate" />\r\n\r\n  <xs:complexType name="ListOfSignedSoftwareCertificate">\r\n    <xs:sequence>\r\n      <xs:element name="SignedSoftwareCertificate" type="tns:SignedSoftwareCertificate" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfSignedSoftwareCertificate" type="tns:ListOfSignedSoftwareCertificate" nillable="true"></xs:element>\r\n\r\n  <xs:element name="SessionAuthenticationToken" type="ua:NodeId" />\r\n\r\n  <xs:complexType name="SignatureData">\r\n    <xs:annotation>\r\n      <xs:documentation>A digital signature.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="Algorithm" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="Signature" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SignatureData" type="tns:SignatureData" />\r\n\r\n  <xs:complexType name="CreateSessionRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Creates a new session with the server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="ClientDescription" type="tns:ApplicationDescription" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="EndpointUrl" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="SessionName" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="ClientNonce" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n      <xs:element name="ClientCertificate" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n      <xs:element name="RequestedSessionTimeout" type="xs:double" minOccurs="0" />\r\n      <xs:element name="MaxResponseMessageSize" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CreateSessionRequest" type="tns:CreateSessionRequest" />\r\n\r\n  <xs:complexType name="CreateSessionResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Creates a new session with the server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SessionId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="AuthenticationToken" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="RevisedSessionTimeout" type="xs:double" minOccurs="0" />\r\n      <xs:element name="ServerNonce" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerCertificate" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerEndpoints" type="tns:ListOfEndpointDescription" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerSoftwareCertificates" type="tns:ListOfSignedSoftwareCertificate" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerSignature" type="tns:SignatureData" minOccurs="0" nillable="true" />\r\n      <xs:element name="MaxRequestMessageSize" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CreateSessionResponse" type="tns:CreateSessionResponse" />\r\n\r\n  <xs:complexType name="UserIdentityToken">\r\n    <xs:annotation>\r\n      <xs:documentation>A base type for a user identity token.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="PolicyId" type="xs:string" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="UserIdentityToken" type="tns:UserIdentityToken" />\r\n\r\n  <xs:complexType name="AnonymousIdentityToken">\r\n    <xs:annotation>\r\n      <xs:documentation>A token representing an anonymous user.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:UserIdentityToken">\r\n        <xs:sequence>\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="AnonymousIdentityToken" type="tns:AnonymousIdentityToken" />\r\n\r\n  <xs:complexType name="UserNameIdentityToken">\r\n    <xs:annotation>\r\n      <xs:documentation>A token representing a user identified by a user name and password.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:UserIdentityToken">\r\n        <xs:sequence>\r\n          <xs:element name="UserName" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="Password" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n          <xs:element name="EncryptionAlgorithm" type="xs:string" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="UserNameIdentityToken" type="tns:UserNameIdentityToken" />\r\n\r\n  <xs:complexType name="X509IdentityToken">\r\n    <xs:annotation>\r\n      <xs:documentation>A token representing a user identified by an X509 certificate.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:UserIdentityToken">\r\n        <xs:sequence>\r\n          <xs:element name="CertificateData" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="X509IdentityToken" type="tns:X509IdentityToken" />\r\n\r\n  <xs:complexType name="IssuedIdentityToken">\r\n    <xs:annotation>\r\n      <xs:documentation>A token representing a user identified by a WS-Security XML token.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:UserIdentityToken">\r\n        <xs:sequence>\r\n          <xs:element name="TokenData" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n          <xs:element name="EncryptionAlgorithm" type="xs:string" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="IssuedIdentityToken" type="tns:IssuedIdentityToken" />\r\n\r\n  <xs:complexType name="ActivateSessionRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Activates a session with the server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="ClientSignature" type="tns:SignatureData" minOccurs="0" nillable="true" />\r\n      <xs:element name="ClientSoftwareCertificates" type="tns:ListOfSignedSoftwareCertificate" minOccurs="0" nillable="true" />\r\n      <xs:element name="LocaleIds" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="UserIdentityToken" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n      <xs:element name="UserTokenSignature" type="tns:SignatureData" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ActivateSessionRequest" type="tns:ActivateSessionRequest" />\r\n\r\n  <xs:complexType name="ActivateSessionResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Activates a session with the server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerNonce" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ActivateSessionResponse" type="tns:ActivateSessionResponse" />\r\n\r\n  <xs:complexType name="CloseSessionRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Closes a session with the server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="DeleteSubscriptions" type="xs:boolean" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CloseSessionRequest" type="tns:CloseSessionRequest" />\r\n\r\n  <xs:complexType name="CloseSessionResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Closes a session with the server.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CloseSessionResponse" type="tns:CloseSessionResponse" />\r\n\r\n  <xs:complexType name="CancelRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Cancels an outstanding request.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="RequestHandle" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CancelRequest" type="tns:CancelRequest" />\r\n\r\n  <xs:complexType name="CancelResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Cancels an outstanding request.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="CancelCount" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CancelResponse" type="tns:CancelResponse" />\r\n\r\n  <xs:simpleType  name="NodeAttributesMask">\r\n    <xs:annotation>\r\n      <xs:documentation>The bits used to specify default attributes for a new node.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="None_0" />\r\n      <xs:enumeration value="AccessLevel_1" />\r\n      <xs:enumeration value="ArrayDimensions_2" />\r\n      <xs:enumeration value="BrowseName_4" />\r\n      <xs:enumeration value="ContainsNoLoops_8" />\r\n      <xs:enumeration value="DataType_16" />\r\n      <xs:enumeration value="Description_32" />\r\n      <xs:enumeration value="DisplayName_64" />\r\n      <xs:enumeration value="EventNotifier_128" />\r\n      <xs:enumeration value="Executable_256" />\r\n      <xs:enumeration value="Historizing_512" />\r\n      <xs:enumeration value="InverseName_1024" />\r\n      <xs:enumeration value="IsAbstract_2048" />\r\n      <xs:enumeration value="MinimumSamplingInterval_4096" />\r\n      <xs:enumeration value="NodeClass_8192" />\r\n      <xs:enumeration value="NodeId_16384" />\r\n      <xs:enumeration value="Symmetric_32768" />\r\n      <xs:enumeration value="UserAccessLevel_65536" />\r\n      <xs:enumeration value="UserExecutable_131072" />\r\n      <xs:enumeration value="UserWriteMask_262144" />\r\n      <xs:enumeration value="ValueRank_524288" />\r\n      <xs:enumeration value="WriteMask_1048576" />\r\n      <xs:enumeration value="Value_2097152" />\r\n      <xs:enumeration value="DataTypeDefinition_4194304" />\r\n      <xs:enumeration value="RolePermissions_8388608" />\r\n      <xs:enumeration value="AccessRestrictions_16777216" />\r\n      <xs:enumeration value="All_33554431" />\r\n      <xs:enumeration value="BaseNode_26501220" />\r\n      <xs:enumeration value="Object_26501348" />\r\n      <xs:enumeration value="ObjectType_26503268" />\r\n      <xs:enumeration value="Variable_26571383" />\r\n      <xs:enumeration value="VariableType_28600438" />\r\n      <xs:enumeration value="Method_26632548" />\r\n      <xs:enumeration value="ReferenceType_26537060" />\r\n      <xs:enumeration value="View_26501356" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="NodeAttributesMask" type="tns:NodeAttributesMask" />\r\n\r\n  <xs:complexType name="NodeAttributes">\r\n    <xs:annotation>\r\n      <xs:documentation>The base attributes for all nodes.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="SpecifiedAttributes" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="DisplayName" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n      <xs:element name="Description" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n      <xs:element name="WriteMask" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="UserWriteMask" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="NodeAttributes" type="tns:NodeAttributes" />\r\n\r\n  <xs:complexType name="ObjectAttributes">\r\n    <xs:annotation>\r\n      <xs:documentation>The attributes for an object node.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NodeAttributes">\r\n        <xs:sequence>\r\n          <xs:element name="EventNotifier" type="xs:unsignedByte" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ObjectAttributes" type="tns:ObjectAttributes" />\r\n\r\n  <xs:complexType name="VariableAttributes">\r\n    <xs:annotation>\r\n      <xs:documentation>The attributes for a variable node.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NodeAttributes">\r\n        <xs:sequence>\r\n          <xs:element name="Value" type="ua:Variant" minOccurs="0" />\r\n          <xs:element name="DataType" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n          <xs:element name="ValueRank" type="xs:int" minOccurs="0" />\r\n          <xs:element name="ArrayDimensions" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n          <xs:element name="AccessLevel" type="xs:unsignedByte" minOccurs="0" />\r\n          <xs:element name="UserAccessLevel" type="xs:unsignedByte" minOccurs="0" />\r\n          <xs:element name="MinimumSamplingInterval" type="xs:double" minOccurs="0" />\r\n          <xs:element name="Historizing" type="xs:boolean" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="VariableAttributes" type="tns:VariableAttributes" />\r\n\r\n  <xs:complexType name="MethodAttributes">\r\n    <xs:annotation>\r\n      <xs:documentation>The attributes for a method node.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NodeAttributes">\r\n        <xs:sequence>\r\n          <xs:element name="Executable" type="xs:boolean" minOccurs="0" />\r\n          <xs:element name="UserExecutable" type="xs:boolean" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="MethodAttributes" type="tns:MethodAttributes" />\r\n\r\n  <xs:complexType name="ObjectTypeAttributes">\r\n    <xs:annotation>\r\n      <xs:documentation>The attributes for an object type node.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NodeAttributes">\r\n        <xs:sequence>\r\n          <xs:element name="IsAbstract" type="xs:boolean" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ObjectTypeAttributes" type="tns:ObjectTypeAttributes" />\r\n\r\n  <xs:complexType name="VariableTypeAttributes">\r\n    <xs:annotation>\r\n      <xs:documentation>The attributes for a variable type node.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NodeAttributes">\r\n        <xs:sequence>\r\n          <xs:element name="Value" type="ua:Variant" minOccurs="0" />\r\n          <xs:element name="DataType" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n          <xs:element name="ValueRank" type="xs:int" minOccurs="0" />\r\n          <xs:element name="ArrayDimensions" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n          <xs:element name="IsAbstract" type="xs:boolean" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="VariableTypeAttributes" type="tns:VariableTypeAttributes" />\r\n\r\n  <xs:complexType name="ReferenceTypeAttributes">\r\n    <xs:annotation>\r\n      <xs:documentation>The attributes for a reference type node.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NodeAttributes">\r\n        <xs:sequence>\r\n          <xs:element name="IsAbstract" type="xs:boolean" minOccurs="0" />\r\n          <xs:element name="Symmetric" type="xs:boolean" minOccurs="0" />\r\n          <xs:element name="InverseName" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ReferenceTypeAttributes" type="tns:ReferenceTypeAttributes" />\r\n\r\n  <xs:complexType name="DataTypeAttributes">\r\n    <xs:annotation>\r\n      <xs:documentation>The attributes for a data type node.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NodeAttributes">\r\n        <xs:sequence>\r\n          <xs:element name="IsAbstract" type="xs:boolean" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="DataTypeAttributes" type="tns:DataTypeAttributes" />\r\n\r\n  <xs:complexType name="ViewAttributes">\r\n    <xs:annotation>\r\n      <xs:documentation>The attributes for a view node.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NodeAttributes">\r\n        <xs:sequence>\r\n          <xs:element name="ContainsNoLoops" type="xs:boolean" minOccurs="0" />\r\n          <xs:element name="EventNotifier" type="xs:unsignedByte" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ViewAttributes" type="tns:ViewAttributes" />\r\n\r\n  <xs:complexType name="GenericAttributeValue">\r\n    <xs:sequence>\r\n      <xs:element name="AttributeId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="Value" type="ua:Variant" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="GenericAttributeValue" type="tns:GenericAttributeValue" />\r\n\r\n  <xs:complexType name="ListOfGenericAttributeValue">\r\n    <xs:sequence>\r\n      <xs:element name="GenericAttributeValue" type="tns:GenericAttributeValue" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfGenericAttributeValue" type="tns:ListOfGenericAttributeValue" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="GenericAttributes">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NodeAttributes">\r\n        <xs:sequence>\r\n          <xs:element name="AttributeValues" type="tns:ListOfGenericAttributeValue" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="GenericAttributes" type="tns:GenericAttributes" />\r\n\r\n  <xs:complexType name="AddNodesItem">\r\n    <xs:annotation>\r\n      <xs:documentation>A request to add a node to the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ParentNodeId" type="ua:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="ReferenceTypeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="RequestedNewNodeId" type="ua:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="BrowseName" type="ua:QualifiedName" minOccurs="0" nillable="true" />\r\n      <xs:element name="NodeClass" type="tns:NodeClass" minOccurs="0" />\r\n      <xs:element name="NodeAttributes" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n      <xs:element name="TypeDefinition" type="ua:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="AddNodesItem" type="tns:AddNodesItem" />\r\n\r\n  <xs:complexType name="ListOfAddNodesItem">\r\n    <xs:sequence>\r\n      <xs:element name="AddNodesItem" type="tns:AddNodesItem" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfAddNodesItem" type="tns:ListOfAddNodesItem" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="AddNodesResult">\r\n    <xs:annotation>\r\n      <xs:documentation>A result of an add node operation.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="AddedNodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="AddNodesResult" type="tns:AddNodesResult" />\r\n\r\n  <xs:complexType name="ListOfAddNodesResult">\r\n    <xs:sequence>\r\n      <xs:element name="AddNodesResult" type="tns:AddNodesResult" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfAddNodesResult" type="tns:ListOfAddNodesResult" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="AddNodesRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Adds one or more nodes to the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="NodesToAdd" type="tns:ListOfAddNodesItem" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="AddNodesRequest" type="tns:AddNodesRequest" />\r\n\r\n  <xs:complexType name="AddNodesResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Adds one or more nodes to the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="tns:ListOfAddNodesResult" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="AddNodesResponse" type="tns:AddNodesResponse" />\r\n\r\n  <xs:complexType name="AddReferencesItem">\r\n    <xs:annotation>\r\n      <xs:documentation>A request to add a reference to the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="SourceNodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="ReferenceTypeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="IsForward" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="TargetServerUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="TargetNodeId" type="ua:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="TargetNodeClass" type="tns:NodeClass" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="AddReferencesItem" type="tns:AddReferencesItem" />\r\n\r\n  <xs:complexType name="ListOfAddReferencesItem">\r\n    <xs:sequence>\r\n      <xs:element name="AddReferencesItem" type="tns:AddReferencesItem" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfAddReferencesItem" type="tns:ListOfAddReferencesItem" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="AddReferencesRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Adds one or more references to the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="ReferencesToAdd" type="tns:ListOfAddReferencesItem" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="AddReferencesRequest" type="tns:AddReferencesRequest" />\r\n\r\n  <xs:complexType name="AddReferencesResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Adds one or more references to the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="AddReferencesResponse" type="tns:AddReferencesResponse" />\r\n\r\n  <xs:complexType name="DeleteNodesItem">\r\n    <xs:annotation>\r\n      <xs:documentation>A request to delete a node to the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="NodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="DeleteTargetReferences" type="xs:boolean" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteNodesItem" type="tns:DeleteNodesItem" />\r\n\r\n  <xs:complexType name="ListOfDeleteNodesItem">\r\n    <xs:sequence>\r\n      <xs:element name="DeleteNodesItem" type="tns:DeleteNodesItem" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDeleteNodesItem" type="tns:ListOfDeleteNodesItem" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DeleteNodesRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Delete one or more nodes from the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="NodesToDelete" type="tns:ListOfDeleteNodesItem" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteNodesRequest" type="tns:DeleteNodesRequest" />\r\n\r\n  <xs:complexType name="DeleteNodesResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Delete one or more nodes from the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteNodesResponse" type="tns:DeleteNodesResponse" />\r\n\r\n  <xs:complexType name="DeleteReferencesItem">\r\n    <xs:annotation>\r\n      <xs:documentation>A request to delete a node from the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="SourceNodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="ReferenceTypeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="IsForward" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="TargetNodeId" type="ua:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="DeleteBidirectional" type="xs:boolean" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteReferencesItem" type="tns:DeleteReferencesItem" />\r\n\r\n  <xs:complexType name="ListOfDeleteReferencesItem">\r\n    <xs:sequence>\r\n      <xs:element name="DeleteReferencesItem" type="tns:DeleteReferencesItem" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfDeleteReferencesItem" type="tns:ListOfDeleteReferencesItem" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="DeleteReferencesRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Delete one or more references from the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="ReferencesToDelete" type="tns:ListOfDeleteReferencesItem" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteReferencesRequest" type="tns:DeleteReferencesRequest" />\r\n\r\n  <xs:complexType name="DeleteReferencesResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Delete one or more references from the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteReferencesResponse" type="tns:DeleteReferencesResponse" />\r\n\r\n  <xs:simpleType  name="AttributeWriteMask">\r\n    <xs:annotation>\r\n      <xs:documentation>Define bits used to indicate which attributes are writable.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:restriction base="xs:unsignedInt">\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="AttributeWriteMask" type="tns:AttributeWriteMask" />\r\n\r\n  <xs:simpleType  name="BrowseDirection">\r\n    <xs:annotation>\r\n      <xs:documentation>The directions of the references to return.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Forward_0" />\r\n      <xs:enumeration value="Inverse_1" />\r\n      <xs:enumeration value="Both_2" />\r\n      <xs:enumeration value="Invalid_3" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="BrowseDirection" type="tns:BrowseDirection" />\r\n\r\n  <xs:complexType name="ViewDescription">\r\n    <xs:annotation>\r\n      <xs:documentation>The view to browse.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ViewId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="Timestamp" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="ViewVersion" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ViewDescription" type="tns:ViewDescription" />\r\n\r\n  <xs:complexType name="BrowseDescription">\r\n    <xs:annotation>\r\n      <xs:documentation>A request to browse the the references from a node.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="NodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="BrowseDirection" type="tns:BrowseDirection" minOccurs="0" />\r\n      <xs:element name="ReferenceTypeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="IncludeSubtypes" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="NodeClassMask" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="ResultMask" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="BrowseDescription" type="tns:BrowseDescription" />\r\n\r\n  <xs:complexType name="ListOfBrowseDescription">\r\n    <xs:sequence>\r\n      <xs:element name="BrowseDescription" type="tns:BrowseDescription" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfBrowseDescription" type="tns:ListOfBrowseDescription" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="BrowseResultMask">\r\n    <xs:annotation>\r\n      <xs:documentation>A bit mask which specifies what should be returned in a browse response.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="None_0" />\r\n      <xs:enumeration value="ReferenceTypeId_1" />\r\n      <xs:enumeration value="IsForward_2" />\r\n      <xs:enumeration value="NodeClass_4" />\r\n      <xs:enumeration value="BrowseName_8" />\r\n      <xs:enumeration value="DisplayName_16" />\r\n      <xs:enumeration value="TypeDefinition_32" />\r\n      <xs:enumeration value="All_63" />\r\n      <xs:enumeration value="ReferenceTypeInfo_3" />\r\n      <xs:enumeration value="TargetInfo_60" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="BrowseResultMask" type="tns:BrowseResultMask" />\r\n\r\n  <xs:complexType name="ReferenceDescription">\r\n    <xs:annotation>\r\n      <xs:documentation>The description of a reference.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ReferenceTypeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="IsForward" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="NodeId" type="ua:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="BrowseName" type="ua:QualifiedName" minOccurs="0" nillable="true" />\r\n      <xs:element name="DisplayName" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n      <xs:element name="NodeClass" type="tns:NodeClass" minOccurs="0" />\r\n      <xs:element name="TypeDefinition" type="ua:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ReferenceDescription" type="tns:ReferenceDescription" />\r\n\r\n  <xs:complexType name="ListOfReferenceDescription">\r\n    <xs:sequence>\r\n      <xs:element name="ReferenceDescription" type="tns:ReferenceDescription" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfReferenceDescription" type="tns:ListOfReferenceDescription" nillable="true"></xs:element>\r\n\r\n  <xs:element name="ContinuationPoint" type="xs:base64Binary" />\r\n\r\n  <xs:complexType name="BrowseResult">\r\n    <xs:annotation>\r\n      <xs:documentation>The result of a browse operation.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="ContinuationPoint" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n      <xs:element name="References" type="tns:ListOfReferenceDescription" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="BrowseResult" type="tns:BrowseResult" />\r\n\r\n  <xs:complexType name="ListOfBrowseResult">\r\n    <xs:sequence>\r\n      <xs:element name="BrowseResult" type="tns:BrowseResult" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfBrowseResult" type="tns:ListOfBrowseResult" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="BrowseRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Browse the references for one or more nodes from the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="View" type="tns:ViewDescription" minOccurs="0" nillable="true" />\r\n      <xs:element name="RequestedMaxReferencesPerNode" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="NodesToBrowse" type="tns:ListOfBrowseDescription" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="BrowseRequest" type="tns:BrowseRequest" />\r\n\r\n  <xs:complexType name="BrowseResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Browse the references for one or more nodes from the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="tns:ListOfBrowseResult" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="BrowseResponse" type="tns:BrowseResponse" />\r\n\r\n  <xs:complexType name="BrowseNextRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Continues one or more browse operations.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="ReleaseContinuationPoints" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="ContinuationPoints" type="ua:ListOfByteString" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="BrowseNextRequest" type="tns:BrowseNextRequest" />\r\n\r\n  <xs:complexType name="BrowseNextResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Continues one or more browse operations.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="tns:ListOfBrowseResult" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="BrowseNextResponse" type="tns:BrowseNextResponse" />\r\n\r\n  <xs:complexType name="RelativePathElement">\r\n    <xs:annotation>\r\n      <xs:documentation>An element in a relative path.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ReferenceTypeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="IsInverse" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="IncludeSubtypes" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="TargetName" type="ua:QualifiedName" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RelativePathElement" type="tns:RelativePathElement" />\r\n\r\n  <xs:complexType name="ListOfRelativePathElement">\r\n    <xs:sequence>\r\n      <xs:element name="RelativePathElement" type="tns:RelativePathElement" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfRelativePathElement" type="tns:ListOfRelativePathElement" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="RelativePath">\r\n    <xs:annotation>\r\n      <xs:documentation>A relative path constructed from reference types and browse names.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="Elements" type="tns:ListOfRelativePathElement" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RelativePath" type="tns:RelativePath" />\r\n\r\n  <xs:complexType name="BrowsePath">\r\n    <xs:annotation>\r\n      <xs:documentation>A request to translate a path into a node id.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="StartingNode" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="RelativePath" type="tns:RelativePath" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="BrowsePath" type="tns:BrowsePath" />\r\n\r\n  <xs:complexType name="ListOfBrowsePath">\r\n    <xs:sequence>\r\n      <xs:element name="BrowsePath" type="tns:BrowsePath" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfBrowsePath" type="tns:ListOfBrowsePath" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="BrowsePathTarget">\r\n    <xs:annotation>\r\n      <xs:documentation>The target of the translated path.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="TargetId" type="ua:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="RemainingPathIndex" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="BrowsePathTarget" type="tns:BrowsePathTarget" />\r\n\r\n  <xs:complexType name="ListOfBrowsePathTarget">\r\n    <xs:sequence>\r\n      <xs:element name="BrowsePathTarget" type="tns:BrowsePathTarget" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfBrowsePathTarget" type="tns:ListOfBrowsePathTarget" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="BrowsePathResult">\r\n    <xs:annotation>\r\n      <xs:documentation>The result of a translate opearation.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="Targets" type="tns:ListOfBrowsePathTarget" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="BrowsePathResult" type="tns:BrowsePathResult" />\r\n\r\n  <xs:complexType name="ListOfBrowsePathResult">\r\n    <xs:sequence>\r\n      <xs:element name="BrowsePathResult" type="tns:BrowsePathResult" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfBrowsePathResult" type="tns:ListOfBrowsePathResult" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="TranslateBrowsePathsToNodeIdsRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Translates one or more paths in the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="BrowsePaths" type="tns:ListOfBrowsePath" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="TranslateBrowsePathsToNodeIdsRequest" type="tns:TranslateBrowsePathsToNodeIdsRequest" />\r\n\r\n  <xs:complexType name="TranslateBrowsePathsToNodeIdsResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Translates one or more paths in the server address space.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="tns:ListOfBrowsePathResult" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="TranslateBrowsePathsToNodeIdsResponse" type="tns:TranslateBrowsePathsToNodeIdsResponse" />\r\n\r\n  <xs:complexType name="RegisterNodesRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Registers one or more nodes for repeated use within a session.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="NodesToRegister" type="ua:ListOfNodeId" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RegisterNodesRequest" type="tns:RegisterNodesRequest" />\r\n\r\n  <xs:complexType name="RegisterNodesResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Registers one or more nodes for repeated use within a session.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="RegisteredNodeIds" type="ua:ListOfNodeId" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RegisterNodesResponse" type="tns:RegisterNodesResponse" />\r\n\r\n  <xs:complexType name="UnregisterNodesRequest">\r\n    <xs:annotation>\r\n      <xs:documentation>Unregisters one or more previously registered nodes.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="NodesToUnregister" type="ua:ListOfNodeId" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="UnregisterNodesRequest" type="tns:UnregisterNodesRequest" />\r\n\r\n  <xs:complexType name="UnregisterNodesResponse">\r\n    <xs:annotation>\r\n      <xs:documentation>Unregisters one or more previously registered nodes.</xs:documentation>\r\n    </xs:annotation>\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="UnregisterNodesResponse" type="tns:UnregisterNodesResponse" />\r\n\r\n  <xs:element name="Counter" type="xs:unsignedInt" />\r\n\r\n  <xs:element name="NumericRange" type="xs:string" />\r\n\r\n  <xs:element name="Time" type="xs:string" />\r\n\r\n  <xs:element name="Date" type="xs:dateTime" />\r\n\r\n  <xs:complexType name="EndpointConfiguration">\r\n    <xs:sequence>\r\n      <xs:element name="OperationTimeout" type="xs:int" minOccurs="0" />\r\n      <xs:element name="UseBinaryEncoding" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="MaxStringLength" type="xs:int" minOccurs="0" />\r\n      <xs:element name="MaxByteStringLength" type="xs:int" minOccurs="0" />\r\n      <xs:element name="MaxArrayLength" type="xs:int" minOccurs="0" />\r\n      <xs:element name="MaxMessageSize" type="xs:int" minOccurs="0" />\r\n      <xs:element name="MaxBufferSize" type="xs:int" minOccurs="0" />\r\n      <xs:element name="ChannelLifetime" type="xs:int" minOccurs="0" />\r\n      <xs:element name="SecurityTokenLifetime" type="xs:int" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="EndpointConfiguration" type="tns:EndpointConfiguration" />\r\n\r\n  <xs:complexType name="ListOfEndpointConfiguration">\r\n    <xs:sequence>\r\n      <xs:element name="EndpointConfiguration" type="tns:EndpointConfiguration" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfEndpointConfiguration" type="tns:ListOfEndpointConfiguration" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="QueryDataDescription">\r\n    <xs:sequence>\r\n      <xs:element name="RelativePath" type="tns:RelativePath" minOccurs="0" nillable="true" />\r\n      <xs:element name="AttributeId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="IndexRange" type="xs:string" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="QueryDataDescription" type="tns:QueryDataDescription" />\r\n\r\n  <xs:complexType name="ListOfQueryDataDescription">\r\n    <xs:sequence>\r\n      <xs:element name="QueryDataDescription" type="tns:QueryDataDescription" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfQueryDataDescription" type="tns:ListOfQueryDataDescription" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="NodeTypeDescription">\r\n    <xs:sequence>\r\n      <xs:element name="TypeDefinitionNode" type="ua:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="IncludeSubTypes" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="DataToReturn" type="tns:ListOfQueryDataDescription" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="NodeTypeDescription" type="tns:NodeTypeDescription" />\r\n\r\n  <xs:complexType name="ListOfNodeTypeDescription">\r\n    <xs:sequence>\r\n      <xs:element name="NodeTypeDescription" type="tns:NodeTypeDescription" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfNodeTypeDescription" type="tns:ListOfNodeTypeDescription" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="FilterOperator">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Equals_0" />\r\n      <xs:enumeration value="IsNull_1" />\r\n      <xs:enumeration value="GreaterThan_2" />\r\n      <xs:enumeration value="LessThan_3" />\r\n      <xs:enumeration value="GreaterThanOrEqual_4" />\r\n      <xs:enumeration value="LessThanOrEqual_5" />\r\n      <xs:enumeration value="Like_6" />\r\n      <xs:enumeration value="Not_7" />\r\n      <xs:enumeration value="Between_8" />\r\n      <xs:enumeration value="InList_9" />\r\n      <xs:enumeration value="And_10" />\r\n      <xs:enumeration value="Or_11" />\r\n      <xs:enumeration value="Cast_12" />\r\n      <xs:enumeration value="InView_13" />\r\n      <xs:enumeration value="OfType_14" />\r\n      <xs:enumeration value="RelatedTo_15" />\r\n      <xs:enumeration value="BitwiseAnd_16" />\r\n      <xs:enumeration value="BitwiseOr_17" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="FilterOperator" type="tns:FilterOperator" />\r\n\r\n  <xs:complexType name="QueryDataSet">\r\n    <xs:sequence>\r\n      <xs:element name="NodeId" type="ua:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="TypeDefinitionNode" type="ua:ExpandedNodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="Values" type="ua:ListOfVariant" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="QueryDataSet" type="tns:QueryDataSet" />\r\n\r\n  <xs:complexType name="ListOfQueryDataSet">\r\n    <xs:sequence>\r\n      <xs:element name="QueryDataSet" type="tns:QueryDataSet" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfQueryDataSet" type="tns:ListOfQueryDataSet" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="NodeReference">\r\n    <xs:sequence>\r\n      <xs:element name="NodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="ReferenceTypeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="IsForward" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="ReferencedNodeIds" type="ua:ListOfNodeId" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="NodeReference" type="tns:NodeReference" />\r\n\r\n  <xs:complexType name="ListOfNodeReference">\r\n    <xs:sequence>\r\n      <xs:element name="NodeReference" type="tns:NodeReference" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfNodeReference" type="tns:ListOfNodeReference" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ContentFilterElement">\r\n    <xs:sequence>\r\n      <xs:element name="FilterOperator" type="tns:FilterOperator" minOccurs="0" />\r\n      <xs:element name="FilterOperands" type="ua:ListOfExtensionObject" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ContentFilterElement" type="tns:ContentFilterElement" />\r\n\r\n  <xs:complexType name="ListOfContentFilterElement">\r\n    <xs:sequence>\r\n      <xs:element name="ContentFilterElement" type="tns:ContentFilterElement" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfContentFilterElement" type="tns:ListOfContentFilterElement" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ContentFilter">\r\n    <xs:sequence>\r\n      <xs:element name="Elements" type="tns:ListOfContentFilterElement" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ContentFilter" type="tns:ContentFilter" />\r\n\r\n  <xs:complexType name="ListOfContentFilter">\r\n    <xs:sequence>\r\n      <xs:element name="ContentFilter" type="tns:ContentFilter" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfContentFilter" type="tns:ListOfContentFilter" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="FilterOperand">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="FilterOperand" type="tns:FilterOperand" />\r\n\r\n  <xs:complexType name="ElementOperand">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:FilterOperand">\r\n        <xs:sequence>\r\n          <xs:element name="Index" type="xs:unsignedInt" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ElementOperand" type="tns:ElementOperand" />\r\n\r\n  <xs:complexType name="LiteralOperand">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:FilterOperand">\r\n        <xs:sequence>\r\n          <xs:element name="Value" type="ua:Variant" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="LiteralOperand" type="tns:LiteralOperand" />\r\n\r\n  <xs:complexType name="AttributeOperand">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:FilterOperand">\r\n        <xs:sequence>\r\n          <xs:element name="NodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n          <xs:element name="Alias" type="xs:string" minOccurs="0" nillable="true" />\r\n          <xs:element name="BrowsePath" type="tns:RelativePath" minOccurs="0" nillable="true" />\r\n          <xs:element name="AttributeId" type="xs:unsignedInt" minOccurs="0" />\r\n          <xs:element name="IndexRange" type="xs:string" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="AttributeOperand" type="tns:AttributeOperand" />\r\n\r\n  <xs:complexType name="SimpleAttributeOperand">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:FilterOperand">\r\n        <xs:sequence>\r\n          <xs:element name="TypeDefinitionId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n          <xs:element name="BrowsePath" type="ua:ListOfQualifiedName" minOccurs="0" nillable="true" />\r\n          <xs:element name="AttributeId" type="xs:unsignedInt" minOccurs="0" />\r\n          <xs:element name="IndexRange" type="xs:string" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="SimpleAttributeOperand" type="tns:SimpleAttributeOperand" />\r\n\r\n  <xs:complexType name="ListOfSimpleAttributeOperand">\r\n    <xs:sequence>\r\n      <xs:element name="SimpleAttributeOperand" type="tns:SimpleAttributeOperand" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfSimpleAttributeOperand" type="tns:ListOfSimpleAttributeOperand" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ContentFilterElementResult">\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="OperandStatusCodes" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="OperandDiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ContentFilterElementResult" type="tns:ContentFilterElementResult" />\r\n\r\n  <xs:complexType name="ListOfContentFilterElementResult">\r\n    <xs:sequence>\r\n      <xs:element name="ContentFilterElementResult" type="tns:ContentFilterElementResult" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfContentFilterElementResult" type="tns:ListOfContentFilterElementResult" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ContentFilterResult">\r\n    <xs:sequence>\r\n      <xs:element name="ElementResults" type="tns:ListOfContentFilterElementResult" minOccurs="0" nillable="true" />\r\n      <xs:element name="ElementDiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ContentFilterResult" type="tns:ContentFilterResult" />\r\n\r\n  <xs:complexType name="ParsingResult">\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="DataStatusCodes" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DataDiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ParsingResult" type="tns:ParsingResult" />\r\n\r\n  <xs:complexType name="ListOfParsingResult">\r\n    <xs:sequence>\r\n      <xs:element name="ParsingResult" type="tns:ParsingResult" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfParsingResult" type="tns:ListOfParsingResult" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="QueryFirstRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="View" type="tns:ViewDescription" minOccurs="0" nillable="true" />\r\n      <xs:element name="NodeTypes" type="tns:ListOfNodeTypeDescription" minOccurs="0" nillable="true" />\r\n      <xs:element name="Filter" type="tns:ContentFilter" minOccurs="0" nillable="true" />\r\n      <xs:element name="MaxDataSetsToReturn" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="MaxReferencesToReturn" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="QueryFirstRequest" type="tns:QueryFirstRequest" />\r\n\r\n  <xs:complexType name="QueryFirstResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="QueryDataSets" type="tns:ListOfQueryDataSet" minOccurs="0" nillable="true" />\r\n      <xs:element name="ContinuationPoint" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n      <xs:element name="ParsingResults" type="tns:ListOfParsingResult" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n      <xs:element name="FilterResult" type="tns:ContentFilterResult" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="QueryFirstResponse" type="tns:QueryFirstResponse" />\r\n\r\n  <xs:complexType name="QueryNextRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="ReleaseContinuationPoint" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="ContinuationPoint" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="QueryNextRequest" type="tns:QueryNextRequest" />\r\n\r\n  <xs:complexType name="QueryNextResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="QueryDataSets" type="tns:ListOfQueryDataSet" minOccurs="0" nillable="true" />\r\n      <xs:element name="RevisedContinuationPoint" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="QueryNextResponse" type="tns:QueryNextResponse" />\r\n\r\n  <xs:simpleType  name="TimestampsToReturn">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Source_0" />\r\n      <xs:enumeration value="Server_1" />\r\n      <xs:enumeration value="Both_2" />\r\n      <xs:enumeration value="Neither_3" />\r\n      <xs:enumeration value="Invalid_4" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="TimestampsToReturn" type="tns:TimestampsToReturn" />\r\n\r\n  <xs:complexType name="ReadValueId">\r\n    <xs:sequence>\r\n      <xs:element name="NodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="AttributeId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="IndexRange" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="DataEncoding" type="ua:QualifiedName" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ReadValueId" type="tns:ReadValueId" />\r\n\r\n  <xs:complexType name="ListOfReadValueId">\r\n    <xs:sequence>\r\n      <xs:element name="ReadValueId" type="tns:ReadValueId" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfReadValueId" type="tns:ListOfReadValueId" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ReadRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="MaxAge" type="xs:double" minOccurs="0" />\r\n      <xs:element name="TimestampsToReturn" type="tns:TimestampsToReturn" minOccurs="0" />\r\n      <xs:element name="NodesToRead" type="tns:ListOfReadValueId" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ReadRequest" type="tns:ReadRequest" />\r\n\r\n  <xs:complexType name="ReadResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="ua:ListOfDataValue" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ReadResponse" type="tns:ReadResponse" />\r\n\r\n  <xs:complexType name="HistoryReadValueId">\r\n    <xs:sequence>\r\n      <xs:element name="NodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="IndexRange" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="DataEncoding" type="ua:QualifiedName" minOccurs="0" nillable="true" />\r\n      <xs:element name="ContinuationPoint" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryReadValueId" type="tns:HistoryReadValueId" />\r\n\r\n  <xs:complexType name="ListOfHistoryReadValueId">\r\n    <xs:sequence>\r\n      <xs:element name="HistoryReadValueId" type="tns:HistoryReadValueId" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfHistoryReadValueId" type="tns:ListOfHistoryReadValueId" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="HistoryReadResult">\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="ContinuationPoint" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n      <xs:element name="HistoryData" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryReadResult" type="tns:HistoryReadResult" />\r\n\r\n  <xs:complexType name="ListOfHistoryReadResult">\r\n    <xs:sequence>\r\n      <xs:element name="HistoryReadResult" type="tns:HistoryReadResult" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfHistoryReadResult" type="tns:ListOfHistoryReadResult" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="HistoryReadDetails">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryReadDetails" type="tns:HistoryReadDetails" />\r\n\r\n  <xs:complexType name="ReadEventDetails">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:HistoryReadDetails">\r\n        <xs:sequence>\r\n          <xs:element name="NumValuesPerNode" type="xs:unsignedInt" minOccurs="0" />\r\n          <xs:element name="StartTime" type="xs:dateTime" minOccurs="0" />\r\n          <xs:element name="EndTime" type="xs:dateTime" minOccurs="0" />\r\n          <xs:element name="Filter" type="tns:EventFilter" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ReadEventDetails" type="tns:ReadEventDetails" />\r\n\r\n  <xs:complexType name="ReadRawModifiedDetails">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:HistoryReadDetails">\r\n        <xs:sequence>\r\n          <xs:element name="IsReadModified" type="xs:boolean" minOccurs="0" />\r\n          <xs:element name="StartTime" type="xs:dateTime" minOccurs="0" />\r\n          <xs:element name="EndTime" type="xs:dateTime" minOccurs="0" />\r\n          <xs:element name="NumValuesPerNode" type="xs:unsignedInt" minOccurs="0" />\r\n          <xs:element name="ReturnBounds" type="xs:boolean" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ReadRawModifiedDetails" type="tns:ReadRawModifiedDetails" />\r\n\r\n  <xs:complexType name="ReadProcessedDetails">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:HistoryReadDetails">\r\n        <xs:sequence>\r\n          <xs:element name="StartTime" type="xs:dateTime" minOccurs="0" />\r\n          <xs:element name="EndTime" type="xs:dateTime" minOccurs="0" />\r\n          <xs:element name="ProcessingInterval" type="xs:double" minOccurs="0" />\r\n          <xs:element name="AggregateType" type="ua:ListOfNodeId" minOccurs="0" nillable="true" />\r\n          <xs:element name="AggregateConfiguration" type="tns:AggregateConfiguration" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ReadProcessedDetails" type="tns:ReadProcessedDetails" />\r\n\r\n  <xs:complexType name="ReadAtTimeDetails">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:HistoryReadDetails">\r\n        <xs:sequence>\r\n          <xs:element name="ReqTimes" type="ua:ListOfDateTime" minOccurs="0" nillable="true" />\r\n          <xs:element name="UseSimpleBounds" type="xs:boolean" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="ReadAtTimeDetails" type="tns:ReadAtTimeDetails" />\r\n\r\n  <xs:complexType name="HistoryData">\r\n    <xs:sequence>\r\n      <xs:element name="DataValues" type="ua:ListOfDataValue" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryData" type="tns:HistoryData" />\r\n\r\n  <xs:complexType name="ModificationInfo">\r\n    <xs:sequence>\r\n      <xs:element name="ModificationTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="UpdateType" type="tns:HistoryUpdateType" minOccurs="0" />\r\n      <xs:element name="UserName" type="xs:string" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ModificationInfo" type="tns:ModificationInfo" />\r\n\r\n  <xs:complexType name="ListOfModificationInfo">\r\n    <xs:sequence>\r\n      <xs:element name="ModificationInfo" type="tns:ModificationInfo" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfModificationInfo" type="tns:ListOfModificationInfo" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="HistoryModifiedData">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:HistoryData">\r\n        <xs:sequence>\r\n          <xs:element name="ModificationInfos" type="tns:ListOfModificationInfo" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryModifiedData" type="tns:HistoryModifiedData" />\r\n\r\n  <xs:complexType name="HistoryEvent">\r\n    <xs:sequence>\r\n      <xs:element name="Events" type="tns:ListOfHistoryEventFieldList" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryEvent" type="tns:HistoryEvent" />\r\n\r\n  <xs:complexType name="HistoryReadRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="HistoryReadDetails" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n      <xs:element name="TimestampsToReturn" type="tns:TimestampsToReturn" minOccurs="0" />\r\n      <xs:element name="ReleaseContinuationPoints" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="NodesToRead" type="tns:ListOfHistoryReadValueId" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryReadRequest" type="tns:HistoryReadRequest" />\r\n\r\n  <xs:complexType name="HistoryReadResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="tns:ListOfHistoryReadResult" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryReadResponse" type="tns:HistoryReadResponse" />\r\n\r\n  <xs:complexType name="WriteValue">\r\n    <xs:sequence>\r\n      <xs:element name="NodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="AttributeId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="IndexRange" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="Value" type="ua:DataValue" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="WriteValue" type="tns:WriteValue" />\r\n\r\n  <xs:complexType name="ListOfWriteValue">\r\n    <xs:sequence>\r\n      <xs:element name="WriteValue" type="tns:WriteValue" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfWriteValue" type="tns:ListOfWriteValue" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="WriteRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="NodesToWrite" type="tns:ListOfWriteValue" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="WriteRequest" type="tns:WriteRequest" />\r\n\r\n  <xs:complexType name="WriteResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="WriteResponse" type="tns:WriteResponse" />\r\n\r\n  <xs:complexType name="HistoryUpdateDetails">\r\n    <xs:sequence>\r\n      <xs:element name="NodeId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryUpdateDetails" type="tns:HistoryUpdateDetails" />\r\n\r\n  <xs:simpleType  name="HistoryUpdateType">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Insert_1" />\r\n      <xs:enumeration value="Replace_2" />\r\n      <xs:enumeration value="Update_3" />\r\n      <xs:enumeration value="Delete_4" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="HistoryUpdateType" type="tns:HistoryUpdateType" />\r\n\r\n  <xs:simpleType  name="PerformUpdateType">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Insert_1" />\r\n      <xs:enumeration value="Replace_2" />\r\n      <xs:enumeration value="Update_3" />\r\n      <xs:enumeration value="Remove_4" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="PerformUpdateType" type="tns:PerformUpdateType" />\r\n\r\n  <xs:complexType name="UpdateDataDetails">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:HistoryUpdateDetails">\r\n        <xs:sequence>\r\n          <xs:element name="PerformInsertReplace" type="tns:PerformUpdateType" minOccurs="0" />\r\n          <xs:element name="UpdateValues" type="ua:ListOfDataValue" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="UpdateDataDetails" type="tns:UpdateDataDetails" />\r\n\r\n  <xs:complexType name="UpdateStructureDataDetails">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:HistoryUpdateDetails">\r\n        <xs:sequence>\r\n          <xs:element name="PerformInsertReplace" type="tns:PerformUpdateType" minOccurs="0" />\r\n          <xs:element name="UpdateValues" type="ua:ListOfDataValue" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="UpdateStructureDataDetails" type="tns:UpdateStructureDataDetails" />\r\n\r\n  <xs:complexType name="UpdateEventDetails">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:HistoryUpdateDetails">\r\n        <xs:sequence>\r\n          <xs:element name="PerformInsertReplace" type="tns:PerformUpdateType" minOccurs="0" />\r\n          <xs:element name="Filter" type="tns:EventFilter" minOccurs="0" nillable="true" />\r\n          <xs:element name="EventData" type="tns:ListOfHistoryEventFieldList" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="UpdateEventDetails" type="tns:UpdateEventDetails" />\r\n\r\n  <xs:complexType name="DeleteRawModifiedDetails">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:HistoryUpdateDetails">\r\n        <xs:sequence>\r\n          <xs:element name="IsDeleteModified" type="xs:boolean" minOccurs="0" />\r\n          <xs:element name="StartTime" type="xs:dateTime" minOccurs="0" />\r\n          <xs:element name="EndTime" type="xs:dateTime" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteRawModifiedDetails" type="tns:DeleteRawModifiedDetails" />\r\n\r\n  <xs:complexType name="DeleteAtTimeDetails">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:HistoryUpdateDetails">\r\n        <xs:sequence>\r\n          <xs:element name="ReqTimes" type="ua:ListOfDateTime" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteAtTimeDetails" type="tns:DeleteAtTimeDetails" />\r\n\r\n  <xs:complexType name="DeleteEventDetails">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:HistoryUpdateDetails">\r\n        <xs:sequence>\r\n          <xs:element name="EventIds" type="ua:ListOfByteString" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteEventDetails" type="tns:DeleteEventDetails" />\r\n\r\n  <xs:complexType name="HistoryUpdateResult">\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="OperationResults" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryUpdateResult" type="tns:HistoryUpdateResult" />\r\n\r\n  <xs:complexType name="ListOfHistoryUpdateResult">\r\n    <xs:sequence>\r\n      <xs:element name="HistoryUpdateResult" type="tns:HistoryUpdateResult" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfHistoryUpdateResult" type="tns:ListOfHistoryUpdateResult" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="HistoryUpdateRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="HistoryUpdateDetails" type="ua:ListOfExtensionObject" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryUpdateRequest" type="tns:HistoryUpdateRequest" />\r\n\r\n  <xs:complexType name="HistoryUpdateResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="tns:ListOfHistoryUpdateResult" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryUpdateResponse" type="tns:HistoryUpdateResponse" />\r\n\r\n  <xs:complexType name="CallMethodRequest">\r\n    <xs:sequence>\r\n      <xs:element name="ObjectId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="MethodId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="InputArguments" type="ua:ListOfVariant" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CallMethodRequest" type="tns:CallMethodRequest" />\r\n\r\n  <xs:complexType name="ListOfCallMethodRequest">\r\n    <xs:sequence>\r\n      <xs:element name="CallMethodRequest" type="tns:CallMethodRequest" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfCallMethodRequest" type="tns:ListOfCallMethodRequest" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="CallMethodResult">\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="InputArgumentResults" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="InputArgumentDiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n      <xs:element name="OutputArguments" type="ua:ListOfVariant" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CallMethodResult" type="tns:CallMethodResult" />\r\n\r\n  <xs:complexType name="ListOfCallMethodResult">\r\n    <xs:sequence>\r\n      <xs:element name="CallMethodResult" type="tns:CallMethodResult" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfCallMethodResult" type="tns:ListOfCallMethodResult" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="CallRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="MethodsToCall" type="tns:ListOfCallMethodRequest" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CallRequest" type="tns:CallRequest" />\r\n\r\n  <xs:complexType name="CallResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="tns:ListOfCallMethodResult" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CallResponse" type="tns:CallResponse" />\r\n\r\n  <xs:simpleType  name="MonitoringMode">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Disabled_0" />\r\n      <xs:enumeration value="Sampling_1" />\r\n      <xs:enumeration value="Reporting_2" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="MonitoringMode" type="tns:MonitoringMode" />\r\n\r\n  <xs:simpleType  name="DataChangeTrigger">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Status_0" />\r\n      <xs:enumeration value="StatusValue_1" />\r\n      <xs:enumeration value="StatusValueTimestamp_2" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="DataChangeTrigger" type="tns:DataChangeTrigger" />\r\n\r\n  <xs:simpleType  name="DeadbandType">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="None_0" />\r\n      <xs:enumeration value="Absolute_1" />\r\n      <xs:enumeration value="Percent_2" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="DeadbandType" type="tns:DeadbandType" />\r\n\r\n  <xs:complexType name="MonitoringFilter">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="MonitoringFilter" type="tns:MonitoringFilter" />\r\n\r\n  <xs:complexType name="DataChangeFilter">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:MonitoringFilter">\r\n        <xs:sequence>\r\n          <xs:element name="Trigger" type="tns:DataChangeTrigger" minOccurs="0" />\r\n          <xs:element name="DeadbandType" type="xs:unsignedInt" minOccurs="0" />\r\n          <xs:element name="DeadbandValue" type="xs:double" minOccurs="0" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="DataChangeFilter" type="tns:DataChangeFilter" />\r\n\r\n  <xs:complexType name="EventFilter">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:MonitoringFilter">\r\n        <xs:sequence>\r\n          <xs:element name="SelectClauses" type="tns:ListOfSimpleAttributeOperand" minOccurs="0" nillable="true" />\r\n          <xs:element name="WhereClause" type="tns:ContentFilter" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="EventFilter" type="tns:EventFilter" />\r\n\r\n  <xs:complexType name="AggregateConfiguration">\r\n    <xs:sequence>\r\n      <xs:element name="UseServerCapabilitiesDefaults" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="TreatUncertainAsBad" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="PercentDataBad" type="xs:unsignedByte" minOccurs="0" />\r\n      <xs:element name="PercentDataGood" type="xs:unsignedByte" minOccurs="0" />\r\n      <xs:element name="UseSlopedExtrapolation" type="xs:boolean" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="AggregateConfiguration" type="tns:AggregateConfiguration" />\r\n\r\n  <xs:complexType name="AggregateFilter">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:MonitoringFilter">\r\n        <xs:sequence>\r\n          <xs:element name="StartTime" type="xs:dateTime" minOccurs="0" />\r\n          <xs:element name="AggregateType" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n          <xs:element name="ProcessingInterval" type="xs:double" minOccurs="0" />\r\n          <xs:element name="AggregateConfiguration" type="tns:AggregateConfiguration" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="AggregateFilter" type="tns:AggregateFilter" />\r\n\r\n  <xs:complexType name="MonitoringFilterResult">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="MonitoringFilterResult" type="tns:MonitoringFilterResult" />\r\n\r\n  <xs:complexType name="EventFilterResult">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:MonitoringFilterResult">\r\n        <xs:sequence>\r\n          <xs:element name="SelectClauseResults" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n          <xs:element name="SelectClauseDiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n          <xs:element name="WhereClauseResult" type="tns:ContentFilterResult" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="EventFilterResult" type="tns:EventFilterResult" />\r\n\r\n  <xs:complexType name="AggregateFilterResult">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:MonitoringFilterResult">\r\n        <xs:sequence>\r\n          <xs:element name="RevisedStartTime" type="xs:dateTime" minOccurs="0" />\r\n          <xs:element name="RevisedProcessingInterval" type="xs:double" minOccurs="0" />\r\n          <xs:element name="RevisedAggregateConfiguration" type="tns:AggregateConfiguration" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="AggregateFilterResult" type="tns:AggregateFilterResult" />\r\n\r\n  <xs:complexType name="MonitoringParameters">\r\n    <xs:sequence>\r\n      <xs:element name="ClientHandle" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="SamplingInterval" type="xs:double" minOccurs="0" />\r\n      <xs:element name="Filter" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n      <xs:element name="QueueSize" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="DiscardOldest" type="xs:boolean" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="MonitoringParameters" type="tns:MonitoringParameters" />\r\n\r\n  <xs:complexType name="MonitoredItemCreateRequest">\r\n    <xs:sequence>\r\n      <xs:element name="ItemToMonitor" type="tns:ReadValueId" minOccurs="0" nillable="true" />\r\n      <xs:element name="MonitoringMode" type="tns:MonitoringMode" minOccurs="0" />\r\n      <xs:element name="RequestedParameters" type="tns:MonitoringParameters" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="MonitoredItemCreateRequest" type="tns:MonitoredItemCreateRequest" />\r\n\r\n  <xs:complexType name="ListOfMonitoredItemCreateRequest">\r\n    <xs:sequence>\r\n      <xs:element name="MonitoredItemCreateRequest" type="tns:MonitoredItemCreateRequest" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfMonitoredItemCreateRequest" type="tns:ListOfMonitoredItemCreateRequest" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="MonitoredItemCreateResult">\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="MonitoredItemId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RevisedSamplingInterval" type="xs:double" minOccurs="0" />\r\n      <xs:element name="RevisedQueueSize" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="FilterResult" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="MonitoredItemCreateResult" type="tns:MonitoredItemCreateResult" />\r\n\r\n  <xs:complexType name="ListOfMonitoredItemCreateResult">\r\n    <xs:sequence>\r\n      <xs:element name="MonitoredItemCreateResult" type="tns:MonitoredItemCreateResult" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfMonitoredItemCreateResult" type="tns:ListOfMonitoredItemCreateResult" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="CreateMonitoredItemsRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="TimestampsToReturn" type="tns:TimestampsToReturn" minOccurs="0" />\r\n      <xs:element name="ItemsToCreate" type="tns:ListOfMonitoredItemCreateRequest" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CreateMonitoredItemsRequest" type="tns:CreateMonitoredItemsRequest" />\r\n\r\n  <xs:complexType name="CreateMonitoredItemsResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="tns:ListOfMonitoredItemCreateResult" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CreateMonitoredItemsResponse" type="tns:CreateMonitoredItemsResponse" />\r\n\r\n  <xs:complexType name="MonitoredItemModifyRequest">\r\n    <xs:sequence>\r\n      <xs:element name="MonitoredItemId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RequestedParameters" type="tns:MonitoringParameters" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="MonitoredItemModifyRequest" type="tns:MonitoredItemModifyRequest" />\r\n\r\n  <xs:complexType name="ListOfMonitoredItemModifyRequest">\r\n    <xs:sequence>\r\n      <xs:element name="MonitoredItemModifyRequest" type="tns:MonitoredItemModifyRequest" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfMonitoredItemModifyRequest" type="tns:ListOfMonitoredItemModifyRequest" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="MonitoredItemModifyResult">\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="RevisedSamplingInterval" type="xs:double" minOccurs="0" />\r\n      <xs:element name="RevisedQueueSize" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="FilterResult" type="ua:ExtensionObject" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="MonitoredItemModifyResult" type="tns:MonitoredItemModifyResult" />\r\n\r\n  <xs:complexType name="ListOfMonitoredItemModifyResult">\r\n    <xs:sequence>\r\n      <xs:element name="MonitoredItemModifyResult" type="tns:MonitoredItemModifyResult" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfMonitoredItemModifyResult" type="tns:ListOfMonitoredItemModifyResult" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ModifyMonitoredItemsRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="TimestampsToReturn" type="tns:TimestampsToReturn" minOccurs="0" />\r\n      <xs:element name="ItemsToModify" type="tns:ListOfMonitoredItemModifyRequest" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ModifyMonitoredItemsRequest" type="tns:ModifyMonitoredItemsRequest" />\r\n\r\n  <xs:complexType name="ModifyMonitoredItemsResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="tns:ListOfMonitoredItemModifyResult" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ModifyMonitoredItemsResponse" type="tns:ModifyMonitoredItemsResponse" />\r\n\r\n  <xs:complexType name="SetMonitoringModeRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="MonitoringMode" type="tns:MonitoringMode" minOccurs="0" />\r\n      <xs:element name="MonitoredItemIds" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SetMonitoringModeRequest" type="tns:SetMonitoringModeRequest" />\r\n\r\n  <xs:complexType name="SetMonitoringModeResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SetMonitoringModeResponse" type="tns:SetMonitoringModeResponse" />\r\n\r\n  <xs:complexType name="SetTriggeringRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="TriggeringItemId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="LinksToAdd" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n      <xs:element name="LinksToRemove" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SetTriggeringRequest" type="tns:SetTriggeringRequest" />\r\n\r\n  <xs:complexType name="SetTriggeringResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="AddResults" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="AddDiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n      <xs:element name="RemoveResults" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="RemoveDiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SetTriggeringResponse" type="tns:SetTriggeringResponse" />\r\n\r\n  <xs:complexType name="DeleteMonitoredItemsRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="MonitoredItemIds" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteMonitoredItemsRequest" type="tns:DeleteMonitoredItemsRequest" />\r\n\r\n  <xs:complexType name="DeleteMonitoredItemsResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteMonitoredItemsResponse" type="tns:DeleteMonitoredItemsResponse" />\r\n\r\n  <xs:complexType name="CreateSubscriptionRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="RequestedPublishingInterval" type="xs:double" minOccurs="0" />\r\n      <xs:element name="RequestedLifetimeCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RequestedMaxKeepAliveCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="MaxNotificationsPerPublish" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="PublishingEnabled" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="Priority" type="xs:unsignedByte" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CreateSubscriptionRequest" type="tns:CreateSubscriptionRequest" />\r\n\r\n  <xs:complexType name="CreateSubscriptionResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RevisedPublishingInterval" type="xs:double" minOccurs="0" />\r\n      <xs:element name="RevisedLifetimeCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RevisedMaxKeepAliveCount" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="CreateSubscriptionResponse" type="tns:CreateSubscriptionResponse" />\r\n\r\n  <xs:complexType name="ModifySubscriptionRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RequestedPublishingInterval" type="xs:double" minOccurs="0" />\r\n      <xs:element name="RequestedLifetimeCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RequestedMaxKeepAliveCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="MaxNotificationsPerPublish" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="Priority" type="xs:unsignedByte" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ModifySubscriptionRequest" type="tns:ModifySubscriptionRequest" />\r\n\r\n  <xs:complexType name="ModifySubscriptionResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="RevisedPublishingInterval" type="xs:double" minOccurs="0" />\r\n      <xs:element name="RevisedLifetimeCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RevisedMaxKeepAliveCount" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ModifySubscriptionResponse" type="tns:ModifySubscriptionResponse" />\r\n\r\n  <xs:complexType name="SetPublishingModeRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="PublishingEnabled" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="SubscriptionIds" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SetPublishingModeRequest" type="tns:SetPublishingModeRequest" />\r\n\r\n  <xs:complexType name="SetPublishingModeResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SetPublishingModeResponse" type="tns:SetPublishingModeResponse" />\r\n\r\n  <xs:complexType name="NotificationMessage">\r\n    <xs:sequence>\r\n      <xs:element name="SequenceNumber" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="PublishTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="NotificationData" type="ua:ListOfExtensionObject" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="NotificationMessage" type="tns:NotificationMessage" />\r\n\r\n  <xs:complexType name="NotificationData">\r\n    <xs:sequence>\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="NotificationData" type="tns:NotificationData" />\r\n\r\n  <xs:complexType name="DataChangeNotification">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NotificationData">\r\n        <xs:sequence>\r\n          <xs:element name="MonitoredItems" type="tns:ListOfMonitoredItemNotification" minOccurs="0" nillable="true" />\r\n          <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="DataChangeNotification" type="tns:DataChangeNotification" />\r\n\r\n  <xs:complexType name="MonitoredItemNotification">\r\n    <xs:sequence>\r\n      <xs:element name="ClientHandle" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="Value" type="ua:DataValue" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="MonitoredItemNotification" type="tns:MonitoredItemNotification" />\r\n\r\n  <xs:complexType name="ListOfMonitoredItemNotification">\r\n    <xs:sequence>\r\n      <xs:element name="MonitoredItemNotification" type="tns:MonitoredItemNotification" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfMonitoredItemNotification" type="tns:ListOfMonitoredItemNotification" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="EventNotificationList">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NotificationData">\r\n        <xs:sequence>\r\n          <xs:element name="Events" type="tns:ListOfEventFieldList" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="EventNotificationList" type="tns:EventNotificationList" />\r\n\r\n  <xs:complexType name="EventFieldList">\r\n    <xs:sequence>\r\n      <xs:element name="ClientHandle" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="EventFields" type="ua:ListOfVariant" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="EventFieldList" type="tns:EventFieldList" />\r\n\r\n  <xs:complexType name="ListOfEventFieldList">\r\n    <xs:sequence>\r\n      <xs:element name="EventFieldList" type="tns:EventFieldList" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfEventFieldList" type="tns:ListOfEventFieldList" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="HistoryEventFieldList">\r\n    <xs:sequence>\r\n      <xs:element name="EventFields" type="ua:ListOfVariant" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="HistoryEventFieldList" type="tns:HistoryEventFieldList" />\r\n\r\n  <xs:complexType name="ListOfHistoryEventFieldList">\r\n    <xs:sequence>\r\n      <xs:element name="HistoryEventFieldList" type="tns:HistoryEventFieldList" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfHistoryEventFieldList" type="tns:ListOfHistoryEventFieldList" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="StatusChangeNotification">\r\n    <xs:complexContent mixed="false">\r\n      <xs:extension base="tns:NotificationData">\r\n        <xs:sequence>\r\n          <xs:element name="Status" type="ua:StatusCode" minOccurs="0" />\r\n          <xs:element name="DiagnosticInfo" type="ua:DiagnosticInfo" minOccurs="0" nillable="true" />\r\n        </xs:sequence>\r\n      </xs:extension>\r\n    </xs:complexContent>\r\n  </xs:complexType>\r\n  <xs:element name="StatusChangeNotification" type="tns:StatusChangeNotification" />\r\n\r\n  <xs:complexType name="SubscriptionAcknowledgement">\r\n    <xs:sequence>\r\n      <xs:element name="SubscriptionId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="SequenceNumber" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SubscriptionAcknowledgement" type="tns:SubscriptionAcknowledgement" />\r\n\r\n  <xs:complexType name="ListOfSubscriptionAcknowledgement">\r\n    <xs:sequence>\r\n      <xs:element name="SubscriptionAcknowledgement" type="tns:SubscriptionAcknowledgement" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfSubscriptionAcknowledgement" type="tns:ListOfSubscriptionAcknowledgement" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="PublishRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionAcknowledgements" type="tns:ListOfSubscriptionAcknowledgement" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="PublishRequest" type="tns:PublishRequest" />\r\n\r\n  <xs:complexType name="PublishResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="AvailableSequenceNumbers" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n      <xs:element name="MoreNotifications" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="NotificationMessage" type="tns:NotificationMessage" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="PublishResponse" type="tns:PublishResponse" />\r\n\r\n  <xs:complexType name="RepublishRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RetransmitSequenceNumber" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RepublishRequest" type="tns:RepublishRequest" />\r\n\r\n  <xs:complexType name="RepublishResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="NotificationMessage" type="tns:NotificationMessage" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RepublishResponse" type="tns:RepublishResponse" />\r\n\r\n  <xs:complexType name="TransferResult">\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="AvailableSequenceNumbers" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="TransferResult" type="tns:TransferResult" />\r\n\r\n  <xs:complexType name="ListOfTransferResult">\r\n    <xs:sequence>\r\n      <xs:element name="TransferResult" type="tns:TransferResult" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfTransferResult" type="tns:ListOfTransferResult" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="TransferSubscriptionsRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionIds" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n      <xs:element name="SendInitialValues" type="xs:boolean" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="TransferSubscriptionsRequest" type="tns:TransferSubscriptionsRequest" />\r\n\r\n  <xs:complexType name="TransferSubscriptionsResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="tns:ListOfTransferResult" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="TransferSubscriptionsResponse" type="tns:TransferSubscriptionsResponse" />\r\n\r\n  <xs:complexType name="DeleteSubscriptionsRequest">\r\n    <xs:sequence>\r\n      <xs:element name="RequestHeader" type="tns:RequestHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionIds" type="ua:ListOfUInt32" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteSubscriptionsRequest" type="tns:DeleteSubscriptionsRequest" />\r\n\r\n  <xs:complexType name="DeleteSubscriptionsResponse">\r\n    <xs:sequence>\r\n      <xs:element name="ResponseHeader" type="tns:ResponseHeader" minOccurs="0" nillable="true" />\r\n      <xs:element name="Results" type="ua:ListOfStatusCode" minOccurs="0" nillable="true" />\r\n      <xs:element name="DiagnosticInfos" type="ua:ListOfDiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DeleteSubscriptionsResponse" type="tns:DeleteSubscriptionsResponse" />\r\n\r\n  <xs:complexType name="BuildInfo">\r\n    <xs:sequence>\r\n      <xs:element name="ProductUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="ManufacturerName" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="ProductName" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="SoftwareVersion" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="BuildNumber" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="BuildDate" type="xs:dateTime" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="BuildInfo" type="tns:BuildInfo" />\r\n\r\n  <xs:simpleType  name="RedundancySupport">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="None_0" />\r\n      <xs:enumeration value="Cold_1" />\r\n      <xs:enumeration value="Warm_2" />\r\n      <xs:enumeration value="Hot_3" />\r\n      <xs:enumeration value="Transparent_4" />\r\n      <xs:enumeration value="HotAndMirrored_5" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="RedundancySupport" type="tns:RedundancySupport" />\r\n\r\n  <xs:simpleType  name="ServerState">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Running_0" />\r\n      <xs:enumeration value="Failed_1" />\r\n      <xs:enumeration value="NoConfiguration_2" />\r\n      <xs:enumeration value="Suspended_3" />\r\n      <xs:enumeration value="Shutdown_4" />\r\n      <xs:enumeration value="Test_5" />\r\n      <xs:enumeration value="CommunicationFault_6" />\r\n      <xs:enumeration value="Unknown_7" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="ServerState" type="tns:ServerState" />\r\n\r\n  <xs:complexType name="RedundantServerDataType">\r\n    <xs:sequence>\r\n      <xs:element name="ServerId" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServiceLevel" type="xs:unsignedByte" minOccurs="0" />\r\n      <xs:element name="ServerState" type="tns:ServerState" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="RedundantServerDataType" type="tns:RedundantServerDataType" />\r\n\r\n  <xs:complexType name="ListOfRedundantServerDataType">\r\n    <xs:sequence>\r\n      <xs:element name="RedundantServerDataType" type="tns:RedundantServerDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfRedundantServerDataType" type="tns:ListOfRedundantServerDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="EndpointUrlListDataType">\r\n    <xs:sequence>\r\n      <xs:element name="EndpointUrlList" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="EndpointUrlListDataType" type="tns:EndpointUrlListDataType" />\r\n\r\n  <xs:complexType name="ListOfEndpointUrlListDataType">\r\n    <xs:sequence>\r\n      <xs:element name="EndpointUrlListDataType" type="tns:EndpointUrlListDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfEndpointUrlListDataType" type="tns:ListOfEndpointUrlListDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="NetworkGroupDataType">\r\n    <xs:sequence>\r\n      <xs:element name="ServerUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="NetworkPaths" type="tns:ListOfEndpointUrlListDataType" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="NetworkGroupDataType" type="tns:NetworkGroupDataType" />\r\n\r\n  <xs:complexType name="ListOfNetworkGroupDataType">\r\n    <xs:sequence>\r\n      <xs:element name="NetworkGroupDataType" type="tns:NetworkGroupDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfNetworkGroupDataType" type="tns:ListOfNetworkGroupDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="SamplingIntervalDiagnosticsDataType">\r\n    <xs:sequence>\r\n      <xs:element name="SamplingInterval" type="xs:double" minOccurs="0" />\r\n      <xs:element name="MonitoredItemCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="MaxMonitoredItemCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="DisabledMonitoredItemCount" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SamplingIntervalDiagnosticsDataType" type="tns:SamplingIntervalDiagnosticsDataType" />\r\n\r\n  <xs:complexType name="ListOfSamplingIntervalDiagnosticsDataType">\r\n    <xs:sequence>\r\n      <xs:element name="SamplingIntervalDiagnosticsDataType" type="tns:SamplingIntervalDiagnosticsDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfSamplingIntervalDiagnosticsDataType" type="tns:ListOfSamplingIntervalDiagnosticsDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ServerDiagnosticsSummaryDataType">\r\n    <xs:sequence>\r\n      <xs:element name="ServerViewCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="CurrentSessionCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="CumulatedSessionCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="SecurityRejectedSessionCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RejectedSessionCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="SessionTimeoutCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="SessionAbortCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="CurrentSubscriptionCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="CumulatedSubscriptionCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="PublishingIntervalCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="SecurityRejectedRequestsCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RejectedRequestsCount" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ServerDiagnosticsSummaryDataType" type="tns:ServerDiagnosticsSummaryDataType" />\r\n\r\n  <xs:complexType name="ServerStatusDataType">\r\n    <xs:sequence>\r\n      <xs:element name="StartTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="CurrentTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="State" type="tns:ServerState" minOccurs="0" />\r\n      <xs:element name="BuildInfo" type="tns:BuildInfo" minOccurs="0" nillable="true" />\r\n      <xs:element name="SecondsTillShutdown" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="ShutdownReason" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ServerStatusDataType" type="tns:ServerStatusDataType" />\r\n\r\n  <xs:complexType name="SessionDiagnosticsDataType">\r\n    <xs:sequence>\r\n      <xs:element name="SessionId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="SessionName" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="ClientDescription" type="tns:ApplicationDescription" minOccurs="0" nillable="true" />\r\n      <xs:element name="ServerUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="EndpointUrl" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="LocaleIds" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="ActualSessionTimeout" type="xs:double" minOccurs="0" />\r\n      <xs:element name="MaxResponseMessageSize" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="ClientConnectionTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="ClientLastContactTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="CurrentSubscriptionsCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="CurrentMonitoredItemsCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="CurrentPublishRequestsInQueue" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="TotalRequestCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="UnauthorizedRequestCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="ReadCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="HistoryReadCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="WriteCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="HistoryUpdateCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="CallCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="CreateMonitoredItemsCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="ModifyMonitoredItemsCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="SetMonitoringModeCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="SetTriggeringCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="DeleteMonitoredItemsCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="CreateSubscriptionCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="ModifySubscriptionCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="SetPublishingModeCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="PublishCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="RepublishCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="TransferSubscriptionsCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="DeleteSubscriptionsCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="AddNodesCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="AddReferencesCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="DeleteNodesCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="DeleteReferencesCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="BrowseCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="BrowseNextCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="TranslateBrowsePathsToNodeIdsCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="QueryFirstCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="QueryNextCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="RegisterNodesCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n      <xs:element name="UnregisterNodesCount" type="tns:ServiceCounterDataType" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SessionDiagnosticsDataType" type="tns:SessionDiagnosticsDataType" />\r\n\r\n  <xs:complexType name="ListOfSessionDiagnosticsDataType">\r\n    <xs:sequence>\r\n      <xs:element name="SessionDiagnosticsDataType" type="tns:SessionDiagnosticsDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfSessionDiagnosticsDataType" type="tns:ListOfSessionDiagnosticsDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="SessionSecurityDiagnosticsDataType">\r\n    <xs:sequence>\r\n      <xs:element name="SessionId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="ClientUserIdOfSession" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="ClientUserIdHistory" type="ua:ListOfString" minOccurs="0" nillable="true" />\r\n      <xs:element name="AuthenticationMechanism" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="Encoding" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="TransportProtocol" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="SecurityMode" type="tns:MessageSecurityMode" minOccurs="0" />\r\n      <xs:element name="SecurityPolicyUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="ClientCertificate" type="xs:base64Binary" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SessionSecurityDiagnosticsDataType" type="tns:SessionSecurityDiagnosticsDataType" />\r\n\r\n  <xs:complexType name="ListOfSessionSecurityDiagnosticsDataType">\r\n    <xs:sequence>\r\n      <xs:element name="SessionSecurityDiagnosticsDataType" type="tns:SessionSecurityDiagnosticsDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfSessionSecurityDiagnosticsDataType" type="tns:ListOfSessionSecurityDiagnosticsDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="ServiceCounterDataType">\r\n    <xs:sequence>\r\n      <xs:element name="TotalCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="ErrorCount" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ServiceCounterDataType" type="tns:ServiceCounterDataType" />\r\n\r\n  <xs:complexType name="StatusResult">\r\n    <xs:sequence>\r\n      <xs:element name="StatusCode" type="ua:StatusCode" minOccurs="0" />\r\n      <xs:element name="DiagnosticInfo" type="ua:DiagnosticInfo" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="StatusResult" type="tns:StatusResult" />\r\n\r\n  <xs:complexType name="ListOfStatusResult">\r\n    <xs:sequence>\r\n      <xs:element name="StatusResult" type="tns:StatusResult" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfStatusResult" type="tns:ListOfStatusResult" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="SubscriptionDiagnosticsDataType">\r\n    <xs:sequence>\r\n      <xs:element name="SessionId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="SubscriptionId" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="Priority" type="xs:unsignedByte" minOccurs="0" />\r\n      <xs:element name="PublishingInterval" type="xs:double" minOccurs="0" />\r\n      <xs:element name="MaxKeepAliveCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="MaxLifetimeCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="MaxNotificationsPerPublish" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="PublishingEnabled" type="xs:boolean" minOccurs="0" />\r\n      <xs:element name="ModifyCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="EnableCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="DisableCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RepublishRequestCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RepublishMessageRequestCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="RepublishMessageCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="TransferRequestCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="TransferredToAltClientCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="TransferredToSameClientCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="PublishRequestCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="DataChangeNotificationsCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="EventNotificationsCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="NotificationsCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="LatePublishRequestCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="CurrentKeepAliveCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="CurrentLifetimeCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="UnacknowledgedMessageCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="DiscardedMessageCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="MonitoredItemCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="DisabledMonitoredItemCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="MonitoringQueueOverflowCount" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="NextSequenceNumber" type="xs:unsignedInt" minOccurs="0" />\r\n      <xs:element name="EventQueueOverFlowCount" type="xs:unsignedInt" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SubscriptionDiagnosticsDataType" type="tns:SubscriptionDiagnosticsDataType" />\r\n\r\n  <xs:complexType name="ListOfSubscriptionDiagnosticsDataType">\r\n    <xs:sequence>\r\n      <xs:element name="SubscriptionDiagnosticsDataType" type="tns:SubscriptionDiagnosticsDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfSubscriptionDiagnosticsDataType" type="tns:ListOfSubscriptionDiagnosticsDataType" nillable="true"></xs:element>\r\n\r\n  <xs:simpleType  name="ModelChangeStructureVerbMask">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="NodeAdded_1" />\r\n      <xs:enumeration value="NodeDeleted_2" />\r\n      <xs:enumeration value="ReferenceAdded_4" />\r\n      <xs:enumeration value="ReferenceDeleted_8" />\r\n      <xs:enumeration value="DataTypeChanged_16" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="ModelChangeStructureVerbMask" type="tns:ModelChangeStructureVerbMask" />\r\n\r\n  <xs:complexType name="ModelChangeStructureDataType">\r\n    <xs:sequence>\r\n      <xs:element name="Affected" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="AffectedType" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="Verb" type="xs:unsignedByte" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ModelChangeStructureDataType" type="tns:ModelChangeStructureDataType" />\r\n\r\n  <xs:complexType name="ListOfModelChangeStructureDataType">\r\n    <xs:sequence>\r\n      <xs:element name="ModelChangeStructureDataType" type="tns:ModelChangeStructureDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfModelChangeStructureDataType" type="tns:ListOfModelChangeStructureDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="SemanticChangeStructureDataType">\r\n    <xs:sequence>\r\n      <xs:element name="Affected" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="AffectedType" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="SemanticChangeStructureDataType" type="tns:SemanticChangeStructureDataType" />\r\n\r\n  <xs:complexType name="ListOfSemanticChangeStructureDataType">\r\n    <xs:sequence>\r\n      <xs:element name="SemanticChangeStructureDataType" type="tns:SemanticChangeStructureDataType" minOccurs="0" maxOccurs="unbounded" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ListOfSemanticChangeStructureDataType" type="tns:ListOfSemanticChangeStructureDataType" nillable="true"></xs:element>\r\n\r\n  <xs:complexType name="Range">\r\n    <xs:sequence>\r\n      <xs:element name="Low" type="xs:double" minOccurs="0" />\r\n      <xs:element name="High" type="xs:double" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="Range" type="tns:Range" />\r\n\r\n  <xs:complexType name="EUInformation">\r\n    <xs:sequence>\r\n      <xs:element name="NamespaceUri" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="UnitId" type="xs:int" minOccurs="0" />\r\n      <xs:element name="DisplayName" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n      <xs:element name="Description" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="EUInformation" type="tns:EUInformation" />\r\n\r\n  <xs:simpleType  name="AxisScaleEnumeration">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="Linear_0" />\r\n      <xs:enumeration value="Log_1" />\r\n      <xs:enumeration value="Ln_2" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="AxisScaleEnumeration" type="tns:AxisScaleEnumeration" />\r\n\r\n  <xs:complexType name="ComplexNumberType">\r\n    <xs:sequence>\r\n      <xs:element name="Real" type="xs:float" minOccurs="0" />\r\n      <xs:element name="Imaginary" type="xs:float" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ComplexNumberType" type="tns:ComplexNumberType" />\r\n\r\n  <xs:complexType name="DoubleComplexNumberType">\r\n    <xs:sequence>\r\n      <xs:element name="Real" type="xs:double" minOccurs="0" />\r\n      <xs:element name="Imaginary" type="xs:double" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="DoubleComplexNumberType" type="tns:DoubleComplexNumberType" />\r\n\r\n  <xs:complexType name="AxisInformation">\r\n    <xs:sequence>\r\n      <xs:element name="EngineeringUnits" type="tns:EUInformation" minOccurs="0" nillable="true" />\r\n      <xs:element name="EURange" type="tns:Range" minOccurs="0" nillable="true" />\r\n      <xs:element name="Title" type="ua:LocalizedText" minOccurs="0" nillable="true" />\r\n      <xs:element name="AxisScaleType" type="tns:AxisScaleEnumeration" minOccurs="0" />\r\n      <xs:element name="AxisSteps" type="ua:ListOfDouble" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="AxisInformation" type="tns:AxisInformation" />\r\n\r\n  <xs:complexType name="XVType">\r\n    <xs:sequence>\r\n      <xs:element name="X" type="xs:double" minOccurs="0" />\r\n      <xs:element name="Value" type="xs:float" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="XVType" type="tns:XVType" />\r\n\r\n  <xs:complexType name="ProgramDiagnosticDataType">\r\n    <xs:sequence>\r\n      <xs:element name="CreateSessionId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="CreateClientName" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="InvocationCreationTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="LastTransitionTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="LastMethodCall" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="LastMethodSessionId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="LastMethodInputArguments" type="tns:ListOfArgument" minOccurs="0" nillable="true" />\r\n      <xs:element name="LastMethodOutputArguments" type="tns:ListOfArgument" minOccurs="0" nillable="true" />\r\n      <xs:element name="LastMethodCallTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="LastMethodReturnStatus" type="tns:StatusResult" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ProgramDiagnosticDataType" type="tns:ProgramDiagnosticDataType" />\r\n\r\n  <xs:complexType name="ProgramDiagnostic2DataType">\r\n    <xs:sequence>\r\n      <xs:element name="CreateSessionId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="CreateClientName" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="InvocationCreationTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="LastTransitionTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="LastMethodCall" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="LastMethodSessionId" type="ua:NodeId" minOccurs="0" nillable="true" />\r\n      <xs:element name="LastMethodInputArguments" type="tns:ListOfArgument" minOccurs="0" nillable="true" />\r\n      <xs:element name="LastMethodOutputArguments" type="tns:ListOfArgument" minOccurs="0" nillable="true" />\r\n      <xs:element name="LastMethodInputValues" type="ua:ListOfVariant" minOccurs="0" nillable="true" />\r\n      <xs:element name="LastMethodOutputValues" type="ua:ListOfVariant" minOccurs="0" nillable="true" />\r\n      <xs:element name="LastMethodCallTime" type="xs:dateTime" minOccurs="0" />\r\n      <xs:element name="LastMethodReturnStatus" type="tns:StatusResult" minOccurs="0" nillable="true" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="ProgramDiagnostic2DataType" type="tns:ProgramDiagnostic2DataType" />\r\n\r\n  <xs:complexType name="Annotation">\r\n    <xs:sequence>\r\n      <xs:element name="Message" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="UserName" type="xs:string" minOccurs="0" nillable="true" />\r\n      <xs:element name="AnnotationTime" type="xs:dateTime" minOccurs="0" />\r\n    </xs:sequence>\r\n  </xs:complexType>\r\n  <xs:element name="Annotation" type="tns:Annotation" />\r\n\r\n  <xs:simpleType  name="ExceptionDeviationFormat">\r\n    <xs:restriction base="xs:string">\r\n      <xs:enumeration value="AbsoluteValue_0" />\r\n      <xs:enumeration value="PercentOfValue_1" />\r\n      <xs:enumeration value="PercentOfRange_2" />\r\n      <xs:enumeration value="PercentOfEURange_3" />\r\n      <xs:enumeration value="Unknown_4" />\r\n    </xs:restriction>\r\n  </xs:simpleType>\r\n  <xs:element name="ExceptionDeviationFormat" type="tns:ExceptionDeviationFormat" />\r\n\r\n</xs:schema>', ua.VariantType.ByteString)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8254")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15039")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14829")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16024")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15730")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12677")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16027")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14811")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15591")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15594")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15585")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15588")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14805")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14808")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14832")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16030")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16033")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14320")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16037")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16040")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16047")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16050")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16053")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16056")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21180")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16062")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16065")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16068")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16071")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21183")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21186")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21189")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16077")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16080")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16083")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16086")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16089")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16092")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16095")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14835")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16098")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21192")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16104")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16107")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16110")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16113")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16116")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16119")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=17473")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=21195")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15640")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16125")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16144")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16147")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16127")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18166")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18169")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18172")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18175")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8285")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8291")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14826")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12759")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12762")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8918")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8300")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12201")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8297")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8303")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8417")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12894")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12897")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8333")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8306")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8309")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8312")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8315")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8318")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8363")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8366")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8369")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8372")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12712")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12715")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8321")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8564")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8567")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8570")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8573")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8576")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8579")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8582")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8639")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8702")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8708")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8711")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8807")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8327")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8843")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11951")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11954")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8846")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8849")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8852")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8855")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8858")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8861")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8294")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8864")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8867")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8870")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8873")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8876")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12175")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12178")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12083")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12086")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8882")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15402")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8879")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=92")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8252")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=72")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8254")
    node.BrowseName = ua.QualifiedName.from_string("NamespaceUri")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A URI that uniquely identifies the dictionary.")
    attrs.DisplayName = ua.LocalizedText("NamespaceUri")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant('http://opcfoundation.org/UA/2008/02/Types.xsd', ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8254")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=8254")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15039")
    node.BrowseName = ua.QualifiedName.from_string("Deprecated")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Indicates that all of the definitions for the dictionary are available through a DataTypeDefinition Attribute.")
    attrs.DisplayName = ua.LocalizedText("Deprecated")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.Value = ua.Variant(True, ua.VariantType.Boolean)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15039")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15039")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14829")
    node.BrowseName = ua.QualifiedName.from_string("KeyValuePair")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("KeyValuePair")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='KeyValuePair']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14829")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14829")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16024")
    node.BrowseName = ua.QualifiedName.from_string("EndpointType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='EndpointType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16024")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16024")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15730")
    node.BrowseName = ua.QualifiedName.from_string("IdentityMappingRuleType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("IdentityMappingRuleType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='IdentityMappingRuleType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15730")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15730")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12677")
    node.BrowseName = ua.QualifiedName.from_string("TrustListDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TrustListDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='TrustListDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12677")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12677")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16027")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeSchemaHeader")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataTypeSchemaHeader")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DataTypeSchemaHeader']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16027")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16027")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14811")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataTypeDescription")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DataTypeDescription']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14811")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14811")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15591")
    node.BrowseName = ua.QualifiedName.from_string("StructureDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StructureDescription")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='StructureDescription']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15591")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15591")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15594")
    node.BrowseName = ua.QualifiedName.from_string("EnumDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumDescription")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='EnumDescription']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15594")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15594")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15585")
    node.BrowseName = ua.QualifiedName.from_string("SimpleTypeDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SimpleTypeDescription")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='SimpleTypeDescription']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15585")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15585")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15588")
    node.BrowseName = ua.QualifiedName.from_string("UABinaryFileDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UABinaryFileDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='UABinaryFileDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15588")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15588")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14805")
    node.BrowseName = ua.QualifiedName.from_string("DataSetMetaDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetMetaDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DataSetMetaDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14805")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14805")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14808")
    node.BrowseName = ua.QualifiedName.from_string("FieldMetaData")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("FieldMetaData")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='FieldMetaData']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14808")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14808")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14832")
    node.BrowseName = ua.QualifiedName.from_string("ConfigurationVersionDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ConfigurationVersionDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ConfigurationVersionDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14832")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14832")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16030")
    node.BrowseName = ua.QualifiedName.from_string("PublishedDataSetDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishedDataSetDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='PublishedDataSetDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16033")
    node.BrowseName = ua.QualifiedName.from_string("PublishedDataSetSourceDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishedDataSetSourceDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='PublishedDataSetSourceDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16033")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16033")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14320")
    node.BrowseName = ua.QualifiedName.from_string("PublishedVariableDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishedVariableDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='PublishedVariableDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14320")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14320")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16037")
    node.BrowseName = ua.QualifiedName.from_string("PublishedDataItemsDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishedDataItemsDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='PublishedDataItemsDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16037")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16037")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16040")
    node.BrowseName = ua.QualifiedName.from_string("PublishedEventsDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PublishedEventsDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='PublishedEventsDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16040")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16040")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16047")
    node.BrowseName = ua.QualifiedName.from_string("DataSetWriterDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetWriterDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DataSetWriterDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16047")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16047")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16050")
    node.BrowseName = ua.QualifiedName.from_string("DataSetWriterTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetWriterTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DataSetWriterTransportDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16050")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16050")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16053")
    node.BrowseName = ua.QualifiedName.from_string("DataSetWriterMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetWriterMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DataSetWriterMessageDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16053")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16053")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16056")
    node.BrowseName = ua.QualifiedName.from_string("PubSubGroupDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PubSubGroupDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='PubSubGroupDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16056")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16056")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21180")
    node.BrowseName = ua.QualifiedName.from_string("WriterGroupDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("WriterGroupDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='WriterGroupDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21180")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21180")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16062")
    node.BrowseName = ua.QualifiedName.from_string("WriterGroupTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("WriterGroupTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='WriterGroupTransportDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16062")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16062")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16065")
    node.BrowseName = ua.QualifiedName.from_string("WriterGroupMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("WriterGroupMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='WriterGroupMessageDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16065")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16065")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16068")
    node.BrowseName = ua.QualifiedName.from_string("PubSubConnectionDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PubSubConnectionDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='PubSubConnectionDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16068")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16068")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16071")
    node.BrowseName = ua.QualifiedName.from_string("ConnectionTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ConnectionTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ConnectionTransportDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16071")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16071")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21183")
    node.BrowseName = ua.QualifiedName.from_string("NetworkAddressDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NetworkAddressDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='NetworkAddressDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21183")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21186")
    node.BrowseName = ua.QualifiedName.from_string("NetworkAddressUrlDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NetworkAddressUrlDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='NetworkAddressUrlDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21186")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21186")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21189")
    node.BrowseName = ua.QualifiedName.from_string("ReaderGroupDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ReaderGroupDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ReaderGroupDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21189")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21189")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16077")
    node.BrowseName = ua.QualifiedName.from_string("ReaderGroupTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ReaderGroupTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ReaderGroupTransportDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16077")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16080")
    node.BrowseName = ua.QualifiedName.from_string("ReaderGroupMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ReaderGroupMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ReaderGroupMessageDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16080")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16080")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16083")
    node.BrowseName = ua.QualifiedName.from_string("DataSetReaderDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetReaderDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DataSetReaderDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16083")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16083")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16086")
    node.BrowseName = ua.QualifiedName.from_string("DataSetReaderTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetReaderTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DataSetReaderTransportDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16086")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16086")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16089")
    node.BrowseName = ua.QualifiedName.from_string("DataSetReaderMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataSetReaderMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DataSetReaderMessageDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16089")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16089")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16092")
    node.BrowseName = ua.QualifiedName.from_string("SubscribedDataSetDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SubscribedDataSetDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='SubscribedDataSetDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16092")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16092")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16095")
    node.BrowseName = ua.QualifiedName.from_string("TargetVariablesDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TargetVariablesDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='TargetVariablesDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16095")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14835")
    node.BrowseName = ua.QualifiedName.from_string("FieldTargetDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("FieldTargetDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='FieldTargetDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14835")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14835")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16098")
    node.BrowseName = ua.QualifiedName.from_string("SubscribedDataSetMirrorDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SubscribedDataSetMirrorDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='SubscribedDataSetMirrorDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16098")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21192")
    node.BrowseName = ua.QualifiedName.from_string("PubSubConfigurationDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("PubSubConfigurationDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='PubSubConfigurationDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21192")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21192")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16104")
    node.BrowseName = ua.QualifiedName.from_string("UadpWriterGroupMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UadpWriterGroupMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='UadpWriterGroupMessageDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16104")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16107")
    node.BrowseName = ua.QualifiedName.from_string("UadpDataSetWriterMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UadpDataSetWriterMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='UadpDataSetWriterMessageDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16107")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16107")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16110")
    node.BrowseName = ua.QualifiedName.from_string("UadpDataSetReaderMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UadpDataSetReaderMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='UadpDataSetReaderMessageDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16110")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16110")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16113")
    node.BrowseName = ua.QualifiedName.from_string("JsonWriterGroupMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("JsonWriterGroupMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='JsonWriterGroupMessageDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16113")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16113")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16116")
    node.BrowseName = ua.QualifiedName.from_string("JsonDataSetWriterMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("JsonDataSetWriterMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='JsonDataSetWriterMessageDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16116")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16116")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16119")
    node.BrowseName = ua.QualifiedName.from_string("JsonDataSetReaderMessageDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("JsonDataSetReaderMessageDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='JsonDataSetReaderMessageDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16119")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16119")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17473")
    node.BrowseName = ua.QualifiedName.from_string("DatagramConnectionTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DatagramConnectionTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DatagramConnectionTransportDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=17473")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=17473")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21195")
    node.BrowseName = ua.QualifiedName.from_string("DatagramWriterGroupTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DatagramWriterGroupTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DatagramWriterGroupTransportDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=21195")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=21195")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15640")
    node.BrowseName = ua.QualifiedName.from_string("BrokerConnectionTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrokerConnectionTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='BrokerConnectionTransportDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15640")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15640")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16125")
    node.BrowseName = ua.QualifiedName.from_string("BrokerWriterGroupTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrokerWriterGroupTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='BrokerWriterGroupTransportDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16125")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16125")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16144")
    node.BrowseName = ua.QualifiedName.from_string("BrokerDataSetWriterTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrokerDataSetWriterTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='BrokerDataSetWriterTransportDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16144")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16144")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16147")
    node.BrowseName = ua.QualifiedName.from_string("BrokerDataSetReaderTransportDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BrokerDataSetReaderTransportDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='BrokerDataSetReaderTransportDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16147")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16147")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16127")
    node.BrowseName = ua.QualifiedName.from_string("RolePermissionType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RolePermissionType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='RolePermissionType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16127")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=16127")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=18166")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeDefinition")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DataTypeDefinition")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DataTypeDefinition']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=18166")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=18166")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=18169")
    node.BrowseName = ua.QualifiedName.from_string("StructureField")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StructureField")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='StructureField']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=18169")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=18169")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=18172")
    node.BrowseName = ua.QualifiedName.from_string("StructureDefinition")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StructureDefinition")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='StructureDefinition']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=18172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=18172")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=18175")
    node.BrowseName = ua.QualifiedName.from_string("EnumDefinition")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumDefinition")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='EnumDefinition']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=18175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=18175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8285")
    node.BrowseName = ua.QualifiedName.from_string("Argument")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Argument")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='Argument']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8285")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8285")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8291")
    node.BrowseName = ua.QualifiedName.from_string("EnumValueType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumValueType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='EnumValueType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8291")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8291")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14826")
    node.BrowseName = ua.QualifiedName.from_string("EnumField")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumField")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='EnumField']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14826")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=14826")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12759")
    node.BrowseName = ua.QualifiedName.from_string("OptionSet")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OptionSet")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='OptionSet']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12759")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12759")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12762")
    node.BrowseName = ua.QualifiedName.from_string("Union")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Union")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='Union']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12762")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12762")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8918")
    node.BrowseName = ua.QualifiedName.from_string("TimeZoneDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("TimeZoneDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='TimeZoneDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8918")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8918")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8300")
    node.BrowseName = ua.QualifiedName.from_string("ApplicationDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ApplicationDescription")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ApplicationDescription']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8300")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8300")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12201")
    node.BrowseName = ua.QualifiedName.from_string("ServerOnNetwork")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerOnNetwork")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ServerOnNetwork']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12201")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12201")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8297")
    node.BrowseName = ua.QualifiedName.from_string("UserTokenPolicy")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UserTokenPolicy")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='UserTokenPolicy']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8297")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8297")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8303")
    node.BrowseName = ua.QualifiedName.from_string("EndpointDescription")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointDescription")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='EndpointDescription']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8303")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8303")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8417")
    node.BrowseName = ua.QualifiedName.from_string("RegisteredServer")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RegisteredServer")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='RegisteredServer']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8417")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8417")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12894")
    node.BrowseName = ua.QualifiedName.from_string("DiscoveryConfiguration")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DiscoveryConfiguration")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DiscoveryConfiguration']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12894")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12894")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12897")
    node.BrowseName = ua.QualifiedName.from_string("MdnsDiscoveryConfiguration")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MdnsDiscoveryConfiguration")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='MdnsDiscoveryConfiguration']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12897")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12897")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8333")
    node.BrowseName = ua.QualifiedName.from_string("SignedSoftwareCertificate")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SignedSoftwareCertificate")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='SignedSoftwareCertificate']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8333")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8333")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8306")
    node.BrowseName = ua.QualifiedName.from_string("UserIdentityToken")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UserIdentityToken")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='UserIdentityToken']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8306")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8306")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8309")
    node.BrowseName = ua.QualifiedName.from_string("AnonymousIdentityToken")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AnonymousIdentityToken")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='AnonymousIdentityToken']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8309")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8309")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8312")
    node.BrowseName = ua.QualifiedName.from_string("UserNameIdentityToken")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("UserNameIdentityToken")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='UserNameIdentityToken']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8312")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8312")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8315")
    node.BrowseName = ua.QualifiedName.from_string("X509IdentityToken")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("X509IdentityToken")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='X509IdentityToken']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8315")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8315")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8318")
    node.BrowseName = ua.QualifiedName.from_string("IssuedIdentityToken")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("IssuedIdentityToken")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='IssuedIdentityToken']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8318")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8318")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8363")
    node.BrowseName = ua.QualifiedName.from_string("AddNodesItem")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AddNodesItem")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='AddNodesItem']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8363")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8363")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8366")
    node.BrowseName = ua.QualifiedName.from_string("AddReferencesItem")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AddReferencesItem")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='AddReferencesItem']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8369")
    node.BrowseName = ua.QualifiedName.from_string("DeleteNodesItem")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteNodesItem")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DeleteNodesItem']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8369")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8369")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8372")
    node.BrowseName = ua.QualifiedName.from_string("DeleteReferencesItem")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DeleteReferencesItem")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DeleteReferencesItem']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8372")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8372")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12712")
    node.BrowseName = ua.QualifiedName.from_string("RelativePathElement")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RelativePathElement")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='RelativePathElement']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12712")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12712")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12715")
    node.BrowseName = ua.QualifiedName.from_string("RelativePath")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RelativePath")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='RelativePath']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12715")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12715")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8321")
    node.BrowseName = ua.QualifiedName.from_string("EndpointConfiguration")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointConfiguration")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='EndpointConfiguration']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8321")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8321")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8564")
    node.BrowseName = ua.QualifiedName.from_string("ContentFilterElement")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ContentFilterElement")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ContentFilterElement']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8564")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8567")
    node.BrowseName = ua.QualifiedName.from_string("ContentFilter")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ContentFilter")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ContentFilter']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8567")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8567")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8570")
    node.BrowseName = ua.QualifiedName.from_string("FilterOperand")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("FilterOperand")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='FilterOperand']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8570")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8570")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8573")
    node.BrowseName = ua.QualifiedName.from_string("ElementOperand")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ElementOperand")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ElementOperand']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8573")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8573")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8576")
    node.BrowseName = ua.QualifiedName.from_string("LiteralOperand")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("LiteralOperand")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='LiteralOperand']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8576")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8576")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8579")
    node.BrowseName = ua.QualifiedName.from_string("AttributeOperand")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AttributeOperand")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='AttributeOperand']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8579")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8579")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8582")
    node.BrowseName = ua.QualifiedName.from_string("SimpleAttributeOperand")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SimpleAttributeOperand")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='SimpleAttributeOperand']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8582")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8582")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8639")
    node.BrowseName = ua.QualifiedName.from_string("HistoryEvent")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryEvent")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='HistoryEvent']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8639")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8639")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8702")
    node.BrowseName = ua.QualifiedName.from_string("MonitoringFilter")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("MonitoringFilter")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='MonitoringFilter']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8702")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8702")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8708")
    node.BrowseName = ua.QualifiedName.from_string("EventFilter")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EventFilter")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='EventFilter']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8708")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8708")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8711")
    node.BrowseName = ua.QualifiedName.from_string("AggregateConfiguration")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AggregateConfiguration")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='AggregateConfiguration']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8711")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8711")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8807")
    node.BrowseName = ua.QualifiedName.from_string("HistoryEventFieldList")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("HistoryEventFieldList")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='HistoryEventFieldList']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8807")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8807")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8327")
    node.BrowseName = ua.QualifiedName.from_string("BuildInfo")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("BuildInfo")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='BuildInfo']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8327")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8327")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8843")
    node.BrowseName = ua.QualifiedName.from_string("RedundantServerDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("RedundantServerDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='RedundantServerDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8843")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8843")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11951")
    node.BrowseName = ua.QualifiedName.from_string("EndpointUrlListDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EndpointUrlListDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='EndpointUrlListDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11951")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11951")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11954")
    node.BrowseName = ua.QualifiedName.from_string("NetworkGroupDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("NetworkGroupDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='NetworkGroupDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11954")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=11954")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8846")
    node.BrowseName = ua.QualifiedName.from_string("SamplingIntervalDiagnosticsDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SamplingIntervalDiagnosticsDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='SamplingIntervalDiagnosticsDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8846")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8846")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8849")
    node.BrowseName = ua.QualifiedName.from_string("ServerDiagnosticsSummaryDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerDiagnosticsSummaryDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ServerDiagnosticsSummaryDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8849")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8849")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8852")
    node.BrowseName = ua.QualifiedName.from_string("ServerStatusDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServerStatusDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ServerStatusDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8852")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8852")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8855")
    node.BrowseName = ua.QualifiedName.from_string("SessionDiagnosticsDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionDiagnosticsDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='SessionDiagnosticsDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8855")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8855")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8858")
    node.BrowseName = ua.QualifiedName.from_string("SessionSecurityDiagnosticsDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SessionSecurityDiagnosticsDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='SessionSecurityDiagnosticsDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8858")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8858")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8861")
    node.BrowseName = ua.QualifiedName.from_string("ServiceCounterDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ServiceCounterDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ServiceCounterDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8861")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8861")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8294")
    node.BrowseName = ua.QualifiedName.from_string("StatusResult")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("StatusResult")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='StatusResult']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8294")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8294")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8864")
    node.BrowseName = ua.QualifiedName.from_string("SubscriptionDiagnosticsDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SubscriptionDiagnosticsDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='SubscriptionDiagnosticsDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8864")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8864")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8867")
    node.BrowseName = ua.QualifiedName.from_string("ModelChangeStructureDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ModelChangeStructureDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ModelChangeStructureDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8867")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8867")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8870")
    node.BrowseName = ua.QualifiedName.from_string("SemanticChangeStructureDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("SemanticChangeStructureDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='SemanticChangeStructureDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8870")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8870")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8873")
    node.BrowseName = ua.QualifiedName.from_string("Range")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Range")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='Range']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8873")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8873")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8876")
    node.BrowseName = ua.QualifiedName.from_string("EUInformation")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EUInformation")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='EUInformation']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8876")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8876")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12175")
    node.BrowseName = ua.QualifiedName.from_string("ComplexNumberType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ComplexNumberType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ComplexNumberType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12175")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12178")
    node.BrowseName = ua.QualifiedName.from_string("DoubleComplexNumberType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("DoubleComplexNumberType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='DoubleComplexNumberType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12178")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12178")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12083")
    node.BrowseName = ua.QualifiedName.from_string("AxisInformation")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("AxisInformation")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='AxisInformation']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12083")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12083")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12086")
    node.BrowseName = ua.QualifiedName.from_string("XVType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("XVType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='XVType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12086")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=12086")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8882")
    node.BrowseName = ua.QualifiedName.from_string("ProgramDiagnosticDataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ProgramDiagnosticDataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ProgramDiagnosticDataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8882")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8882")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15402")
    node.BrowseName = ua.QualifiedName.from_string("ProgramDiagnostic2DataType")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("ProgramDiagnostic2DataType")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='ProgramDiagnostic2DataType']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15402")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=15402")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8879")
    node.BrowseName = ua.QualifiedName.from_string("Annotation")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=8252")
    node.ReferenceTypeId = ua.NodeId.from_string("i=47")
    node.TypeDefinition = ua.NodeId.from_string("i=69")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("Annotation")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.Value = ua.Variant("//xs:element[@name='Annotation']", ua.VariantType.String)
    attrs.ValueRank = -1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8879")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=69")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=47")
    ref.SourceNodeId = ua.NodeId.from_string("i=8879")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8252")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15041")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=14533")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14533")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15041")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16150")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15528")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=16150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15528")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16150")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15042")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=15634")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15042")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15634")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15042")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15361")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=338")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15361")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=338")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15361")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15362")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=853")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15362")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=853")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15362")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15363")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=11943")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15363")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11943")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15363")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15364")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=11944")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15364")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11944")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15364")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15365")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=856")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15365")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=856")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15365")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15366")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=859")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=859")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15366")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15367")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=862")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15367")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=862")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15367")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15368")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=865")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15368")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=865")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15368")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15369")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=868")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15369")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=868")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15369")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15370")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=871")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15370")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=871")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15370")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15371")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=299")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15371")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=299")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15371")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15372")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=874")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15372")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=874")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15372")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15373")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=877")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15373")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=877")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15373")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15374")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=897")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15374")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=897")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15374")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
